@@ -1,6 +1,3 @@
-/* $Id$Revision: */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,63 +5,30 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 #include "config.h"
 
+#include <stdbool.h>
 #include <stdio.h>
 #include <stdlib.h>
 #define STANDALONE
-#include "general.h"
-#include "QuadTree.h"
+#include <sparse/general.h>
+#include <sparse/QuadTree.h>
 #include <time.h>
-#include "SparseMatrix.h"
+#include <sparse/SparseMatrix.h>
 #include <getopt.h>
-#include "string.h"
+#include <string.h>
 #include "make_map.h"
-#include "spring_electrical.h"
-#include "post_process.h"
-#include "overlap.h"
-#include "clustering.h"
-#include "ingraphs.h"
-#include "DotIO.h"
-#include "colorutil.h"
-#include "color_palette.h"
-
-#ifdef _WIN32
-#define strdup(x) _strdup(x)
-#endif
-enum {POINTS_ALL = 1, POINTS_LABEL, POINTS_RANDOM};
-enum {maxlen = 10000000};
-enum {MAX_GRPS = 10000};
-static char swork[maxlen];
-
-#if 0
-void *gmalloc(size_t nbytes)
-{
-    char *rv;
-    if (nbytes == 0)
-        return NULL;
-    rv = malloc(nbytes);
-    if (rv == NULL) {
-        fprintf(stderr, "out of memory\n");
-        abort();
-    }
-    return rv;
-}
-
-void *grealloc(void *ptr, size_t size)
-{
-    void *p = realloc(ptr, size);
-    if (p == NULL && size) {
-        fprintf(stderr, "out of memory\n");
-        abort();
-    }
-    return p;
-}
-
-#endif
+#include <sfdpgen/spring_electrical.h>
+#include <sfdpgen/post_process.h>
+#include <neatogen/overlap.h>
+#include <sparse/clustering.h>
+#include <ingraphs/ingraphs.h>
+#include <sparse/DotIO.h>
+#include <sparse/colorutil.h>
+#include <sparse/color_palette.h>
 
 typedef struct {
     char* cmd;
@@ -75,10 +39,9 @@ typedef struct {
     int nrandom; 
     int show_points; 
     real bbox_margin[2]; 
-    int whatout;
     int useClusters;
     int clusterMethod;
-    int plotedges;
+    bool plotedges;
     int color_scheme;
     real line_width;
     char *color_scheme_str;
@@ -87,7 +50,7 @@ typedef struct {
     real *bg_color;
     int improve_contiguity_n;
     int nart;
-    int color_optimize;
+    bool color_optimize;
     int maxcluster;
     int nedgep;
     char *line_color;
@@ -96,58 +59,7 @@ typedef struct {
     int seed;      /* seed used to calculate Fiedler vector */
 } params_t;
 
-int string_split(char *s, char sp, char ***ss0, int *ntokens0){
-  /* give a string s ending with a \0, split into an array of strings using separater sp, 
-     with \0 inserted. Return 0 if successful, 1 if length of string exceed buffer size */
-  int ntokens = 0, len = 0;
-
-  int i;
-  char **ss;
-  char *swork1 = swork;
-  if (strlen(s) > maxlen) {
-    swork1 = MALLOC(sizeof(char)*maxlen);
-  }
-
-  for (i = 0; i < strlen(s); i++){
-    if (s[i] == sp){
-      ntokens++;
-    } else if (s[i] == '\n' || s[i]== EOF){
-      ntokens++;
-      break;
-    }
-  }
-
-  ss = malloc(sizeof(char*)*(ntokens+1));
-  ntokens = 0;
-  for (i = 0; i < strlen(s); i++){
-    if (s[i] == sp){
-      swork1[len++] = '\0';
-      ss[ntokens] = malloc(sizeof(char)*(len+1));
-      strcpy(ss[ntokens], swork1);
-      len = 0;
-      ntokens++;
-      continue;
-    } else if (s[i] == '\n' || s[i] == EOF){
-      swork1[len++] = '\0';
-      ss[ntokens] = malloc(sizeof(char)*(len+1));
-      strcpy(ss[ntokens], swork1);
-      len = 0;
-      ntokens++;
-      break;
-    }
-    swork1[len++] = s[i];
-  }
-
-  *ntokens0 = ntokens;
-
-  *ss0 = ss;
-
-  if (swork1 != swork) FREE(swork1);
-  return 0;
-
-}
-
-static char* usestr =
+static const char usestr[] =
 "   where graphfile must contain node positions, and widths and heights for each node. No overlap between nodes should be present. Acceptable options are: \n\
     -a k - average number of artificial points added along the bounding box of the labels. If < 0, a suitable value is selected automatically. (-1)\n\
     -b v - polygon line width, with v < 0 for no line. (0)\n\
@@ -241,7 +153,7 @@ static void
 init(int argc, char **argv, params_t* pm)
 {
   char* cmd = argv[0];
-  unsigned int c;
+  int c;
   real s;
   int v, r;
   char stmp[3];  /* two character string plus '\0' */
@@ -255,24 +167,21 @@ init(int argc, char **argv, params_t* pm)
   pm->highlight_cluster = 0;
   pm->useClusters = 0;
   pm->clusterMethod = CLUSTERING_MODULARITY;
-  pm->plotedges = 0;
-  pm->whatout = 0;
+  pm->plotedges = false;
   pm->show_points = 0;
   pm->color_scheme = COLOR_SCHEME_PASTEL; 
   pm->line_width = 0;
   pm->plot_label = NULL;
   pm->bg_color = NULL;
   pm->improve_contiguity_n = 0;
-  pm->whatout = OUT_DOT;
   pm->nart = -1;
-  pm->color_optimize = 1;
+  pm->color_optimize = true;
   pm->maxcluster = 0;
   pm->nedgep = 0;
 
   pm->cmd = cmd;
   pm->infiles = NULL;
-  pm->line_color = N_NEW(10,char);
-  strcpy(pm->line_color,"#000000");
+  pm->line_color = strdup("#000000");
   pm->include_OK_points = FALSE;
   pm->seed = 123;
 
@@ -280,7 +189,7 @@ init(int argc, char **argv, params_t* pm)
   pm->bbox_margin[0] =  pm->bbox_margin[1] = 0;
 
   opterr = 0;
-  while ((c = getopt(argc, argv, ":evODQko:m:s:r:p:c:C:l:b:g:t:a:h:z:d:")) != -1) {
+  while ((c = getopt(argc, argv, ":evODQko:m:s:r:p:c:C:l:b:g:t:a:h:z:d:?")) != -1) {
     switch (c) {
     case 'm':
       if ((sscanf(optarg,"%lf",&s) > 0) && (s != 0)){
@@ -292,15 +201,6 @@ init(int argc, char **argv, params_t* pm)
     case 'Q':
       pm->clusterMethod = CLUSTERING_MQ;
       break;
-#if 0
-    case 'q':
-      if ((sscanf(optarg,"%d",&r) > 0) && r >=0 && r <=OUT_PROCESSING){
-        pm->whatout = r;
-      } else {
-        usage(cmd,1);
-      }
-      break;
-#endif
     case 's':
       if ((sscanf(optarg,"%lf",&s) > 0)){
         pm->shore_depth_tol = s;
@@ -343,13 +243,13 @@ init(int argc, char **argv, params_t* pm)
       pm->useClusters = 1;
       break;
     case 'e':
-      pm->plotedges = 1;
+      pm->plotedges = true;
       break;
     case 'o':
 	  pm->outfile = openFile(optarg, "w", pm->cmd);
       break;
     case 'O':
-      pm->color_optimize = 0;
+      pm->color_optimize = false;
       break;
     case 'a':
       if ((sscanf(optarg,"%d",&r) > 0)){
@@ -408,18 +308,18 @@ init(int argc, char **argv, params_t* pm)
       }
       break;
     case 'l':
-      if (pm->plot_label) free (pm->plot_label);
+      free (pm->plot_label);
       pm->plot_label = strdup (optarg);
       break;
     case ':':
       fprintf(stderr, "gvpack: option -%c missing argument - ignored\n", optopt);
       break;
     case '?':
-      if (optopt == '?')
+      if (optopt == '\0' || optopt == '?')
         usage(cmd, 0);
       else {
-        fprintf(stderr, " option -%c unrecognized - ignored\n", optopt);
-        usage(cmd, 0);
+        fprintf(stderr, " option -%c unrecognized\n", optopt);
+        usage(cmd, 1);
       }
       break;
     }
@@ -433,56 +333,6 @@ init(int argc, char **argv, params_t* pm)
     pm->outfile = stdout;
 }
 
-#if 0
-static void get_graph_node_attribute(Agraph_t* g, char *tag, char *format, size_t len, void *x_default_val, int *nn, void *x, int *flag){
-  /* read a node attribute. Example
-     {real x0[2];
-     real *x = NULL;
-
-     x0[0] = x0[1] = 0.;
-     get_graph_node_attribute(g, "pos", "%lf,%lf", sizeof(real)*2, x0, &n, &x, &flag)
-
-     or, do not supply x0 if you want error flagged when pos tag is not available:
-
-     get_graph_node_attribute(g, "pos", "%lf,%lf", sizeof(real)*2, NULL, &n, x, &flag);
-
-     assert(!flag);
-     FREE(x);
-     }
-  */
-  Agnode_t* n;
-  int nnodes;
-
-
-  *flag = 0;
-
-  if (!g) {
-    *flag = -1;
-    return;
-  }
-
-  nnodes = agnnodes (g);
-  *nn = nnodes;
-  for (n = agfstnode (g); n; n = agnxtnode (g, n)) {
-    if (agget(n, tag)){
-      if (strcmp(format,"%s") == 0){
-	strcpy(x, agget(n, tag));
-      } else {
-	sscanf(agget(n, tag), format, x);
-      }
-
-    } else if (x_default_val){
-      memcpy(x, x_default_val, len);
-    } else {
-      *flag = -1;
-      return;
-    }
-    x += len;
-  }
-
-}
-#endif
-
 static int
 validateCluster (int n, int* grouping, int clust_num)
 {
@@ -504,8 +354,6 @@ makeMap (SparseMatrix graph, int n, real* x, real* width, int* grouping,
   real edge_bridge_tol = 0.;
   int npolys, nverts, *polys_groups, exclude_random;
   real *x_poly, *xcombined;
-  enum {max_string_length = 1000};
-  enum {MAX_GRPS = 10000};
   SparseMatrix country_graph;
   int improve_contiguity_n = pm->improve_contiguity_n;
 #ifdef TIME
@@ -515,16 +363,6 @@ makeMap (SparseMatrix graph, int n, real* x, real* width, int* grouping,
   int nart, nrandom;
 
   exclude_random = TRUE;
-#if 0
-  if (argc >= 2) {
-    fp = fopen(argv[1],"r");
-    graph = SparseMatrix_import_matrix_market(fp, FORMAT_CSR);
-  }
-
-  if (whatout == OUT_M){
-    printf("Show[{");
-  }
-#endif
 
 
 #ifdef TIME
@@ -557,7 +395,7 @@ makeMap (SparseMatrix graph, int n, real* x, real* width, int* grouping,
      contiguous so we move point positions to improve contiguity */
   if (graph && improve_contiguity_n) {
     for (i = 0; i < improve_contiguity_n; i++){
-      improve_contiguity(n, dim, grouping, poly_point_map, x, graph, width);
+      improve_contiguity(n, dim, grouping, poly_point_map, x, graph);
       nart = nart0;
       nrandom = nr0;
       make_map_from_rectangle_groups(exclude_random, pm->include_OK_points,
@@ -570,7 +408,7 @@ makeMap (SparseMatrix graph, int n, real* x, real* width, int* grouping,
       SparseMatrix D;
       D = SparseMatrix_get_real_adjacency_matrix_symmetrized(graph);
       remove_overlap(dim, D, x, width, 1000, 5000.,
-		     ELSCHEME_NONE, 0, NULL, NULL, TRUE, &flag);
+		     ELSCHEME_NONE, 0, NULL, NULL, TRUE);
       
       nart = nart0;
       nrandom = nr0;
@@ -583,81 +421,9 @@ makeMap (SparseMatrix graph, int n, real* x, real* width, int* grouping,
     
   }
 
-#if 0
-  if (whatout == OUT_DOT){
-#endif
     Dot_SetClusterColor(g, rgb_r,  rgb_g,  rgb_b, grouping);
-    plot_dot_map(g, n, dim, x, polys, poly_lines, pm->line_width, pm->line_color, x_poly, polys_groups, labels, width, fsz, rgb_r, rgb_g, rgb_b, pm->opacity,
-           pm->plot_label, pm->bg_color, (pm->plotedges?graph:NULL), pm->outfile);
-#if 0
-    }
-    goto RETURN;
-  }
-
-  if (whatout == OUT_PROCESSING){
-    if (plotedges){
-      plot_processing_map(g, n, dim, x, polys, poly_lines, line_width, nverts, x_poly, polys_groups, labels, width, fsz, rgb_r, rgb_g, rgb_b, plot_label, bg_color, graph);
-    } else {
-      plot_processing_map(g, n, dim, x, polys, poly_lines, line_width, nverts, x_poly, polys_groups, labels, width, fsz, rgb_r, rgb_g, rgb_b, plot_label, bg_color, NULL);
-    }
-
-    goto RETURN;
-  }
-
-  if (whatout == OUT_PS){
-    if (plotedges){
-      plot_ps_map(n, dim, x, polys, poly_lines, line_width, x_poly, polys_groups, labels, width, fsz, rgb_r, rgb_g, rgb_b, plot_label, bg_color, graph);
-    } else {
-      plot_ps_map(n, dim, x, polys, poly_lines, line_width, x_poly, polys_groups, labels, width, fsz, rgb_r, rgb_g, rgb_b, plot_label, bg_color, NULL);
-    }
-
-    goto RETURN;
-  }
-
-
-  if (whatout == OUT_M_COUNTRY_GRAPH){
-    SparseMatrix_print("(*country graph=*)",country_graph);
-    goto RETURN;
-    
-  }
-
-  
-  /*plot_polys(FALSE, polys, x_poly, polys_groups, rgb_r, rgb_g, rgb_b);*/
-  if (whatout == OUT_M){
-    plot_polys(FALSE, polys, x_poly, polys_groups, NULL, NULL, NULL);
-    printf(",");
-
-    plot_polys(TRUE, poly_lines, x_poly, polys_groups, NULL, NULL, NULL);
- 
-    if (show_points){
-      if (show_points == POINTS_ALL){
-	printf(",");
-	plot_points(n + nart + nrandom - 4, dim, xcombined);
-      } else if (show_points == POINTS_LABEL){
-	printf(",");
-	plot_points(n + nart - 4, dim, xcombined);
-      } else if (show_points == POINTS_RANDOM){
-	printf(",");
-	plot_points(MAX(1,nrandom - 4), dim, xcombined+dim*(n+nart));
-      } else {
-	assert(0);
-      }
-    }
-    if (plotedges){
-      printf(",");
-      plot_edges(n, dim, x, graph);
-    }
-    
-    if (labels){
-      printf(",");
-      plot_labels(n, dim, xcombined, labels);
-    }
-    
-    printf("}]\n");
-  }
-
- RETURN:
-#endif
+    plot_dot_map(g, n, dim, x, polys, poly_lines, pm->line_width, pm->line_color, x_poly, polys_groups, labels, fsz, rgb_r, rgb_g, rgb_b, pm->opacity,
+           (pm->plotedges?graph:NULL), pm->outfile);
   SparseMatrix_delete(polys);
   SparseMatrix_delete(poly_lines);
   SparseMatrix_delete(poly_point_map);
