@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 #ifdef FEATURE_CS
@@ -597,7 +594,7 @@ FILE *SFopenFile (char *name, char *mode, char *prompt, char *failed) {
     SFchdir (SFstartDir);
     if ((fp = fopen (name, mode)) == NULL) {
         char *buf;
-        char *errormsg = strerror (errno);
+        const char *errormsg = strerror (errno);
         if (errormsg) {
             buf = XtMalloc (
                 strlen (failed) + strlen (errormsg) + strlen (prompt) + 2
