@@ -1,6 +1,4 @@
-#ifndef GLUTRENDER_H
-#define	GLUTRENDER_H
-
+#pragma once
 
 #ifdef __cplusplus
 extern "C" {
@@ -11,4 +9,3 @@ extern "C" {
 #ifdef __cplusplus
 }				/* end extern "C" */
 #endif
-#endif
