@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,28 +5,22 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 #include <stdio.h>
-#include "compat.h"
 #include <stdlib.h>
 #include "gui.h"
-/* #include "abstring.h" */
 #include <glade/glade.h>
 #include <gdk/gdkkeysyms.h>
 #include <gdk/gdk.h>
 #include "viewport.h"
-#include "memory.h"
+#include <common/memory.h>
+#include <cgraph/strcasecmp.h>
 
 
 static char guibuffer[BUFSIZ];	//general purpose buffer
 
-#ifdef _WIN32
-extern int strcasecmp(const char *s1, const char *s2);
-extern int strncasecmp(const char *s1, const char *s2, unsigned int n);
-#endif
-
 GdkWindow *window1;
 GtkWidget *statusbar1;
 
@@ -55,13 +46,6 @@ attribute attr[MAXIMUM_WIDGET_COUNT];
 //call this function only ones
 void create_object_properties(void)
 {
-#ifdef UNUSED
-    char *data0 = "TEST0";
-    char *data1 = "TEST1";
-    char *data2 = "TEST2";
-    char *data3 = "TEST3";
-    char *data4 = "TEST4";
-#endif
     GladeXML *xml;
     GtkWidget *widget;
     xml = glade_xml_new(smyrnaGlade, NULL, NULL);
@@ -144,17 +128,6 @@ void Color_Widget_bg(char *colorstring, GtkWidget * widget)
     gtk_widget_modify_base(widget, GTK_STATE_NORMAL, &color);
 }
 
-
-#ifdef UNUSED
-void Color_Widget_fg(int r, int g, int b, GtkWidget * widget)
-{
-    GdkColor color;
-    gdk_color_parse("red", &color);
-    gtk_widget_modify_fg(widget, GTK_STATE_NORMAL, &color);
-
-}
-#endif
-
 void load_graph_properties(Agraph_t * graph)
 {
     //dlgOpenGraph , GtkDialog
@@ -247,44 +220,6 @@ char *get_attribute_string_value_from_widget(attribute * att)
 	return guibuffer;
     }
 }
-#if UNUSED
-void change_selected_graph_attributes(Agraph_t * g, char *attrname,
-				      char *attrvalue)
-{
-    agattr(g, AGRAPH, attrname, "");
-    agset(view->g[view->activeGraph], attrname, attrvalue);
-
-
-}
-void change_selected_node_attributes(Agraph_t * g, char *attrname,
-				     char *attrvalue)
-{
-    int ind = 0;
-    Agsym_t* ap = agattr(g, AGNODE, attrname, NULL);
-
-    if (!ap)
-	ap = agattr(g, AGNODE, attrname, "");
-	
-    for (ind = 0; ind < view->Topview->Nodecount; ind++) {
-	if (view->Topview->Nodes[ind].data.Selected == 1)
-	    agxset(view->Topview->Nodes[ind].Node, ap, attrvalue);
-    }
-}
-void change_selected_edge_attributes(Agraph_t * g, char *attrname,
-				     char *attrvalue)
-{
-    int ind = 0;
-    Agsym_t* ap = agattr(g, AGEDGE, attrname, NULL);
-
-    if (!ap)
-	ap = agattr(g, AGEDGE, attrname, "");
-	
-    for (ind = 0; ind < view->Topview->Edgecount; ind++) {
-	if (view->Topview->Edges[ind].data.Selected == 1)
-	    agxset(view->Topview->Edges[ind].Edge, ap, attrvalue);
-    }
-}
-#endif
 
 void load_attributes(void)
 {
@@ -307,8 +242,6 @@ void load_attributes(void)
 	    ind = 0;
 	    while (pch != NULL) {
 		ss = strdup(pch);
-		//                              ABRemove(&ss,'\"');
-		//                              ABRemove(&ss,' ');
 		pch = strtok(NULL, ",");
 		switch (ind) {
 		case 0:
