@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,11 +5,11 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#ifndef POLYTESS_H
-#define POLYTESS_H
+#pragma once
+
 #include "smyrnadefs.h"
 
 #ifdef __cplusplus
@@ -23,8 +20,7 @@ extern "C" {
 	GLenum windingRule;
     }tessPoly;
     extern int drawTessPolygon(sdot_op* p);
-    extern int testDraw();
+    extern int testDraw(void);
 #ifdef __cplusplus
 }				/* end extern "C" */
 #endif
-#endif
