@@ -1,5 +1,3 @@
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -7,11 +5,10 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#ifndef SMYRNADEFS_H
-#define SMYRNADEFS_H
+#pragma once
 
 #ifdef _WIN32
 #ifndef NO_WIN_HEADER
@@ -24,16 +21,15 @@
 #define _BB
 #endif
 
-#include "xdot.h"
+#include <xdot/xdot.h>
 #include <gtk/gtk.h>
 #include <GL/gl.h>
 #include <GL/glu.h>
 #include <gtk/gtkgl.h>
-#include "cgraph.h"
-#include "glcompset.h"
+#include <cgraph/cgraph.h>
+#include <glcomp/glcompset.h>
 #include "hier.h"
-#include "md5.h"
-#include "glutils.h"
+#include <glcomp/glutils.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -72,8 +68,8 @@ typedef struct _ArcBall_t ArcBall_t;
 
 #define GLOBAL_Z_OFFSET			0.001
 
-#define MAX_ZOOM	500
-#define MIN_ZOOM	0.005
+#define MAX_ZOOM	500.0f
+#define MIN_ZOOM	0.005f
 #define ZOOM_STEPS	100
 
 #define ZOOM_STEP	0.5
@@ -696,8 +692,6 @@ typedef struct
 	float FontSizeConst;
 	glCompSet *widgets;	//for novice user open gl menu
 	int visiblenodecount;	/*helper variable to know the number of the nodes being rendered, good data to optimize speed */
-	md5_byte_t orig_key[16];	/*md5 result for original graph */
-	md5_byte_t final_key[16];	/*md5 result right before graph is saved */
 	char *initFileName;	//file name from command line
 	int initFile;
 	int drawSplines;
@@ -707,7 +701,6 @@ typedef struct
 	char *template_file;
 	char *attr_file;
 	int flush;
-	line interpol;
 	gvprscript *scripts;
 	int script_count;	/*# of scripts */
 	GtkComboBox *graphComboBox;	/*pointer to graph combo box at top right */
@@ -740,4 +733,3 @@ typedef struct
 #ifdef __cplusplus
 }				/* end extern "C" */
 #endif
-#endif
