@@ -1,6 +1,3 @@
-/* $Id$Revision: */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,10 +5,10 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
-#ifndef TOPFISHEYEVIEW_H
-#define TOPFISHEYEVIEW_H
+
+#pragma once
 
 #include "smyrnadefs.h"
 #include "hier.h"
@@ -41,4 +38,3 @@ extern "C" {
 #ifdef __cplusplus
 }				/* end extern "C" */
 #endif
-#endif
