@@ -1,6 +1,3 @@
-/* $Id$Revision: */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,19 +5,19 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 #include "topviewfuncs.h"
-#include "cgraph.h"
+#include <cgraph/cgraph.h>
 #include "smyrna_utils.h"
-#include "colorprocs.h"
+#include <common/colorprocs.h>
 #include "draw.h"
 #include "frmobjectui.h"
-#include "xdot.h"
-#include "glutils.h"
+#include <xdot/xdot.h>
+#include <glcomp/glutils.h>
 #include "selectionfuncs.h"
-#include "memory.h"
+#include <common/memory.h>
 #include <ctype.h>
 
 static xdot *parseXdotwithattrs(void *e)
@@ -84,30 +81,6 @@ static void set_boundaries(Agraph_t * g, topview * t)
     view->bdzBottom = 0;
 }
 
-#if UNUSED
-static float init_node_size(Agraph_t * g, topview * t)
-{
-    float vsize;
-    int percent;
-    float sz;
-    percent = atoi(agget(g, "nodesize"));
-    if (percent == 0)
-	percent = 0.000001;
-    vsize =
-	0.05 * sqrt((view->bdxRight - view->bdxLeft) *
-		    (view->bdyTop - view->bdyBottom));
-    sz =	vsize * 2  * percent / 100.0 /
-	sqrt(t->Nodecount);
-/*    if (t->init_node_size < 1)
-	t->init_node_size=1;*/
-//    t->init_zoom = view->zoom;
-    t->init_zoom = -20;
-    return  sz;
-
-}
-#endif
-
-
 static void draw_xdot(xdot* x,float base_z)
 {
 	int i;
@@ -144,7 +117,7 @@ static GLfloat getEdgeLength(Agedge_t *  edge)
     A=getEdgeTail(edge);
     B=getEdgeHead(edge);
     rv=(A.x-B.x)*(A.x-B.x) + (A.y-B.y)*(A.y-B.y) +(A.z-B.z)*(A.z-B.z);
-    rv=sqrt(rv);
+    rv=sqrtf(rv);
     return rv;
 }
 static void glCompColorxlate(glCompColor* c,char* str)
@@ -355,7 +328,7 @@ static void renderNodes(Agraph_t * g)
 
     x=parseXdotwithattrs(g);
     if (x) {
-	draw_xdot(x,-0.2);
+	draw_xdot(x,-0.2f);
 	freeXDot (x);
     }
     for (v = agfstnode(g); v; v = agnxtnode(g, v)) 
@@ -363,7 +336,7 @@ static void renderNodes(Agraph_t * g)
 	    if(!object_color(v,&c))
 		continue;
 	    x=parseXdotwithattrs(v);
-	    draw_xdot(x,-0.1);
+	    draw_xdot(x,-0.1f);
 
 	    if(x)
 		freeXDot (x);
@@ -453,8 +426,8 @@ static void renderSelectedEdges(Agraph_t * g)
 	    glColor4f(1,0,0,1);	    
 	    posT = ED_posTail(e);
 	    posH = ED_posHead(e);
-	    posT.z +=0.01;
-	    posH.z +=0.01;
+	    posT.z +=0.01f;
+	    posH.z +=0.01f;
 	    draw_edge(&posT,&posH,getEdgeLength(e),0);
 	}
     }
@@ -890,7 +863,6 @@ void updateSmGraph(Agraph_t * g,topview* t)
 
     set_boundaries(g,t);
     t->avgedgelength = totalELength / t->Edgecount;
-//    t->init_node_size=init_node_size(g, t);
     view->Topview=t;
 
 
@@ -939,9 +911,7 @@ void renderSmGraph(Agraph_t * g,topview* t)
 
     glEnable(GL_POINT_SMOOTH);
     glEnable(GL_DEPTH_TEST);
-    /* glDepthFunc (GL_ALWAYS); */
     glEnable(GL_DEPTH);
-//    glDepthMask(0);
 
     if(view->drawedges)
     {
@@ -970,7 +940,4 @@ void renderSmGraph(Agraph_t * g,topview* t)
 
 void freeSmGraph(Agraph_t * g,topview* t)
 {
-    return ;
 }
-
-
