@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 #ifdef __cplusplus
@@ -24,12 +21,8 @@ extern "C" {
 #include <stdlib.h>
 #include <string.h>
 
-#include "cgraph.h"
-#include "cghdr.h"
-
-#ifdef _WIN32
-#define strdup(x) _strdup(x)
-#endif
+#include <cgraph/cgraph.h>
+#include <cgraph/cghdr.h>
 
     extern void gv_to_gxl(Agraph_t *, FILE *);
 #ifdef HAVE_EXPAT
