@@ -1,12 +1,5 @@
-/* $Id$Revision: */
-/* vim:set shiftwidth=4 ts=8: */
-
 #include <stdio.h>
-#include <cgraph.h>
-
-#ifdef _WIN32
-#define strdup(x) _strdup(x)
-#endif
+#include <cgraph/cgraph.h>
 
 typedef struct {
     Dtlink_t link;
