@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,12 +5,12 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 
 #include    "convert.h"
-#include    "agxbuf.h"
+#include    <cgraph/agxbuf.h>
 #include    <getopt.h>
 #ifdef HAVE_EXPAT
 #include    <expat.h>
@@ -55,15 +52,15 @@ struct slist {
     char buf[1];
 };
 
-#define NEW(t)      (t*)malloc(sizeof(t))
-#define N_NEW(n,t)  (t*)malloc((n)*sizeof(t))
+#define NEW(t)      malloc(sizeof(t))
+#define N_NEW(n,t)  calloc((n),sizeof(t))
 /* Round x up to next multiple of y, which is a power of 2 */
 #define ROUND2(x,y) (((x) + ((y)-1)) & ~((y)-1))
 
 static void pushString(slist ** stk, const char *s)
 {
     int sz = ROUND2(sizeof(slist) + strlen(s), sizeof(void *));
-    slist *sp = (slist *) N_NEW(sz, char);
+    slist *sp = N_NEW(sz, char);
     strcpy(sp->buf, s);
     sp->next = *stk;
     *stk = sp;
@@ -454,7 +451,7 @@ startElementHandler(void *userData, const char *name, const char **atts)
 	    Agraph_t *subg;
 	    if (isAnonGraph((char *) id)) {
 		static int anon_id = 1;
-		sprintf(buf, "%%%d", anon_id++);
+		snprintf(buf, sizeof(buf), "%%%d", anon_id++);
 		id = buf;
 	    }
 	    subg = agsubg(G, (char *) id, 1);
@@ -498,7 +495,7 @@ startElementHandler(void *userData, const char *name, const char **atts)
 	    head = tname;
 
         if (G == 0)
-            fprintf(stderr,"edge source %s target %s outside graph, ignored\n",(char*)tail,(char*)head);
+            fprintf(stderr,"edge source %s target %s outside graph, ignored\n",tail,head);
         else {
             bind_edge(tail, head);
 
@@ -586,8 +583,7 @@ static void endElementHandler(void *userData, const char *name)
 	    setGraphAttr(G, name, value, ud);
 	    break;
 	}
-	if (dynbuf)
-	    free(dynbuf);
+	free(dynbuf);
 	ud->globalAttrType = TAG_NONE;
     } 
 }
@@ -607,7 +603,7 @@ static void characterDataHandler(void *userData, const char *s, int length)
     agxbput_n(&ud->xml_attr_value, (char *) s, length);
 }
 
-Agraph_t *graphml_to_gv(char* gname, FILE * graphmlFile, int* rv)
+static Agraph_t *graphml_to_gv(char* gname, FILE * graphmlFile, int* rv)
 {
     char buf[BUFSIZE];
     int done;
@@ -723,6 +719,8 @@ static void initargs(int argc, char **argv)
 	    Verbose = 1;
 	    break;
 	case 'o':
+	    if (outFile != NULL)
+		fclose(outFile);
 	    outFile = openFile(optarg, "w");
 	    break;
 	case ':':
