@@ -1,9 +1,6 @@
-/* $Id$Revision: */
-/* vim:set shiftwidth=4 ts=8: */
-
 /**********************************************************
 *      This software is part of the graphviz package      *
-*                http://www.graphviz.org/                 *
+*                  https://graphviz.org                   *
 *                                                         *
 *            Copyright (c) 1994-2004 AT&T Corp.           *
 *                and is licensed under the                *
@@ -26,9 +23,9 @@
 
 #include <getopt.h>
 
-#include <cgraph.h>
+#include <cgraph/cgraph.h>
 #include <ctype.h>
-#include <ingraphs.h>
+#include <ingraphs/ingraphs.h>
 
 static FILE *outFile;
 static char *CmdName;
@@ -121,11 +118,7 @@ parseStyle (char* s)
     char* ip;
     char* sep = " \t,";
 
-#ifdef _WIN32 
-	s = _strdup(s);
-#else
 	s = strdup(s);
-#endif
     for (ip = strtok (s, sep); ip; ip = strtok (NULL, sep)) {
 	if (streq(ip,"invis")) flags |= INVIS;
 	else if (streq(ip,"filled")) flags |= FILL;
@@ -704,6 +697,8 @@ static void initargs(int argc, char **argv)
     while ((c = getopt(argc, argv, ":o:")) != -1) {
 	switch (c) {
 	case 'o':
+	    if (outFile != NULL)
+		fclose(outFile);
 	    outFile = openFile(optarg, "w");
 	    break;
 	case ':':
