@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 
@@ -23,19 +20,16 @@
 #include <getopt.h>
 
 #include <assert.h>
-#include "gvc.h"
-#include "render.h"
-#include "neatoprocs.h"
-#include "ingraphs.h"
-#include "pack.h"
+#include <gvc/gvc.h>
+#include <common/render.h>
+#include <neatogen/neatoprocs.h>
+#include <ingraphs/ingraphs.h>
+#include <pack/pack.h>
 
-/*visual studio*/
 #if defined(_WIN32)
-#define extern __declspec(dllimport)
+  __declspec(dllimport)
 #endif
-/*end visual studio*/
 extern gvplugin_library_t gvplugin_neato_layout_LTX_library;
-#undef extern
 
 lt_symlist_t lt_preloaded_symbols[] = {
 #if defined(_WIN32)
@@ -195,7 +189,7 @@ static void init(int argc, char *argv[], pack_info* pinfo)
     pinfo->sz = 0;
 
     opterr = 0;
-    while ((c = getopt(argc, argv, ":na:gvum:s:o:G:")) != -1) {
+    while ((c = getopt(argc, argv, ":na:gvum:s:o:G:?")) != -1) {
 	switch (c) {
 	case 'a':
 	    len = strlen(optarg) + 2;
@@ -221,6 +215,8 @@ static void init(int argc, char *argv[], pack_info* pinfo)
 	    setUInt(&pinfo->margin, optarg);
 	    break;
 	case 'o':
+	    if (outfp != NULL)
+		fclose(outfp);
 	    outfp = openFile(optarg, "w");
 	    break;
 	case 'u':
@@ -241,11 +237,13 @@ static void init(int argc, char *argv[], pack_info* pinfo)
 	    fprintf(stderr, "gvpack: option -%c missing argument - ignored\n", optopt);
 	    break;
 	case '?':
-	    if (optopt == '?')
+	    if (optopt == '\0' || optopt == '?')
 		usage(0);
-	    else
+	    else {
 		fprintf(stderr,
-			"gvpack: option -%c unrecognized - ignored\n", optopt);
+			"gvpack: option -%c unrecognized\n", optopt);
+		usage(1);
+	    }
 	    break;
 	}
     }
@@ -338,10 +336,13 @@ static void cloneDfltAttrs(Agraph_t *old, Agraph_t *new, int kind)
     Agsym_t *a;
 
     for (a = agnxtattr(old, kind, 0); a; a =  agnxtattr(old, kind, a)) {
-	if (aghtmlstr(a->defval))
-	    agattr (new, kind, a->name, agstrdup_html(new, a->defval));
-	else
+	if (aghtmlstr(a->defval)) {
+	    char *s = agstrdup_html(new, a->defval);
+	    agattr(new, kind, a->name, s);
+	    agstrfree(new, s); // drop the extra reference count we bumped for s
+	} else {
 	    agattr (new, kind, a->name, a->defval);
+	}
     }
 }
 static void cloneAttrs(void *old, void *new)
@@ -354,10 +355,13 @@ static void cloneAttrs(void *old, void *new)
 
     for (a = agnxtattr(g, kind, 0); a; a =  agnxtattr(g, kind, a)) {
 	s = agxget (old, a);
-	if (aghtmlstr(s))
-	    agset(new, a->name, agstrdup_html(ng, s));
-	else
+	if (aghtmlstr(s)) {
+	    char *scopy = agstrdup_html(ng, s);
+	    agset(new, a->name, scopy);
+	    agstrfree(ng, scopy); // drop the extra reference count we bumped for scopy
+	} else {
 	    agset(new, a->name, s);
+	}
     }
 }
 
@@ -439,7 +443,7 @@ static void fillDict(Dt_t * newdict, Agraph_t* g, int kind)
     for (a = agnxtattr(g,kind,0); a; a = agnxtattr(g,kind,a)) {
 	name = a->name;
 	value = a->defval;
-	rv = (attr_t *) dtmatch(newdict, name);
+	rv = dtmatch(newdict, name);
 	if (!rv) {
 	    rv = NEW(attr_t);
 	    rv->name = name;
@@ -528,7 +532,7 @@ static void redoBB(Agraph_t * g, char *s, Agsym_t * G_bb, point delta)
 	bb.LL.y += delta.y;
 	bb.UR.x += delta.x;
 	bb.UR.y += delta.y;
-	sprintf(buf, "%d,%d,%d,%d", bb.LL.x, bb.LL.y, bb.UR.x, bb.UR.y);
+	snprintf(buf, sizeof(buf), "%d,%d,%d,%d", bb.LL.x, bb.LL.y, bb.UR.x, bb.UR.y);
 	agxset(g, G_bb->index, buf);
     }
 }
@@ -549,12 +553,12 @@ static char *xName(Dt_t * names, char *oldname)
     pair_t *p;
     int len;
 
-    p = (pair_t *) dtmatch(names, oldname);
+    p = dtmatch(names, oldname);
     if (p) {
 	p->cnt++;
 	len = strlen(oldname) + 100; /* 100 for "_gv" and decimal no. */
 	if (namelen < len) {
-	    if (name) free (name);
+	    free (name);
 	    name = N_NEW(len, char);
 	    namelen = len;
 	}
@@ -817,7 +821,7 @@ static Agraph_t **readGraphs(int *cp, GVC_t* gvc)
  * Compute the bounding box containing the graphs.
  * We can just use the bounding boxes of the graphs.
  */
-boxf compBB(Agraph_t ** gs, int cnt)
+static boxf compBB(Agraph_t ** gs, int cnt)
 {
     boxf bb, bb2;
     int i;
