@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,15 +5,16 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 
 #include    "convert.h"
-#include    "agxbuf.h"
+#include    <cgraph/agxbuf.h>
 #ifdef HAVE_EXPAT
 #include    <expat.h>
 #include    <ctype.h>
+#include    <stdbool.h>
 
 #ifndef XML_STATUS_ERROR
 #define XML_STATUS_ERROR 0
@@ -37,10 +35,13 @@
 #define GXL_COMP    "_gxl_composite_"
 #define GXL_LOC     "_gxl_locator_"
 
-#define	TAG_NONE	-1
-#define	TAG_GRAPH	0
-#define TAG_NODE	1
-#define TAG_EDGE	2
+typedef enum {
+  TAG_NONE,
+  TAG_GRAPH,
+  TAG_NODE,
+  TAG_EDGE,
+  TAG_HTML_LIKE_STRING,
+} attr_t;
 
 typedef struct slist slist;
 struct slist {
@@ -48,15 +49,23 @@ struct slist {
     char buf[1];
 };
 
-#define NEW(t)      (t*)malloc(sizeof(t))
-#define N_NEW(n,t)  (t*)malloc((n)*sizeof(t))
+static void *gcalloc(size_t nmemb, size_t size)
+{
+    char *rv = calloc(nmemb, size);
+    if (rv == NULL) {
+	fprintf(stderr, "out of memory\n");
+	exit(EXIT_FAILURE);
+    }
+    return rv;
+}
+
 /* Round x up to next multiple of y, which is a power of 2 */
 #define ROUND2(x,y) (((x) + ((y)-1)) & ~((y)-1))
 
 static void pushString(slist ** stk, const char *s)
 {
     int sz = ROUND2(sizeof(slist) + strlen(s), sizeof(void *));
-    slist *sp = (slist *) N_NEW(sz, char);
+    slist *sp = gcalloc(sz, sizeof(char));
     strcpy(sp->buf, s);
     sp->next = *stk;
     *stk = sp;
@@ -99,15 +108,15 @@ typedef struct userdata {
     agxbuf composite_buffer;
     slist *elements;
     int listen;
-    int closedElementType;
-    int globalAttrType;
+    attr_t closedElementType;
+    attr_t globalAttrType;
     int compositeReadState;
     int edgeinverted;
     Dt_t *nameMap;
 } userdata_t;
 
 static Agraph_t *root;		/* root graph */
-static int Current_class;	/* Current element type */
+static attr_t Current_class;	/* Current element type */
 static Agraph_t *G;		/* Current graph */
 static Agnode_t *N;		/* Set if Current_class == TAG_NODE */
 static Agedge_t *E;		/* Set if Current_class == TAG_EDGE */
@@ -123,7 +132,9 @@ typedef struct {
 
 static namev_t *make_nitem(Dt_t * d, namev_t * objp, Dtdisc_t * disc)
 {
-    namev_t *np = NEW(namev_t);
+    namev_t *np = malloc(sizeof(namev_t));
+    if (np == NULL)
+	return NULL;
     np->name = objp->name;
     np->unique_name = 0;
     return np;
@@ -149,7 +160,9 @@ static Dtdisc_t nameDisc = {
 
 static userdata_t *genUserdata(void)
 {
-    userdata_t *user = NEW(userdata_t);
+    userdata_t *user = malloc(sizeof(userdata_t));
+    if (user == NULL)
+	return NULL;
     agxbinit(&(user->xml_attr_name), NAMEBUF, 0);
     agxbinit(&(user->xml_attr_value), SMALLBUF, 0);
     agxbinit(&(user->composite_buffer), SMALLBUF, 0);
@@ -270,7 +283,8 @@ static void setName(Dt_t * names, Agobj_t * n, char *value)
 static char *defval = "";
 
 static void
-setNodeAttr(Agnode_t * np, char *name, char *value, userdata_t * ud)
+setNodeAttr(Agnode_t * np, char *name, char *value, userdata_t * ud,
+  bool is_html)
 {
     Agsym_t *ap;
 
@@ -280,7 +294,13 @@ setNodeAttr(Agnode_t * np, char *name, char *value, userdata_t * ud)
 	ap = agattr(root, AGNODE, name, 0);
 	if (!ap)
 	    ap = agattr(root, AGNODE, name, defval);
-	agxset(np, ap, value);
+	if (is_html) {
+	    char *val = agstrdup_html(root, value);
+	    agxset(np, ap, val);
+	    agstrfree(root, val); // drop the extra reference count we bumped for val
+	} else {
+	    agxset(np, ap, value);
+	}
     }
 }
 
@@ -308,7 +328,8 @@ setGlobalNodeAttr(Agraph_t * g, char *name, char *value, userdata_t * ud)
 }
 
 static void
-setEdgeAttr(Agedge_t * ep, char *name, char *value, userdata_t * ud)
+setEdgeAttr(Agedge_t * ep, char *name, char *value, userdata_t * ud,
+  bool is_html)
 {
     Agsym_t *ap;
     char *attrname;
@@ -321,7 +342,6 @@ setEdgeAttr(Agedge_t * ep, char *name, char *value, userdata_t * ud)
 	ap = agattr(root, AGEDGE, attrname, 0);
 	if (!ap)
 	    ap = agattr(root, AGEDGE, attrname, defval);
-	agxset(ep, ap, value);
     } else if (strcmp(name, "tailport") == 0) {
 	if (ud->edgeinverted)
 	    attrname = "headport";
@@ -330,11 +350,17 @@ setEdgeAttr(Agedge_t * ep, char *name, char *value, userdata_t * ud)
 	ap = agattr(root, AGEDGE, attrname, 0);
 	if (!ap)
 	    ap = agattr(root, AGEDGE, attrname, defval);
-	agxset(ep, ap, value);
     } else {
 	ap = agattr(root, AGEDGE, name, 0);
 	if (!ap)
 	    ap = agattr(root, AGEDGE, name, defval);
+    }
+
+    if (is_html) {
+	char *val = agstrdup_html(root, value);
+	agxset(ep, ap, val);
+	agstrfree(root, val); // drop the extra reference count we bumped for val
+    } else {
 	agxset(ep, ap, value);
     }
 }
@@ -379,17 +405,19 @@ setGraphAttr(Agraph_t * g, char *name, char *value, userdata_t * ud)
     }
 }
 
-static void setAttr(char *name, char *value, userdata_t * ud)
+static void setAttr(char *name, char *value, userdata_t * ud, bool is_html)
 {
     switch (Current_class) {
     case TAG_GRAPH:
 	setGraphAttr(G, name, value, ud);
 	break;
     case TAG_NODE:
-	setNodeAttr(N, name, value, ud);
+	setNodeAttr(N, name, value, ud, is_html);
 	break;
     case TAG_EDGE:
-	setEdgeAttr(E, name, value, ud);
+	setEdgeAttr(E, name, value, ud, is_html);
+	break;
+    default:
 	break;
     }
 }
@@ -437,7 +465,7 @@ startElementHandler(void *userData, const char *name, const char **atts)
 	    Agraph_t *subg;
 	    if (isAnonGraph((char *) id)) {
 		static int anon_id = 1;
-		sprintf(buf, "%%%d", anon_id++);
+		snprintf(buf, sizeof(buf), "%%%d", anon_id++);
 		id = buf;
 	    }
 	    subg = agsubg(G, (char *) id, 1);
@@ -501,22 +529,22 @@ startElementHandler(void *userData, const char *name, const char **atts)
 
 	pos = get_xml_attr("fromorder", atts);
 	if (pos > 0) {
-	    setEdgeAttr(E, GXL_FROM, (char *) atts[pos], ud);
+	    setEdgeAttr(E, GXL_FROM, (char *) atts[pos], ud, false);
 	}
 
 	pos = get_xml_attr("toorder", atts);
 	if (pos > 0) {
-	    setEdgeAttr(E, GXL_TO, (char *) atts[pos], ud);
+	    setEdgeAttr(E, GXL_TO, (char *) atts[pos], ud, false);
 	}
 
 	pos = get_xml_attr("id", atts);
 	if (pos > 0) {
-	    setEdgeAttr(E, GXL_ID, (char *) atts[pos], ud);
+	    setEdgeAttr(E, GXL_ID, (char *) atts[pos], ud, false);
 	}
     } else if (strcmp(name, "attr") == 0) {
 	const char *attrname = atts[get_xml_attr("name", atts)];
 
-	agxbput(&ud->xml_attr_name, (char *) attrname);
+	agxbput(&ud->xml_attr_name, attrname);
 	pos = get_xml_attr("kind", atts);
 
 	if (pos > 0) {
@@ -526,6 +554,8 @@ startElementHandler(void *userData, const char *name, const char **atts)
 		ud->globalAttrType = TAG_EDGE;
 	    else if (strcmp("graph", atts[pos]) == 0)
 		ud->globalAttrType = TAG_GRAPH;
+	    else if (strcmp("HTML-like string", atts[pos]) == 0)
+		ud->globalAttrType = TAG_HTML_LIKE_STRING;
 	} else {
 	    ud->globalAttrType = TAG_NONE;
 	}
@@ -536,23 +566,20 @@ startElementHandler(void *userData, const char *name, const char **atts)
 
 	ud->listen = TRUE;
 	if (ud->compositeReadState) {
-	    agxbputc(&ud->composite_buffer, '<');
-	    agxbput(&ud->composite_buffer, (char *) name);
-	    agxbputc(&ud->composite_buffer, '>');
+	    agxbprint(&ud->composite_buffer, "<%s>", name);
 	}
     } else if (strcmp(name, "rel") == 0 || strcmp(name, "relend") == 0) {
 	fprintf(stderr, "%s element is ignored by DOT\n", name);
     } else if (strcmp(name, "type") == 0) {
 	pos = get_xml_attr("xlink:href", atts);
 	if (pos > 0) {
-	    setAttr(GXL_TYPE, (char *) atts[pos], ud);
+	    setAttr(GXL_TYPE, (char *) atts[pos], ud, false);
 	}
     } else if (strcmp(name, "locator") == 0) {
 	pos = get_xml_attr("xlink:href", atts);
 	if (pos > 0) {
 	    const char *href = atts[pos];
-	    agxbput(&ud->xml_attr_value, GXL_LOC);
-	    agxbput(&ud->xml_attr_value, (char *) href);
+	    agxbprint(&ud->xml_attr_value, "%s%s", GXL_LOC, href);
 	}
     } else if (strcmp(name, "seq") == 0
 	       || strcmp(name, "set") == 0
@@ -560,9 +587,7 @@ startElementHandler(void *userData, const char *name, const char **atts)
 	       || strcmp(name, "tup") == 0 || strcmp(name, "enum") == 0) {
 
 	ud->compositeReadState = TRUE;
-	agxbputc(&ud->composite_buffer, '<');
-	agxbput(&ud->composite_buffer, (char *) name);
-	agxbputc(&ud->composite_buffer, '>');
+	agxbprint(&ud->composite_buffer, "<%s>", name);
     } else {
 	/* must be some extension */
 	fprintf(stderr,
@@ -606,7 +631,7 @@ static void endElementHandler(void *userData, const char *name)
 	    if (len <= SMALLBUF) {
 		name = buf;
 	    } else {
-		name = dynbuf = N_NEW(len, char);
+		name = dynbuf = gcalloc(len, sizeof(char));
 		strcpy(name, GXL_COMP);
 	    }
 	    strcpy(name + sizeof(GXL_COMP) - 1,
@@ -621,7 +646,7 @@ static void endElementHandler(void *userData, const char *name)
 
 	switch (ud->globalAttrType) {
 	case TAG_NONE:
-	    setAttr(name, value, ud);
+	    setAttr(name, value, ud, false);
 	    break;
 	case TAG_NODE:
 	    setGlobalNodeAttr(G, name, value, ud);
@@ -632,28 +657,24 @@ static void endElementHandler(void *userData, const char *name)
 	case TAG_GRAPH:
 	    setGraphAttr(G, name, value, ud);
 	    break;
+	case TAG_HTML_LIKE_STRING:
+	    setAttr(name, value, ud, true);
+	    break;
 	}
-	if (dynbuf)
-	    free(dynbuf);
+	free(dynbuf);
 	ud->globalAttrType = TAG_NONE;
     } else if (strcmp(name, "string") == 0
 	       || strcmp(name, "bool") == 0
 	       || strcmp(name, "int") == 0 || strcmp(name, "float") == 0) {
 	ud->listen = FALSE;
 	if (ud->compositeReadState) {
-	    agxbputc(&ud->composite_buffer, '<');
-	    agxbputc(&ud->composite_buffer, '/');
-	    agxbput(&ud->composite_buffer, (char *) name);
-	    agxbputc(&ud->composite_buffer, '>');
+	    agxbprint(&ud->composite_buffer, "</%s>", name);
 	}
     } else if (strcmp(name, "seq") == 0
 	       || strcmp(name, "set") == 0
 	       || strcmp(name, "bag") == 0
 	       || strcmp(name, "tup") == 0 || strcmp(name, "enum") == 0) {
-	agxbputc(&ud->composite_buffer, '<');
-	agxbputc(&ud->composite_buffer, '/');
-	agxbput(&ud->composite_buffer, (char *) name);
-	agxbputc(&ud->composite_buffer, '>');
+	agxbprint(&ud->composite_buffer, "</%s>", name);
     }
 }
 
@@ -665,11 +686,11 @@ static void characterDataHandler(void *userData, const char *s, int length)
 	return;
 
     if (ud->compositeReadState) {
-	agxbput_n(&ud->composite_buffer, (char *) s, length);
+	agxbput_n(&ud->composite_buffer, s, length);
 	return;
     }
 
-    agxbput_n(&ud->xml_attr_value, (char *) s, length);
+    agxbput_n(&ud->xml_attr_value, s, length);
 }
 
 Agraph_t *gxl_to_gv(FILE * gxlFile)
@@ -679,6 +700,11 @@ Agraph_t *gxl_to_gv(FILE * gxlFile)
     userdata_t *udata = genUserdata();
     XML_Parser parser = XML_ParserCreate(NULL);
 
+    if (udata == NULL) {
+	fprintf(stderr, "out of memory\n");
+	exit(1);
+    }
+
     XML_SetUserData(parser, udata);
     XML_SetElementHandler(parser, startElementHandler, endElementHandler);
     XML_SetCharacterDataHandler(parser, characterDataHandler);
