@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 /*
@@ -18,12 +15,12 @@
  * single dir support for pathaccess()
  */
 
-#include <ast.h>
+#include <ast/ast.h>
 
-char *pathcat(char *path, register const char *dirs, int sep,
-	      const char *a, register const char *b)
+char *pathcat(char *path, const char *dirs, int sep,
+	      const char *a, const char *b)
 {
-    register char *s;
+    char *s;
 
     s = path;
     while (*dirs && *dirs != sep)
