@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,10 +5,12 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#include	<cghdr.h>
+#include	<cgraph/cghdr.h>
+#include	<cgraph/unreachable.h>
+#include	<stddef.h>
 
 /*
  * dynamic attributes
@@ -27,15 +26,17 @@ Dtdisc_t AgDataDictDisc = {
     (int) offsetof(Agsym_t, name),	/* use symbol name as key */
     -1,
     (int) offsetof(Agsym_t, link),
-    NIL(Dtmake_f),
+    NULL,
     freesym,
-    NIL(Dtcompar_f),
-    NIL(Dthash_f)
+    NULL,
+    NULL,
+    NULL,
+    NULL,
 };
 
 static char DataDictName[] = "_AG_datadict";
 static void init_all_attrs(Agraph_t * g);
-static Agdesc_t ProtoDesc = { 1, 0, 1, 0, 1, 1 };
+static Agdesc_t ProtoDesc = { 1, 0, 1, 0, 1, 1, 0, 0 };
 static Agraph_t *ProtoGraph;
 
 Agdatadict_t *agdatadict(Agraph_t * g, int cflag)
@@ -49,7 +50,7 @@ Agdatadict_t *agdatadict(Agraph_t * g, int cflag)
     return rv;
 }
 
-Dict_t *agdictof(Agraph_t * g, int kind)
+static Dict_t *agdictof(Agraph_t * g, int kind)
 {
     Agdatadict_t *dd;
     Dict_t *dict;
@@ -69,18 +70,18 @@ Dict_t *agdictof(Agraph_t * g, int kind)
 	    break;
 	default:
 	    agerr(AGERR,"agdictof: unknown kind %d\n", kind);
-	    dict = NIL(Dict_t *);
+	    dict = NULL;
 	    break;
     } else
-	dict = NIL(Dict_t *);
+	dict = NULL;
     return dict;
 }
 
-Agsym_t *agnewsym(Agraph_t * g, char *name, char *value, int id, int kind)
+static Agsym_t *agnewsym(Agraph_t * g, char *name, char *value, int id, int kind)
 {
     Agsym_t *sym;
     sym = agalloc(g, sizeof(Agsym_t));
-    sym->kind = kind;
+    sym->kind = (unsigned char) kind;
     sym->name = agstrdup(g, name);
     sym->defval = agstrdup(g, value);
     sym->id = id;
@@ -92,8 +93,7 @@ static void agcopydict(Dict_t * src, Dict_t * dest, Agraph_t * g, int kind)
     Agsym_t *sym, *newsym;
 
     assert(dtsize(dest) == 0);
-    for (sym = (Agsym_t *) dtfirst(src); sym;
-	 sym = (Agsym_t *) dtnext(src, sym)) {
+    for (sym = dtfirst(src); sym; sym = dtnext(src, sym)) {
 	newsym = agnewsym(g, sym->name, sym->defval, sym->id, kind);
 	newsym->print = sym->print;
 	newsym->fixed = sym->fixed;
@@ -106,8 +106,7 @@ static Agdatadict_t *agmakedatadict(Agraph_t * g)
     Agraph_t *par;
     Agdatadict_t *parent_dd, *dd;
 
-    dd = (Agdatadict_t *) agbindrec(g, DataDictName, sizeof(Agdatadict_t),
-				    FALSE);
+    dd = agbindrec(g, DataDictName, sizeof(Agdatadict_t), FALSE);
     dd->dict.n = agdtopen(g, &AgDataDictDisc, Dttree);
     dd->dict.e = agdtopen(g, &AgDataDictDisc, Dttree);
     dd->dict.g = agdtopen(g, &AgDataDictDisc, Dttree);
@@ -118,7 +117,7 @@ static Agdatadict_t *agmakedatadict(Agraph_t * g)
 	dtview(dd->dict.e, parent_dd->dict.e);
 	dtview(dd->dict.g, parent_dd->dict.g);
     } else {
-	if (ProtoGraph && (g != ProtoGraph)) {
+	if (ProtoGraph && g != ProtoGraph) {
 	    /* it's not ok to dtview here for several reasons. the proto
 	       graph could change, and the sym indices don't match */
 	    parent_dd = agdatadict(ProtoGraph, FALSE);
@@ -131,20 +130,20 @@ static Agdatadict_t *agmakedatadict(Agraph_t * g)
 }
 
 /* look up an attribute with possible viewpathing */
-Agsym_t *agdictsym(Dict_t * dict, char *name)
+static Agsym_t *agdictsym(Dict_t * dict, char *name)
 {
     Agsym_t key;
-    key.name = (char *) name;
-    return (Agsym_t *) dtsearch(dict, &key);
+    key.name = name;
+    return dtsearch(dict, &key);
 }
 
 /* look up attribute in local dictionary with no view pathing */
-Agsym_t *aglocaldictsym(Dict_t * dict, char *name)
+static Agsym_t *aglocaldictsym(Dict_t * dict, char *name)
 {
     Agsym_t *rv;
     Dict_t *view;
 
-    view = dtview(dict, NIL(Dict_t *));
+    view = dtview(dict, NULL);
     rv = agdictsym(dict, name);
     dtview(dict, view);
     return rv;
@@ -156,11 +155,11 @@ Agsym_t *agattrsym(void *obj, char *name)
     Agsym_t *rv;
     char *arg = name;
 
-    data = agattrrec((Agobj_t *) obj);
+    data = agattrrec(obj);
     if (data)
 	rv = agdictsym(data->dict, arg);
     else
-	rv = NILsym;
+	rv = NULL;
     return rv;
 }
 
@@ -187,7 +186,7 @@ static Agrec_t *agmakeattrs(Agraph_t * context, void *obj)
     rec = agbindrec(obj, AgDataRecName, sizeof(Agattr_t), FALSE);
     datadict = agdictof(context, AGTYPE(obj));
     assert(datadict);
-    if (rec->dict == NIL(Dict_t *)) {
+    if (rec->dict == NULL) {
 	rec->dict = agdictof(agroot(context), AGTYPE(obj));
 	/* don't malloc(0) */
 	sz = topdictsize(obj);
@@ -195,8 +194,7 @@ static Agrec_t *agmakeattrs(Agraph_t * context, void *obj)
 	    sz = MINATTR;
 	rec->str = agalloc(agraphof(obj), (size_t) sz * sizeof(char *));
 	/* doesn't call agxset() so no obj-modified callbacks occur */
-	for (sym = (Agsym_t *) dtfirst(datadict); sym;
-	     sym = (Agsym_t *) dtnext(datadict, sym))
+	for (sym = dtfirst(datadict); sym; sym = dtnext(datadict, sym))
 	    rec->str[sym->id] = agstrdup(agraphof(obj), sym->defval);
     } else {
 	assert(rec->dict == datadict);
@@ -221,7 +219,7 @@ static void freesym(Dict_t * d, void * obj, Dtdisc_t * disc)
     Agsym_t *sym;
 
     NOTUSED(d);
-    sym = (Agsym_t *) obj;
+    sym = obj;
     NOTUSED(disc);
     agstrfree(Ag_G_global, sym->name);
     agstrfree(Ag_G_global, sym->defval);
@@ -239,22 +237,20 @@ static void addattr(Agraph_t * g, Agobj_t * obj, Agsym_t * sym)
     Agattr_t *attr;
 
     attr = (Agattr_t *) agattrrec(obj);
-    assert(attr != NIL(Agattr_t *));
+    assert(attr != NULL);
     if (sym->id >= MINATTR)
 	attr->str = (char **) AGDISC(g, mem)->resize(AGCLOS(g, mem),
 						     attr->str,
-						     sym->id *
+						     (size_t) sym->id *
 						     sizeof(char *),
-						     (sym->id +
+						     ((size_t) sym->id +
 						      1) * sizeof(char *));
     attr->str[sym->id] = agstrdup(g, sym->defval);
-    /* agmethod_upd(g,obj,sym);  JCE and GN didn't like this. */
 }
 
 
 static Agsym_t *setattr(Agraph_t * g, int kind, char *name, char *value)
 {
-    Agdatadict_t *dd;
     Dict_t *ldict, *rdict;
     Agsym_t *lsym, *psym, *rsym, *rv;
     Agraph_t *root;
@@ -263,7 +259,7 @@ static Agsym_t *setattr(Agraph_t * g, int kind, char *name, char *value)
 
     assert(value);
     root = agroot(g);
-    dd = agdatadict(g, TRUE);	/* force initialization of string attributes */
+    agdatadict(g, TRUE);	/* force initialization of string attributes */
     ldict = agdictof(g, kind);
     lsym = aglocaldictsym(ldict, name);
     if (lsym) {			/* update old local definition */
@@ -295,6 +291,8 @@ static Agsym_t *setattr(Agraph_t * g, int kind, char *name, char *value)
 		    for (e = agfstout(root, n); e; e = agnxtout(root, e))
 			addattr(g, (Agobj_t *) e, rsym);
 		break;
+	    default:
+		UNREACHABLE();
 	    }
 	    rv = rsym;
 	}
@@ -317,7 +315,7 @@ static Agsym_t *getattr(Agraph_t * g, int kind, char *name)
 
 /*
  * create or update an existing attribute and return its descriptor.
- * if the new value is NIL(char*), this is only a search, no update.
+ * if the new value is NULL, this is only a search, no update.
  * when a new attribute is created, existing graphs/nodes/edges
  * receive its default value.
  */
@@ -344,9 +342,9 @@ Agsym_t *agnxtattr(Agraph_t * g, int kind, Agsym_t * attr)
 
     if ((d = agdictof(g, kind))) {
 	if (attr)
-	    rv = (Agsym_t *) dtnext(d, attr);
+	    rv = dtnext(d, attr);
 	else
-	    rv = (Agsym_t *) dtfirst(d);
+	    rv = dtfirst(d);
     } else
 	rv = 0;
     return rv;
@@ -356,15 +354,13 @@ Agsym_t *agnxtattr(Agraph_t * g, int kind, Agsym_t * attr)
 
 void agraphattr_init(Agraph_t * g)
 {
-    /* Agdatadict_t *dd; */
-    /* Agrec_t                      *attr; */
     Agraph_t *context;
 
     g->desc.has_attrs = 1;
-    /* dd = */ agmakedatadict(g);
+    agmakedatadict(g);
     if (!(context = agparent(g)))
 	context = g;
-    /* attr = */ agmakeattrs(context, g);
+    agmakeattrs(context, g);
 }
 
 int agraphattr_delete(Agraph_t * g)
@@ -392,7 +388,7 @@ void agnodeattr_init(Agraph_t * g, Agnode_t * n)
     Agattr_t *data;
 
     data = agattrrec(n);
-    if ((!data) || (!data->dict))
+    if (!data || !data->dict)
 	(void) agmakeattrs(g, n);
 }
 
@@ -411,7 +407,7 @@ void agedgeattr_init(Agraph_t * g, Agedge_t * e)
     Agattr_t *data;
 
     data = agattrrec(e);
-    if ((!data) || (!data->dict))
+    if (!data || !data->dict)
 	(void) agmakeattrs(g, e);
 }
 
@@ -432,11 +428,11 @@ char *agget(void *obj, char *name)
     char *rv;
 
     sym = agattrsym(obj, name);
-    if (sym == NILsym)
+    if (sym == NULL)
 	rv = 0;			/* note was "", but this provides more info */
     else {
-	data = agattrrec((Agobj_t *) obj);
-	rv = (char *) (data->str[sym->id]);
+	data = agattrrec(obj);
+	rv = (char *) data->str[sym->id];
     }
     return rv;
 }
@@ -446,8 +442,8 @@ char *agxget(void *obj, Agsym_t * sym)
     Agattr_t *data;
     char *rv;
 
-    data = agattrrec((Agobj_t *) obj);
-    assert((sym->id >= 0) && (sym->id < topdictsize(obj)));
+    data = agattrrec(obj);
+    assert(sym->id >= 0 && sym->id < topdictsize(obj));
     rv = (char *) (data->str[sym->id]);
     return rv;
 }
@@ -458,7 +454,7 @@ int agset(void *obj, char *name, char *value)
     int rv;
 
     sym = agattrsym(obj, name);
-    if (sym == NILsym)
+    if (sym == NULL)
 	rv = FAILURE;
     else
 	rv = agxset(obj, sym, value);
@@ -473,9 +469,9 @@ int agxset(void *obj, Agsym_t * sym, char *value)
     Agsym_t *lsym;
 
     g = agraphof(obj);
-    hdr = (Agobj_t *) obj;
+    hdr = obj;
     data = agattrrec(hdr);
-    assert((sym->id >= 0) && (sym->id < topdictsize(obj)));
+    assert(sym->id >= 0 && sym->id < topdictsize(obj));
     agstrfree(g, data->str[sym->id]);
     data->str[sym->id] = agstrdup(g, value);
     if (hdr->tag.objtype == AGRAPH) {
@@ -518,7 +514,7 @@ static void init_all_attrs(Agraph_t * g)
 
     root = agroot(g);
     agapply(root, (Agobj_t *) root, (agobjfn_t) agraphattr_init,
-	    NIL(Agdisc_t *), TRUE);
+	    NULL, TRUE);
     for (n = agfstnode(root); n; n = agnxtnode(root, n)) {
 	agnodeattr_init(g, n);
 	for (e = agfstout(root, n); e; e = agnxtout(root, e)) {
