@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,17 +5,13 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 #ifndef ATT_GRAPHPVT_H
 #define ATT_GRAPHPVT_H 1
 #define _BLD_cgraph 1
 
-#ifndef EXTERN
-#define EXTERN extern
-#endif
-
 #ifdef _WIN32
 #   ifdef EXPORT_CGHDR
 #       define CGHDR_API __declspec(dllexport)
@@ -41,11 +34,7 @@
 #ifdef HAVE_UNISTD_H
 #include	<unistd.h>
 #endif				/* HAVE_UNISTD_H */
-#ifdef DEBUG
 #include <assert.h>
-#else
-#define assert(x)
-#endif
 #include <stdint.h>
 
 #ifndef streq
@@ -75,7 +64,7 @@ CGHDR_API int agapply(Agraph_t * g, Agobj_t * obj, agobjfn_t fn, void *arg,
 	    int preorder);
 
 	/* global variables */
-EXTERN Agraph_t *Ag_G_global;
+extern Agraph_t *Ag_G_global;
 extern char *AgDataRecName;
 
 	/* set ordering disciplines */
@@ -106,7 +95,7 @@ uint64_t agnextseq(Agraph_t * g, int objtype);
 /* dict helper functions */
 Dict_t *agdtopen(Agraph_t * g, Dtdisc_t * disc, Dtmethod_t * method);
 void agdtdisc(Agraph_t * g, Dict_t * dict, Dtdisc_t * disc);
-long agdtdelete(Agraph_t * g, Dict_t * dict, void *obj);
+int agdtdelete(Agraph_t * g, Dict_t * dict, void *obj);
 int agdtclose(Agraph_t * g, Dict_t * dict);
 void *agdictobjmem(Dict_t * dict, void * p, size_t size,
 		   Dtdisc_t * disc);
