@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,10 +5,10 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#include "cghdr.h"
+#include <cgraph/cghdr.h>
 
 static void agflatten_elist(Dict_t * d, Dtlink_t ** lptr, int flag)
 {
@@ -52,9 +49,3 @@ void agflatten(Agraph_t * g, int flag)
 	}
     }
 }
-
-void agnotflat(Agraph_t * g)
-{
-    if (g->desc.flatlock)
-	agerr(AGERR, "flat lock broken");
-}
