@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,14 +5,18 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
+#include <stdbool.h>
+#include <stddef.h>
 #include <stdio.h>		/* need sprintf() */
 #include <ctype.h>
-#include "cghdr.h"
+#include <cgraph/cghdr.h>
+#include <cgraph/strcasecmp.h>
+#include <inttypes.h>
 
-#define EMPTY(s)		((s == 0) || (s)[0] == '\0')
+#define EMPTY(s)		(((s) == 0) || (s)[0] == '\0')
 #define MAX(a,b)     ((a)>(b)?(a):(b))
 #define CHKRV(v)     {if ((v) == EOF) return EOF;}
 
@@ -43,23 +44,6 @@ static int indent(Agraph_t * g, iochan_t * ofile)
     return 0;
 }
 
-#ifndef HAVE_STRCASECMP
-
-#include <string.h>
-
-static int strcasecmp(const char *s1, const char *s2)
-{
-    while ((*s1 != '\0')
-	   && (tolower(*(unsigned char *) s1) ==
-	       tolower(*(unsigned char *) s2))) {
-	s1++;
-	s2++;
-    }
-
-    return tolower(*(unsigned char *) s1) - tolower(*(unsigned char *) s2);
-}
-#endif
-
     /* alphanumeric, '.', '-', or non-ascii; basically, chars used in unquoted ids */
 #define is_id_char(c) (isalnum(c) || ((c) == '.') || ((c) == '-') || !isascii(c))
 
@@ -72,12 +56,12 @@ static char *_agstrcanon(char *arg, char *buf)
     char *s, *p;
     unsigned char uc;
     int cnt = 0, dotcnt = 0;
-    int needs_quotes = FALSE;
+    bool needs_quotes = false;
     int maybe_num;
-    int backslash_pending = FALSE;
+    bool backslash_pending = false;
     static const char *tokenlist[]	/* must agree with scan.l */
 	= { "node", "edge", "strict", "graph", "digraph", "subgraph",
-	NIL(char *)
+	NULL
     };
     const char **tok;
 
@@ -87,32 +71,32 @@ static char *_agstrcanon(char *arg, char *buf)
     p = buf;
     *p++ = '\"';
     uc = *(unsigned char *) s++;
-    maybe_num = isdigit(uc) || (uc == '.') || (uc == '-');
+    maybe_num = isdigit(uc) || uc == '.' || uc == '-';
     while (uc) {
 	if (uc == '\"') {
 	    *p++ = '\\';
-	    needs_quotes = TRUE;
+	    needs_quotes = true;
 	} 
 	else if (maybe_num) {
 	    if (uc == '-') {
 		if (cnt) {
 		    maybe_num = FALSE;
-		    needs_quotes = TRUE;
+		    needs_quotes = true;
 		}
 	    }
 	    else if (uc == '.') {
 		if (dotcnt++) {
 		    maybe_num = FALSE;
-		    needs_quotes = TRUE;
+		    needs_quotes = true;
 		}
 	    }
 	    else if (!isdigit(uc)) {
 		maybe_num = FALSE;
-		needs_quotes = TRUE;
+		needs_quotes = true;
 	    }
 	}
 	else if (!ISALNUM(uc))
-	    needs_quotes = TRUE;
+	    needs_quotes = true;
 	*p++ = (char) uc;
 	uc = *(unsigned char *) s++;
 	cnt++;
@@ -121,27 +105,27 @@ static char *_agstrcanon(char *arg, char *buf)
  	 * id char.
 	 */
 	if (Max_outputline) {
-            if (uc && backslash_pending && !(is_id_char(p[-1]) || (p[-1] == '\\')) && is_id_char(uc)) {
+            if (uc && backslash_pending && !(is_id_char(p[-1]) || p[-1] == '\\') && is_id_char(uc)) {
         	*p++ = '\\';
         	*p++ = '\n';
-        	needs_quotes = TRUE;
-        	backslash_pending = FALSE;
+        	needs_quotes = true;
+        	backslash_pending = false;
 		cnt = 0;
             } else if (uc && (cnt >= Max_outputline)) {
-        	if (!(is_id_char(p[-1]) || (p[-1] == '\\')) && is_id_char(uc)) {
+        	if (!(is_id_char(p[-1]) || p[-1] == '\\') && is_id_char(uc)) {
 	            *p++ = '\\';
     	            *p++ = '\n';
-	            needs_quotes = TRUE;
+	            needs_quotes = true;
 		    cnt = 0;
         	} else {
-                    backslash_pending = TRUE;
+                    backslash_pending = true;
         	}
 	    }
 	}
     }
     *p++ = '\"';
     *p = '\0';
-    if (needs_quotes || ((cnt == 1) && ((*arg == '.') || (*arg == '-'))))
+    if (needs_quotes || (cnt == 1 && (*arg == '.' || *arg == '-')))
 	return buf;
 
     /* Use quotes to protect tokens (example, a node named "node") */
@@ -157,15 +141,7 @@ static char *_agstrcanon(char *arg, char *buf)
  */
 static char *agcanonhtmlstr(char *arg, char *buf)
 {
-    char *s, *p;
-
-    s = arg;
-    p = buf;
-    *p++ = '<';
-    while (*s)
-	*p++ = *s++;
-    *p++ = '>';
-    *p = '\0';
+    sprintf(buf, "<%s>", arg);
     return buf;
 }
 
@@ -190,10 +166,7 @@ static char *getoutputbuffer(char *str)
 
     req = MAX(2 * strlen(str) + 2, BUFSIZ);
     if (req > len) {
-	if (rv)
-	    rv = realloc(rv, req);
-	else
-	    rv = malloc(req);
+	rv = realloc(rv, req);
 	len = req;
     }
     return rv;
@@ -235,7 +208,18 @@ static int _write_canonstr(Agraph_t * g, iochan_t * ofile, char *str,
 
 static int write_canonstr(Agraph_t * g, iochan_t * ofile, char *str)
 {
-    return _write_canonstr(g, ofile, str, TRUE);
+    char *s;
+    int r;
+
+    /* str may not have been allocated by agstrdup, so we first need to turn it
+     * into a valid refstr
+     */
+    s = agstrdup(g, str);
+
+    r = _write_canonstr(g, ofile, s, TRUE);
+
+    agstrfree(g, s);
+    return r;
 }
 
 static int write_dict(Agraph_t * g, iochan_t * ofile, char *name,
@@ -246,15 +230,14 @@ static int write_dict(Agraph_t * g, iochan_t * ofile, char *name,
     Agsym_t *sym, *psym;
 
     if (!top)
-	view = dtview(dict, NIL(Dict_t *));
+	view = dtview(dict, NULL);
     else
 	view = 0;
-    for (sym = (Agsym_t *) dtfirst(dict); sym;
-	 sym = (Agsym_t *) dtnext(dict, sym)) {
+    for (sym = dtfirst(dict); sym; sym = dtnext(dict, sym)) {
 	if (EMPTY(sym->defval) && !sym->print) {	/* try to skip empty str (default) */
-	    if (view == NIL(Dict_t *))
+	    if (view == NULL)
 		continue;	/* no parent */
-	    psym = (Agsym_t *) dtsearch(view, sym);
+	    psym = dtsearch(view, sym);
 	    assert(psym);
 	    if (EMPTY(psym->defval) && psym->print)
 		continue;	/* also empty in parent */
@@ -299,29 +282,29 @@ static int write_dicts(Agraph_t * g, iochan_t * ofile, int top)
 static int write_hdr(Agraph_t * g, iochan_t * ofile, int top)
 {
     char *name, *sep, *kind, *strict;
-    int root = 0;
-    int hasName = 1;
+    bool root = false;
+    bool hasName = true;
 
     Attrs_not_written_flag = AGATTRWF(g);
     strict = "";
     if (NOT(top) && agparent(g))
 	kind = "sub";
     else {
-	root = 1;
+	root = true;
 	if (g->desc.directed)
 	    kind = "di";
 	else
 	    kind = "";
 	if (agisstrict(g))
 	    strict = "strict ";
-	Tailport = agattr(g, AGEDGE, TAILPORT_ID, NIL(char *));
-	Headport = agattr(g, AGEDGE, HEADPORT_ID, NIL(char *));
+	Tailport = agattr(g, AGEDGE, TAILPORT_ID, NULL);
+	Headport = agattr(g, AGEDGE, HEADPORT_ID, NULL);
     }
     name = agnameof(g);
     sep = " ";
     if (!name || name[0] == LOCALNAMEPREFIX) {
 	sep = name = "";
-	hasName = 0;
+	hasName = false;
     }
     CHKRV(indent(g, ofile));
     CHKRV(ioput(g, ofile, strict));
@@ -350,7 +333,7 @@ static int write_trl(Agraph_t * g, iochan_t * ofile)
     return 0;
 }
 
-static int irrelevant_subgraph(Agraph_t * g)
+static bool irrelevant_subgraph(Agraph_t * g)
 {
     int i, n;
     Agattr_t *sdata, *pdata, *rdata;
@@ -360,24 +343,24 @@ static int irrelevant_subgraph(Agraph_t * g)
 
     name = agnameof(g);
     if (name && name[0] != LOCALNAMEPREFIX)
-	return FALSE;
+	return false;
     if ((sdata = agattrrec(g)) && (pdata = agattrrec(agparent(g)))) {
 	rdata = agattrrec(agroot(g));
 	n = dtsize(rdata->dict);
 	for (i = 0; i < n; i++)
 	    if (sdata->str[i] && pdata->str[i]
 		&& strcmp(sdata->str[i], pdata->str[i]))
-		return FALSE;
+		return false;
     }
     dd = agdatadict(g, FALSE);
     if (!dd)
-	return TRUE;
-    if ((dtsize(dd->dict.n) > 0) || (dtsize(dd->dict.e) > 0))
-	return FALSE;
-    return TRUE;
+	return true;
+    if (dtsize(dd->dict.n) > 0 || dtsize(dd->dict.e) > 0)
+	return false;
+    return true;
 }
 
-int node_in_subg(Agraph_t * g, Agnode_t * n)
+static bool node_in_subg(Agraph_t * g, Agnode_t * n)
 {
     Agraph_t *subg;
 
@@ -385,44 +368,42 @@ int node_in_subg(Agraph_t * g, Agnode_t * n)
 	if (irrelevant_subgraph(subg))
 	    continue;
 	if (agsubnode(subg, n, FALSE))
-	    return TRUE;
+	    return true;
     }
-    return FALSE;
+    return false;
 }
 
-static int has_no_edges(Agraph_t * g, Agnode_t * n)
+static bool has_no_edges(Agraph_t * g, Agnode_t * n)
 {
-    return ((agfstin(g, n) == NIL(Agedge_t *))
-	    && (agfstout(g, n) == NIL(Agedge_t *)));
+    return agfstin(g, n) == NULL && agfstout(g, n) == NULL;
 }
 
-static int has_no_predecessor_below(Agraph_t * g, Agnode_t * n,
+static bool has_no_predecessor_below(Agraph_t * g, Agnode_t * n,
 				    uint64_t val)
 {
     Agedge_t *e;
 
     if (AGSEQ(n) < val)
-	return FALSE;
+	return false;
     for (e = agfstin(g, n); e; e = agnxtin(g, e))
 	if (AGSEQ(e->node) < val)
-	    return FALSE;
-    return TRUE;
+	    return false;
+    return true;
 }
 
-static int not_default_attrs(Agraph_t * g, Agnode_t * n)
+static bool not_default_attrs(Agraph_t * g, Agnode_t * n)
 {
     Agattr_t *data;
     Agsym_t *sym;
 
     NOTUSED(g);
     if ((data = agattrrec(n))) {
-	for (sym = (Agsym_t *) dtfirst(data->dict); sym;
-	     sym = (Agsym_t *) dtnext(data->dict, sym)) {
+	for (sym = dtfirst(data->dict); sym; sym = dtnext(data->dict, sym)) {
 	    if (data->str[sym->id] != sym->defval)
-		return TRUE;
+		return true;
 	}
     }
-    return FALSE;
+    return false;
 }
 
 static int write_subgs(Agraph_t * g, iochan_t * ofile)
@@ -474,7 +455,7 @@ static int write_nondefault_attrs(void *obj, iochan_t * ofile,
     int cnt = 0;
     int rv;
 
-    if ((AGTYPE(obj) == AGINEDGE) || (AGTYPE(obj) == AGOUTEDGE)) {
+    if (AGTYPE(obj) == AGINEDGE || AGTYPE(obj) == AGOUTEDGE) {
 	CHKRV(rv = write_edge_name(obj, ofile, FALSE));
 	if (rv)
 	    cnt++;
@@ -482,12 +463,11 @@ static int write_nondefault_attrs(void *obj, iochan_t * ofile,
     data = agattrrec(obj);
     g = agraphof(obj);
     if (data)
-	for (sym = (Agsym_t *) dtfirst(defdict); sym;
-	     sym = (Agsym_t *) dtnext(defdict, sym)) {
-	    if ((AGTYPE(obj) == AGINEDGE) || (AGTYPE(obj) == AGOUTEDGE)) {
-		if (Tailport && (sym->id == Tailport->id))
+	for (sym = dtfirst(defdict); sym; sym = dtnext(defdict, sym)) {
+	    if (AGTYPE(obj) == AGINEDGE || AGTYPE(obj) == AGOUTEDGE) {
+		if (Tailport && sym->id == Tailport->id)
 		    continue;
-		if (Headport && (sym->id == Headport->id))
+		if (Headport && sym->id == Headport->id)
 		    continue;
 	    }
 	    if (data->str[sym->id] != sym->defval) {
@@ -513,7 +493,7 @@ static int write_nondefault_attrs(void *obj, iochan_t * ofile,
 
 static int write_nodename(Agnode_t * n, iochan_t * ofile)
 {
-    char *name, buf[20];
+    char *name;
     Agraph_t *g;
 
     name = agnameof(n);
@@ -521,7 +501,8 @@ static int write_nodename(Agnode_t * n, iochan_t * ofile)
     if (name) {
 	CHKRV(write_canonstr(g, ofile, name));
     } else {
-	sprintf(buf, "_%ld_SUSPECT", AGID(n));	/* could be deadly wrong */
+	char buf[sizeof("__SUSPECT") + 20];
+	snprintf(buf, sizeof(buf), "_%" PRIu64 "_SUSPECT", AGID(n));	/* could be deadly wrong */
 	CHKRV(ioput(g, ofile, buf));
     }
     return 0;
@@ -529,7 +510,7 @@ static int write_nodename(Agnode_t * n, iochan_t * ofile)
 
 static int attrs_written(void *obj)
 {
-    return (AGATTRWF((Agobj_t *) obj));
+    return AGATTRWF(obj);
 }
 
 static int write_node(Agnode_t * n, iochan_t * ofile, Dict_t * d)
@@ -548,14 +529,14 @@ static int write_node(Agnode_t * n, iochan_t * ofile, Dict_t * d)
  * a subgraph or one of its predecessors, and if it is a singleton
  * or has non-default attributes.
  */
-static int write_node_test(Agraph_t * g, Agnode_t * n,
+static bool write_node_test(Agraph_t * g, Agnode_t * n,
 			   uint64_t pred_id)
 {
-    if (NOT(node_in_subg(g, n)) && has_no_predecessor_below(g, n, pred_id)) {
+    if (!node_in_subg(g, n) && has_no_predecessor_below(g, n, pred_id)) {
 	if (has_no_edges(g, n) || not_default_attrs(g, n))
-	    return TRUE;
+	    return true;
     }
-    return FALSE;
+    return false;
 }
 
 static int write_port(Agedge_t * e, iochan_t * ofile, Agsym_t * port)
@@ -629,9 +610,6 @@ static int write_body(Agraph_t * g, iochan_t * ofile)
     Agnode_t *n, *prev;
     Agedge_t *e;
     Agdatadict_t *dd;
-    /* int                  has_attr; */
-
-    /* has_attr = (agattrrec(g) != NIL(Agattr_t*)); */
 
     CHKRV(write_subgs(g, ofile));
     dd = agdatadict(g, FALSE);
@@ -640,8 +618,7 @@ static int write_body(Agraph_t * g, iochan_t * ofile)
 	    CHKRV(write_node(n, ofile, dd ? dd->dict.n : 0));
 	prev = n;
 	for (e = agfstout(g, n); e; e = agnxtout(g, e)) {
-	    if ((prev != aghead(e))
-		&& write_node_test(g, aghead(e), AGSEQ(n))) {
+	    if (prev != aghead(e) && write_node_test(g, aghead(e), AGSEQ(n))) {
 		CHKRV(write_node(aghead(e), ofile, dd ? dd->dict.n : 0));
 		prev = aghead(e);
 	    }
@@ -653,7 +630,7 @@ static int write_body(Agraph_t * g, iochan_t * ofile)
     return 0;
 }
 
-static void set_attrwf(Agraph_t * g, int toplevel, int value)
+static void set_attrwf(Agraph_t * g, bool toplevel, bool value)
 {
     Agraph_t *subg;
     Agnode_t *n;
@@ -661,7 +638,7 @@ static void set_attrwf(Agraph_t * g, int toplevel, int value)
 
     AGATTRWF(g) = value;
     for (subg = agfstsubg(g); subg; subg = agnxtsubg(subg)) {
-	set_attrwf(subg, FALSE, value);
+	set_attrwf(subg, false, value);
     }
     if (toplevel) {
 	for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
@@ -682,10 +659,10 @@ int agwrite(Agraph_t * g, void *ofile)
     Level = 0;			/* re-initialize tab level */
     if ((s = agget(g, "linelength")) && isdigit(*s)) {
 	len = (int)strtol(s, (char **)NULL, 10);
-	if ((len == 0) || (len >= MIN_OUTPUTLINE))
+	if (len == 0 || len >= MIN_OUTPUTLINE)
 	    Max_outputline = len;
     }
-    set_attrwf(g, TRUE, FALSE);
+    set_attrwf(g, true, false);
     CHKRV(write_hdr(g, ofile, TRUE));
     CHKRV(write_body(g, ofile));
     CHKRV(write_trl(g, ofile));
