@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,11 +5,12 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 
-#include "render.h"
+#include <common/render.h>
+#include <math.h>
 
 #define EPSILON .0001
 
@@ -211,10 +209,21 @@ void arrow_flags(Agedge_t * e, int *sflag, int *eflag)
 	    }
 	}
     }
-    if (E_arrowhead && (*eflag == ARR_TYPE_NORM) && ((attr = agxget(e, E_arrowhead)))[0])
-	arrow_match_name(attr, eflag);
-    if (E_arrowtail && (*sflag == ARR_TYPE_NORM) && ((attr = agxget(e, E_arrowtail)))[0])
-	arrow_match_name(attr, sflag);
+    if (*eflag == ARR_TYPE_NORM) {
+	/* we cannot use the pre-constructed E_arrowhead here because the order in
+	 * which edge attributes appear and are thus parsed into a dictionary mean
+	 * E_arrowhead->id potentially points at a stale attribute value entry
+	 */
+	Agsym_t *arrowhead = agfindedgeattr(agraphof(e), "arrowhead");
+	if (arrowhead != NULL && ((attr = agxget(e, arrowhead)))[0])
+		arrow_match_name(attr, eflag);
+    }
+    if (*sflag == ARR_TYPE_NORM) {
+	/* similar to above, we cannot use E_arrowtail here */
+	Agsym_t *arrowtail = agfindedgeattr(agraphof(e), "arrowtail");
+	if (arrowtail != NULL && ((attr = agxget(e, arrowtail)))[0])
+		arrow_match_name(attr, sflag);
+    }
     if (ED_conc_opp_flag(e)) {
 	edge_t *f;
 	int s0, e0;
@@ -612,7 +621,7 @@ static void arrow_type_dot(GVJ_t * job, pointf p, pointf u, double arrowsize, do
     double r;
     pointf AF[2];
 
-    r = sqrt(u.x * u.x + u.y * u.y) / 2.;
+    r = hypot(u.x, u.y) / 2.;
     AF[0].x = p.x + u.x / 2. - r;
     AF[0].y = p.y + u.y / 2. - r;
     AF[1].x = p.x + u.x / 2. + r;
@@ -699,7 +708,7 @@ boxf arrow_bb(pointf p, pointf u, double arrowsize, int flag)
     u.x -= p.x;
     u.y -= p.y;
     /* the EPSILONs are to keep this stable as length of u approaches 0.0 */
-    s = ARROW_LENGTH * arrowsize / (sqrt(u.x * u.x + u.y * u.y) + EPSILON);
+    s = ARROW_LENGTH * arrowsize / (hypot(u.x, u.y) + EPSILON);
     u.x += (u.x >= 0.0) ? EPSILON : -EPSILON;
     u.y += (u.y >= 0.0) ? EPSILON : -EPSILON;
     u.x *= s;
@@ -746,7 +755,7 @@ void arrow_gen(GVJ_t * job, emit_state_t emit_state, pointf p, pointf u, double
     u.x -= p.x;
     u.y -= p.y;
     /* the EPSILONs are to keep this stable as length of u approaches 0.0 */
-    s = ARROW_LENGTH / (sqrt(u.x * u.x + u.y * u.y) + EPSILON);
+    s = ARROW_LENGTH / (hypot(u.x, u.y) + EPSILON);
     u.x += (u.x >= 0.0) ? EPSILON : -EPSILON;
     u.y += (u.y >= 0.0) ? EPSILON : -EPSILON;
     u.x *= s;
