@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,35 +5,25 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 #include <stdio.h>
 
 
 #include <stdlib.h>
-#ifdef _WIN32
-#include <string.h>
-#include <ctype.h>
-#include "compat.h"
-#endif
 #include <string.h>
 #include <ctype.h>
 
-#include "arith.h"
-#include "color.h"
-#include "colorprocs.h"
-#include "colortbl.h"
-#include "memory.h"
+#include <common/arith.h>
+#include <common/color.h>
+#include <common/colorprocs.h>
+#include <common/colortbl.h>
+#include <common/memory.h>
+#include <cgraph/strcasecmp.h>
 
 static char* colorscheme;
 
-#ifdef _MSC_VER
-extern int strcasecmp(const char *s1, const char *s2);
-extern int strncasecmp(const char *s1, const char *s2, unsigned int n);
-#endif
-
-
 static void hsv2rgb(double h, double s, double v,
 			double *r, double *g, double *b)
 {
@@ -139,7 +126,7 @@ static void rgb2cmyk(double r, double g, double b, double *c, double *m,
 
 static int colorcmpf(const void *p0, const void *p1)
 {
-    return strcasecmp(((hsvrgbacolor_t *) p0)->name, ((hsvrgbacolor_t *) p1)->name);
+    return strcasecmp(((const hsvrgbacolor_t *) p0)->name, ((const hsvrgbacolor_t *) p1)->name);
 }
 
 char *canontoken(char *str)
@@ -520,20 +507,22 @@ int colorCvt(gvcolor_t *ocolor, gvcolor_t *ncolor)
     s = buf;
     switch (ocolor->type) {
     case HSVA_DOUBLE :
-	sprintf (buf, "%.03f %.03f %.03f %.03f", 
+	snprintf(buf, sizeof(buf), "%.03f %.03f %.03f %.03f",
 	    ocolor->u.HSVA[0], ocolor->u.HSVA[1], ocolor->u.HSVA[2], ocolor->u.HSVA[3]);
 	break;
     case RGBA_BYTE :
-	sprintf (buf, "#%02x%02x%02x%02x", 
+	snprintf(buf, sizeof(buf), "#%02x%02x%02x%02x",
 	    ocolor->u.rgba[0], ocolor->u.rgba[1], ocolor->u.rgba[2], ocolor->u.rgba[3]);
 	break;
     case RGBA_WORD:
 	rgba_wordToByte (ocolor->u.rrggbbaa, rgba);
-	sprintf (buf, "#%02x%02x%02x%02x", rgba[0], rgba[1], rgba[2], rgba[3]);
+	snprintf(buf, sizeof(buf), "#%02x%02x%02x%02x", rgba[0], rgba[1], rgba[2],
+	         rgba[3]);
 	break;
     case RGBA_DOUBLE:
 	rgba_dblToByte (ocolor->u.RGBA, rgba);
-	sprintf (buf, "#%02x%02x%02x%02x", rgba[0], rgba[1], rgba[2], rgba[3]);
+	snprintf(buf, sizeof(buf), "#%02x%02x%02x%02x", rgba[0], rgba[1], rgba[2],
+	         rgba[3]);
 	break;
     case COLOR_STRING:
 	s = ocolor->u.string;
