@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,16 +5,18 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 
-#include "render.h"
-#include "htmltable.h"
+#include <common/render.h>
+#include <common/htmltable.h>
 #include "htmlparse.h"
-#include "htmllex.h"
-#include "cdt.h"
+#include <common/htmllex.h>
+#include <cdt/cdt.h>
 #include <ctype.h>
+#include <cgraph/strcasecmp.h>
+#include <limits.h>
 
 #ifdef HAVE_EXPAT
 #include <expat.h>
@@ -85,11 +84,6 @@ static void lexerror(const char *name)
 typedef int (*attrFn) (void *, char *);
 typedef int (*bcmpfn) (const void *, const void *);
 
-#define MAX_CHAR    (((unsigned char)(~0)) >> 1)
-#define MIN_CHAR    ((signed char)(~MAX_CHAR))
-#define MAX_UCHAR   ((unsigned char)(~0))
-#define MAX_USHORT  ((unsigned short)(~0))
-
 /* Mechanism for automatically processing attributes */
 typedef struct {
     char *name;			/* attribute name */
@@ -170,19 +164,11 @@ static int portfn(htmldata_t * p, char *v)
 static int stylefn(htmldata_t * p, char *v)
 {
     int rv = 0;
-    char c;
     char* tk;
     char* buf = strdup (v);
     for (tk = strtok (buf, DELIM); tk; tk = strtok (NULL, DELIM)) {
-	c = (char) toupper(*tk);
-	if (c == 'R') {
-	    if (!strcasecmp(tk + 1, "OUNDED")) p->style |= ROUNDED;
-	    else if (!strcasecmp(tk + 1, "ADIAL")) p->style |= RADIAL;
-	    else {
-		agerr(AGWARN, "Illegal value %s for STYLE - ignored\n", tk);
-		rv = 1;
-	    }
-	}
+	if (!strcasecmp(tk, "ROUNDED")) p->style |= ROUNDED;
+	else if (!strcasecmp(tk, "RADIAL")) p->style |= RADIAL;
 	else if(!strcasecmp(tk,"SOLID")) p->style &= ~(DOTTED|DASHED);
 	else if(!strcasecmp(tk,"INVISIBLE") || !strcasecmp(tk,"INVIS")) p->style |= INVISIBLE;
 	else if(!strcasecmp(tk,"DOTTED")) p->style |= DOTTED;
@@ -251,7 +237,7 @@ static int borderfn(htmldata_t * p, char *v)
 {
     long u;
 
-    if (doInt(v, "BORDER", 0, MAX_UCHAR, &u))
+    if (doInt(v, "BORDER", 0, UCHAR_MAX, &u))
 	return 1;
     p->border = (unsigned char) u;
     p->flags |= BORDER_SET;
@@ -262,7 +248,7 @@ static int cellpaddingfn(htmldata_t * p, char *v)
 {
     long u;
 
-    if (doInt(v, "CELLPADDING", 0, MAX_UCHAR, &u))
+    if (doInt(v, "CELLPADDING", 0, UCHAR_MAX, &u))
 	return 1;
     p->pad = (unsigned char) u;
     p->flags |= PAD_SET;
@@ -273,7 +259,7 @@ static int cellspacingfn(htmldata_t * p, char *v)
 {
     long u;
 
-    if (doInt(v, "CELLSPACING", MIN_CHAR, MAX_CHAR, &u))
+    if (doInt(v, "CELLSPACING", SCHAR_MIN, SCHAR_MAX, &u))
 	return 1;
     p->space = (signed char) u;
     p->flags |= SPACE_SET;
@@ -284,7 +270,7 @@ static int cellborderfn(htmltbl_t * p, char *v)
 {
     long u;
 
-    if (doInt(v, "CELLSBORDER", 0, MAX_CHAR, &u))
+    if (doInt(v, "CELLSBORDER", 0, SCHAR_MAX, &u))
 	return 1;
     p->cb = (unsigned char) u;
     return 0;
@@ -313,10 +299,9 @@ static int rowsfn(htmltbl_t * p, char *v)
 static int fixedsizefn(htmldata_t * p, char *v)
 {
     int rv = 0;
-    char c = (char) toupper(*(unsigned char *) v);
-    if ((c == 'T') && !strcasecmp(v + 1, "RUE"))
+    if (!strcasecmp(v, "TRUE"))
 	p->flags |= FIXED_FLAG;
-    else if ((c != 'F') || strcasecmp(v + 1, "ALSE")) {
+    else if (strcasecmp(v, "FALSE")) {
 	agerr(AGWARN, "Illegal value %s for FIXEDSIZE - ignored\n", v);
 	rv = 1;
     }
@@ -326,12 +311,11 @@ static int fixedsizefn(htmldata_t * p, char *v)
 static int valignfn(htmldata_t * p, char *v)
 {
     int rv = 0;
-    char c = (char) toupper(*v);
-    if ((c == 'B') && !strcasecmp(v + 1, "OTTOM"))
+    if (!strcasecmp(v, "BOTTOM"))
 	p->flags |= VALIGN_BOTTOM;
-    else if ((c == 'T') && !strcasecmp(v + 1, "OP"))
+    else if (!strcasecmp(v, "TOP"))
 	p->flags |= VALIGN_TOP;
-    else if ((c != 'M') || strcasecmp(v + 1, "IDDLE")) {
+    else if (strcasecmp(v, "MIDDLE")) {
 	agerr(AGWARN, "Illegal value %s for VALIGN - ignored\n", v);
 	rv = 1;
     }
@@ -341,12 +325,11 @@ static int valignfn(htmldata_t * p, char *v)
 static int halignfn(htmldata_t * p, char *v)
 {
     int rv = 0;
-    char c = (char) toupper(*v);
-    if ((c == 'L') && !strcasecmp(v + 1, "EFT"))
+    if (!strcasecmp(v, "LEFT"))
 	p->flags |= HALIGN_LEFT;
-    else if ((c == 'R') && !strcasecmp(v + 1, "IGHT"))
+    else if (!strcasecmp(v, "RIGHT"))
 	p->flags |= HALIGN_RIGHT;
-    else if ((c != 'C') || strcasecmp(v + 1, "ENTER")) {
+    else if (strcasecmp(v, "CENTER")) {
 	agerr(AGWARN, "Illegal value %s for ALIGN - ignored\n", v);
 	rv = 1;
     }
@@ -356,14 +339,13 @@ static int halignfn(htmldata_t * p, char *v)
 static int cell_halignfn(htmldata_t * p, char *v)
 {
     int rv = 0;
-    char c = (char) toupper(*v);
-    if ((c == 'L') && !strcasecmp(v + 1, "EFT"))
+    if (!strcasecmp(v, "LEFT"))
 	p->flags |= HALIGN_LEFT;
-    else if ((c == 'R') && !strcasecmp(v + 1, "IGHT"))
+    else if (!strcasecmp(v, "RIGHT"))
 	p->flags |= HALIGN_RIGHT;
-    else if ((c == 'T') && !strcasecmp(v + 1, "EXT"))
+    else if (!strcasecmp(v, "TEXT"))
 	p->flags |= HALIGN_TEXT;
-    else if ((c != 'C') || strcasecmp(v + 1, "ENTER"))
+    else if (strcasecmp(v, "CENTER"))
 	rv = 1;
     if (rv)
 	agerr(AGWARN, "Illegal value %s for ALIGN in TD - ignored\n", v);
@@ -373,12 +355,11 @@ static int cell_halignfn(htmldata_t * p, char *v)
 static int balignfn(htmldata_t * p, char *v)
 {
     int rv = 0;
-    char c = (char) toupper(*v);
-    if ((c == 'L') && !strcasecmp(v + 1, "EFT"))
+    if (!strcasecmp(v, "LEFT"))
 	p->flags |= BALIGN_LEFT;
-    else if ((c == 'R') && !strcasecmp(v + 1, "IGHT"))
+    else if (!strcasecmp(v, "RIGHT"))
 	p->flags |= BALIGN_RIGHT;
-    else if ((c != 'C') || strcasecmp(v + 1, "ENTER"))
+    else if (strcasecmp(v, "CENTER"))
 	rv = 1;
     if (rv)
 	agerr(AGWARN, "Illegal value %s for BALIGN in TD - ignored\n", v);
@@ -389,7 +370,7 @@ static int heightfn(htmldata_t * p, char *v)
 {
     long u;
 
-    if (doInt(v, "HEIGHT", 0, MAX_USHORT, &u))
+    if (doInt(v, "HEIGHT", 0, USHRT_MAX, &u))
 	return 1;
     p->height = (unsigned short) u;
     return 0;
@@ -399,7 +380,7 @@ static int widthfn(htmldata_t * p, char *v)
 {
     long u;
 
-    if (doInt(v, "WIDTH", 0, MAX_USHORT, &u))
+    if (doInt(v, "WIDTH", 0, USHRT_MAX, &u))
 	return 1;
     p->width = (unsigned short) u;
     return 0;
@@ -409,7 +390,7 @@ static int rowspanfn(htmlcell_t * p, char *v)
 {
     long u;
 
-    if (doInt(v, "ROWSPAN", 0, MAX_USHORT, &u))
+    if (doInt(v, "ROWSPAN", 0, USHRT_MAX, &u))
 	return 1;
     if (u == 0) {
 	agerr(AGWARN, "ROWSPAN value cannot be 0 - ignored\n");
@@ -423,7 +404,7 @@ static int colspanfn(htmlcell_t * p, char *v)
 {
     long u;
 
-    if (doInt(v, "COLSPAN", 0, MAX_USHORT, &u))
+    if (doInt(v, "COLSPAN", 0, USHRT_MAX, &u))
 	return 1;
     if (u == 0) {
 	agerr(AGWARN, "COLSPAN value cannot be 0 - ignored\n");
@@ -449,7 +430,7 @@ static int ptsizefn(textfont_t * p, char *v)
 {
     long u;
 
-    if (doInt(v, "POINT-SIZE", 0, MAX_UCHAR, &u))
+    if (doInt(v, "POINT-SIZE", 0, UCHAR_MAX, &u))
 	return 1;
     p->size = (double) u;
     return 0;
@@ -470,12 +451,11 @@ static int scalefn(htmlimg_t * p, char *v)
 static int alignfn(int *p, char *v)
 {
     int rv = 0;
-    char c = (char) toupper(*v);
-    if ((c == 'R') && !strcasecmp(v + 1, "IGHT"))
+    if (!strcasecmp(v, "RIGHT"))
 	*p = 'r';
-    else if ((c == 'L') || !strcasecmp(v + 1, "EFT"))
+    else if (!strcasecmp(v, "LEFT"))
 	*p = 'l';
-    else if ((c == 'C') || strcasecmp(v + 1, "ENTER")) 
+    else if (!strcasecmp(v, "CENTER"))
 	*p = 'n';
     else {
 	agerr(AGWARN, "Illegal value %s for ALIGN - ignored\n", v);
@@ -637,8 +617,7 @@ static void startElement(void *user, const char *name, char **atts)
 	htmllval.tbl = mkTbl(atts);
 	state.inCell = 0;
 	state.tok = T_table;
-    } else if ((strcasecmp(name, "TR") == 0)
-	       || (strcasecmp(name, "TH") == 0)) {
+    } else if (strcasecmp(name, "TR") == 0 || strcasecmp(name, "TH") == 0) {
 	state.inCell = 0;
 	state.tok = T_row;
     } else if (strcasecmp(name, "TD") == 0) {
@@ -691,8 +670,7 @@ static void endElement(void *user, const char *name)
     if (strcasecmp(name, "TABLE") == 0) {
 	state.tok = T_end_table;
 	state.inCell = 1;
-    } else if ((strcasecmp(name, "TR") == 0)
-	       || (strcasecmp(name, "TH") == 0)) {
+    } else if (strcasecmp(name, "TR") == 0 || strcasecmp(name, "TH") == 0) {
 	state.tok = T_end_row;
     } else if (strcasecmp(name, "TD") == 0) {
 	state.tok = T_end_cell;
@@ -757,7 +735,7 @@ static void characterData(void *user, const char *s, int length)
 	    c = *s++;
 	    if (c >= ' ') {
 		cnt++;
-		agxbputc(state.xb, c);
+		agxbputc(state.xb, (char)c);
 	    }
 	}
 	if (cnt) state.tok = T_string;
@@ -829,7 +807,7 @@ static char *eatComment(char *p)
     s--;			/* move back to '\0' or '>' */
     if (*s) {
 	char *t = s - 2;
-	if ((t < p) || strncmp(t, "--", 2)) {
+	if (t < p || strncmp(t, "--", 2)) {
 	    agerr(AGWARN, "Unclosed comment\n");
 	    state.warn = 1;
 	}
@@ -847,10 +825,10 @@ static char *findNext(char *s, agxbuf* xb)
     char c;
 
     if (*s == '<') {
-	if ((*t == '!') && !strncmp(t + 1, "--", 2))
+	if (!strncmp(t, "!--", 3))
 	    t = eatComment(t + 3);
 	else
-	    while (*t && (*t != '>'))
+	    while (*t && *t != '>')
 		t++;
 	if (*t != '>') {
 	    agerr(AGWARN, "Label closed before end of HTML element\n");
@@ -859,8 +837,8 @@ static char *findNext(char *s, agxbuf* xb)
 	    t++;
     } else {
 	t = s;
-	while ((c = *t) && (c != '<')) {
-	    if ((c == '&') && (*(t+1) != '#')) {
+	while ((c = *t) && c != '<') {
+	    if (c == '&' && *(t+1) != '#') {
 		t = scanEntity(t + 1, xb);
 	    }
 	    else {
@@ -871,6 +849,41 @@ static char *findNext(char *s, agxbuf* xb)
     }
     return t;
 }
+
+/** guard a trailing right square bracket (]) from misinterpretation
+ *
+ * When parsing in incremental mode, expat tries to recognize malformed CDATA
+ * section terminators. See XML_TOK_TRAILING_RSQB in the expat source. As a
+ * result, when seeing text that ends in a ']' expat buffers this internally and
+ * returns truncated text for the current parse. The ']' is flushed as part of
+ * the next parsing call when expat learns it is not a CDATA section terminator.
+ *
+ * To prevent this situation from occurring, this function turns any trailing
+ * ']' into its XML escape sequence. This causes expat to realize immediately it
+ * is not part of a CDATA section terminator and flush it in the first parsing
+ * call. This has no effect on the final output, because expat handles the
+ * translation back from this escape sequence to ']'.
+ *
+ * @param xb Buffer containing content to protect
+ */
+static void protect_rsqb(agxbuf *xb) {
+
+  // if the buffer is empty, we have nothing to do
+  if (xb->buf == xb->ptr) {
+    return;
+  }
+
+  // if the buffer does not end in a ], we have nothing to do
+  if (xb->ptr[-1] != ']') {
+    return;
+  }
+
+  // rewind over the ]
+  --xb->ptr;
+
+  // write an XML-escaped version of ]
+  agxbput(xb, "&#93;");
+}
 #endif
 
 int htmllineno()
@@ -1046,6 +1059,9 @@ int htmllex()
 		len = endp - s;
 	    }
 	}
+
+	protect_rsqb(&state.lb);
+
 	state.prevtok = state.currtok;
 	state.prevtoklen = state.currtoklen;
 	state.currtok = s;
@@ -1053,7 +1069,7 @@ int htmllex()
 	if ((llen = agxblen(&state.lb)))
 	    rv = XML_Parse(state.parser, agxbuse(&state.lb),llen, 0);
 	else
-	    rv = XML_Parse(state.parser, s, len, (len ? 0 : 1));
+	    rv = XML_Parse(state.parser, s, len, len ? 0 : 1);
 	if (rv == XML_STATUS_ERROR) {
 	    if (!state.error) {
 		agerr(AGERR, "%s in line %d \n",
@@ -1067,7 +1083,7 @@ int htmllex()
 	if (endp)
 	    state.ptr = endp;
     } while (state.tok == 0);
-#if DEBUG
+#ifdef DEBUG
     printTok (state.tok);
 #endif
     return state.tok;
