@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,15 +5,19 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 #include <ctype.h>
-#include "render.h"
-#include "htmltable.h"
-#include "gvc.h"
-#include "xdot.h"
-#include "agxbuf.h"
+#include <common/render.h>
+#include <common/htmltable.h>
+#include <errno.h>
+#include <gvc/gvc.h>
+#include <xdot/xdot.h>
+#include <cgraph/agxbuf.h>
+#include <cgraph/strcasecmp.h>
+#include <stddef.h>
+#include <string.h>
 
 static char *usageFmt =
     "Usage: %s [-Vv?] [-(GNE)name=val] [-(KTlso)<val>] <dot files>\n";
@@ -298,8 +299,16 @@ int dotneato_args_initialize(GVC_t * gvc, int argc, char **argv)
 		}
 		v = gvjobs_output_langname(gvc, val);
 		if (!v) {
-		    fprintf(stderr, "Format: \"%s\" not recognized. Use one of:%s\n",
-			val, gvplugin_list(gvc, API_device, val));
+		    /* TODO: Detect empty results from gvplugin_list() and prompt to configure with '-c' */
+		    char *fmts;
+		    fprintf(stderr, "Format: \"%s\" not recognized.", val);
+		    fmts = gvplugin_list(gvc, API_device, val);
+		    if (strlen(fmts) > 1) {
+			fprintf(stderr, " Use one of:%s\n", fmts);
+		    } else {
+			/* Q: Should 'dot -c' be suggested generally or only when val = "dot"? */
+			fprintf(stderr, " No formats found.\nPerhaps \"dot -c\" needs to be run (with installer's privileges) to register the plugins?\n");
+		    }
 		    if (GvExitOnUsage) exit(1);
 		    return(2);
 		}
@@ -317,8 +326,16 @@ int dotneato_args_initialize(GVC_t * gvc, int argc, char **argv)
                         fprintf(stderr, "Perhaps \"dot -c\" needs to be run (with installer's privileges) to register the plugins?\n");
                     }
 		    else {
-                        fprintf(stderr, "Use one of:%s\n",
-				gvplugin_list(gvc, API_layout, val));
+			/* TODO: Detect empty results from gvplugin_list() and prompt to configure with '-c' */
+			/* fprintf(stderr, "Use one of:%s\n", gvplugin_list(gvc, API_layout, val)); */
+			char *lyts;
+			lyts = gvplugin_list(gvc, API_layout, val);
+			if (strlen(lyts) > 1) {
+			    fprintf(stderr, " Use one of:%s\n", lyts);
+			} else {
+			    /* Q: Should 'dot -c' be suggested generally or only when val = "dot"? */
+			    fprintf(stderr, " No layouts found.\nPerhaps \"dot -c\" needs to be run (with installer's privileges) to register the plugins?\n");
+			}
 		    }
 		    if (GvExitOnUsage) exit(1);
 		    return(2);
@@ -412,10 +429,20 @@ int dotneato_args_initialize(GVC_t * gvc, int argc, char **argv)
 	i = gvlayout_select(gvc, layout);
 	if (i == NO_SUPPORT) {
 	    fprintf(stderr, "There is no layout engine support for \"%s\"\n", layout);
-            if (streq(layout, "dot"))
+            if (streq(layout, "dot")) {
 		fprintf(stderr, "Perhaps \"dot -c\" needs to be run (with installer's privileges) to register the plugins?\n");
-	    else 
-		fprintf(stderr, "Use one of:%s\n", gvplugin_list(gvc, API_layout, ""));
+	    } else {
+		/* TODO: Detect empty results from gvplugin_list() and prompt to configure with '-c' */
+		/* fprintf(stderr, "Use one of:%s\n", gvplugin_list(gvc, API_layout, "")); */
+		char *lyts;
+		lyts = gvplugin_list(gvc, API_layout, "");
+		if (strlen(lyts) > 1) {
+                    fprintf(stderr, " Use one of:%s\n", lyts);
+		} else {
+		    /* Q: Should 'dot -c' be suggested generally or only when val = "dot"? */
+		    fprintf(stderr, " No layouts found.\nPerhaps \"dot -c\" needs to be run (with installer's privileges) to register the plugins?\n");
+		}
+	    }
 
 	    if (GvExitOnUsage) exit(1);
 	    return(2);
@@ -550,7 +577,7 @@ graph_t *gvNextInputGraph(GVC_t *gvc)
 	    }
 	    else {
 		while ((fn = gvc->input_filenames[fidx++]) && !(fp = fopen(fn, "r")))  {
-		    agerr(AGERR, "%s: can't open %s\n", gvc->common.cmdname, fn);
+		    agerr(AGERR, "%s: can't open %s: %s\n", gvc->common.cmdname, fn, strerror(errno));
 		    graphviz_errors++;
 		}
 	    }
@@ -564,7 +591,7 @@ graph_t *gvNextInputGraph(GVC_t *gvc)
 #ifdef EXPERIMENTAL_MYFGETS
 	g = agread_usergets(fp, myfgets);
 #else
-	g = agread(fp,NIL(Agdisc_t*));
+	g = agread(fp,NULL);
 #endif
 	if (g) {
 	    gvg_init(gvc, g, fn, gidx++);
@@ -854,7 +881,7 @@ void graph_cleanup(graph_t *g)
 {
     if (GD_drawing(g) && GD_drawing(g)->xdots)
 	freeXDot ((xdot*)GD_drawing(g)->xdots);
-    if (GD_drawing(g) && GD_drawing(g)->id)
+    if (GD_drawing(g))
 	free (GD_drawing(g)->id);
     free(GD_drawing(g));
     GD_drawing(g) = NULL;
@@ -907,7 +934,7 @@ void do_graph_label(graph_t * sg)
 
 	GD_has_labels(sg->root) |= GRAPH_LABEL;
 
-	GD_label(sg) = make_label((void*)sg, str, (aghtmlstr(str) ? LT_HTML : LT_NONE),
+	GD_label(sg) = make_label(sg, str, (aghtmlstr(str) ? LT_HTML : LT_NONE),
 	    late_double(sg, agfindgraphattr(sg, "fontsize"),
 			DEFAULT_FONTSIZE, MIN_FONTSIZE),
 	    late_nnstring(sg, agfindgraphattr(sg, "fontname"),
