@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 #ifndef GV_LOGIC_H
@@ -35,10 +32,6 @@ extern "C" {
 #define NOTUSED(var) (void) var
 #endif
 
-#ifndef NULL
-#define NULL (void *)0
-#endif
-
 #ifndef NIL
 #define NIL(type) ((type)0)
 #endif
