@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 #ifndef GV_MACROS_H
@@ -33,17 +30,11 @@
 #define EDGE_TYPE(g) (GD_flags(g) & (7 << 1))
 
 #ifndef streq
-#define streq(a,b)		(*(a)==*(b)&&!strcmp(a,b))
+#define streq(a,b)		(!strcmp(a,b))
 #endif
 
 #define XPAD(d) ((d).x += 4*GAP)
 #define YPAD(d) ((d).y += 2*GAP)
 #define PAD(d)  {XPAD(d); YPAD(d);}
 
-#define OTHERDIR(dir) ((dir == CCW) ? CW : CCW)
-
-#define NEXTSIDE(side, dir) ((dir == CCW) ? \
-		((side & 0x8) ? BOTTOM : (side << 1)) : \
-		((side & 0x1) ? LEFT : (side >> 1)))
-
 #endif
