@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,12 +5,12 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 
-#include "render.h"
-#include "xlabels.h"
+#include <common/render.h>
+#include <label/xlabels.h>
 
 static int Rankdir;
 static boolean Flip;
@@ -413,7 +410,6 @@ static void addXLabels(Agraph_t * gp)
     int n_set_lbls = 0;		/* # of set xlabels and edge labels */
     int n_clbls = 0;		/* # of set cluster labels */
     boxf bb;
-    pointf ur;
     textlabel_t* lp;
     label_params_t params;
     object_t* objs;
@@ -489,7 +485,8 @@ static void addXLabels(Agraph_t * gp)
 		bb = addLabelObj (lp, objp, bb);
 	    }
 	    else {
-		addXLabel (lp, objp, xlp, 0, ur); 
+		pointf ignored = { 0.0, 0.0 };
+		addXLabel (lp, objp, xlp, 0, ignored);
 		xlp++;
 	    }
 	}
@@ -680,9 +677,9 @@ void gv_postprocess(Agraph_t * g, int allowTranslation)
     if (Show_boxes) {
 	char buf[BUFSIZ];
 	if (Flip)
-	    sprintf(buf, M2, Offset.x, Offset.y, Offset.x, Offset.y);
+	    snprintf(buf, sizeof(buf), M2, Offset.x, Offset.y, Offset.x, Offset.y);
 	else
-	    sprintf(buf, M1, Offset.y, Offset.x, Offset.y, Offset.x,
+	    snprintf(buf, sizeof(buf), M1, Offset.y, Offset.x, Offset.y, Offset.x,
 		    -Offset.x, -Offset.y);
 	Show_boxes[0] = strdup(buf);
     }
