@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 #ifndef _WIN32
@@ -17,8 +14,9 @@
 
 #include <sys/stat.h>
 
-#include "render.h"
-#include "gvio.h"
+#include <common/render.h>
+#include <gvc/gvio.h>
+#include <cgraph/strcasecmp.h>
 
 static int N_EPSF_files;
 static Dict_t *EPSF_contents;
@@ -84,9 +82,17 @@ static usershape_t *user_init(const char *str)
 	contents = us->data = N_GNEW(statbuf.st_size + 1, char);
 	fseek(fp, 0, SEEK_SET);
 	rc = fread(contents, statbuf.st_size, 1, fp);
-	contents[statbuf.st_size] = '\0';
-	dtinsert(EPSF_contents, us);
-	us->must_inline = must_inline;
+	if (rc == 1) {
+            contents[statbuf.st_size] = '\0';
+            dtinsert(EPSF_contents, us);
+            us->must_inline = must_inline;
+        }
+        else {
+            agerr(AGWARN, "couldn't read from epsf file %s\n", str);
+            free(us->data);
+            free(us);
+            us = NULL;
+        }
     } else {
 	agerr(AGWARN, "BoundingBox not found in epsf file %s\n", str);
 	us = NULL;
@@ -121,8 +127,7 @@ void epsf_init(node_t * n)
 void epsf_free(node_t * n)
 {
 
-    if (ND_shape_info(n))
-	free(ND_shape_info(n));
+    free(ND_shape_info(n));
 }
 
 
