@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property
  * All rights reserved. This program and the accompanying materials
@@ -8,15 +5,18 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#include "render.h"
-#include "agxbuf.h"
-#include "htmltable.h"
-#include "entities.h"
-#include "logic.h"
-#include "gvc.h"
+#include <common/render.h>
+#include <cgraph/agxbuf.h>
+#include <common/htmltable.h>
+#include <common/entities.h>
+#include <common/logic.h>
+#include <math.h>
+#include <gvc/gvc.h>
+#include <cgraph/strcasecmp.h>
+#include <stddef.h>
 
 #ifdef _WIN32
 #define R_OK 4
@@ -167,6 +167,9 @@ node_t *UF_union(node_t * u, node_t * v)
 	ND_UF_size(v) = 1;
     } else
 	v = UF_find(v);
+	/* if we have two copies of the same node, their union is just that node */
+    if (u == v)
+	return u;
     if (ND_id(u) > ND_id(v)) {
 	ND_UF_parent(u) = v;
 	ND_UF_size(v) += ND_UF_size(u);
@@ -266,12 +269,6 @@ Agnodeinfo_t* ND_info(node_t * n) { return ((Agnodeinfo_t*)AGDATA(n));}
 #if !defined(_WIN32)
 #include	<pwd.h>
 
-#if 0
-static void cleanup(void)
-{
-    agxbfree(&xb);
-}
-#endif
 #endif
 
 /* Fgets:
@@ -544,20 +541,11 @@ pointf spline_at_y(splines * spl, double y)
 /* this caching seems to prevent p.x from getting set from bz.list[0].x
 	- optimizer problem ? */
 
-#if 0
-    static splines *mem = NULL;
-
-    if (mem != spl) {
-	mem = spl;
-#endif
 	for (i = 0; i < spl->size; i++) {
 	    bz = spl->list[i];
 	    if (BETWEEN(bz.list[bz.size - 1].y, y, bz.list[0].y))
 		break;
 	}
-#if 0
-    }
-#endif
     if (y > bz.list[0].y)
 	p = bz.list[0];
     else if (y < bz.list[bz.size - 1].y)
@@ -587,7 +575,7 @@ pointf spline_at_y(splines * spl, double y)
 	    t = (low + high) / 2.0;
 	    p = Bezier(c, 3, t, NULL, NULL);
 	    d = p.y - y;
-	    if (ABS(d) <= 1)
+	    if (fabs(d) <= 1)
 		break;
 	    if (d < 0)
 		high = t;
@@ -640,11 +628,11 @@ void common_init_node(node_t * n)
     fi.fontsize = late_double(n, N_fontsize, DEFAULT_FONTSIZE, MIN_FONTSIZE);
     fi.fontname = late_nnstring(n, N_fontname, DEFAULT_FONTNAME);
     fi.fontcolor = late_nnstring(n, N_fontcolor, DEFAULT_COLOR);
-    ND_label(n) = make_label((void*)n, str,
+    ND_label(n) = make_label(n, str,
 	        ((aghtmlstr(str) ? LT_HTML : LT_NONE) | ( (shapeOf(n) == SH_RECORD) ? LT_RECD : LT_NONE)),
 		fi.fontsize, fi.fontname, fi.fontcolor);
     if (N_xlabel && (str = agxget(n, N_xlabel)) && (str[0])) {
-	ND_xlabel(n) = make_label((void*)n, str, (aghtmlstr(str) ? LT_HTML : LT_NONE),
+	ND_xlabel(n) = make_label(n, str, (aghtmlstr(str) ? LT_HTML : LT_NONE),
 				fi.fontsize, fi.fontname, fi.fontcolor);
 	GD_has_labels(agraphof(n)) |= NODE_XLABEL;
     }
@@ -724,7 +712,7 @@ int common_init_edge(edge_t * e)
     if (E_label && (str = agxget(e, E_label)) && (str[0])) {
 	r = 1;
 	initFontEdgeAttr(e, &fi);
-	ED_label(e) = make_label((void*)e, str, (aghtmlstr(str) ? LT_HTML : LT_NONE),
+	ED_label(e) = make_label(e, str, (aghtmlstr(str) ? LT_HTML : LT_NONE),
 				fi.fontsize, fi.fontname, fi.fontcolor);
 	GD_has_labels(sg) |= EDGE_LABEL;
 	ED_label_ontop(e) =
@@ -734,7 +722,7 @@ int common_init_edge(edge_t * e)
     if (E_xlabel && (str = agxget(e, E_xlabel)) && (str[0])) {
 	if (!fi.fontname)
 	    initFontEdgeAttr(e, &fi);
-	ED_xlabel(e) = make_label((void*)e, str, (aghtmlstr(str) ? LT_HTML : LT_NONE),
+	ED_xlabel(e) = make_label(e, str, (aghtmlstr(str) ? LT_HTML : LT_NONE),
 				fi.fontsize, fi.fontname, fi.fontcolor);
 	GD_has_labels(sg) |= EDGE_XLABEL;
     }
@@ -743,14 +731,14 @@ int common_init_edge(edge_t * e)
     /* vladimir */
     if (E_headlabel && (str = agxget(e, E_headlabel)) && (str[0])) {
 	initFontLabelEdgeAttr(e, &fi, &lfi);
-	ED_head_label(e) = make_label((void*)e, str, (aghtmlstr(str) ? LT_HTML : LT_NONE),
+	ED_head_label(e) = make_label(e, str, (aghtmlstr(str) ? LT_HTML : LT_NONE),
 				lfi.fontsize, lfi.fontname, lfi.fontcolor);
 	GD_has_labels(sg) |= HEAD_LABEL;
     }
     if (E_taillabel && (str = agxget(e, E_taillabel)) && (str[0])) {
 	if (!lfi.fontname)
 	    initFontLabelEdgeAttr(e, &fi, &lfi);
-	ED_tail_label(e) = make_label((void*)e, str, (aghtmlstr(str) ? LT_HTML : LT_NONE),
+	ED_tail_label(e) = make_label(e, str, (aghtmlstr(str) ? LT_HTML : LT_NONE),
 				lfi.fontsize, lfi.fontname, lfi.fontcolor);
 	GD_has_labels(sg) |= TAIL_LABEL;
     }
@@ -952,28 +940,20 @@ static node_t *clustNode(node_t * n, graph_t * cg, agxbuf * xb,
 {
     node_t *cn;
     static int idx = 0;
-    char num[100];
 
-    agxbput(xb, "__");
-    sprintf(num, "%d", idx++);
-    agxbput(xb, num);
-    agxbputc(xb, ':');
-    agxbput(xb, agnameof(cg));
+    agxbprint(xb, "__%d:%s", idx++, agnameof(cg));
 
     cn = agnode(agroot(cg), agxbuse(xb), 1);
     agbindrec(cn, "Agnodeinfo_t", sizeof(Agnodeinfo_t), TRUE);
 
     SET_CLUST_NODE(cn);
 	agsubnode(cg,cn,1);
-	//aginsert(cg, cn);
 	agsubnode(clg,n,1);
-	//aginsert(clg, n);
 
     /* set attributes */
     N_label = setAttr(agraphof(cn), cn, "label", "", N_label);
     N_style = setAttr(agraphof(cn), cn, "style", "invis", N_style);
     N_shape = setAttr(agraphof(cn), cn, "shape", "box", N_shape);
-    /* N_width = setAttr (cn->graph, cn, "width", "0.0001", N_width); */
 
     return cn;
 }
@@ -1079,7 +1059,7 @@ static item *mapEdge(Dt_t * map, edge_t * e)
 
     key[0] = agtail(e);
     key[1] = aghead(e);
-    return (item *) dtmatch(map, &key);
+    return dtmatch(map, &key);
 }
 
 /* checkCompound:
@@ -1339,7 +1319,7 @@ safe_dcl(graph_t * g, int obj_kind, char *name, char *def)
 }
 
 static int comp_entities(const void *e1, const void *e2) {
-  return strcmp(((struct entities_s *)e1)->name, ((struct entities_s *)e2)->name);
+  return strcmp(((const struct entities_s *)e1)->name, ((const struct entities_s *)e2)->name);
 }
 
 #define MAXENTLEN 8
@@ -1365,10 +1345,7 @@ char* scanEntity (char* t, agxbuf* xb)
     res = bsearch(&key, entities, NR_OF_ENTITIES,
         sizeof(entities[0]), comp_entities);
     if (!res) return t;
-    sprintf (buf, "%d", res->value);
-    agxbputc(xb, '#');
-    agxbput(xb, buf);
-    agxbputc(xb, ';');
+    agxbprint(xb, "#%d;", res->value);
     return (endp+1);
 }
 
@@ -1476,7 +1453,6 @@ char* htmlEntityUTF8 (char* s, graph_t* g)
     static boolean warned;
     char*  ns;
     agxbuf xb;
-    unsigned char buf[BUFSIZ];
     unsigned char c;
     unsigned int v;
 
@@ -1488,7 +1464,7 @@ char* htmlEntityUTF8 (char* s, graph_t* g)
 	warned = 0;
     }
 
-    agxbinit(&xb, BUFSIZ, buf);
+    agxbinit(&xb, 0, NULL);
 
     while ((c = *(unsigned char*)s++)) {
         if (c < 0xC0)
@@ -1522,12 +1498,12 @@ char* htmlEntityUTF8 (char* s, graph_t* g)
 		    if (v < 0x7F) /* entity needs 1 byte in UTF8 */
 			c = v;
 		    else if (v < 0x07FF) { /* entity needs 2 bytes in UTF8 */
-			agxbputc(&xb, (v >> 6) | 0xC0);
+			agxbputc(&xb, (char)((v >> 6) | 0xC0));
 			c = (v & 0x3F) | 0x80;
 		    }
 		    else { /* entity needs 3 bytes in UTF8 */
-			agxbputc(&xb, (v >> 12) | 0xE0);
-			agxbputc(&xb, ((v >> 6) & 0x3F) | 0x80);
+			agxbputc(&xb, (char)((v >> 12) | 0xE0));
+			agxbputc(&xb, (char)(((v >> 6) & 0x3F) | 0x80));
 			c = (v & 0x3F) | 0x80;
 		    }
 		    }
@@ -1535,7 +1511,7 @@ char* htmlEntityUTF8 (char* s, graph_t* g)
         else /* copy n byte UTF8 characters */
             for (ui = 0; ui < uc; ++ui)
                 if ((*s & 0xC0) == 0x80) {
-                    agxbputc(&xb, c);
+                    agxbputc(&xb, (char)c);
                     c = *(unsigned char*)s++;
                 }
                 else {
@@ -1546,9 +1522,9 @@ char* htmlEntityUTF8 (char* s, graph_t* g)
 		            c = cvtAndAppend (c, &xb);
                     break;
 	            }
-	    agxbputc(&xb, c);
+        agxbputc(&xb, (char)c);
     }
-    ns = strdup (agxbuse(&xb));
+    ns = agxbdisown(&xb);
     agxbfree(&xb);
     return ns;
 }
@@ -1562,10 +1538,9 @@ char* latin1ToUTF8 (char* s)
 {
     char*  ns;
     agxbuf xb;
-    unsigned char buf[BUFSIZ];
     unsigned int  v;
 
-    agxbinit(&xb, BUFSIZ, buf);
+    agxbinit(&xb, 0, NULL);
 
     /* Values are either a byte (<= 256) or come from htmlEntity, whose
      * values are all less than 0x07FF, so we need at most 3 bytes.
@@ -1576,18 +1551,18 @@ char* latin1ToUTF8 (char* s)
 	    if (!v) v = '&';
         }
 	if (v < 0x7F)
-	    agxbputc(&xb, v);
+	    agxbputc(&xb, (char)v);
 	else if (v < 0x07FF) {
-	    agxbputc(&xb, (v >> 6) | 0xC0);
-	    agxbputc(&xb, (v & 0x3F) | 0x80);
+	    agxbputc(&xb, (char)((v >> 6) | 0xC0));
+	    agxbputc(&xb, (char)((v & 0x3F) | 0x80));
 	}
 	else {
-	    agxbputc(&xb, (v >> 12) | 0xE0);
-	    agxbputc(&xb, ((v >> 6) & 0x3F) | 0x80);
-	    agxbputc(&xb, (v & 0x3F) | 0x80);
+	    agxbputc(&xb, (char)((v >> 12) | 0xE0));
+	    agxbputc(&xb, (char)(((v >> 6) & 0x3F) | 0x80));
+	    agxbputc(&xb, (char)((v & 0x3F) | 0x80));
 	}
     }
-    ns = strdup (agxbuse(&xb));
+    ns = agxbdisown(&xb);
     agxbfree(&xb);
     return ns;
 }
@@ -1602,23 +1577,22 @@ utf8ToLatin1 (char* s)
 {
     char*  ns;
     agxbuf xb;
-    unsigned char buf[BUFSIZ];
     unsigned char c;
     unsigned char outc;
 
-    agxbinit(&xb, BUFSIZ, buf);
+    agxbinit(&xb, 0, NULL);
 
     while ((c = *(unsigned char*)s++)) {
 	if (c < 0x7F)
-	    agxbputc(&xb, c);
+	    agxbputc(&xb, (char)c);
 	else {
 	    outc = (c & 0x03) << 6;
 	    c = *(unsigned char*)s++;
 	    outc = outc | (c & 0x3F);
-	    agxbputc(&xb, outc);
+	    agxbputc(&xb, (char)outc);
 	}
     }
-    ns = strdup (agxbuse(&xb));
+    ns = agxbdisown(&xb);
     agxbfree(&xb);
     return ns;
 }
@@ -1709,81 +1683,42 @@ boolean overlap_edge(edge_t *e, boxf b)
 /* edgeType:
  * Convert string to edge type.
  */
-int edgeType (char* s, int dflt)
+static int edgeType(const char *s, int dflt)
 {
-    int et;
-
-    if (!s || (*s == '\0')) return dflt;
-
-    et = ET_NONE;
-    switch (*s) {
-    case '0' :    /* false */
-	et = ET_LINE;
-	break;
-    case '1' :    /* true */
-    case '2' :
-    case '3' :
-    case '4' :
-    case '5' :
-    case '6' :
-    case '7' :
-    case '8' :
-    case '9' :
-	et = ET_SPLINE;
-	break;
-    case 'c' :
-    case 'C' :
-	if (!strcasecmp (s+1, "urved"))
-	    et = ET_CURVED;
-	else if (!strcasecmp (s+1, "ompound"))
-	    et = ET_COMPOUND;
-	break;
-    case 'f' :
-    case 'F' :
-	if (!strcasecmp (s+1, "alse"))
-	    et = ET_LINE;
-	break;
-    case 'l' :
-    case 'L' :
-	if (!strcasecmp (s+1, "ine"))
-	    et = ET_LINE;
-	break;
-    case 'n' :
-    case 'N' :
-	if (!strcasecmp (s+1, "one")) return et;
-	if (!strcasecmp (s+1, "o")) return ET_LINE;
-	break;
-    case 'o' :
-    case 'O' :
-	if (!strcasecmp (s+1, "rtho"))
-	    et = ET_ORTHO;
-	break;
-    case 'p' :
-    case 'P' :
-	if (!strcasecmp (s+1, "olyline"))
-	    et = ET_PLINE;
-	break;
-    case 's' :
-    case 'S' :
-	if (!strcasecmp (s+1, "pline"))
-	    et = ET_SPLINE;
-	break;
-    case 't' :
-    case 'T' :
-	if (!strcasecmp (s+1, "rue"))
-	    et = ET_SPLINE;
-	break;
-    case 'y' :
-    case 'Y' :
-	if (!strcasecmp (s+1, "es"))
-	    et = ET_SPLINE;
-	break;
+    if (s == NULL || strcmp(s, "") == 0) {
+	return dflt;
     }
-    if (!et) {
-	agerr(AGWARN, "Unknown \"splines\" value: \"%s\" - ignored\n", s);
-	et = dflt;
+
+    if (*s == '0') { /* false */
+	return ET_LINE;
+    } else if (*s >= '1' && *s <= '9') { /* true */
+	return ET_SPLINE;
+    } else if (strcasecmp(s, "curved") == 0) {
+	return ET_CURVED;
+    } else if (strcasecmp(s, "compound") == 0) {
+	return ET_COMPOUND;
+    } else if (strcasecmp(s, "false") == 0) {
+	return ET_LINE;
+    } else if (strcasecmp(s, "line") == 0) {
+	return ET_LINE;
+    } else if (strcasecmp(s, "none") == 0) {
+	return ET_NONE;
+    } else if (strcasecmp(s, "no") == 0) {
+	return ET_LINE;
+    } else if (strcasecmp(s, "ortho") == 0) {
+	return ET_ORTHO;
+    } else if (strcasecmp(s, "polyline") == 0) {
+	return ET_PLINE;
+    } else if (strcasecmp(s, "spline") == 0) {
+	return ET_SPLINE;
+    } else if (strcasecmp(s, "true") == 0) {
+	return ET_SPLINE;
+    } else if (strcasecmp(s, "yes") == 0) {
+	return ET_SPLINE;
     }
-    return et;
+
+    agerr(AGWARN, "Unknown \"splines\" value: \"%s\" - ignored\n", s);
+    return dflt;
 }
 
 /* setEdgeType:
@@ -1885,53 +1820,6 @@ void get_gradient_points(pointf * A, pointf * G, int n, float angle, int flags)
     }
 }
 
-#ifndef WIN32_STATIC
-#ifndef HAVE_STRCASECMP
-
-
-#include <string.h>
-//#include <ctype.h>
-
-
-int strcasecmp(const char *s1, const char *s2)
-{
-    while ((*s1 != '\0')
-	   && (tolower(*(unsigned char *) s1) ==
-	       tolower(*(unsigned char *) s2))) {
-	s1++;
-	s2++;
-    }
-
-    return tolower(*(unsigned char *) s1) - tolower(*(unsigned char *) s2);
-}
-
-#endif				/* HAVE_STRCASECMP */
-#endif				/* WIN32_STATIC */
-
-#ifndef WIN32_STATIC
-#ifndef HAVE_STRNCASECMP
-#include <string.h>
-//#include <ctype.h>
-
-int strncasecmp(const char *s1, const char *s2, unsigned int n)
-{
-    if (n == 0)
-	return 0;
-
-    while ((n-- != 0)
-	   && (tolower(*(unsigned char *) s1) ==
-	       tolower(*(unsigned char *) s2))) {
-	if (n == 0 || *s1 == '\0' || *s2 == '\0')
-	    return 0;
-	s1++;
-	s2++;
-    }
-
-    return tolower(*(unsigned char *) s1) - tolower(*(unsigned char *) s2);
-}
-
-#endif				/* HAVE_STRNCASECMP */
-#endif                          /* WIN32_STATIC */
 void gv_free_splines(edge_t * e)
 {
     int i;
@@ -1958,7 +1846,7 @@ void gv_cleanup_edge(edge_t * e)
 
 void gv_cleanup_node(node_t * n)
 {
-    if (ND_pos(n)) free(ND_pos(n));
+    free(ND_pos(n));
     if (ND_shape(n))
         ND_shape(n)->fns->freefn(n);
     free_label(ND_label(n));
@@ -1983,25 +1871,8 @@ void gv_nodesize(node_t * n, boolean flip)
     }
 }
 
-#ifdef _WIN32
-void fix_fc(void)
-{
-    char buf[28192];
-    char buf2[28192];
-    int cur=0;
-    FILE* fp;
-
-    if((fp = fopen("fix-fc.exe", "r")) == NULL)
-	    return ;
-    fclose (fp);
-    if (!system ("fix-fc.exe")) {
-	system ("del fix-fc.exe");
-	system ("dot -c");	//run dot -c once too since we already run things :)
-    }
-}
-#endif
-
 #ifndef HAVE_DRAND48
+#pragma weak drand48
 double drand48(void)
 {
     double d;
@@ -2079,8 +1950,3 @@ findCluster (Dt_t* map, char* name)
     else
 	return NULL;
 }
-
-Agnodeinfo_t* ninf(Agnode_t* n) {return (Agnodeinfo_t*)AGDATA(n);}
-Agraphinfo_t* ginf(Agraph_t* g) {return (Agraphinfo_t*)AGDATA(g);}
-Agedgeinfo_t* einf(Agedge_t* e) {return (Agedgeinfo_t*)AGDATA(e);}
-/* void dumpG(Agraph_t* g) { agwrite(g, stderr); } */
