@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 #ifndef _UTILS_H
@@ -27,13 +24,6 @@ extern "C" {
 #endif
 /*end visual studio*/
 
-#ifndef HAVE_STRCASECMP
-    extern int strcasecmp(const char *s1, const char *s2);
-#endif
-#ifndef HAVE_STRNCASECMP
-    extern int strncasecmp(const char *s1, const char *s2, size_t n);
-#endif
-
     extern nodequeue *new_queue(int);
     extern void free_queue(nodequeue *);
     extern void enqueue(nodequeue *, Agnode_t *);
@@ -103,7 +93,6 @@ extern "C" {
 
     extern Agsym_t *setAttr(graph_t*, void*, char*name, char *value, Agsym_t*);
     extern void setEdgeType (graph_t* g, int dflt);
-    extern int edgeType (char* s, int dflt);
     extern int is_a_cluster (Agraph_t* g);
 
     /* from postproc.c */ 
@@ -116,14 +105,6 @@ extern "C" {
     /* from psusershape.c */
     extern void cat_libfile(GVJ_t * job, const char **arglib, const char **stdlib);
 
-Agnodeinfo_t* ninf(Agnode_t* n);
-Agraphinfo_t* ginf(Agraph_t* g);
-Agedgeinfo_t* einf(Agedge_t* e);
-    /**/
-#ifdef _WIN32	
-	extern void fix_fc(void);
-#endif
-
 #undef extern
 
 #ifdef __cplusplus
