@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 
@@ -16,10 +13,12 @@
  * set edge splines.
  */
 
-#include "dot.h"
+#include <dotgen/dot.h>
+#include <math.h>
+#include <stddef.h>
 
 #ifdef ORTHO
-#include <ortho.h>
+#include <ortho/ortho.h>
 #endif
 
 #define	NSUB	9		/* number of subdivisions, re-aiming splines */
@@ -605,15 +604,15 @@ static int edgecmp(edge_t** ptr0, edge_t** ptr1)
 
     t0 = ND_rank(agtail(le0)) - ND_rank(aghead(le0));
     t1 = ND_rank(agtail(le1)) - ND_rank(aghead(le1));
-    v0 = ABS((int)t0);   /* ugly, but explicit as to how we avoid equality tests on fp numbers */
-    v1 = ABS((int)t1);
+    v0 = abs((int)t0);   /* ugly, but explicit as to how we avoid equality tests on fp numbers */
+    v1 = abs((int)t1);
     if (v0 != v1)
 	return (v0 - v1);
 
     t0 = ND_coord(agtail(le0)).x - ND_coord(aghead(le0)).x;
     t1 = ND_coord(agtail(le1)).x - ND_coord(aghead(le1)).x;
-    v0 = ABS((int)t0);
-    v1 = ABS((int)t1);
+    v0 = abs((int)t0);
+    v1 = abs((int)t1);
     if (v0 != v1)
 	return (v0 - v1);
 
@@ -792,9 +791,9 @@ cloneGraph (graph_t* g, attr_state_t* attr_state)
     Agsym_t* sym;
     graph_t* auxg;
     if (agisdirected(g))
-	auxg = agopen ("auxg",Agdirected, NIL(Agdisc_t *));
+	auxg = agopen ("auxg",Agdirected, NULL);
     else
-	auxg = agopen ("auxg",Agundirected, NIL(Agdisc_t *));
+	auxg = agopen ("auxg",Agundirected, NULL);
     agbindrec(auxg, "Agraphinfo_t", sizeof(Agraphinfo_t), TRUE);
     agattr(auxg, AGRAPH, "rank", "");
     GD_drawing(auxg) = NEW(layout_t);
@@ -1410,8 +1409,8 @@ make_flat_labeled_edge(graph_t* g, spline_info_t* sp, path* P, edge_t* e, int et
 	lb.UR.y = ND_coord(ln).y + ND_ht(ln)/2;
 	ydelta = ND_coord(ln).y - GD_rank(g)[ND_rank(tn)].ht1 -
 		ND_coord(tn).y + GD_rank(g)[ND_rank(tn)].ht2;
-	ydelta /= 6.;
-	lb.LL.y = lb.UR.y - MAX(5.,ydelta); 
+	ydelta /= 6;
+	lb.LL.y = lb.UR.y - MAX(5,ydelta);
 
 	boxn = 0;
 	makeFlatEnd (g, sp, P, tn, e, &tend, TRUE);
@@ -1674,7 +1673,7 @@ makeLineEdge(graph_t* g, edge_t* fe, pointf* points, node_t** hp)
 	e = ED_to_orig(e);
     hn = aghead(e);
     tn = agtail(e);
-    delr = ABS(ND_rank(hn)-ND_rank(tn));
+    delr = abs(ND_rank(hn)-ND_rank(tn));
     if ((delr == 1) || ((delr == 2) && (GD_has_labels(g->root) & EDGE_LABEL)))
 	return 0;
     if (agtail(fe) == agtail(e)) {
@@ -1757,7 +1756,7 @@ make_regular_edge(graph_t* g, spline_info_t* sp, path * P, edge_t ** edges, int
     sl = 0;
     e = edges[ind];
     hackflag = FALSE;
-    if (ABS(ND_rank(agtail(e)) - ND_rank(aghead(e))) > 1) {
+    if (abs(ND_rank(agtail(e)) - ND_rank(aghead(e))) > 1) {
 	fwdedgeai = *(Agedgeinfo_t*)e->base.data;
 	fwdedgea.out = *e;
 	fwdedgea.in = *AGOUT2IN(e);
@@ -1952,33 +1951,23 @@ completeregularpath(path * P, edge_t * first, edge_t * last,
     edge_t *uleft, *uright, *lleft, *lright;
     int i, fb, lb;
     splines *spl;
-    pointf *pp;
-    int pn;
 
     fb = lb = -1;
     uleft = uright = NULL;
     uleft = top_bound(first, -1), uright = top_bound(first, 1);
     if (uleft) {
 	if (!(spl = getsplinepoints(uleft))) return;
-	pp = spl->list[0].list;
-       	pn = spl->list[0].size;
     }
     if (uright) {
 	if (!(spl = getsplinepoints(uright))) return;
-	pp = spl->list[0].list;
-       	pn = spl->list[0].size;
     }
     lleft = lright = NULL;
     lleft = bot_bound(last, -1), lright = bot_bound(last, 1);
     if (lleft) {
 	if (!(spl = getsplinepoints(lleft))) return;
-	pp = spl->list[spl->size - 1].list;
-       	pn = spl->list[spl->size - 1].size;
     }
     if (lright) {
 	if (!(spl = getsplinepoints(lright))) return;
-	pp = spl->list[spl->size - 1].list;
-       	pn = spl->list[spl->size - 1].size;
     }
     for (i = 0; i < tendp->boxn; i++)
 	add_box(P, tendp->boxes[i]);
@@ -2079,13 +2068,8 @@ static boxf makeregularend(boxf b, int side, double y)
 }
 
 #ifndef DONT_WANT_ANY_ENDPOINT_PATH_REFINEMENT
-void refineregularends(left, right, endp, dir, b, boxes, boxnp)
-edge_t *left, *right;
-pathend_t *endp;
-int dir;
-box b;
-box *boxes;
-int *boxnp;
+void refineregularends(edge_t *left, edge_t *right, pathend_t *endp, int dir,
+  box b, box *boxes, int *boxnp)
 {
     splines *lspls, *rspls;
     point pp, cp;
@@ -2308,9 +2292,7 @@ static void recover_slack(edge_t * e, path * p)
     }
 }
 
-static void resize_vn(vn, lx, cx, rx)
-node_t *vn;
-int lx, cx, rx;
+static void resize_vn(node_t *vn, int lx, int cx, int rx)
 {
     ND_coord(vn).x = cx;
     ND_lw(vn) = cx - lx, ND_rw(vn) = rx - cx;
@@ -2323,10 +2305,6 @@ static edge_t *top_bound(edge_t * e, int side)
     int i;
 
     for (i = 0; (f = ND_out(agtail(e)).list[i]); i++) {
-#if 0				/* were we out of our minds? */
-	if (ED_tail_port(e).p.x != ED_tail_port(f).p.x)
-	    continue;
-#endif
 	if (side * (ND_order(aghead(f)) - ND_order(aghead(e))) <= 0)
 	    continue;
 	if ((ED_spl(f) == NULL)
@@ -2345,10 +2323,6 @@ static edge_t *bot_bound(edge_t * e, int side)
     int i;
 
     for (i = 0; (f = ND_in(aghead(e)).list[i]); i++) {
-#if 0				/* same here */
-	if (ED_head_port(e).p.x != ED_head_port(f).p.x)
-	    continue;
-#endif
 	if (side * (ND_order(agtail(f)) - ND_order(agtail(e))) <= 0)
 	    continue;
 	if ((ED_spl(f) == NULL)
@@ -2502,16 +2476,14 @@ neighbor(graph_t* g, node_t *vn, edge_t *ie, edge_t *oe, int dir)
     return rv;
 }
 
-static boolean pathscross(n0, n1, ie1, oe1)
-node_t *n0, *n1;
-edge_t *ie1, *oe1;
+static boolean pathscross(node_t *n0, node_t *n1, edge_t *ie1, edge_t *oe1)
 {
     edge_t *e0, *e1;
     node_t *na, *nb;
     int order, cnt;
 
-    order = (ND_order(n0) > ND_order(n1));
-    if ((ND_out(n0).size != 1) && (ND_out(n0).size != 1))
+    order = ND_order(n0) > ND_order(n1);
+    if (ND_out(n0).size != 1 && ND_out(n1).size != 1)
 	return FALSE;
     e1 = oe1;
     if (ND_out(n0).size == 1 && e1) {
@@ -2521,10 +2493,10 @@ edge_t *ie1, *oe1;
 		break;
 	    if (order != (ND_order(na) > ND_order(nb)))
 		return TRUE;
-	    if ((ND_out(na).size != 1) || (ND_node_type(na) == NORMAL))
+	    if (ND_out(na).size != 1 || ND_node_type(na) == NORMAL)
 		break;
 	    e0 = ND_out(na).list[0];
-	    if ((ND_out(nb).size != 1) || (ND_node_type(nb) == NORMAL))
+	    if (ND_out(nb).size != 1 || ND_node_type(nb) == NORMAL)
 		break;
 	    e1 = ND_out(nb).list[0];
 	}
@@ -2537,10 +2509,10 @@ edge_t *ie1, *oe1;
 		break;
 	    if (order != (ND_order(na) > ND_order(nb)))
 		return TRUE;
-	    if ((ND_in(na).size != 1) || (ND_node_type(na) == NORMAL))
+	    if (ND_in(na).size != 1 || ND_node_type(na) == NORMAL)
 		break;
 	    e0 = ND_in(na).list[0];
-	    if ((ND_in(nb).size != 1) || (ND_node_type(nb) == NORMAL))
+	    if (ND_in(nb).size != 1 || ND_node_type(nb) == NORMAL)
 		break;
 	    e1 = ND_in(nb).list[0];
 	}
