@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 
@@ -19,7 +16,12 @@
  * because mincross may compare nodes in different clusters.
  */
 
-#include "dot.h"
+#include <assert.h>
+#include <cgraph/cgraph.h>
+#include <dotgen/dot.h>
+#include <limits.h>
+#include <stdlib.h>
+#include <string.h>
 
 /* #define DEBUG */
 #define MARK(v)		(ND_mark(v))
@@ -37,7 +39,7 @@ static void init_mincross(graph_t * g);
 static void merge2(graph_t * g);
 static void init_mccomp(graph_t * g, int c);
 static void cleanup2(graph_t * g, int nc);
-static int mincross_clust(graph_t * par, graph_t * g, int);
+static int mincross_clust(graph_t * g, int);
 static int mincross(graph_t * g, int startpass, int endpass, int);
 static void mincross_step(graph_t * g, int pass);
 static void mincross_options(graph_t * g);
@@ -70,7 +72,7 @@ static edge_t **TE_list;
 static int *TI_list;
 static boolean ReMincross;
 
-#if DEBUG > 1
+#if defined(DEBUG) && DEBUG > 1
 static void indent(graph_t* g)
 {
   if (g->parent) {
@@ -84,11 +86,11 @@ static char* nname(node_t* v)
         static char buf[1000];
 	if (ND_node_type(v)) {
 		if (ND_ranktype(v) == CLUSTER)
-			sprintf (buf, "v%s_%p", agnameof(ND_clust(v)), v);
+			snprintf(buf, sizeof(buf), "v%s_%p", agnameof(ND_clust(v)), v);
 		else
-			sprintf (buf, "v_%p", v);
+			snprintf(buf, sizeof(buf), "v_%p", v);
 	} else
-		sprintf (buf, "%s", agnameof(v));
+		snprintf(buf, sizeof(buf), "%s", agnameof(v));
 	return buf;
 }
 static void dumpg (graph_t* g)
@@ -258,7 +260,7 @@ fixLabelOrder (graph_t* g, rank_t* rk)
     indices = N_NEW(agnnodes(g), int);
 
     for (n = agfstnode(g); n; n = agnxtnode(g,n)) {
-	if (ND_x(n) || (agdegree(g,n,1,1) == 0)) continue;
+	if (ND_x(n) || agdegree(g,n,1,1) == 0) continue;
 	if (getComp(g, n, sg, indices)) {
 	    int i, sz = agnnodes(sg);
 	    cnt = topsort (g, sg, arr);
@@ -300,7 +302,7 @@ checkLabelOrder (graph_t* g)
 	    u = rk->v[j];
 	    if ((e = (edge_t*)ND_alg(u))) {
 		if (!lg) lg = agopen ("lg", Agstrictdirected, 0);
-		sprintf (buf, "%d", j);
+		snprintf(buf, sizeof(buf), "%d", j);
 		n = agnode(lg, buf, 1);
 		agbindrec(n, "info", sizeof(info_t), 1);
 		lo = ND_order(aghead(ND_out(u).list[0]));
@@ -334,6 +336,23 @@ void dot_mincross(graph_t * g, int doBalance)
     int c, nc;
     char *s;
 
+    /* check whether malformed input has led to empty cluster that the crossing
+     * functions will not anticipate
+     */
+    {
+	size_t i;
+	for (i = 1; i <= (size_t)GD_n_cluster(g); ) {
+	    if (agfstnode(GD_clust(g)[i]) == NULL) {
+	      agwarningf("removing empty cluster\n");
+	      memmove(&GD_clust(g)[i], &GD_clust(g)[i + 1],
+	        ((size_t)GD_n_cluster(g) - i) * sizeof(GD_clust(g)[0]));
+	      --GD_n_cluster(g);
+	    } else {
+	      ++i;
+	    }
+	}
+    }
+
     init_mincross(g);
 
     for (nc = c = 0; c < GD_comp(g).size; c++) {
@@ -345,15 +364,14 @@ void dot_mincross(graph_t * g, int doBalance)
 
     /* run mincross on contents of each cluster */
     for (c = 1; c <= GD_n_cluster(g); c++) {
-	nc += mincross_clust(g, GD_clust(g)[c], doBalance);
+	nc += mincross_clust(GD_clust(g)[c], doBalance);
 #ifdef DEBUG
 	check_vlists(GD_clust(g)[c]);
 	check_order();
 #endif
     }
 
-    if ((GD_n_cluster(g) > 0)
-	&& (!(s = agget(g, "remincross")) || (mapbool(s)))) {
+    if (GD_n_cluster(g) > 0 && (!(s = agget(g, "remincross")) || mapbool(s))) {
 	mark_lowclusters(g);
 	ReMincross = TRUE;
 	nc = mincross(g, 2, 2, doBalance);
@@ -507,7 +525,7 @@ static void ordered_edges(graph_t * g)
     }
 }
 
-static int mincross_clust(graph_t * par, graph_t * g, int doBalance)
+static int mincross_clust(graph_t * g, int doBalance)
 {
     int c, nc;
 
@@ -518,7 +536,7 @@ static int mincross_clust(graph_t * par, graph_t * g, int doBalance)
     nc = mincross(g, 2, 2, doBalance);
 
     for (c = 1; c <= GD_n_cluster(g); c++)
-	nc += mincross_clust(g, GD_clust(g)[c], doBalance);
+	nc += mincross_clust(GD_clust(g)[c], doBalance);
 
     save_vlist(g);
     return nc;
@@ -531,19 +549,16 @@ static int left2right(graph_t * g, node_t * v, node_t * w)
 
     /* CLUSTER indicates orig nodes of clusters, and vnodes of skeletons */
     if (ReMincross == FALSE) {
-	if ((ND_clust(v) != ND_clust(w)) && (ND_clust(v)) && (ND_clust(w))) {
+	if (ND_clust(v) != ND_clust(w) && ND_clust(v) && ND_clust(w)) {
 	    /* the following allows cluster skeletons to be swapped */
-	    if ((ND_ranktype(v) == CLUSTER)
-		&& (ND_node_type(v) == VIRTUAL))
+	    if (ND_ranktype(v) == CLUSTER && ND_node_type(v) == VIRTUAL)
 		return FALSE;
-	    if ((ND_ranktype(w) == CLUSTER)
-		&& (ND_node_type(w) == VIRTUAL))
+	    if (ND_ranktype(w) == CLUSTER && ND_node_type(w) == VIRTUAL)
 		return FALSE;
 	    return TRUE;
-	    /*return ((ND_ranktype(v) != CLUSTER) && (ND_ranktype(w) != CLUSTER)); */
 	}
     } else {
-	if ((ND_clust(v)) != (ND_clust(w)))
+	if (ND_clust(v) != ND_clust(w))
 	    return TRUE;
     }
     M = GD_rank(g)[ND_rank(v)].flat;
@@ -562,19 +577,17 @@ static int left2right(graph_t * g, node_t * v, node_t * w)
 
 static int in_cross(node_t * v, node_t * w)
 {
-    register edge_t **e1, **e2;
-    register int inv, cross = 0, t;
+    edge_t **e1, **e2;
+    int inv, cross = 0, t;
 
     for (e2 = ND_in(w).list; *e2; e2++) {
-	register int cnt = ED_xpenalty(*e2);		
+	int cnt = ED_xpenalty(*e2);		
 		
-	inv = ND_order((agtail(*e2)));
+	inv = ND_order(agtail(*e2));
 
 	for (e1 = ND_in(v).list; *e1; e1++) {
 	    t = ND_order(agtail(*e1)) - inv;
-	    if ((t > 0)
-		|| ((t == 0)
-		    && (  ED_tail_port(*e1).p.x > ED_tail_port(*e2).p.x)))
+	    if (t > 0 || (t == 0 && ED_tail_port(*e1).p.x > ED_tail_port(*e2).p.x))
 		cross += ED_xpenalty(*e1) * cnt;
 	}
     }
@@ -583,19 +596,17 @@ static int in_cross(node_t * v, node_t * w)
 
 static int out_cross(node_t * v, node_t * w)
 {
-    register edge_t **e1, **e2;
-    register int inv, cross = 0, t;
+    edge_t **e1, **e2;
+    int inv, cross = 0, t;
 
     for (e2 = ND_out(w).list; *e2; e2++) {
-	register int cnt = ED_xpenalty(*e2);
+	int cnt = ED_xpenalty(*e2);
 	inv = ND_order(aghead(*e2));
 
 	for (e1 = ND_out(v).list; *e1; e1++) {
 	    t = ND_order(aghead(*e1)) - inv;
-	    if ((t > 0)
-		|| ((t == 0)
-		    && ((ED_head_port(*e1)).p.x > (ED_head_port(*e2)).p.x)))
-		cross += ((ED_xpenalty(*e1)) * cnt);
+	    if (t > 0 || (t == 0 && (ED_head_port(*e1)).p.x > (ED_head_port(*e2)).p.x))
+		cross += ED_xpenalty(*e1) * cnt;
 	}
     }
     return cross;
@@ -653,7 +664,7 @@ static void balanceNodes(graph_t * g, int r, node_t * v, node_t * w)
 	    sepIndex = i;
     }
 
-    nullType = (ND_node_type(s) == NORMAL) ? VIRTUAL : NORMAL;
+    nullType = ND_node_type(s) == NORMAL ? VIRTUAL : NORMAL;
 
     /* count the number of null nodes to the left and 
      * right of the separator node 
@@ -731,23 +742,6 @@ static int balance(graph_t * g)
 		c0 += out_cross(v, w);
 		c1 += out_cross(w, v);
 	    }
-#if 0
-	    if ((c1 < c0) || ((c0 > 0) && reverse && (c1 == c0))) {
-		exchange(v, w);
-		rv += (c0 - c1);
-		GD_rank(Root)[r].valid = FALSE;
-		GD_rank(g)[r].candidate = TRUE;
-
-		if (r > GD_minrank(g)) {
-		    GD_rank(Root)[r - 1].valid = FALSE;
-		    GD_rank(g)[r - 1].candidate = TRUE;
-		}
-		if (r < GD_maxrank(g)) {
-		    GD_rank(Root)[r + 1].valid = FALSE;
-		    GD_rank(g)[r + 1].candidate = TRUE;
-		}
-	    }
-#endif
 
 	    if (c1 <= c0) {
 		balanceNodes(g, r, v, w);
@@ -779,9 +773,9 @@ static int transpose_step(graph_t * g, int r, int reverse)
 	    c0 += out_cross(v, w);
 	    c1 += out_cross(w, v);
 	}
-	if ((c1 < c0) || ((c0 > 0) && reverse && (c1 == c0))) {
+	if (c1 < c0 || (c0 > 0 && reverse && c1 == c0)) {
 	    exchange(v, w);
-	    rv += (c0 - c1);
+	    rv += c0 - c1;
 	    GD_rank(Root)[r].valid = FALSE;
 	    GD_rank(g)[r].candidate = TRUE;
 
@@ -806,20 +800,11 @@ static void transpose(graph_t * g, int reverse)
 	GD_rank(g)[r].candidate = TRUE;
     do {
 	delta = 0;
-#ifdef NOTDEF
-	/* don't run both the upward and downward passes- they cancel. 
-	   i tried making it depend on whether an odd or even pass, 
-	   but that didn't help. */
-	for (r = GD_maxrank(g); r >= GD_minrank(g); r--)
-	    if (GD_rank(g)[r].candidate)
-		delta += transpose_step(g, r, reverse);
-#endif
 	for (r = GD_minrank(g); r <= GD_maxrank(g); r++) {
 	    if (GD_rank(g)[r].candidate) {
 		delta += transpose_step(g, r, reverse);
 	    }
 	}
-	/*} while (delta > ncross(g)*(1.0 - Convergence)); */
     } while (delta >= 1);
 }
 
@@ -846,7 +831,6 @@ static int mincross(graph_t * g, int startpass, int endpass, int doBalance)
 		save_best(g);
 		best_cross = cur_cross;
 	    }
-	    trying = 0;
 	} else {
 	    maxthispass = MaxIter;
 	    if (cur_cross > best_cross)
@@ -893,8 +877,6 @@ static void restore_best(graph_t * g)
     node_t *n;
     int i, r;
 
-    /* for (n = GD_nlist(g); n; n = ND_next(n)) */
-	/* ND_order(n) = saveorder(n); */
     for (r = GD_minrank(g); r <= GD_maxrank(g); r++) {
 	for (i = 0; i < GD_rank(g)[r].n; i++) {
 	    n = GD_rank(g)[r].v[i];
@@ -911,8 +893,6 @@ static void restore_best(graph_t * g)
 static void save_best(graph_t * g)
 {
     node_t *n;
-    /* for (n = GD_nlist(g); n; n = ND_next(n)) */
-	/* saveorder(n) = ND_order(n); */
     int i, r;
     for (r = GD_minrank(g); r <= GD_maxrank(g); r++) {
 	for (i = 0; i < GD_rank(g)[r].n; i++) {
@@ -1032,13 +1012,13 @@ assert((rv == 0) || (ND_order(rv)-ND_order(v))*dir > 0);
 
 static int is_a_normal_node_of(graph_t * g, node_t * v)
 {
-    return ((ND_node_type(v) == NORMAL) && agcontains(g, v));
+    return ND_node_type(v) == NORMAL && agcontains(g, v);
 }
 
 static int is_a_vnode_of_an_edge_of(graph_t * g, node_t * v)
 {
-    if ((ND_node_type(v) == VIRTUAL)
-	&& (ND_in(v).size == 1) && (ND_out(v).size == 1)) {
+    if (ND_node_type(v) == VIRTUAL
+	&& ND_in(v).size == 1 && ND_out(v).size == 1) {
 	edge_t *e = ND_out(v).list[0];
 	while (ED_edge_type(e) != NORMAL)
 	    e = ED_to_orig(e);
@@ -1050,7 +1030,7 @@ static int is_a_vnode_of_an_edge_of(graph_t * g, node_t * v)
 
 static int inside_cluster(graph_t * g, node_t * v)
 {
-    return (is_a_normal_node_of(g, v) | is_a_vnode_of_an_edge_of(g, v));
+    return is_a_normal_node_of(g, v) | is_a_vnode_of_an_edge_of(g, v);
 }
 
 static node_t *furthestnode(graph_t * g, node_t * v, int dir)
@@ -1167,10 +1147,9 @@ realFillRanks (Agraph_t* g, int rnks[], int rnks_sz, Agraph_t* sg)
 static void
 fillRanks (Agraph_t* g)
 {
-    Agraph_t* sg;
     int rnks_sz = GD_maxrank(g) + 2;
     int* rnks = N_NEW(rnks_sz, int);
-    sg = realFillRanks (g, rnks, rnks_sz, NULL);
+    realFillRanks (g, rnks, rnks_sz, NULL);
     free (rnks);
 }
 
@@ -1184,8 +1163,6 @@ static void init_mincross(graph_t * g)
     ReMincross = FALSE;
     Root = g;
     /* alloc +1 for the null terminator usage in do_ordering() */
-    /* also, the +1 avoids attempts to alloc 0 sizes, something
-       that efence complains about */
     size = agnedges(dot_root(g)) + 1;
     TE_list = N_NEW(size, edge_t *);
     TI_list = N_NEW(size, int);
@@ -1200,7 +1177,7 @@ static void init_mincross(graph_t * g)
     GlobalMaxRank = GD_maxrank(g);
 }
 
-void flat_rev(Agraph_t * g, Agedge_t * e)
+static void flat_rev(Agraph_t * g, Agedge_t * e)
 {
     int j;
     Agedge_t *rev;
@@ -1213,10 +1190,7 @@ void flat_rev(Agraph_t * g, Agedge_t * e)
 		break;
     if (rev) {
 	merge_oneway(e, rev);
-	if (ED_to_virt(e) == 0)
-	    ED_to_virt(e) = rev;
-	if ((ED_edge_type(rev) == FLATORDER)
-	    && (ED_to_orig(rev) == 0))
+	if (ED_edge_type(rev) == FLATORDER && ED_to_orig(rev) == 0)
 	    ED_to_orig(rev) = e;
 	elist_append(e, ND_other(agtail(e)));
     } else {
@@ -1239,7 +1213,7 @@ static void flat_search(graph_t * g, node_t * v)
 
     ND_mark(v) = TRUE;
     ND_onstack(v) = TRUE;
-    hascl = (GD_n_cluster(dot_root(g)) > 0);
+    hascl = GD_n_cluster(dot_root(g)) > 0;
     if (ND_flat_out(v).list)
 	for (i = 0; (e = ND_flat_out(v).list[i]); i++) {
 	    if (hascl
@@ -1278,7 +1252,7 @@ static void flat_breakcycles(graph_t * g)
 	    v = GD_rank(g)[r].v[i];
 	    ND_mark(v) = ND_onstack(v) = FALSE;
 	    flatindex(v) = i;
-	    if ((ND_flat_out(v).size > 0) && (flat == 0)) {
+	    if (ND_flat_out(v).size > 0 && flat == 0) {
 		GD_rank(g)[r].flat =
 		    new_matrix(GD_rank(g)[r].n, GD_rank(g)[r].n);
 		flat = 1;
@@ -1359,7 +1333,7 @@ void install_in_rank(graph_t * g, node_t * n)
 	      __LINE__, agnameof(n), ND_order(n), r, GD_rank(Root)[r].an);
 	return;
     }
-    if ((r < GD_minrank(g)) || (r > GD_maxrank(g))) {
+    if (r < GD_minrank(g) || r > GD_maxrank(g)) {
 	agerr(AGERR, "install_in_rank, line %d: rank %d not in rank range [%d,%d]\n",
 	      __LINE__, r, GD_minrank(g), GD_maxrank(g));
 	return;
@@ -1367,7 +1341,7 @@ void install_in_rank(graph_t * g, node_t * n)
     if (GD_rank(g)[r].v + ND_order(n) >
 	GD_rank(g)[r].av + GD_rank(Root)[r].an) {
 	agerr(AGERR, "install_in_rank, line %d: GD_rank(g)[%d].v + ND_order(%s) [%d] > GD_rank(g)[%d].av + GD_rank(Root)[%d].an [%d]\n",
-	      __LINE__, r, agnameof(n),GD_rank(g)[r].v + ND_order(n), r, r, GD_rank(g)[r].av+GD_rank(Root)[r].an);
+	      __LINE__, r, agnameof(n),ND_order(n), r, r, GD_rank(Root)[r].an);
 	return;
     }
 }
@@ -1403,7 +1377,7 @@ void build_ranks(graph_t * g, int pass)
 	GD_rank(g)[i].n = 0;
 
     for (n = GD_nlist(g); n; n = ND_next(n)) {
-	otheredges = ((pass == 0) ? ND_in(n).list : ND_out(n).list);
+	otheredges = pass == 0 ? ND_in(n).list : ND_out(n).list;
 	if (otheredges[0] != NULL)
 	    continue;
 	if (MARK(n) == FALSE) {
@@ -1423,7 +1397,7 @@ void build_ranks(graph_t * g, int pass)
 	agerr(AGERR, "surprise\n");
     for (i = GD_minrank(g); i <= GD_maxrank(g); i++) {
 	GD_rank(Root)[i].valid = FALSE;
-	if (GD_flip(g) && (GD_rank(g)[i].n > 0)) {
+	if (GD_flip(g) && GD_rank(g)[i].n > 0) {
 	    int n, ndiv2;
 	    node_t **vlist = GD_rank(g)[i].v;
 	    n = GD_rank(g)[i].n - 1;
@@ -1433,7 +1407,7 @@ void build_ranks(graph_t * g, int pass)
 	}
     }
 
-    if ((g == dot_root(g)) && ncross(g) > 0)
+    if (g == dot_root(g) && ncross(g) > 0)
 	transpose(g, FALSE);
     free_queue(q);
 }
@@ -1586,7 +1560,7 @@ static void reorder(graph_t * g, int r, int reverse, int hasfixed)
 	lp = vlist;
 	while (lp < ep) {
 	    /* find leftmost node that can be compared */
-	    while ((lp < ep) && (ND_mval(*lp) < 0))
+	    while (lp < ep && ND_mval(*lp) < 0)
 		lp++;
 	    if (lp >= ep)
 		break;
@@ -1606,17 +1580,17 @@ static void reorder(graph_t * g, int r, int reverse, int hasfixed)
 	    }
 	    if (rp >= ep)
 		break;
-	    if (muststay == FALSE) {
-		register int p1 = (ND_mval(*lp));
-		register int p2 = (ND_mval(*rp));
-		if ((p1 > p2) || ((p1 == p2) && (reverse))) {
+	    if (!muststay) {
+		int p1 = ND_mval(*lp);
+		int p2 = ND_mval(*rp);
+		if (p1 > p2 || (p1 == p2 && reverse)) {
 		    exchange(*lp, *rp);
 		    changed++;
 		}
 	    }
 	    lp = rp;
 	}
-	if ((hasfixed == FALSE) && (reverse == FALSE))
+	if (!hasfixed && !reverse)
 	    ep--;
     }
 
@@ -1632,18 +1606,10 @@ static void mincross_step(graph_t * g, int pass)
     int r, other, first, last, dir;
     int hasfixed, reverse;
 
-    if ((pass % 4) < 2)
+    if (pass % 4 < 2)
 	reverse = TRUE;
     else
 	reverse = FALSE;
-    if (pass % 2) {
-	r = GD_maxrank(g) - 1;
-	dir = -1;
-    } /* up pass */
-    else {
-	r = 1;
-	dir = 1;
-    }				/* down pass */
 
     if (pass % 2 == 0) {	/* down pass */
 	first = GD_minrank(g) + 1;
@@ -1711,7 +1677,7 @@ static int rcross(graph_t * g, int r)
 	Count[i] = 0;
 
     for (top = 0; top < GD_rank(g)[r].n; top++) {
-	register edge_t *e;
+	edge_t *e;
 	if (max > 0) {
 	    for (i = 0; (e = ND_out(rtop[top]).list[i]); i++) {
 		for (k = ND_order(aghead(e)) + 1; k <= max; k++)
@@ -1719,7 +1685,7 @@ static int rcross(graph_t * g, int r)
 	    }
 	}
 	for (i = 0; (e = ND_out(rtop[top]).list[i]); i++) {
-	    register int inv = ND_order(aghead(e));
+	    int inv = ND_order(aghead(e));
 	    if (inv > max)
 		max = inv;
 	    Count[inv] += ED_xpenalty(e);
@@ -1758,7 +1724,7 @@ int ncross(graph_t * g)
 
 static int ordercmpf(int *i0, int *i1)
 {
-    return (*i0) - (*i1);
+    return *i0 - *i1;
 }
 
 /* flat_mval:
@@ -1901,6 +1867,14 @@ void virtual_weight(edge_t * e)
 {
     int t;
     t = table[endpoint_class(agtail(e))][endpoint_class(aghead(e))];
+
+    /* check whether the upcoming computation will overflow */
+    assert(t >= 0);
+    if (INT_MAX / t < ED_weight(e)) {
+	agerr(AGERR, "overflow when calculating virtual weight of edge\n");
+	exit(EXIT_FAILURE);
+    }
+
     ED_weight(e) *= t;
 }
 
@@ -1958,7 +1932,7 @@ static void mincross_options(graph_t * g)
     Convergence = .995;
 
     p = agget(g, "mclimit");
-    if (p && ((f = atof(p)) > 0.0)) {
+    if (p && (f = atof(p)) > 0.0) {
 	MinQuit = MAX(1, MinQuit * f);
 	MaxIter = MAX(1, MaxIter * f);
     }
@@ -1970,9 +1944,9 @@ void check_exchange(node_t * v, node_t * w)
     int i, r;
     node_t *u;
 
-    if ((ND_clust(v) == NULL) && (ND_clust(w) == NULL))
+    if (ND_clust(v) == NULL && ND_clust(w) == NULL)
 	return;
-    assert((ND_clust(v) == NULL) || (ND_clust(w) == NULL));
+    assert(ND_clust(v) == NULL || ND_clust(w) == NULL);
     assert(ND_rank(v) == ND_rank(w));
     assert(ND_order(v) < ND_order(w));
     r = ND_rank(v);
