@@ -1,5 +1,3 @@
-/* vim:set shiftwidth=4 ts=4: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -7,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 /*
@@ -23,22 +21,19 @@
 #define _BLD_sfio 1
 #endif
 
-#include "exlib.h"
-#include "exop.h"
+#include <expr/exlib.h>
+#include <expr/exop.h>
+#include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
 #include <assert.h>
 #include <time.h>
 #ifdef _WIN32
-#include <stdlib.h>
 #define srand48 srand
 #define drand48 rand
 #endif
 
-#ifdef OLD
-#include <tm.h>
-#else
 #define TIME_LEN 80             /* max. characters to store time */
-#endif
 
 static Extype_t	eval(Expr_t*, Exnode_t*, void*);
 
@@ -49,20 +44,20 @@ static Extype_t	eval(Expr_t*, Exnode_t*, void*);
 static char*
 lexname(int op, int subop)
 {
-	register char*	b;
+	char*	b;
 
 	static int	n;
 	static char	buf[TOTNAME][MAXNAME];
 
 	if (op > MINTOKEN && op < MAXTOKEN)
-		return (char*)exop[op - MINTOKEN];
+		return (char*)exop((size_t)op - MINTOKEN);
 	if (++n >= TOTNAME)
 		n = 0;
 	b = buf[n];
 	if (op == '=')
 	{
 		if (subop > MINTOKEN && subop < MAXTOKEN)
-			sfsprintf(b, MAXNAME, "%s=", exop[subop - MINTOKEN]);
+			sfsprintf(b, MAXNAME, "%s=", exop((size_t)subop - MINTOKEN));
 		else if (subop > ' ' && subop <= '~')
 			sfsprintf(b, MAXNAME, "%c=", subop);
 		else
@@ -83,7 +78,7 @@ lexname(int op, int subop)
  * 
  */
 static int
-evaldyn (Expr_t * ex, register Exnode_t * expr, void *env, int delete)
+evaldyn (Expr_t * ex, Exnode_t * expr, void *env, int delete)
 {
 	Exassoc_t *b;
 	Extype_t v;
@@ -93,7 +88,7 @@ evaldyn (Expr_t * ex, register Exnode_t * expr, void *env, int delete)
 
 	v = eval(ex, expr->data.variable.index, env);
 	if (expr->data.variable.symbol->index_type == INTEGER) {
-		if (!(b = (Exassoc_t *) dtmatch((Dt_t *) expr->data.variable.symbol->local.pointer, &v))) {
+		if (!(b = dtmatch((Dt_t *) expr->data.variable.symbol->local.pointer, &v))) {
 			return 0;
 		}
 	} 
@@ -108,7 +103,7 @@ evaldyn (Expr_t * ex, register Exnode_t * expr, void *env, int delete)
 			keyname = buf;
 		} else
 			keyname = v.string;
-		if (!(b = (Exassoc_t *) dtmatch((Dt_t *) expr->data.variable.
+		if (!(b = dtmatch((Dt_t *) expr->data.variable.
 			symbol->local.pointer, keyname))) {
 			return 0;
 		}
@@ -126,7 +121,7 @@ evaldyn (Expr_t * ex, register Exnode_t * expr, void *env, int delete)
  */
 
 static Extype_t
-getdyn(Expr_t* ex, register Exnode_t* expr, void* env, Exassoc_t** assoc)
+getdyn(Expr_t* ex, Exnode_t* expr, void* env, Exassoc_t** assoc)
 {
 	Exassoc_t*	b;
 	Extype_t	v;
@@ -134,12 +129,12 @@ getdyn(Expr_t* ex, register Exnode_t* expr, void* env, Exassoc_t** assoc)
 	if (expr->data.variable.index)
 	{
 		Extype_t key;
-		char	buf[2*(sizeof(key.integer))+1];  /* no. of hex chars needed plus null byte */
+		char	buf[2*sizeof(key.integer)+1];  /* no. of hex chars needed plus null byte */
 		char *keyname;
 
 		v = eval(ex, expr->data.variable.index, env);
 		if (expr->data.variable.symbol->index_type == INTEGER) {
-			if (!(b = (Exassoc_t *) dtmatch((Dt_t *) expr->data.variable.symbol->local.pointer, &v))) 
+			if (!(b = dtmatch((Dt_t *) expr->data.variable.symbol->local.pointer, &v)))
 			{
 				if (!(b = newof(0, Exassoc_t, 1, 0)))
 					exnospace();
@@ -157,7 +152,7 @@ getdyn(Expr_t* ex, register Exnode_t* expr, void* env, Exassoc_t** assoc)
 				keyname = buf;
 			} else
 				keyname = v.string;
-			if (!(b = (Exassoc_t *) dtmatch((Dt_t *) expr->data.variable.symbol->local.pointer, keyname))) 
+			if (!(b = dtmatch((Dt_t *) expr->data.variable.symbol->local.pointer, keyname)))
 			{
 				if (!(b = newof(0, Exassoc_t, 1, strlen(keyname))))
 					exnospace();
@@ -198,23 +193,23 @@ typedef struct
 static int
 prformat(Sfio_t* sp, void* vp, Sffmt_t* dp)
 {
-	register Fmt_t*		fmt = (Fmt_t*)dp;
-	register Exnode_t*	node;
-	register char*		s;
-	register char*		txt;
+	Fmt_t*		fmt = (Fmt_t*)dp;
+	Exnode_t*	node;
+	char*		s;
+	char*		txt;
 	int			n;
 	int			from;
 	int			to = 0;
 	time_t			tm;
-#ifndef OLD
     struct tm *stm;
-#endif
 
 
+	(void)sp;
+
 	dp->flags |= SFFMT_VALUE;
 	if (fmt->args)
 	{
-		if ((node = (dp->fmt == '*') ? fmt->args->param[dp->size] : fmt->args->arg))
+		if ((node = dp->fmt == '*' ? fmt->args->param[dp->size] : fmt->args->arg))
 			fmt->value = exeval(fmt->expr, node, fmt->env);
 		else
 			fmt->value.integer = 0;
@@ -252,7 +247,7 @@ prformat(Sfio_t* sp, void* vp, Sffmt_t* dp)
 			fmt->value = exeval(fmt->expr, node, fmt->env);
 		else
 		{
-			node = excast(fmt->expr, node, to, NiL, 0);
+			node = excast(fmt->expr, node, to, NULL, 0);
 			fmt->value = exeval(fmt->expr, node, fmt->env);
 			node->data.operand.left = 0;
 			exfree(fmt->expr, node);
@@ -274,15 +269,15 @@ prformat(Sfio_t* sp, void* vp, Sffmt_t* dp)
 	switch (to)
 	{
 	case STRING:
-		*((char**)vp) = fmt->value.string;
+		*(char**)vp = fmt->value.string;
 		fmt->fmt.size = -1;
 		break;
 	case FLOATING:
-		*((double*)vp) = fmt->value.floating;
+		*(double*)vp = fmt->value.floating;
 		fmt->fmt.size = sizeof(double);
 		break;
 	default:
-		*((Sflong_t*)vp) = fmt->value.integer;
+		*(Sflong_t*)vp = fmt->value.integer;
 		dp->size = sizeof(Sflong_t);
 		break;
 	}
@@ -293,7 +288,7 @@ prformat(Sfio_t* sp, void* vp, Sffmt_t* dp)
 		else
 		{
 			sfprintf(fmt->tmp, "%.*s", dp->n_str, dp->t_str);
-			txt = exstash(fmt->tmp, NiL);
+			txt = exstash(fmt->tmp, NULL);
 		}
 	}
 	else
@@ -302,14 +297,14 @@ prformat(Sfio_t* sp, void* vp, Sffmt_t* dp)
 	{
 	case 'q':
 	case 'Q':
-		s = *((char**)vp);
-		*((char**)vp) = fmtquote(s, "$'", "'", strlen(s), 0);
+		s = *(char**)vp;
+		*(char**)vp = fmtquote(s, "$'", "'", strlen(s), 0);
 		dp->fmt = 's';
 		dp->size = -1;
 		break;
 	case 'S':
 		dp->flags &= ~SFFMT_LONG;
-		s = *((char**)vp);
+		s = *(char**)vp;
 		if (txt)
 		{
 			if (streq(txt, "identifier"))
@@ -324,21 +319,21 @@ prformat(Sfio_t* sp, void* vp, Sffmt_t* dp)
 			{
 				for (; *s; s++)
 					if (isupper(*s))
-						*s = tolower(*s);
+						*s = (char)tolower(*s);
 					else if (islower(*s))
-						*s = toupper(*s);
+						*s = (char)toupper(*s);
 			}
 			else if (streq(txt, "lower"))
 			{
 				for (; *s; s++)
 					if (isupper(*s))
-						*s = tolower(*s);
+						*s = (char)tolower(*s);
 			}
 			else if (streq(txt, "upper"))
 			{
 				for (; *s; s++)
 					if (islower(*s))
-						*s = toupper(*s);
+						*s = (char)toupper(*s);
 			}
 			else if (streq(txt, "variable"))
 			{
@@ -352,18 +347,14 @@ prformat(Sfio_t* sp, void* vp, Sffmt_t* dp)
 		break;
 	case 't':
 	case 'T':
-		if ((tm = *((Sflong_t*)vp)) == -1)
-			tm = time(NiL);
-#ifndef OLD
+		if ((tm = *(Sflong_t*)vp) == -1)
+			tm = time(NULL);
         if (!txt)
             txt = "%?%K";
         s = fmtbuf(TIME_LEN);
         stm = localtime(&tm);
         strftime(s, TIME_LEN, txt, stm);
-        *((char **) vp) = s;
-#else
-		*((char**)vp) = fmttime(txt ? txt : "%?%K", tm);
-#endif
+        *(char **)vp = s;
 		dp->fmt = 's';
 		dp->size = -1;
 		break;
@@ -376,7 +367,7 @@ prformat(Sfio_t* sp, void* vp, Sffmt_t* dp)
  */
 
 static int
-prints(Expr_t * ex, register Exnode_t * expr, void *env, Sfio_t * sp)
+prints(Expr_t * ex, Exnode_t * expr, void *env, Sfio_t * sp)
 {
     Extype_t v;
     Exnode_t *args;
@@ -398,21 +389,20 @@ prints(Expr_t * ex, register Exnode_t * expr, void *env, Sfio_t * sp)
 static int
 print(Expr_t* ex, Exnode_t* expr, void* env, Sfio_t* sp)
 {
-	register Print_t*	x;
+	Print_t*	x;
 	Extype_t		v;
 	Fmt_t			fmt;
 
 	if (!sp)
 	{
 		v = eval(ex, expr->data.print.descriptor, env);
-		if (v.integer < 0 || v.integer >= elementsof(ex->file) || (!(sp = ex->file[v.integer]) && !(sp = ex->file[v.integer] = sfnew(NiL, NiL, SF_UNBOUND, v.integer, SF_READ|SF_WRITE))))
+		if (v.integer < 0 || v.integer >= elementsof(ex->file) || (!(sp = ex->file[v.integer]) && !(sp = ex->file[v.integer] = sfnew(NULL, NULL, SF_UNBOUND, v.integer, SF_READ|SF_WRITE))))
 		{
 			exerror("printf: %d: invalid descriptor", v.integer);
 			return -1;
 		}
 	}
 	memset(&fmt, 0, sizeof(fmt));
-	fmt.fmt.version = SFIO_VERSION;
 	fmt.fmt.extf = prformat;
 	fmt.expr = ex;
 	fmt.env = env;
@@ -450,8 +440,10 @@ print(Expr_t* ex, Exnode_t* expr, void* env, Sfio_t* sp)
 static int
 scformat(Sfio_t* sp, void* vp, Sffmt_t* dp)
 {
-	register Fmt_t*		fmt = (Fmt_t*)dp;
-	register Exnode_t*	node;
+	Fmt_t*		fmt = (Fmt_t*)dp;
+	Exnode_t*	node;
+
+	(void)sp;
 
 	if (!fmt->actuals)
 	{
@@ -469,7 +461,7 @@ scformat(Sfio_t* sp, void* vp, Sffmt_t* dp)
 			return -1;
 		}
 		fmt->fmt.size = sizeof(double);
-		*((void**)vp) = &node->data.variable.symbol->value->data.constant.value;
+		*(void**)vp = &node->data.variable.symbol->value->data.constant.value;
 		break;
 	case 's':
 	case '[':
@@ -481,7 +473,8 @@ scformat(Sfio_t* sp, void* vp, Sffmt_t* dp)
 		if (node->data.variable.symbol->value->data.constant.value.string == expr.nullstring)
 			node->data.variable.symbol->value->data.constant.value.string = 0;
 		fmt->fmt.size = 1024;
-		*((void**)vp) = node->data.variable.symbol->value->data.constant.value.string = vmnewof(fmt->expr->vm, node->data.variable.symbol->value->data.constant.value.string, char, fmt->fmt.size, 0);
+		*(void**)vp = node->data.variable.symbol->value->data.constant.value.string = vmnewof(fmt->expr->vm, node->data.variable.symbol->value->data.constant.value.string, char, fmt->fmt.size, 0);
+		memset(node->data.variable.symbol->value->data.constant.value.string, 0, sizeof(char) * (size_t)fmt->fmt.size);
 		break;
 	case 'c':
 		if (node->type != CHARACTER) {
@@ -498,7 +491,7 @@ scformat(Sfio_t* sp, void* vp, Sffmt_t* dp)
 			return -1;
 		}
 		dp->size = sizeof(Sflong_t);
-		*((void**)vp) = &node->data.variable.symbol->value->data.constant.value;
+		*(void**)vp = &node->data.variable.symbol->value->data.constant.value;
 		break;
 	}
 	fmt->actuals = fmt->actuals->data.operand.right;
@@ -528,7 +521,7 @@ scan(Expr_t* ex, Exnode_t* expr, void* env, Sfio_t* sp)
 		}
 		else
 			v.integer = 0;
-		if ((v.integer < 0) || (v.integer >= elementsof(ex->file)) || (!(sp = ex->file[v.integer]) && !(sp = ex->file[v.integer] = sfnew(NiL, NiL, SF_UNBOUND, v.integer, SF_READ|SF_WRITE))))
+		if (v.integer < 0 || v.integer >= elementsof(ex->file) || (!(sp = ex->file[v.integer]) && !(sp = ex->file[v.integer] = sfnew(NULL, NULL, SF_UNBOUND, v.integer, SF_READ|SF_WRITE))))
 		{
 			exerror("scanf: %d: invalid descriptor", v.integer);
 			return 0;
@@ -536,7 +529,6 @@ scan(Expr_t* ex, Exnode_t* expr, void* env, Sfio_t* sp)
 	}
  get:
 	memset(&fmt, 0, sizeof(fmt));
-	fmt.fmt.version = SFIO_VERSION;
 	fmt.fmt.extf = scformat;
 	fmt.expr = ex;
 	fmt.env = env;
@@ -555,10 +547,15 @@ scan(Expr_t* ex, Exnode_t* expr, void* env, Sfio_t* sp)
  */
 
 static char*
-str_add(Expr_t* ex, register char* l, register char* r)
+str_add(Expr_t* ex, char* l, char* r)
 {
-	sfprintf(ex->tmp, "%s%s", l, r);
-	return exstash(ex->tmp, ex->ve);
+	size_t sz = strlen(l) + strlen(r) + 1;
+	char *s = vmalloc(ex->ve, sz);
+	if (s == NULL) {
+		return exnospace();
+	}
+	snprintf(s, sz, "%s%s", l, r);
+	return s;
 }
 
 /*
@@ -566,10 +563,10 @@ str_add(Expr_t* ex, register char* l, register char* r)
  */
 
 static char*
-str_ior(Expr_t* ex, register char* l, register char* r)
+str_ior(Expr_t* ex, char* l, char* r)
 {
-	register int	c;
-	register char*	s = l;
+	int	c;
+	char*	s = l;
 
 	while ((c = *s++))
 		if (!strchr(s, c))
@@ -585,9 +582,9 @@ str_ior(Expr_t* ex, register char* l, register char* r)
  */
 
 static char*
-str_and(Expr_t* ex, register char* l, register char* r)
+str_and(Expr_t* ex, char* l, char* r)
 {
-	register int	c;
+	int	c;
 
 	while ((c = *l++))
 		if (strchr(r, c) && !strchr(l, c))
@@ -600,10 +597,10 @@ str_and(Expr_t* ex, register char* l, register char* r)
  */
 
 static char*
-str_xor(Expr_t* ex, register char* l, register char* r)
+str_xor(Expr_t* ex, char* l, char* r)
 {
-	register int	c;
-	register char*	s = l;
+	int	c;
+	char*	s = l;
 
 	while ((c = *s++))
 		if (!strchr(r, c) && !strchr(s, c))
@@ -619,9 +616,9 @@ str_xor(Expr_t* ex, register char* l, register char* r)
  */
 
 static char*
-str_mod(Expr_t* ex, register char* l, register char* r)
+str_mod(Expr_t* ex, char* l, char* r)
 {
-	register int	c;
+	int	c;
 
 	while ((c = *l++))
 		if (!strchr(r, c) && !strchr(l, c))
@@ -634,10 +631,10 @@ str_mod(Expr_t* ex, register char* l, register char* r)
  */
 
 static char*
-str_mpy(Expr_t* ex, register char* l, register char* r)
+str_mpy(Expr_t* ex, char* l, char* r)
 {
-	register int	lc;
-	register int	rc;
+	int	lc;
+	int	rc;
 
 	while ((lc = *l++) && (rc = *r++))
 		sfputc(ex->tmp, lc == rc ? lc : ' ');
@@ -649,7 +646,7 @@ str_mpy(Expr_t* ex, register char* l, register char* r)
  * \digit is replaced with a subgroup match, if any.
  */
 static void
-replace(Sfio_t * s, char *base, register char *repl, int ng, int *sub)
+replace(Sfio_t * s, char *base, char *repl, int ng, int *sub)
 {
 	char c;
 	int idx, offset;
@@ -677,7 +674,7 @@ addItem (Dt_t* arr, Extype_t v, char* tok)
 {
 	Exassoc_t* b;
 
-	if (!(b = (Exassoc_t *) dtmatch(arr, &v))) {
+	if (!(b = dtmatch(arr, &v))) {
 		if (!(b = newof(0, Exassoc_t, 1, 0)))
 	    	exerror("out of space [assoc]");
 		b->key = v;
@@ -690,17 +687,15 @@ addItem (Dt_t* arr, Extype_t v, char* tok)
  * break string into possibly empty fields and store in array
  * return number of fields
  */
-Extype_t
-exsplit(Expr_t * ex, register Exnode_t * expr, void *env)
+static Extype_t
+exsplit(Expr_t * ex, Exnode_t * expr, void *env)
 {
 	Extype_t v;
 	char *str;
 	char *seps;
 	char *tok;
 	size_t sz;
-	Sfio_t* fp = ex->tmp;
 	Dt_t* arr = (Dt_t*)expr->data.split.array->local.pointer;
-	int i;
 
 	str = (eval(ex, expr->data.split.string, env)).string;
 	if (expr->data.split.seps)
@@ -716,7 +711,7 @@ exsplit(Expr_t * ex, register Exnode_t * expr, void *env)
 	    		addItem (arr, v, "");
 	    		v.integer++;
 			}
-			for (i = 1; i < sz; i++) {
+			for (size_t i = 1; i < sz; i++) {
 	    		addItem (arr, v, "");
 	    		v.integer++;
 			}
@@ -728,8 +723,12 @@ exsplit(Expr_t * ex, register Exnode_t * expr, void *env)
 	    	break;
 		}
 		sz = strcspn (str, seps);
-		sfwrite (fp, str, sz);
-		tok = exstrdup(ex, sfstruse(fp));
+		tok = vmalloc(ex->vm, sz + 1);
+		if (tok == NULL) {
+			tok = exnospace();
+		} else {
+			strncpy(tok, str, sz + 1);
+		}
 		addItem (arr, v, tok);
 		v.integer++;
 		str += sz;
@@ -742,15 +741,14 @@ exsplit(Expr_t * ex, register Exnode_t * expr, void *env)
  * tokenize string and store in array
  * return number of tokens
  */
-Extype_t
-extokens(Expr_t * ex, register Exnode_t * expr, void *env)
+static Extype_t
+extokens(Expr_t * ex, Exnode_t * expr, void *env)
 {
 	Extype_t v;
 	char *str;
 	char *seps;
 	char *tok;
 	size_t sz;
-	Sfio_t* fp = ex->tmp;
 	Dt_t* arr = (Dt_t*)expr->data.split.array->local.pointer;
 
 	str = (eval(ex, expr->data.split.string, env)).string;
@@ -768,8 +766,12 @@ extokens(Expr_t * ex, register Exnode_t * expr, void *env)
 
 		sz = strcspn (str, seps);
 		assert (sz);
-		sfwrite (fp, str, sz);
-		tok = exstrdup(ex, sfstruse(fp));
+		tok = vmalloc(ex->vm, sz + 1);
+		if (tok == NULL) {
+			tok = exnospace();
+		} else {
+			strncpy(tok, str, sz + 1);
+		}
 		addItem (arr, v, tok);
 		v.integer++;
 		str += sz;
@@ -781,8 +783,8 @@ extokens(Expr_t * ex, register Exnode_t * expr, void *env)
 /* exsub:
  * return string after pattern substitution
  */
-Extype_t
-exsub(Expr_t * ex, register Exnode_t * expr, void *env, int global)
+static Extype_t
+exsub(Expr_t * ex, Exnode_t * expr, void *env, int global)
 {
 	char *str;
 	char *pat;
@@ -812,7 +814,7 @@ exsub(Expr_t * ex, register Exnode_t * expr, void *env, int global)
 		if (p > pat)
 		    p--;
 		if (*p == '$') {
-		    if ((p > pat) && (*(p - 1) == '\\')) {
+		    if (p > pat && p[-1] == '\\') {
 				*p-- = '\0';
 				*p = '$';
 	    	} else {
@@ -858,7 +860,7 @@ exsub(Expr_t * ex, register Exnode_t * expr, void *env, int global)
 /* exsubstr:
  * return substring.
  */
-static Extype_t exsubstr(Expr_t * ex, register Exnode_t * expr, void *env)
+static Extype_t exsubstr(Expr_t * ex, Exnode_t * expr, void *env)
 {
 	Extype_t s;
 	Extype_t i;
@@ -926,12 +928,12 @@ xPrint(Expr_t * ex, Exnode_t * expr, Extype_t v, Exnode_t * tmp)
 static long seed;
 
 static Extype_t
-eval(Expr_t* ex, register Exnode_t* expr, void* env)
+eval(Expr_t* ex, Exnode_t* expr, void* env)
 {
-	register Exnode_t*	x;
-	register Exnode_t*	a;
-	register Extype_t**	t;
-	register int		n;
+	Exnode_t*	x;
+	Exnode_t*	a;
+	Extype_t**	t;
+	int		n;
 	Extype_t		v;
 	Extype_t		r = {0};
 	Extype_t		i;
@@ -970,13 +972,11 @@ eval(Expr_t* ex, register Exnode_t* expr, void* env)
 				i = eval(ex, x->data.variable.index, env);
 			else
 				i.integer = EX_SCALAR;
-#ifndef OLD
 			if (x->data.variable.dyna) {
 				Extype_t locv;
 				locv = getdyn(ex, x->data.variable.dyna, env, &assoc);
 				x->data.variable.dyna->data.variable.dyna->data.constant.value = locv;
 			}
-#endif
 			r = (*ex->disc->getf)(ex, x, x->data.variable.symbol, x->data.variable.reference, env, (int)i.integer, ex->disc);
 		}
 		v = r;
@@ -1012,13 +1012,11 @@ eval(Expr_t* ex, register Exnode_t* expr, void* env)
 				i = eval(ex, x->data.variable.index, env);
 			else
 				i.integer = EX_SCALAR;
-#ifndef OLD
 			if (x->data.variable.dyna) {
 				Extype_t locv;
 				locv = getdyn(ex, x->data.variable.dyna, env, &assoc);
 				x->data.variable.dyna->data.variable.dyna->data.constant.value = locv;
 			}
-#endif
 			if ((*ex->disc->setf)(ex, x, x->data.variable.symbol, x->data.variable.reference, env, (int)i.integer, v, ex->disc) < 0)
 				exerror("%s: cannot set value", x->data.variable.symbol->name);
 		}
@@ -1149,7 +1147,7 @@ eval(Expr_t* ex, register Exnode_t* expr, void* env)
 		if (expr->data.generate.array->op == DYNAMIC)
 		{
 			n = expr->data.generate.index->type == STRING;
-			for (assoc = (Exassoc_t*)dtfirst((Dt_t*)expr->data.generate.array->data.variable.symbol->local.pointer); assoc; assoc = (Exassoc_t*)dtnext((Dt_t*)expr->data.generate.array->data.variable.symbol->local.pointer, assoc))
+			for (assoc = dtfirst((Dt_t*)expr->data.generate.array->data.variable.symbol->local.pointer); assoc; assoc = dtnext((Dt_t*)expr->data.generate.array->data.variable.symbol->local.pointer, assoc))
 			{
 				v.integer++;
 				if (n)
@@ -1183,10 +1181,10 @@ eval(Expr_t* ex, register Exnode_t* expr, void* env)
 		v.integer = 0;
 		if (expr->data.generate.array->op == DYNAMIC) {
 			n = expr->data.generate.index->type == STRING;
-			for (assoc = (Exassoc_t *) dtlast((Dt_t *) expr->data.generate.array->
+			for (assoc = dtlast((Dt_t *) expr->data.generate.array->
 						   data.variable.symbol->local.
 						   pointer); assoc;
-		 		assoc = (Exassoc_t *) dtprev((Dt_t *) expr->data.generate.array->
+		 		assoc = dtprev((Dt_t *) expr->data.generate.array->
 						  data.variable.symbol->local.pointer,
 						  assoc)) {
 				v.integer++;
@@ -1259,7 +1257,7 @@ eval(Expr_t* ex, register Exnode_t* expr, void* env)
 			expr->data.operand.left->data.variable.reference, args, EX_ARRAY, ex->disc);
 	case FUNCTION:
 		n = 0;
-		args[n++].string = (char*)env;
+		args[n++].string = env;
 		for (x = expr->data.operand.right; x && n < elementsof(args); x = x->data.operand.right)
 			args[n++] = eval(ex, x->data.operand.left, env);
 		return (*ex->disc->getf)(ex, expr->data.operand.left, expr->data.operand.left->data.variable.symbol, expr->data.operand.left->data.variable.reference, args+1, EX_CALL, ex->disc);
@@ -1268,13 +1266,11 @@ eval(Expr_t* ex, register Exnode_t* expr, void* env)
 			i = eval(ex, expr->data.variable.index, env);
 		else
 			i.integer = EX_SCALAR;
-#ifndef OLD
 		if (expr->data.variable.dyna) {
 			Extype_t locv;
 			locv = getdyn(ex, expr->data.variable.dyna, env, &assoc);
 			expr->data.variable.dyna->data.variable.dyna->data.constant.  value = locv;
 		}
-#endif
 		return (*ex->disc->getf)(ex, expr, expr->data.variable.symbol, expr->data.variable.reference, env, (int)i.integer, ex->disc);
 	case INC:
 		n = 1;
@@ -1283,14 +1279,8 @@ eval(Expr_t* ex, register Exnode_t* expr, void* env)
 		v.integer = prints(ex, expr, env, sfstdout);
 		return v;
 	case PRINTF:
-		v.integer = print(ex, expr, env, NiL);
+		v.integer = print(ex, expr, env, NULL);
 		return v;
-#ifdef UNUSED
-	case QUERY:
-		print(ex, expr, env, sfstderr);
-		v.integer = !astquery(2, "");
-		return v;
-#endif
 	case RETURN:
 		ex->loopret = eval(ex, x, env);
 		ex->loopcount = 32767;
@@ -1298,12 +1288,19 @@ eval(Expr_t* ex, register Exnode_t* expr, void* env)
 		return ex->loopret;
 	case SCANF:
 	case SSCANF:
-		v.integer = scan(ex, expr, env, NiL);
+		v.integer = scan(ex, expr, env, NULL);
 		return v;
-	case SPRINTF:
-		print(ex, expr, env, ex->tmp);
-		v.string = exstash(ex->tmp, ex->ve);
+	case SPRINTF: {
+		Sfio_t *buffer = sfstropen();
+		if (buffer == NULL) {
+			fprintf(stderr, "out of memory\n");
+			exit(EXIT_FAILURE);
+		}
+		print(ex, expr, env, buffer);
+		v.string = exstash(buffer, ex->ve);
+		sfstrclose(buffer);
 		return v;
+	}
 	case '=':
 		v = eval(ex, expr->data.operand.right, env);
 		if (expr->subop != '=')
@@ -1317,13 +1314,11 @@ eval(Expr_t* ex, register Exnode_t* expr, void* env)
 					v = eval(ex, x->data.variable.index, env);
 				else
 					v.integer = EX_SCALAR;
-#ifndef OLD
 				if (x->data.variable.dyna) {
 					Extype_t locv;
 					locv = getdyn(ex, x->data.variable.dyna, env, &assoc);
 					x->data.variable.dyna->data.variable.dyna->data.  constant.value = locv;
 				}
-#endif
 				v = (*ex->disc->getf)(ex, x, x->data.variable.symbol, x->data.variable.reference, env, (int)v.integer, ex->disc);
 			}
 			switch (x->type)
@@ -1350,25 +1345,25 @@ eval(Expr_t* ex, register Exnode_t* expr, void* env)
 					if ((r.integer = r.floating) == 0)
 						exerror("floating 0 modulus");
 					else
-						v.floating = ((Sflong_t)v.floating) % r.integer;
+						v.floating = (Sflong_t)v.floating % r.integer;
 					break;
 				case '&':
-					v.floating = ((Sflong_t)v.floating) & ((Sflong_t)r.floating);
+					v.floating = (Sflong_t)v.floating & (Sflong_t)r.floating;
 					break;
 				case '|':
-					v.floating = ((Sflong_t)v.floating) | ((Sflong_t)r.floating);
+					v.floating = (Sflong_t)v.floating | (Sflong_t)r.floating;
 					break;
 				case '^':
-					v.floating = ((Sflong_t)v.floating) ^ ((Sflong_t)r.floating);
+					v.floating = (Sflong_t)v.floating ^ (Sflong_t)r.floating;
 					break;
 				case LS:
-					v.floating = ((Sflong_t)v.floating) << ((Sflong_t)r.floating);
+					v.floating = (Sflong_t)v.floating << (Sflong_t)r.floating;
 					break;
 				case RS:
-#if _WIN32
-					v.floating = (Sflong_t)(((Sfulong_t)v.floating) >> ((Sflong_t)r.floating));
+#ifdef _WIN32
+					v.floating = (Sflong_t)((Sfulong_t)v.floating >> (Sflong_t)r.floating);
 #else
-					v.floating = ((Sfulong_t)v.floating) >> ((Sflong_t)r.floating);
+					v.floating = (Sfulong_t)v.floating >> (Sflong_t)r.floating;
 #endif
 					break;
 				default:
@@ -1515,10 +1510,10 @@ eval(Expr_t* ex, register Exnode_t* expr, void* env)
 			tmp.type = expr->type;
 			return tmp.data.constant.value;
 		case '!':
-			v.floating = !((Sflong_t)v.floating);
+			v.floating = !(Sflong_t)v.floating;
 			return v;
 		case '~':
-			v.floating = ~((Sflong_t)v.floating);
+			v.floating = ~(Sflong_t)v.floating;
 			return v;
 		case '-':
 			if (x)
@@ -1577,22 +1572,22 @@ eval(Expr_t* ex, register Exnode_t* expr, void* env)
  */
 			{
 				Sflong_t op1, op2;
-				op1 = ((Sflong_t) v.floating);
-				op2 = ((Sflong_t) r.floating);
+				op1 = (Sflong_t)v.floating;
+				op2 = (Sflong_t)r.floating;
 				v.floating = (double) (op1 << op2);
 			}
 			return v;
 		case RS:
-#if _WIN32
-			v.floating = (Sflong_t) (((Sfulong_t) v.floating) >> ((Sflong_t) r.floating));
+#ifdef _WIN32
+			v.floating = (Sflong_t) ((Sfulong_t)v.floating >> (Sflong_t)r.floating);
 #else
 /* IBM compilers can't deal with these shift operators on long long.
  *                                      v.floating = ((Sfulong_t)v.floating) >> ((Sflong_t)r.floating);
  */
 			{
 				Sflong_t op1, op2;
-				op1 = ((Sfulong_t) v.floating);
-				op2 = ((Sflong_t) r.floating);
+				op1 = (Sfulong_t)v.floating;
+				op2 = (Sflong_t)r.floating;
 				v.floating = (double) (op1 >> op2);
 			}
 #endif
@@ -1740,8 +1735,8 @@ eval(Expr_t* ex, register Exnode_t* expr, void* env)
  */
 			{
 				Sflong_t op1, op2;
-				op1 = ((Sflong_t) v.floating);
-				op2 = ((Sflong_t) r.floating);
+				op1 = (Sflong_t)v.floating;
+				op2 = (Sflong_t)r.floating;
 				v.floating = (double) (op1 << op2);
 			}
 			return v;
@@ -1752,9 +1747,9 @@ eval(Expr_t* ex, register Exnode_t* expr, void* env)
 			{
 				Sfulong_t op1;
 				Sflong_t op2;
-				op1 = ((Sfulong_t) v.floating);
-				op2 = ((Sflong_t) r.floating);
-				v.integer = (op1 >> op2);
+				op1 = (Sfulong_t)v.floating;
+				op2 = (Sflong_t)r.floating;
+				v.integer = op1 >> op2;
 			}
 			return v;
 		case '<':
@@ -1897,34 +1892,6 @@ exeval(Expr_t* ex, Exnode_t* expr, void* env)
 	return v;
 }
 
-#if 0
-/* strToL:
- * Convert a string representation of an integer
- * to an integer. The string can specify its own form
- * using 0x, etc.
- * If p != NULL, it points to the first character in
- * s where numeric parsing fails, or the last character.
- * The value is returned, with 0 returned for "".
- */
-Sflong_t strToL(char *s, char **p)
-{
-    Sflong_t v;
-    int i;
-    int n;
-
-    v = 0;
-    if (p) {
-	n = sfsscanf(s, "%I*i%n", sizeof(v), &v, &i);
-	if (n > 0)
-	    *p = s + i;
-	else
-	    *p = s;
-    } else
-	sfsscanf(s, "%I*i", sizeof(v), &v);
-    return v;
-}
-#endif
-
 /* exstring:
  * Generate copy of input string using
  * string memory.
@@ -1940,14 +1907,5 @@ char *exstring(Expr_t * ex, char *s)
  */
 void *exstralloc(Expr_t * ex, void *p, size_t sz)
 {
-    return vmresize(ex->ve, p, sz, VM_RSCOPY | VM_RSMOVE);
+    return vmresize(ex->ve, p, sz);
 }
-
-/* exstrfree:
- * Free memory obtained from exstralloc.
- */
-int exstrfree(Expr_t * ex, void *p)
-{
-    return vmfree(ex->ve, p);
-}
-
