@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 
@@ -35,16 +32,15 @@
 #include <limits.h>
 #include <inttypes.h>
 #include <assert.h>
-#include "tlayout.h"
-#include "neatoprocs.h"
-#include "adjust.h"
-#include "comp.h"
-#include "pack.h"
-#include "clusteredges.h"
-#include "dbg.h"
-#include <setjmp.h>
-
-static jmp_buf jbuf;
+#include <fdpgen/tlayout.h>
+#include <math.h>
+#include <neatogen/neatoprocs.h>
+#include <neatogen/adjust.h>
+#include <fdpgen/comp.h>
+#include <pack/pack.h>
+#include <fdpgen/clusteredges.h>
+#include <fdpgen/dbg.h>
+#include <stddef.h>
 
 typedef struct {
     graph_t*  rootg;  /* logical root; graph passed in to fdp_layout */
@@ -85,7 +81,7 @@ finalCC(graph_t * g, int c_cnt, graph_t ** cc, point * pts, graph_t * rg,
     int margin;
     graph_t **cp = cc;
     point *pp = pts;
-    int isRoot = (rg == infop->rootg);
+    int isRoot = rg == infop->rootg;
     int isEmpty = 0;
 
     /* compute graph bounding box in points */
@@ -187,7 +183,7 @@ static node_t *mkDeriveNode(graph_t * dg, char *name)
 
     dn = agnode(dg, name,1);
     agbindrec(dn, "Agnodeinfo_t", sizeof(Agnodeinfo_t), TRUE);	//node custom data
-    ND_alg(dn) = (void *) NEW(dndata);	/* free in freeDeriveNode */
+    ND_alg(dn) = NEW(dndata);	/* free in freeDeriveNode */
     ND_pos(dn) = N_GNEW(GD_ndim(dg), double);
     /* fprintf (stderr, "Creating %s\n", dn->name); */
     return dn;
@@ -310,8 +306,7 @@ static void addCluster(clist_t * clist, graph_t * subg)
 
 /* portName:
  * Generate a name for a port.
- * We use the name of the subgraph and names of the nodes on the edge,
- * if possible. Otherwise, we use the ids of the nodes.
+ * We use the ids of the nodes.
  * This is for debugging. For production, just use edge id and some
  * id for the graph. Note that all the graphs are subgraphs of the
  * root graph.
@@ -322,15 +317,9 @@ static char *portName(graph_t * g, bport_t * p)
     node_t *h = aghead(e);
     node_t *t = agtail(e);
     static char buf[BSZ + 1];
-    int len = 8;
 
-    len += strlen(agnameof(g)) + strlen(agnameof(h)) + strlen(agnameof(t));
-    if (len >= BSZ)
-	sprintf(buf, "_port_%s_%s_%s_%ld", agnameof(g), agnameof(t), agnameof(h),
-		(uint64_t)AGSEQ(e));
-    else
-	sprintf(buf, "_port_%s_(%d)_(%d)_%ld",agnameof(g), ND_id(t), ND_id(h),
-		(uint64_t)AGSEQ(e));
+	snprintf(buf, sizeof(buf), "_port_%s_(%d)_(%d)_%u",agnameof(g),
+		ND_id(t), ND_id(h), AGSEQ(e));
     return buf;
 }
 
@@ -356,7 +345,7 @@ static void chkPos(graph_t* g, node_t* n, layout_info* infop, boxf* bbp)
 	if (g != infop->rootg) {
 	    parent =agparent(g);
 	    pp = agxget(parent, G_coord);
-	    if ((pp == p) || !strcmp(p, pp))
+	    if (pp == p || !strcmp(p, pp))
 		return;
 	}
 	c = '\0';
@@ -428,19 +417,18 @@ static graph_t *deriveGraph(graph_t * g, layout_info * infop)
     graph_t *dg;
     node_t *dn;
     graph_t *subg;
-    char name[100];
     bport_t *pp;
     node_t *n;
     edge_t *de;
     int i, id = 0;
 
-    sprintf(name, "_dg_%d", infop->gid++);
     if (Verbose >= 2)
-	fprintf(stderr, "derive graph %s of %s\n", name, agnameof(g));
+	fprintf(stderr, "derive graph _dg_%d of %s\n", infop->gid, agnameof(g));
+    infop->gid++;
 
-    dg = agopen("derived", Agstrictdirected,NIL(Agdisc_t *));
+    dg = agopen("derived", Agstrictdirected,NULL);
     agbindrec(dg, "Agraphinfo_t", sizeof(Agraphinfo_t), TRUE);
-    GD_alg(dg) = (void *) NEW(gdata);	/* freed in freeDeriveGraph */
+    GD_alg(dg) = NEW(gdata);	/* freed in freeDeriveGraph */
 #ifdef DEBUG
     GORIG(dg) = g;
 #endif
@@ -465,20 +453,6 @@ static graph_t *deriveGraph(graph_t * g, layout_info * infop)
 		chkPos(subg, dn, infop, &fix_bb);
 	for (n = agfstnode(subg); n; n = agnxtnode(subg, n)) {
 	    DNODE(n) = dn;
-#ifdef UNIMPLEMENTED
-/* This code starts the implementation of supporting pinned nodes
- * within clusters. This needs more work. In particular, we may need
- * a separate notion of pinning related to contained nodes, which will
- * allow the cluster itself to wiggle.
- */
-	    if (ND_pinned(n)) {
-		fix_bb.LL.x = MIN(fix_bb.LL.x, ND_pos(n)[0]);
-		fix_bb.LL.y = MIN(fix_bb.LL.y, ND_pos(n)[1]);
-		fix_bb.UR.x = MAX(fix_bb.UR.x, ND_pos(n)[0]);
-		fix_bb.UR.y = MAX(fix_bb.UR.y, ND_pos(n)[1]);
-		ND_pinned(dn) = MAX(ND_pinned(dn), ND_pinned(n));
-	    }
-#endif
 	}
 	if (ND_pinned(dn)) {
 	    ND_pos(dn)[0] = (fix_bb.LL.x + fix_bb.UR.x) / 2;
@@ -489,9 +463,9 @@ static graph_t *deriveGraph(graph_t * g, layout_info * infop)
     /* create derived nodes from remaining nodes */
     for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
 	if (!DNODE(n)) {
-	    if (PARENT(n) && (PARENT(n) != GPARENT(g))) {
+	    if (PARENT(n) && PARENT(n) != GPARENT(g)) {
 		agerr (AGERR, "node \"%s\" is contained in two non-comparable clusters \"%s\" and \"%s\"\n", agnameof(n), agnameof(g), agnameof(PARENT(n)));
-		longjmp (jbuf, 1);
+		return NULL;
 	    }
 	    PARENT(n) = g;
 	    if (IS_CLUST_NODE(n))
@@ -588,8 +562,8 @@ static graph_t *deriveGraph(graph_t * g, layout_info * infop)
  */
 static int ecmp(const void *v1, const void *v2)
 {
-    erec *e1 = (erec *) v1;
-    erec *e2 = (erec *) v2;
+    const erec *e1 = v1;
+    const erec *e2 = v2;
     if (e1->alpha > e2->alpha)
 	return 1;
     else if (e1->alpha < e2->alpha)
@@ -645,7 +619,7 @@ static erec *getEdgeList(node_t * n, graph_t * g)
 	while (i < deg - 1) {
 	    a = erecs[i].alpha;
 	    j = i + 1;
-	    while ((j < deg) && (erecs[j].alpha == a))
+	    while (j < deg && erecs[j].alpha == a)
 		j++;
 	    if (j == i + 1)
 		i = j;
@@ -654,9 +628,7 @@ static erec *getEdgeList(node_t * n, graph_t * g)
 		    bnd = M_PI;	/* all values equal up to end */
 		else
 		    bnd = erecs[j].alpha;
-		delta = (bnd - a) / (j - i);
-		if (delta > ANG)
-		    delta = ANG;
+		delta = fmin((bnd - a) / (j - i), ANG);
 		inc = 0;
 		for (; i < j; i++) {
 		    erecs[i].alpha += inc;
@@ -695,10 +667,8 @@ genPorts(node_t * n, erec * er, bport_t * pp, int idx, double bnd)
     else
 	other = aghead(e);
 
-    delta = (bnd - er->alpha) / cnt;
+    delta = fmin((bnd - er->alpha) / cnt, ANG);
     angle = er->alpha;
-    if (delta > ANG)
-	delta = ANG;
 
     if (n < other) {
 	i = idx;
@@ -710,11 +680,11 @@ genPorts(node_t * n, erec * er, bport_t * pp, int idx, double bnd)
 	delta = -delta;
     }
 
-    ep = (edge_t **) (el = ED_to_virt(e));
+    ep = (edge_t **)ED_to_virt(e);
     for (j = 0; j < ED_count(e); j++, ep++) {
 	el = *ep;
 	pp[i].e = el;
-	pp[i].n = (DNODE(agtail(el)) == n ? agtail(el) : aghead(el));
+	pp[i].n = DNODE(agtail(el)) == n ? agtail(el) : aghead(el);
 	pp[i].alpha = angle;
 	i += inc;
 	angle += delta;
@@ -854,8 +824,7 @@ setClustNodes(graph_t* root)
  * Add edges per components to get better packing, rather than
  * wait until the end.
  */
-static 
-void layout(graph_t * g, layout_info * infop)
+static int layout(graph_t * g, layout_info * infop)
 {
     point *pts = NULL;
     graph_t *dg;
@@ -883,6 +852,9 @@ void layout(graph_t * g, layout_info * infop)
 	DNODE(n) = 0;
 
     dg = deriveGraph(g, infop);
+    if (dg == NULL) {
+	return -1;
+    }
     cc = pg = findCComp(dg, &c_cnt, &pinned);
 
     while ((cg = *pg++)) {
@@ -893,8 +865,10 @@ void layout(graph_t * g, layout_info * infop)
 	    if (ND_clust(n)) {
 		pointf pt;
 		sg = expandCluster(n, cg);	/* attach ports to sg */
-		layout(sg, infop);
-		/* bb.LL == origin */
+		int r = layout(sg, infop);
+		if (r != 0) {
+                    return r;
+		}
 		ND_width(n) = BB(sg).UR.x;
 		ND_height(n) = BB(sg).UR.y;
 		pt.x = POINTS_PER_INCH * BB(sg).UR.x;
@@ -911,8 +885,6 @@ void layout(graph_t * g, layout_info * infop)
 		normalize (cg);
 	    fdp_xLayout(cg, &xpms);
 	}
-	/* set bounding box but don't use ports */
-	/* setBB (cg); */
     }
 
     /* At this point, each connected component has its nodes correctly
@@ -934,8 +906,7 @@ void layout(graph_t * g, layout_info * infop)
 	    bp = 0;
 	infop->pack.fixed = bp;
 	pts = putGraphs(c_cnt, cc, NULL, &infop->pack);
-	if (bp)
-	    free(bp);
+	free(bp);
     } else {
 	pts = NULL;
 	if (c_cnt == 1)
@@ -978,6 +949,8 @@ void layout(graph_t * g, layout_info * infop)
 #ifdef DEBUG
     decInd();
 #endif
+
+    return 0;
 }
 
 /* setBB;
@@ -1009,7 +982,7 @@ static void init_info(graph_t * g, layout_info * infop)
     infop->G_height = agattr(g, AGRAPH, "height", NULL);
     infop->rootg = g;
     infop->gid = 0;
-    infop->pack.mode = getPackInfo(g, l_node, CL_OFFSET / 2, &(infop->pack));
+    infop->pack.mode = getPackInfo(g, l_node, CL_OFFSET / 2, &infop->pack);
 }
 
 /* mkClusters:
@@ -1037,7 +1010,7 @@ mkClusters (graph_t * g, clist_t* pclist, graph_t* parent)
 	{
 	if (!strncmp(agnameof(subg), "cluster", 7)) {
 	    agbindrec(subg, "Agraphinfo_t", sizeof(Agraphinfo_t), TRUE);
-	    GD_alg(subg) = (void *) NEW(gdata);	/* freed in cleanup_subgs */
+	    GD_alg(subg) = NEW(gdata);	/* freed in cleanup_subgs */
 	    GD_ndim(subg) = GD_ndim(parent);
 	    LEVEL(subg) = LEVEL(parent) + 1;
 	    GPARENT(subg) = parent;
@@ -1058,7 +1031,7 @@ mkClusters (graph_t * g, clist_t* pclist, graph_t* parent)
 static void fdp_init_graph(Agraph_t * g)
 {
     setEdgeType (g, ET_LINE);
-    GD_alg(g) = (void *) NEW(gdata);	/* freed in cleanup_graph */
+    GD_alg(g) = NEW(gdata);	/* freed in cleanup_graph */
     GD_ndim(g) = late_int(g, agattr(g,AGRAPH, "dim", NULL), 2, 2);
     Ndim = GD_ndim(g) = MIN(GD_ndim(g), MAXDIM);
 
@@ -1067,12 +1040,15 @@ static void fdp_init_graph(Agraph_t * g)
     fdp_init_node_edge(g);
 }
 
-static void fdpLayout(graph_t * g)
+static int fdpLayout(graph_t * g)
 {
     layout_info info;
 
     init_info(g, &info);
-    layout(g, &info);
+    int r = layout(g, &info);
+    if (r != 0) {
+        return r;
+    }
     setClustNodes(g);
     evalPositions(g,g);
 
@@ -1081,6 +1057,8 @@ static void fdpLayout(graph_t * g)
      * On return from spline drawing, all bounding boxes should be correct.
      */
     setBB(g);
+
+    return 0;
 }
 
 static void
@@ -1096,7 +1074,7 @@ fdpSplines (graph_t * g)
 	    if (trySplines)
 		Nop = 2;
 	}
-	if (trySplines || (et != ET_COMPOUND)) {
+	if (trySplines || et != ET_COMPOUND) {
 	    if (HAS_CLUST_EDGE(g)) {
 		agerr(AGWARN,
 		      "splines and cluster edges not supported - using line segments\n");
@@ -1113,21 +1091,13 @@ fdpSplines (graph_t * g)
 
 void fdp_layout(graph_t * g)
 {
-    /* Agnode_t* n; */
-
     double save_scale = PSinputscale;
         
     PSinputscale = get_inputscale (g);
     fdp_init_graph(g);
-    if (setjmp(jbuf)) {
+    if (fdpLayout(g) != 0) {
 	return;
     }
-    fdpLayout(g);
-#if 0
-    /* free ND_alg field so it can be used in spline routing */
-    if ((n = agfstnode(g)))
-	free(ND_alg(n));
-#endif
     neato_set_aspect(g);
 
     if (EDGE_TYPE(g) != ET_NONE) fdpSplines (g); 
