@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 /* tlayout.c:
@@ -39,9 +36,9 @@
 #include <unistd.h>
 #endif
 #include <ctype.h>
-#include <dbg.h>
-#include <grid.h>
-#include <neato.h>
+#include <fdpgen/dbg.h>
+#include <fdpgen/grid.h>
+#include <neatogen/neato.h>
 
 #ifndef HAVE_SRAND48
 #define srand48 srand
@@ -50,8 +47,8 @@
 extern double drand48(void);
 #endif
 
-#include "tlayout.h"
-#include "globals.h"
+#include <fdpgen/tlayout.h>
+#include <common/globals.h>
 
 #define D_useGrid   (fdp_parms->useGrid)
 #define D_useNew    (fdp_parms->useNew)
@@ -118,9 +115,9 @@ static parms_t parms;
 #define DFLT_seed  1
 #define DFLT_smode INIT_RANDOM
 
-static double cool(double temp, int t)
+static double cool(int t)
 {
-    return (T_T0 * (T_maxIters - t)) / T_maxIters;
+    return T_T0 * (T_maxIters - t) / T_maxIters;
 }
 
 /* reset_params:
@@ -155,7 +152,7 @@ static int init_params(graph_t * g, xparams * xpms)
 	ret = 1;
     }
 
-    xpms->T0 = cool(T_T0, T_pass1);
+    xpms->T0 = cool(T_pass1);
     xpms->K = T_K;
     xpms->C = T_C;
     xpms->numIters = T_maxIters - T_pass1;
@@ -200,7 +197,7 @@ void fdp_initParams(graph_t * g)
 	T_seed = DFLT_smode;
     }
 
-    T_pass1 = (T_unscaled * T_maxIters) / 100;
+    T_pass1 = T_unscaled * T_maxIters / 100;
     T_K2 = T_K * T_K;
 
     if (T_useGrid) {
@@ -342,9 +339,9 @@ static void applyAttr(Agnode_t * p, Agnode_t * q, Agedge_t * e)
     }
     dist = sqrt(dist2);
     if (T_useNew)
-	force = (ED_factor(e) * (dist - ED_dist(e))) / dist;
+	force = ED_factor(e) * (dist - ED_dist(e)) / dist;
     else
-	force = (ED_factor(e) * dist) / ED_dist(e);
+	force = ED_factor(e) * dist / ED_dist(e);
     DISP(q)[0] -= xdelta * force;
     DISP(q)[1] -= ydelta * force;
     DISP(p)[0] += xdelta * force;
@@ -372,14 +369,14 @@ static void updatePos(Agraph_t * g, double temp, bport_t * pp)
 	    x = ND_pos(n)[0] + dx;
 	    y = ND_pos(n)[1] + dy;
 	} else {
-	    double fact = temp / (sqrt(len2));
+	    double fact = temp / sqrt(len2);
 	    x = ND_pos(n)[0] + dx * fact;
 	    y = ND_pos(n)[1] + dy * fact;
 	}
 
 	/* if ports, limit by boundary */
 	if (pp) {
-	    d = sqrt((x * x) / T_Wd2 + (y * y) / T_Ht2);
+	    d = sqrt(x * x / T_Wd2 + y * y / T_Ht2);
 	    if (IS_PORT(n)) {
 		ND_pos(n)[0] = x / d;
 		ND_pos(n)[1] = y / d;
@@ -500,7 +497,7 @@ static pointf initPositions(graph_t * g, bport_t * pp)
 	width = EXPFACTOR * (bb.UR.x - bb.LL.x);
 	height = EXPFACTOR * (bb.UR.y - bb.LL.y);
 	area = 4.0 * T_Wd * T_Ht;
-	quot = (width * height) / area;
+	quot = width * height / area;
 	if (quot >= 1.0) {	/* If bbox has large enough area, use it */
 	    T_Wd = width / 2.0;
 	    T_Ht = height / 2.0;
@@ -578,7 +575,7 @@ static pointf initPositions(graph_t * g, bport_t * pp)
 		for (ep = agfstedge(g, np); ep; ep = agnxtedge(g, ep, np)) {
 		    if (aghead(ep) == agtail(ep))
 			continue;
-		    op = (aghead(ep) == np ? agtail(ep) : aghead(ep));
+		    op = aghead(ep) == np ? agtail(ep) : aghead(ep);
 		    if (!hasPos(op))
 			continue;
 		    if (cnt) {
@@ -680,18 +677,18 @@ void fdp_tLayout(graph_t * g, xparams * xpms)
 	grid = mkGrid(agnnodes(g));
 	adjustGrid(grid, agnnodes(g));
 	for (i = 0; i < T_loopcnt; i++) {
-	    temp = cool(temp, i);
+	    temp = cool(i);
 	    gAdjust(g, temp, pp, grid);
 	}
 	delGrid(grid);
     } else {
 	for (i = 0; i < T_loopcnt; i++) {
-	    temp = cool(temp, i);
+	    temp = cool(i);
 	    adjust(g, temp, pp);
 	}
     }
 
-    if ((ctr.x != 0.0) || (ctr.y != 0.0)) {
+    if (ctr.x != 0.0 || ctr.y != 0.0) {
 	for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
 	    ND_pos(n)[0] += ctr.x;
 	    ND_pos(n)[1] += ctr.y;
