@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 /*
@@ -17,6 +14,7 @@
 
 #include "config.h"
 
+#include <ctype.h>
 #include <stdarg.h>
 #include <stdlib.h>
 #include <string.h>
@@ -29,7 +27,6 @@
 #ifdef _WIN32
 #include <fcntl.h>
 #include <io.h>
-#include "compat.h"
 #endif
 
 #ifdef HAVE_LIBZ
@@ -47,21 +44,22 @@ static unsigned int dfallocated;
 static uint64_t crc;
 #endif /* HAVE_LIBZ */
 
-#include "const.h"
-#include "memory.h"
-#include "gvplugin_device.h"
-#include "gvcjob.h"
-#include "gvcint.h"
-#include "gvcproc.h"
-#include "logic.h"
-#include "gvio.h"
+#include <assert.h>
+#include <common/const.h>
+#include <common/memory.h>
+#include <gvc/gvplugin_device.h>
+#include <gvc/gvcjob.h>
+#include <gvc/gvcint.h>
+#include <gvc/gvcproc.h>
+#include <common/logic.h>
+#include <gvc/gvio.h>
 
 static const int PAGE_ALIGN = 4095;		/* align to a 4K boundary (less one), typical for Linux, Mac OS X and Windows memory allocation */
 
 static size_t gvwrite_no_z (GVJ_t * job, const char *s, size_t len)
 {
     if (job->gvc->write_fn)   /* externally provided write dicipline */
-	return (job->gvc->write_fn)(job, (char*)s, len);
+	return (job->gvc->write_fn)(job, s, len);
     if (job->output_data) {
 	if (len > job->output_data_allocated - (job->output_data_position + 1)) {
 	    /* ensure enough allocation for string = null terminator */
@@ -77,8 +75,10 @@ static size_t gvwrite_no_z (GVJ_t * job, const char *s, size_t len)
 	job->output_data[job->output_data_position] = '\0'; /* keep null termnated */
 	return len;
     }
-    else
-	return fwrite(s, sizeof(char), len, job->output_file);
+    else {
+        assert(job->output_file != NULL);
+        return fwrite(s, sizeof(char), len, job->output_file);
+    }
     return 0;
 }
 
@@ -91,7 +91,7 @@ static void auto_output_filename(GVJ_t *job)
     size_t len;
 
     if (job->graph_index)
-        sprintf(gidx, ".%d", job->graph_index + 1);
+        snprintf(gidx, sizeof(gidx), ".%d", job->graph_index + 1);
     else
         gidx[0] = '\0';
     if (!(fn = job->input_filename))
@@ -214,7 +214,7 @@ size_t gvwrite (GVJ_t * job, const char *s, size_t len)
 	    }
 	}
 
-	crc = crc32(crc, (unsigned char*)s, len);
+	crc = crc32(crc, (const unsigned char*)s, len);
 
 	z->next_in = (unsigned char*)s;
 	z->avail_in = len;
@@ -237,6 +237,7 @@ size_t gvwrite (GVJ_t * job, const char *s, size_t len)
 	}
 
 #else
+        NOTUSED(olen);
 	(job->common->errorfn) ("No libz support.\n");
 	exit(1);
 #endif
@@ -261,13 +262,6 @@ int gvferror (FILE* stream)
     return 0;
 }
 
-size_t gvfwrite (const void *ptr, size_t size, size_t nmemb, FILE *stream)
-{
-    size = sizeof(char);
-    assert(size);
-    return gvwrite((GVJ_t*)stream, ptr, nmemb);
-}
-
 int gvputs(GVJ_t * job, const char *s)
 {
     size_t len = strlen(s);
@@ -275,7 +269,7 @@ int gvputs(GVJ_t * job, const char *s)
     if (gvwrite (job, s, len) != len) {
 	return EOF;
     }
-    return +1;
+    return 1;
 }
 
 int gvputc(GVJ_t * job, int c)
@@ -353,14 +347,14 @@ void gvdevice_finalize(GVJ_t * job)
 	    (job->common->errorfn) ("deflation end problem %d\n", ret);
 	    exit(1);
 	}
-	out[0] = crc;
-	out[1] = crc >> 8;
-	out[2] = crc >> 16;
-	out[3] = crc >> 24;
-	out[4] = z->total_in;
-	out[5] = z->total_in >> 8;
-	out[6] = z->total_in >> 16;
-	out[7] = z->total_in >> 24;
+	out[0] = (unsigned char)crc;
+	out[1] = (unsigned char)(crc >> 8);
+	out[2] = (unsigned char)(crc >> 16);
+	out[3] = (unsigned char)(crc >> 24);
+	out[4] = (unsigned char)z->total_in;
+	out[5] = (unsigned char)(z->total_in >> 8);
+	out[6] = (unsigned char)(z->total_in >> 16);
+	out[7] = (unsigned char)(z->total_in >> 24);
 	gvwrite_no_z(job, (char*)out, sizeof(out));
 #else
 	(job->common->errorfn) ("No libz support\n");
@@ -381,12 +375,7 @@ void gvdevice_finalize(GVJ_t * job)
 	gvdevice_close(job);
     }
 }
-/* gvprintf:
- * Unless vsnprintf is available, this function is unsafe due to the fixed buffer size.
- * It should only be used when the caller is sure the input will not
- * overflow the buffer. In particular, it should be avoided for
- * input coming from users.
- */
+
 void gvprintf(GVJ_t * job, const char *format, ...)
 {
     char buf[BUFSIZ];
@@ -395,9 +384,14 @@ void gvprintf(GVJ_t * job, const char *format, ...)
     char* bp = buf;
 
     va_start(argp, format);
-#ifdef HAVE_VSNPRINTF
-    len = vsnprintf((char *)buf, BUFSIZ, format, argp);
+    {
+	va_list argp2;
+	va_copy(argp2, argp);
+	len = vsnprintf(buf, BUFSIZ, format, argp2);
+	va_end(argp2);
+    }
     if (len < 0) {
+	va_end(argp);
 	agerr (AGERR, "gvprintf: %s\n", strerror(errno));
 	return;
     }
@@ -406,13 +400,8 @@ void gvprintf(GVJ_t * job, const char *format, ...)
      * to write the string without truncation. 
      */
 	bp = gmalloc(len + 1);
-	va_end(argp);
-	va_start(argp, format);
 	len = vsprintf(bp, format, argp);
     }
-#else
-    len = vsprintf((char *)buf, format, argp);
-#endif
     va_end(argp);
 
     gvwrite(job, bp, len);
@@ -477,11 +466,11 @@ static char * gvprintnum (size_t *len, double number)
     showzeros = FALSE;			/* don't print trailing zeros */
     for (i = DECPLACES; N || i > 0; i--) {  /* non zero remainder,
 						or still in fractional part */
-        digit = N % 10;			/* next least-significant digit */
+        digit = (int)(N % 10L);			/* next least-significant digit */
         N /= 10;
         if (digit || showzeros) {	/* if digit is non-zero,
 						or if we are printing zeros */
-            *--result = digit | '0';	/* convert digit to ascii */
+            *--result = (char)digit | '0';	/* convert digit to ascii */
             showzeros = TRUE;		/* from now on we must print zeros */
         }
         if (i == 1) {			/* if completed fractional part */
@@ -529,44 +518,40 @@ int main (int argc, char *argv[])
 
 /* gv_trim_zeros
 * Trailing zeros are removed and decimal point, if possible.
-* Add trailing space if addSpace is non-zero.
+* Assumes the input is the result of %.02f printing.
 */
-static void gv_trim_zeros(char* buf, int addSpace)
+static void gv_trim_zeros(char* buf)
 {
-    char* dotp;
-    char* p;
+  char *dotp = strchr(buf, '.');
+  if (dotp == NULL) {
+    return;
+  }
 
-    if ((dotp = strchr(buf, '.'))) {
-        p = dotp + 1;
-        while (*p) p++;  // find end of string
-        p--;
-        while (*p == '0') *p-- = '\0';
-        if (*p == '.')        // If all decimals were zeros, remove ".".
-            *p = '\0';
-        else
-            p++;
-    }
-    else if (addSpace)
-        p = buf + strlen(buf);
+  // check this really is the result of %.02f printing
+  assert(isdigit(dotp[1]) && isdigit(dotp[2]) && dotp[3] == '\0');
 
-    if (addSpace) { /* p points to null byte */
-        *p++ = ' ';
-        *p = '\0';
+  if (dotp[2] == '0') {
+    if (dotp[1] == '0') {
+      *dotp = '\0';
+    } else {
+      dotp[2] = '\0';
     }
+  }
 }
 
 void gvprintdouble(GVJ_t * job, double num)
 {
     // Prevents values like -0
-    if (num > -0.00000001 && num < 0.00000001)
+    if (num > -0.005 && num < 0.005)
     {
-        num = 0;
+        gvwrite(job, "0", 1);
+        return;
     }
 
     char buf[50];
 
     snprintf(buf, 50, "%.02f", num);
-    gv_trim_zeros(buf, 0);
+    gv_trim_zeros(buf);
 
     gvwrite(job, buf, strlen(buf));
 }
