@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 #include "config.h"
@@ -17,9 +14,9 @@
 #include <stdlib.h>
 #include <math.h>
 
-#include "gvplugin_layout.h"
-#include "gvcint.h"
-#include "gvcproc.h"
+#include <gvc/gvplugin_layout.h>
+#include <gvc/gvcint.h>
+#include <gvc/gvcproc.h>
 
 extern char *strdup_and_subst_obj(char *str, void * n);
 extern void emit_graph(GVJ_t * job, graph_t * g);
@@ -248,10 +245,8 @@ static void gvevent_enter_obj(GVJ_t * job)
     node_t *n;
     Agsym_t *a;
 
-    if (job->active_tooltip) {
-	free(job->active_tooltip);
-	job->active_tooltip = NULL;
-    }
+    free(job->active_tooltip);
+    job->active_tooltip = NULL;
     obj = job->current_obj;
     if (obj) {
         switch (agobjkind(obj)) {
@@ -347,10 +342,8 @@ static void gvevent_select_current_obj(GVJ_t * job)
         }
     }
 
-    if (job->selected_href) {
-	free(job->selected_href);
-        job->selected_href = NULL;
-    }
+    free(job->selected_href);
+    job->selected_href = NULL;
 
     obj = job->selected_obj = job->current_obj;
     if (obj) {
@@ -576,13 +569,13 @@ static void gvevent_read (GVJ_t * job, const char *filename, const char *layout)
 
     gvc = job->gvc;
     if (!filename) {
-	g = agread(stdin,NIL(Agdisc_t *));  // continue processing stdin
+	g = agread(stdin,NULL);  // continue processing stdin
     }
     else {
 	f = fopen(filename, "r");
 	if (!f)
 	   return;   /* FIXME - need some error handling */
-	g = agread(f,NIL(Agdisc_t *));
+	g = agread(f,NULL);
 	fclose(f);
     }
 
