@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 #ifndef GVDEVICE_H
@@ -36,7 +33,6 @@ extern "C" {
 /*end visual studio*/
 
     extern size_t gvwrite (GVJ_t * job, const char *s, size_t len);
-    extern size_t gvfwrite (const void *ptr, size_t size, size_t nmemb, FILE *stream);
     extern int gvferror (FILE *stream);
     extern int gvputc(GVJ_t * job, int c);
     extern int gvputs(GVJ_t * job, const char *s);
