@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 /*
@@ -19,31 +16,25 @@
 
 #include "config.h"
 
+#include <assert.h>
 #include <string.h>
-#include "memory.h"
-#include "const.h"
-#include "macros.h"
-#include "colorprocs.h"
-#include "gvplugin_render.h"
-#include "cgraph.h"
-#include "gvcint.h"
-#include "geom.h"
-#include "geomprocs.h"
-#include "gvcproc.h"
+#include <common/memory.h>
+#include <common/const.h>
+#include <common/macros.h>
+#include <common/colorprocs.h>
+#include <gvc/gvplugin_render.h>
+#include <cgraph/cgraph.h>
+#include <gvc/gvcint.h>
+#include <common/geom.h>
+#include <common/geomprocs.h>
+#include <gvc/gvcproc.h>
+#include <cgraph/strcasecmp.h>
+#include <stdlib.h>
 
 extern int emit_once(char *str);
 extern shape_desc *find_user_shape(char *name);
 extern boolean mapbool(char *s);
 
-#ifndef HAVE_STRCASECMP
-extern int strcasecmp(const char *s1, const char *s2);
-#endif
-
-/* storage for temporary hacks until client API is FP */
-static pointf *AF;
-static int sizeAF;
-/* end hack */
-
 int gvrender_select(GVJ_t * job, const char *str)
 {
     GVC_t *gvc = job->gvc;
@@ -185,7 +176,7 @@ pointf *gvrender_ptf_A(GVJ_t * job, pointf * af, pointf * AF, int n)
 
 static int gvrender_comparestr(const void *s1, const void *s2)
 {
-    return strcmp(*(char **) s1, *(char **) s2);
+    return strcmp(*(char *const *) s1, *(char *const *) s2);
 }
 
 /* gvrender_resolve_color:
@@ -586,12 +577,12 @@ void gvrender_polygon(GVJ_t * job, pointf * af, int n, int filled)
 	    if (job->flags & GVRENDER_DOES_TRANSFORM)
 		gvre->polygon(job, af, n, filled);
 	    else {
-		if (sizeAF < n) {
-		    sizeAF = n + 10;
-		    AF = grealloc(AF, sizeAF * sizeof(pointf));
-		}
+		pointf *AF;
+		assert(n >= 0);
+		AF = gcalloc((size_t)n, sizeof(pointf));
 		gvrender_ptf_A(job, af, AF, n);
 		gvre->polygon(job, AF, n, filled);
+		free(AF);
 	    }
 	    if (noPoly)
 		job->obj->pencolor = save_pencolor;
@@ -626,13 +617,13 @@ void gvrender_beziercurve(GVJ_t * job, pointf * af, int n,
 		gvre->beziercurve(job, af, n, arrow_at_start, arrow_at_end,
 				  filled);
 	    else {
-		if (sizeAF < n) {
-		    sizeAF = n + 10;
-		    AF = grealloc(AF, sizeAF * sizeof(pointf));
-		}
+		pointf *AF;
+		assert(n >= 0);
+		AF = gcalloc((size_t)n, sizeof(pointf));
 		gvrender_ptf_A(job, af, AF, n);
 		gvre->beziercurve(job, AF, n, arrow_at_start, arrow_at_end,
 				  filled);
+		free(AF);
 	    }
 	}
     }
@@ -647,12 +638,12 @@ void gvrender_polyline(GVJ_t * job, pointf * af, int n)
 	    if (job->flags & GVRENDER_DOES_TRANSFORM)
 		gvre->polyline(job, af, n);
 	    else {
-		if (sizeAF < n) {
-		    sizeAF = n + 10;
-		    AF = grealloc(AF, sizeAF * sizeof(pointf));
-		}
+		pointf *AF;
+		assert(n >= 0);
+		AF = gcalloc((size_t)n, sizeof(pointf));
 		gvrender_ptf_A(job, af, AF, n);
 		gvre->polyline(job, AF, n);
+		free(AF);
 	    }
 	}
     }
