@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 #include "config.h"
@@ -25,18 +22,16 @@
 #define GLOB_ABORTED    2   /* Read error.  */
 #define GLOB_NOMATCH    3   /* No matches found.  */
 #define GLOB_NOSORT     4
-#define DMKEY "Software\\Microsoft" //key to look for library dir
 #endif
 
-#include <regex.h>
-#include "types.h"
-#include "logic.h"
-#include "memory.h"
-#include "agxbuf.h"
+#include <common/types.h>
+#include <common/logic.h>
+#include <common/memory.h>
+#include <cgraph/agxbuf.h>
 
 #define _BLD_gvc 1
-#include "utils.h"
-#include "gvplugin_loadimage.h"
+#include <common/utils.h>
+#include <gvc/gvplugin_loadimage.h>
 
 extern char *Gvimagepath;
 extern char *HTTPServerEnVar;
@@ -166,8 +161,46 @@ static unsigned int svg_units_convert(double n, char *u)
     return 0;
 }
 
-static char* svg_attr_value_re = "([a-z][a-zA-Z]*)=\"([^\"]*)\"";
-static regex_t re, *pre = NULL;
+typedef struct {
+  size_t key_start;
+  size_t key_extent;
+  size_t value_start;
+  size_t value_extent;
+} match_t;
+
+static int find_attribute(const char *s, match_t *result) {
+
+  // look for an attribute string matching ([a-z][a-zA-Z]*)="([^"]*)"
+  for (size_t i = 0; s[i] != '\0'; ) {
+    if (s[i] >= 'a' && s[i] <= 'z') {
+      result->key_start = i;
+      result->key_extent = 1;
+      ++i;
+      while ((s[i] >= 'a' && s[i] <= 'z') || (s[i] >= 'A' && s[i] <= 'Z')) {
+        ++i;
+        ++result->key_extent;
+      }
+      if (s[i] == '=' && s[i + 1] == '"') {
+        i += 2;
+        result->value_start = i;
+        result->value_extent = 0;
+        while (s[i] != '"' && s[i] != '\0') {
+          ++i;
+          ++result->value_extent;
+        }
+        if (s[i] == '"') {
+          // found a valid attribute
+          return 0;
+        }
+      }
+    } else {
+      ++i;
+    }
+  }
+
+  // no attribute found
+  return -1;
+}
 
 static void svg_size (usershape_t *us)
 {
@@ -177,28 +210,19 @@ static void svg_size (usershape_t *us)
     char *attribute, *value, *re_string;
     char line[200];
     boolean wFlag = FALSE, hFlag = FALSE;
-#define RE_NMATCH 4
-    regmatch_t re_pmatch[RE_NMATCH];
-
-    /* compile on first use */
-    if (! pre) {
-        if (regcomp(&re, svg_attr_value_re, REG_EXTENDED) != 0) {
-	    agerr(AGERR,"cannot compile regular expression %s", svg_attr_value_re);
-    	}
-	pre = &re;
-    }
 
     fseek(us->f, 0, SEEK_SET);
     while (fgets(line, sizeof(line), us->f) != NULL && (!wFlag || !hFlag)) {
 	re_string = line;
-	while (regexec(&re, re_string, RE_NMATCH, re_pmatch, 0) == 0) {
-	    re_string[re_pmatch[1].rm_eo] = '\0';
-	    re_string[re_pmatch[2].rm_eo] = '\0';
-	    attribute = re_string + re_pmatch[1].rm_so;
-	    value = re_string + re_pmatch[2].rm_so;
-    	    re_string += re_pmatch[0].rm_eo + 1;
+	match_t match;
+	while (find_attribute(re_string, &match) == 0) {
+	    re_string[match.value_start + match.value_extent] = '\0';
+	    attribute = re_string + match.key_start;
+	    value = re_string + match.value_start;
+	    re_string += match.value_start + match.value_extent + 1;
 
-	    if (strcmp(attribute,"width") == 0) {
+	    if (match.key_extent == strlen("width") &&
+	        strncmp(attribute, "width", match.key_extent) == 0) {
 	        if (sscanf(value, "%lf%2s", &n, u) == 2) {
 	            w = svg_units_convert(n, u);
 	            wFlag = TRUE;
@@ -210,7 +234,8 @@ static void svg_size (usershape_t *us)
 		if (hFlag)
 		    break;
 	    }
-	    else if (strcmp(attribute,"height") == 0) {
+	    else if (match.key_extent == strlen("height") &&
+	             strncmp(attribute, "height", match.key_extent) == 0) {
 	        if (sscanf(value, "%lf%2s", &n, u) == 2) {
 	            h = svg_units_convert(n, u);
 	            hFlag = TRUE;
@@ -222,7 +247,8 @@ static void svg_size (usershape_t *us)
                 if (wFlag)
 		    break;
 	    }
-	    else if (strcmp(attribute,"viewBox") == 0
+	    else if (match.key_extent == strlen("viewBox")
+	      && strncmp(attribute, "viewBox", match.key_extent) == 0
 	      && sscanf(value, "%lf %lf %lf %lf", &x0,&y0,&x1,&y1) == 4) {
 		w = x1 - x0 + 1;
 		h = y1 - y0 + 1;
@@ -597,11 +623,7 @@ boolean gvusershape_file_access(usershape_t *us)
 	    agerr(AGWARN, "Filename \"%s\" is unsafe\n", us->name);
 	    return FALSE;
 	}
-#ifndef _WIN32
-	us->f = fopen(fn, "r");
-#else
 	us->f = fopen(fn, "rb");
-#endif
 	if (us->f == NULL) {
 	    agerr(AGWARN, "%s while opening %s\n", strerror(errno), fn);
 	    return FALSE;
@@ -641,8 +663,7 @@ static usershape_t *gvusershape_open (const char *name)
         ImageDict = dtopen(&ImageDictDisc, Dttree);
 
     if (! (us = gvusershape_find(name))) {
-        if (! (us = zmalloc(sizeof(usershape_t))))
-	    return NULL;
+        us = zmalloc(sizeof(usershape_t));
 
 	us->name = agstrdup (0, (char*)name);
 	if (!gvusershape_file_access(us)) {
@@ -654,7 +675,7 @@ static usershape_t *gvusershape_open (const char *name)
 
         switch(imagetype(us)) {
 	    case FT_NULL:
-		if (!(us->data = (void*)find_user_shape(us->name))) {
+		if (!(us->data = find_user_shape(us->name))) {
 		    agerr(AGWARN, "\"%s\" was not found as a file or as a shape library member\n", us->name);
 		    freeUsershape (us);
 		    return NULL;
@@ -687,9 +708,6 @@ static usershape_t *gvusershape_open (const char *name)
 	    case FT_ICO:
 		ico_size(us);
 		break;
-//	    case FT_TIFF:
-//		tiff_size(us);
-//		break;
 	    case FT_EPS:   /* no eps_size code available */
 	    default:
 	        break;
