@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 
@@ -16,14 +13,17 @@
  *  Code for main functions in gpr
  */
 
-#include <actions.h>
-#include <error.h>
-#include <ast.h>
-#include "compile.h"
-#include "sfstr.h"
+#include <gvpr/actions.h>
+#include <ast/error.h>
+#include <ast/ast.h>
+#include <gvpr/compile.h>
+#include <ast/sfstr.h>
+#include <stddef.h>
 #include <string.h>
 #include <stdio.h>
 #include <ctype.h>
+#include <cgraph/agxbuf.h>
+#include <cgraph/strcasecmp.h>
 
 #define KINDS(p) ((AGTYPE(p) == AGRAPH) ? "graph" : (AGTYPE(p) == AGNODE) ? "node" : "edge")
 
@@ -56,22 +56,8 @@ Agraph_t *sameG(void *p1, void *p2, char *fn, char *msg)
  */
 int indexOf(char *s1, char *s2)
 {
-    char c1 = *s2;
-    char c;
-    char *p;
-    int len2;
-
-    if (c1 == '\0')
-	return 0;
-    p = s1;
-    len2 = strlen(s2) - 1;
-    while ((c = *p++)) {
-	if (c != c1)
-	    continue;
-	if (strncmp(p, s2 + 1, len2) == 0)
-	    return ((p - s1) - 1);
-    }
-    return -1;
+    char *s = strstr(s1, s2);
+    return s == NULL ? -1 : (int)(s1 - s);
 }
 
 /* rindexOf:
@@ -80,18 +66,18 @@ int indexOf(char *s1, char *s2)
 int rindexOf(char *s1, char *s2)
 {
     char c1 = *s2;
-    char c;
     char *p;
-    int len1 = strlen(s1);
-    int len2 = strlen(s2);
+    size_t len1 = strlen(s1);
+    size_t len2 = strlen(s2);
 
     if (c1 == '\0')
 	return (len1);
+    if (len2 > len1)
+	return -1;
     p = s1 + (len1 - len2);
     while (p >= s1) {
-	c = *p;
-	if ((c == c1) && (strncmp(p+1, s2+1, len2-1) == 0))
-	    return (p - s1);
+	if (strncmp(p, s2, len2) == 0)
+	    return p - s1;
 	else
 	    p--;
     }
@@ -186,7 +172,7 @@ Agobj_t *copy(Agraph_t * g, Agobj_t * obj)
     int kind = AGTYPE(obj);
     char *name;
 
-    if ((kind != AGRAPH) && !g) {
+    if (kind != AGRAPH && !g) {
 	exerror("NULL graph with non-graph object in copy()");
 	return 0;
     }
@@ -245,7 +231,7 @@ static Agraph_t *cloneSubg(Agraph_t * tgt, Agraph_t * g, Dt_t* emap)
     Agedge_t *newe;
     char* name;
 
-    ng = (Agraph_t *) (copy(tgt, OBJ(g)));
+    ng = (Agraph_t *) copy(tgt, OBJ(g));
     if (!ng)
 	return 0;
     for (t = agfstnode(g); t; t = agnxtnode(g, t)) {
@@ -317,7 +303,7 @@ static void cloneGraph(Agraph_t * tgt, Agraph_t * src)
     Agraph_t *sg;
     char* name;
     Dt_t* emap = dtopen (&edgepair, Dtoset);
-    edgepair_t* data = (edgepair_t*)malloc(sizeof(edgepair_t)*agnedges(src));
+    edgepair_t* data = malloc(sizeof(edgepair_t)*agnedges(src));
     edgepair_t* ep = data;
 
     for (t = agfstnode(src); t; t = agnxtnode(src, t)) {
@@ -363,7 +349,7 @@ Agraph_t *cloneG(Agraph_t * g, char* name)
 {
     Agraph_t* ng;
 
-    if (!name || (*name == '\0'))
+    if (!name || *name == '\0')
 	name = agnameof (g);
     ng = openG(name, g->desc);
     if (ng) {
@@ -390,7 +376,7 @@ Agobj_t *clone(Agraph_t * g, Agobj_t * obj)
     int kind = AGTYPE(obj);
     char *name;
 
-    if ((kind != AGRAPH) && !g) {
+    if (kind != AGRAPH && !g) {
 	exerror("NULL graph with non-graph object in clone()");
 	return 0;
     }
@@ -464,7 +450,7 @@ Agraph_t *compOf(Agraph_t * g, Agnode_t * n)
     for (np = agfstnode(g); np; np = agnxtnode(g, np))
 	CCUNMARK(np);
 
-    sprintf(name, "_cc_%d", id++);
+    snprintf(name, sizeof(name), "_cc_%d", id++);
     cg = openSubg(g, name);
     cc_dfs(g, cg, n);
 
@@ -536,7 +522,7 @@ int lockGraph(Agraph_t * g, int v)
     oldv = data->lock & 1;
     if (v > 0)
 	data->lock |= 1;
-    else if ((v == 0) && oldv) {
+    else if (v == 0 && oldv) {
 	if (data->lock & 2)
 	    agclose(g);
 	else
@@ -694,7 +680,7 @@ int closeFile(Expr_t * ex, int fd)
 {
     int rv;
 
-    if ((0 <= fd) && (fd <= 2)) {
+    if (0 <= fd && fd <= 2) {
 	exerror("closeF: cannot close standard stream %d", fd);
 	return -1;
     }
@@ -716,20 +702,20 @@ char *readLine(Expr_t * ex, int fd)
 {
     Sfio_t *sp;
     int c;
-    Sfio_t *tmps;
+    agxbuf tmps;
     char *line;
 
     if (fd < 0 || fd >= elementsof(ex->file) || !((sp = ex->file[fd]))) {
 	exerror("readL: %d: invalid descriptor", fd);
 	return "";
     }
-    tmps = sfstropen();
-    while (((c = sfgetc(sp)) > 0) && (c != '\n'))
-	sfputc(tmps, c);
+    agxbinit(&tmps, 0, NULL);
+    while ((c = sfgetc(sp)) > 0 && c != '\n')
+	agxbputc(&tmps, c);
     if (c == '\n')
-	sfputc(tmps, c);
-    line = exstring(ex, sfstruse(tmps));
-    sfclose(tmps);
+	agxbputc(&tmps, c);
+    line = exstring(ex, agxbuse(&tmps));
+    agxbfree(&tmps);
     return line;
 }
 
@@ -814,22 +800,13 @@ char *canon(Expr_t * pgm, char *arg)
 }
 
 #include <stdlib.h>
-#ifdef _WIN32
-#include "compat.h"
-#endif
 
-#include "arith.h"
-#include "color.h"
-#include "colortbl.h"
+#include <common/arith.h>
+#include <common/color.h>
+#include <common/colortbl.h>
 
 static char* colorscheme;
 
-#ifdef _MSC_VER
-extern int strcasecmp(const char *s1, const char *s2);
-extern int strncasecmp(const char *s1, const char *s2, unsigned int n);
-#endif
-
-
 static void hsv2rgb(double h, double s, double v,
 			double *r, double *g, double *b)
 {
@@ -932,15 +909,15 @@ static void rgb2cmyk(double r, double g, double b, double *c, double *m,
 
 static int colorcmpf(const void *p0, const void *p1)
 {
-    return strcasecmp(((hsvrgbacolor_t *) p0)->name, ((hsvrgbacolor_t *) p1)->name);
+    return strcasecmp(((const hsvrgbacolor_t *) p0)->name, ((const hsvrgbacolor_t *) p1)->name);
 }
 
 static char *canontoken(char *str)
 {
     static unsigned char *canon;
-    static int allocated;
+    static size_t allocated;
     unsigned char c, *p, *q;
-    int len;
+    size_t len;
 
     p = (unsigned char *) str;
     len = strlen(str);
@@ -950,7 +927,7 @@ static char *canontoken(char *str)
 	if (!canon)
 	    return NULL;
     }
-    q = (unsigned char *) canon;
+    q = canon;
     while ((c = *p++)) {
 	/* if (isalnum(c) == FALSE) */
 	    /* continue; */
@@ -968,8 +945,8 @@ static char *canontoken(char *str)
 static char* fullColor (char* prefix, char* str)
 {
     static char *fulls;
-    static int allocated;
-    int len = strlen (prefix) + strlen (str) + 3;
+    static size_t allocated;
+    size_t len = strlen (prefix) + strlen (str) + 3;
 
     if (len >= allocated) {
 	allocated = len + 10;
@@ -1051,14 +1028,15 @@ int colorxlate(char *str, gvcolor_t * color, color_type_t target_type)
 {
     static hsvrgbacolor_t *last;
     static unsigned char *canon;
-    static int allocated;
+    static size_t allocated;
     unsigned char *p, *q;
     hsvrgbacolor_t fake;
     unsigned char c;
     double H, S, V, A, R, G, B;
     double C, M, Y, K;
     unsigned int r, g, b, a;
-    int len, rc;
+    size_t len;
+    int rc;
 
     color->type = target_type;
 
@@ -1069,8 +1047,8 @@ int colorxlate(char *str, gvcolor_t * color, color_type_t target_type)
     /* test for rgb value such as: "#ff0000"
        or rgba value such as "#ff000080" */
     a = 255;			/* default alpha channel value=opaque in case not supplied */
-    if ((*p == '#')
-	&& (sscanf((char *) p, "#%2x%2x%2x%2x", &r, &g, &b, &a) >= 3)) {
+    if (*p == '#'
+	&& sscanf((char *) p, "#%2x%2x%2x%2x", &r, &g, &b, &a) >= 3) {
 	switch (target_type) {
 	case HSVA_DOUBLE:
 	    R = (double) r / 255.0;
@@ -1120,7 +1098,7 @@ int colorxlate(char *str, gvcolor_t * color, color_type_t target_type)
     }
 
     /* test for hsv value such as: ".6,.5,.3" */
-    if (((c = *p) == '.') || isdigit(c)) {
+    if ((c = *p) == '.' || isdigit(c)) {
 	int cnt;
 	len = strlen((char*)p);
 	if (len >= allocated) {
@@ -1197,22 +1175,17 @@ int colorxlate(char *str, gvcolor_t * color, color_type_t target_type)
     fake.name = resolveColor(str);
     if (!fake.name)
 	return COLOR_MALLOC_FAIL;
-    if ((last == NULL)
-	|| (last->name[0] != fake.name[0])
-	|| (strcmp(last->name, fake.name))) {
-	last = (hsvrgbacolor_t *) bsearch((void *) &fake,
-				      (void *) color_lib,
-				      sizeof(color_lib) /
-				      sizeof(hsvrgbacolor_t), sizeof(fake),
-				      colorcmpf);
+    if (last == NULL || strcmp(last->name, fake.name)) {
+	last = bsearch(&fake, color_lib, sizeof(color_lib) / sizeof(hsvrgbacolor_t),
+	               sizeof(fake), colorcmpf);
     }
     if (last != NULL) {
 	switch (target_type) {
 	case HSVA_DOUBLE:
-	    color->u.HSVA[0] = ((double) last->h) / 255.0;
-	    color->u.HSVA[1] = ((double) last->s) / 255.0;
-	    color->u.HSVA[2] = ((double) last->v) / 255.0;
-	    color->u.HSVA[3] = ((double) last->a) / 255.0;
+	    color->u.HSVA[0] = (double) last->h / 255.0;
+	    color->u.HSVA[1] = (double) last->s / 255.0;
+	    color->u.HSVA[2] = (double) last->v / 255.0;
+	    color->u.HSVA[3] = (double) last->a / 255.0;
 	    break;
 	case RGBA_BYTE:
 	    color->u.rgba[0] = last->r;
@@ -1291,7 +1264,7 @@ char *colorx (Expr_t* ex, char* incolor, char* fmt, Sfio_t* fp)
     int rc;
     int alpha;
 
-    if ((*fmt == '\0') || (*incolor == '\0'))
+    if (*fmt == '\0' || *incolor == '\0')
 	return "";
     if (*fmt == 'R') {
 	type = RGBA_BYTE;
