@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,12 +5,12 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 
 /*
- *  Compile-time and run-time interface between gpr and libexpr
+ *  Compile-time and run-time interface between gvpr and libexpr
  */
 
 #include "config.h"
@@ -22,24 +19,27 @@
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
-#include "compile.h"
+#include <gvpr/compile.h>
 #include <assert.h>
-#include "cgraph.h"
-#include <error.h>
-#include <actions.h>
-#include "sfstr.h"
+#include <cgraph/cgraph.h>
+#include <ast/error.h>
+#include <gvpr/actions.h>
+#include <ast/sfstr.h>
 #include <string.h>
 #include <stdio.h>
 #include <math.h>
 
-#define ISEDGE(e) (AGTYPE(e)&2)
+static int isedge(Agobj_t *obj) {
+  return AGTYPE(obj) == AGOUTEDGE || AGTYPE(obj) == AGINEDGE;
+}
+
 #define MIN(a,b)        ((a)<(b)?(a):(b))
 #define MAX(a,b)        ((a)>(b)?(a):(b))
 
-#include <gdefs.h>
+#include <gvpr/gdefs.h>
 
-#include "ctype.h"
-#include "trie.c"
+#include <ctype.h>
+#include <gvpr/trie.c>
 
 #define BITS_PER_BYTE 8
 #ifdef HAVE_INTPTR_T
@@ -52,17 +52,17 @@
 
 static int iofread(void *chan, char *buf, int bufsize)
 {
-    return read(sffileno((Sfio_t *) chan), buf, bufsize);
+    return read(sffileno(chan), buf, bufsize);
 }
 
 static int ioputstr(void *chan, const char *str)
 {
-    return sfputr((Sfio_t *) chan, str, -1);
+    return sfputr(chan, str, -1);
 }
 
 static int ioflush(void *chan)
 {
-    return sfsync((Sfio_t *) chan);
+    return sfsync(chan);
 }
 
 static Agiodisc_t gprIoDisc = { iofread, ioputstr, ioflush };
@@ -191,12 +191,21 @@ static char *symName(Expr_t * ex, int op)
     if (op >= MINNAME && op <= MAXNAME)
 	return gprnames[op];
     else {
-	Sfio_t *sf = sfstropen();
-	char *s;
+	// calculate how much space we need to construct a name
+	int bytes = vsnprintf(NULL, 0, "<unknown (%d)>", op);
+	if (bytes < 0) {
+		fprintf(stderr, "%s: vsnprintf failure\n", __func__);
+		exit(EXIT_FAILURE);
+	}
+
+	// construct a managed buffer to store this name
+	char *s = vmalloc(ex->ve, (size_t)bytes + 1);
+
+	// make the name
+	if (s != NULL) {
+		snprintf(s, (size_t)bytes + 1, "<unknown (%d)>", op);
+	}
 
-	sfprintf(sf, "<unknown (%d)>", op);
-	s = exstring(ex, sfstruse(sf));
-	sfclose(sf);
 	return s;
     }
 }
@@ -251,7 +260,7 @@ static Agdesc_t xargs(char *args)
 static char *deparse(Expr_t * ex, Exnode_t * n, Sfio_t * sf)
 {
     exdump(ex, n, sf);
-    return (sfstruse(sf));
+    return sfstruse(sf);
 }
 
 /* deref:
@@ -317,7 +326,7 @@ static Agobj_t *deref(Expr_t * pgm, Exnode_t * x, Exref_t * ref,
 		exerror("Current object $ not defined");
 		return 0;
 	    }
-	    if (ISEDGE(objp))
+	    if (isedge(objp))
 		return deref(pgm, x, ref->next,
 			     (Agobj_t *) AGHEAD((Agedge_t *) objp), state);
 	    else
@@ -328,7 +337,7 @@ static Agobj_t *deref(Expr_t * pgm, Exnode_t * x, Exref_t * ref,
 		exerror("Current object $ not defined");
 		return 0;
 	    }
-	    if (ISEDGE(objp))
+	    if (isedge(objp))
 		return deref(pgm, x, ref->next,
 			     (Agobj_t *) AGTAIL((Agedge_t *) objp), state);
 	    else
@@ -355,7 +364,7 @@ assignable (Agobj_t *objp, unsigned char* name)
     unsigned char* p = name;
 
     TFA_Init();
-    while ((TFA_State >= 0) && (ch = *p)) {
+    while (TFA_State >= 0 && (ch = *p)) {
         TFA_Advance(ch & ~127 ? 127 : ch);
         p++;
     }
@@ -420,7 +429,7 @@ kindToStr (int kind)
 static char*
 kindOf (Agobj_t* objp)
 {
-    return (kindToStr (agobjkind (objp)));
+    return kindToStr (agobjkind (objp));
 }
 
 /* lookup:
@@ -433,7 +442,7 @@ static int lookup(Expr_t * pgm, Agobj_t * objp, Exid_t * sym, Extype_t * v,
     if (sym->lex == ID) {
 	switch (sym->index) {
 	case M_head:
-	    if (ISEDGE(objp))
+	    if (isedge(objp))
 		v->integer = PTR2INT(AGHEAD((Agedge_t *) objp));
 	    else {
 		error(ERROR_WARNING, "head of non-edge");
@@ -441,7 +450,7 @@ static int lookup(Expr_t * pgm, Agobj_t * objp, Exid_t * sym, Extype_t * v,
 	    }
 	    break;
 	case M_tail:
-	    if (ISEDGE(objp))
+	    if (isedge(objp))
 		v->integer = PTR2INT(AGTAIL((Agedge_t *) objp));
 	    else {
 		error(ERROR_WARNING, "tail of non-edge");
@@ -477,7 +486,7 @@ static int lookup(Expr_t * pgm, Agobj_t * objp, Exid_t * sym, Extype_t * v,
 	    break;
 	case M_X:
 	    if (AGTYPE(objp) == AGNODE) {
-		if (posOf ((Agnode_t *) objp, 0, &(v->floating)))
+		if (posOf ((Agnode_t *) objp, 0, &v->floating))
 		    exerror("no x coordinate for node \"%s\"", agnameof(objp));
 	    } else {
 		exerror("x coordinate of non-node");
@@ -486,7 +495,7 @@ static int lookup(Expr_t * pgm, Agobj_t * objp, Exid_t * sym, Extype_t * v,
 	    break;
 	case M_Y:
 	    if (AGTYPE(objp) == AGNODE) {
-		if (posOf ((Agnode_t *) objp, 1, &(v->floating)))
+		if (posOf ((Agnode_t *) objp, 1, &v->floating))
 		    exerror("no y coordinate for node \"%s\"", agnameof(objp));
 	    } else {
 		exerror("x coordinate of non-node");
@@ -678,8 +687,8 @@ getval(Expr_t * pgm, Exnode_t * node, Exid_t * sym, Exref_t * ref,
 
     assert(sym->lex != CONSTANT);
     if (elt == EX_CALL) {
-	args = (Extype_t *) env;
-	state = (Gpr_t *) (disc->user);
+	args = env;
+	state = (Gpr_t *) disc->user;
 	switch (sym->index) {
 	case F_graph:
 	    gp = openG(args[0].string, xargs(args[1].string));
@@ -1245,10 +1254,10 @@ getval(Expr_t * pgm, Exnode_t * node, Exid_t * sym, Exref_t * ref,
 	    if (!objp) {
 		error(ERROR_WARNING, "NULL object passed to delete()");
 		v.integer = 1;
-	    } else if (objp == (Agobj_t *) (state->curgraph)) {
+	    } else if (objp == (Agobj_t *) state->curgraph) {
 		error(ERROR_WARNING, "cannot delete current graph $G");
 		v.integer = 1;
-	    } else if (objp == (Agobj_t *) (state->target)) {
+	    } else if (objp == (Agobj_t *) state->target) {
 		error(ERROR_WARNING, "cannot delete target graph $T");
 		v.integer = 1;
 	    } else if (objp == state->curobj) {
@@ -1506,8 +1515,8 @@ getval(Expr_t * pgm, Exnode_t * node, Exid_t * sym, Exref_t * ref,
 	}
 	return v;
     } else if (elt == EX_ARRAY) {
-	args = (Extype_t *) env;
-	state = (Gpr_t *) (disc->user);
+	args = env;
+	state = (Gpr_t *) disc->user;
 	switch (sym->index) {
 	case A_ARGV:
 	    v.string = getArg(args[0].integer, state);
@@ -1519,13 +1528,13 @@ getval(Expr_t * pgm, Exnode_t * node, Exid_t * sym, Exref_t * ref,
 	return v;
     }
 
-    state = (Gpr_t *) env;
+    state = env;
     if (ref) {
 	objp = deref(pgm, node, ref, 0, state);
 	if (!objp)
 	    exerror("null reference in expression %s",
 		  deparse(pgm, node, state->tmp));
-    } else if ((sym->lex == ID) && (sym->index <= LAST_V)) {
+    } else if (sym->lex == ID && sym->index <= LAST_V) {
 	switch (sym->index) {
 	case V_this:
 	    v.integer = PTR2INT(state->curobj);
@@ -1607,7 +1616,7 @@ setval(Expr_t * pgm, Exnode_t * x, Exid_t * sym, Exref_t * ref,
     int iv;
     int rv = 0;
 
-    state = (Gpr_t *) env;
+    state = env;
     if (ref) {
 	objp = deref(pgm, x, ref, 0, state);
 	if (!objp) {
@@ -1615,7 +1624,7 @@ setval(Expr_t * pgm, Exnode_t * x, Exid_t * sym, Exref_t * ref,
 		  ref->symbol->name, deparse(pgm, x, state->tmp));
 	    return -1;
 	}
-    } else if ((MINNAME <= sym->index) && (sym->index <= MAXNAME)) {
+    } else if (MINNAME <= sym->index && sym->index <= MAXNAME) {
 	switch (sym->index) {
 	case V_outgraph:
 	    state->outgraph = INT2PTR(Agraph_t *, v.integer);
@@ -1630,7 +1639,7 @@ setval(Expr_t * pgm, Exnode_t * x, Exid_t * sym, Exref_t * ref,
 	    break;
 	case V_travroot:
 	    np = INT2PTR(Agnode_t *, v.integer);
-	    if (!np || (agroot(np) == state->curgraph))
+	    if (!np || agroot(np) == state->curgraph)
 		state->tvroot = np;
 	    else {
 		error(1, "cannot set $tvroot, node %s not in $G : ignored",
@@ -1639,7 +1648,7 @@ setval(Expr_t * pgm, Exnode_t * x, Exid_t * sym, Exref_t * ref,
 	    break;
 	case V_travnext:
 	    np = INT2PTR(Agnode_t *, v.integer);
-	    if (!np || (agroot(np) == state->curgraph)) {
+	    if (!np || agroot(np) == state->curgraph) {
 		state->tvnext = np;
 		state->flags |= GV_NEXT_SET;
 	    } else {
@@ -1668,15 +1677,15 @@ setval(Expr_t * pgm, Exnode_t * x, Exid_t * sym, Exref_t * ref,
 	}
     }
     
-    assignable (objp, (unsigned char*)(sym->name));
+    assignable (objp, (unsigned char*)sym->name);
     return setattr(objp, sym->name, v.string);
 }
 
 static int codePhase;
 
-#define haveGraph    ((1 <= codePhase) && (codePhase <= 4))
-#define haveTarget   ((2 <= codePhase) && (codePhase <= 4))
-#define inWalk       ((2 <= codePhase) && (codePhase <= 3))
+#define haveGraph    (1 <= codePhase && codePhase <= 4)
+#define haveTarget   (2 <= codePhase && codePhase <= 4)
+#define inWalk       (2 <= codePhase && codePhase <= 3)
 
 /* typeChk:
  * Type check input type against implied type of symbol sym.
@@ -1849,7 +1858,7 @@ refval(Expr_t * pgm, Exnode_t * node, Exid_t * sym, Exref_t * ref,
 	}
     } else {
 	if (!typeChkExp(ref, sym)) {
-	    Gpr_t *state = (Gpr_t *) (disc->user);
+	    Gpr_t *state = (Gpr_t *) disc->user;
 	    exerror("type error using %s",
 		    deparse(pgm, node, state->tmp));
 	}
@@ -1865,7 +1874,7 @@ refval(Expr_t * pgm, Exnode_t * node, Exid_t * sym, Exref_t * ref,
  * Return -1 if operation cannot be done, 0 otherwise.
  * If arg is > 0, operation unnecessary; just report possibility.
  */
-int
+static int
 binary(Expr_t * pg, Exnode_t * l, Exnode_t * ex, Exnode_t * r, int arg,
        Exdisc_t * disc)
 {
@@ -1931,7 +1940,7 @@ binary(Expr_t * pg, Exnode_t * l, Exnode_t * ex, Exnode_t * r, int arg,
     }
 
     /* l is a graph object; make sure r is also */
-    if (r && (r->type == T_tvtyp))
+    if (r && r->type == T_tvtyp)
 	return -1;
 
     lobjp = INT2PTR(Agobj_t *, l->data.constant.value.integer);
@@ -2085,7 +2094,7 @@ tvtypeToStr (int v)
  * Return -1 if conversion cannot be done, 0 otherwise.
  * If arg is > 0, conversion unnecessary; just report possibility.
  */
-static int stringOf(Expr_t * prog, register Exnode_t * x, int arg, Exdisc_t* disc)
+static int stringOf(Expr_t * prog, Exnode_t * x, int arg, Exdisc_t* disc)
 {
     Agobj_t *objp;
     int rv = 0;
@@ -2105,7 +2114,7 @@ static int stringOf(Expr_t * prog, register Exnode_t * x, int arg, Exdisc_t* dis
 	    rv = -1;
 	}
 	else {
-	    Gpr_t* state = (Gpr_t *) (disc->user);
+	    Gpr_t* state = (Gpr_t *) disc->user;
 	    x->data.constant.value.string = nameOf(prog, objp, state->tmp);
 	}
     }
@@ -2118,12 +2127,10 @@ static int stringOf(Expr_t * prog, register Exnode_t * x, int arg, Exdisc_t* dis
  * Return -1 if conversion cannot be done, 0 otherwise.
  * If arg is > 0, conversion unnecessary; just report possibility.
  * In particular, assume x != 0 if arg == 0.
- * Use #ifdef OLD to remove graph object conversion to strings,
- * as this seemed to dangerous.
  */
 static int
-convert(Expr_t * prog, register Exnode_t * x, int type,
-	register Exid_t * xref, int arg, Exdisc_t * disc)
+convert(Expr_t * prog, Exnode_t * x, int type,
+	Exid_t * xref, int arg, Exdisc_t * disc)
 {
     Agobj_t *objp;
     int ret = -1;
@@ -2131,9 +2138,9 @@ convert(Expr_t * prog, register Exnode_t * x, int type,
     /* If both types are built-in, let libexpr handle */
     if (BUILTIN(type) && BUILTIN(x->type))
 	return -1;
-    if ((type == T_obj) && (x->type <= T_obj))
+    if (type == T_obj && x->type <= T_obj)
 	ret = 0;		/* trivial cast from specific graph object to T_obj */
-    else if ((type <= T_obj) && (x->type == INTEGER)) {
+    else if (type <= T_obj && x->type == INTEGER) {
 	if (x->data.constant.value.integer == 0)
 	    ret = 0;		/* allow NULL pointer */
     } else if (type == INTEGER) {
@@ -2141,7 +2148,7 @@ convert(Expr_t * prog, register Exnode_t * x, int type,
     } else if (x->type == T_obj) {
 	/* check dynamic type */
 	if (arg) {
-	    if ((type != FLOATING) && (type <= T_obj))
+	    if (type != FLOATING && type <= T_obj)
 		ret = 0;
 	} else {
 	    objp = INT2PTR(Agobj_t *, x->data.constant.value.integer);
@@ -2155,15 +2162,9 @@ convert(Expr_t * prog, register Exnode_t * x, int type,
 		    ret = 0;
 		break;
 	    case T_edge:
-		if (!objp || ISEDGE(objp))
+		if (!objp || isedge(objp))
 		    ret = 0;
 		break;
-#ifdef OLD
-	    case STRING:
-		x->data.constant.value.string = nameOf(prog, objp);
-		ret = 0;
-		break;
-#endif
 	    }
 	}
     } else if (type == STRING) {
@@ -2174,17 +2175,7 @@ convert(Expr_t * prog, register Exnode_t * x, int type,
 		    tvtypeToStr (x->data.constant.value.integer);
 	    }
 	}
-#ifdef OLD
-	else {
-	    objp = INT2PTR(Agobj_t *, x->data.constant.value.integer);
-	    if (objp) {
-		x->data.constant.value.string = nameOf(prog, objp);
-		ret = 0;
-	    } else
-		cvtError(xref, "Uninitialized object");
-	}
-#endif
-    } else if ((type == T_tvtyp) && (x->type == INTEGER)) {
+    } else if (type == T_tvtyp && x->type == INTEGER) {
 	if (arg)
 	    ret = 0;
 	else if (validTVT(x->data.constant.value.integer))
@@ -2208,7 +2199,7 @@ convert(Expr_t * prog, register Exnode_t * x, int type,
 	    }
 	}
     }
-    if (!arg && (ret == 0))
+    if (!arg && ret == 0)
 	x->type = type;
     return ret;
 }
@@ -2232,7 +2223,7 @@ static int
 matchval(Expr_t * pgm, Exnode_t * xstr, const char *str, Exnode_t * xpat,
 	 const char *pat, void *env, Exdisc_t * disc)
 {
-    return strgrpmatch(str, pat, NiL, 0,
+    return strgrpmatch(str, pat, NULL, 0,
 		       STR_MAXIMAL | STR_LEFT | STR_RIGHT);
 }
 
@@ -2319,8 +2310,8 @@ static Exnode_t *compile(Expr_t * prog, char *src, char *input, int line,
     rv = excomp(prog, src, line, 0, sf);
     sfclose(sf);
 
-    if (rv >= 0 && (getErrorErrors() == 0))
-	e = exexpr(prog, lbl, NiL, kind);
+    if (rv >= 0 && getErrorErrors() == 0)
+	e = exexpr(prog, lbl, NULL, kind);
 
     return e;
 }
@@ -2403,7 +2394,7 @@ static int mkBlock(comp_block* bp, Expr_t * prog, char *src, parse_block *inp, S
 	symbols[0].type = T_node;
 	tchk[V_this][1] = Y(V);
 	bp->n_nstmts = inp->n_nstmts;
-	sprintf (label, "_nd%d", i);
+	snprintf(label, sizeof(label), "_nd%d", i);
 	bp->node_stmts = mkStmts(prog, src, inp->node_stmts,
 				inp->n_nstmts, label, tmps);
 	if (getErrorErrors())
@@ -2416,7 +2407,7 @@ static int mkBlock(comp_block* bp, Expr_t * prog, char *src, parse_block *inp, S
 	symbols[0].type = T_edge;
 	tchk[V_this][1] = Y(E);
 	bp->n_estmts = inp->n_estmts;
-	sprintf (label, "_eg%d", i);
+	snprintf(label, sizeof(label), "_eg%d", i);
 	bp->edge_stmts = mkStmts(prog, src, inp->edge_stmts,
 				inp->n_estmts, label, tmps);
 	if (getErrorErrors())
@@ -2479,7 +2470,7 @@ comp_prog *compileProg(parse_prog * inp, Gpr_t * state, int flags)
 	}
     }
 
-    if (!(initDisc(state)))
+    if (!initDisc(state))
 	goto finish;
     
     exinit();
@@ -2568,7 +2559,7 @@ freeCompileProg (comp_prog *p)
  */
 int walksGraph(comp_block * p)
 {
-    return (p->walks);
+    return p->walks;
 }
 
 /* usesGraph;
@@ -2577,7 +2568,7 @@ int walksGraph(comp_block * p)
  */
 int usesGraph(comp_prog * p)
 {
-    return (p->flags);
+    return p->flags;
 }
 
 void ptchk(void)
