@@ -1,5 +1,3 @@
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property
  * All rights reserved. This program and the accompanying materials
@@ -7,11 +5,10 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#ifndef SPLIT_Q_H
-#define SPLIT_Q_H
+#pragma once
 
 #ifdef __cplusplus
 extern "C" {
@@ -20,8 +17,8 @@ extern "C" {
 /*-----------------------------------------------------------------------------
 | Definitions and global variables.
 -----------------------------------------------------------------------------*/
-#include <rectangle.h>
-#include <index.h>
+#include <label/rectangle.h>
+#include <label/index.h>
 
 #ifndef METHODS
 #define METHODS 1
@@ -47,5 +44,3 @@ void SplitNode(RTree_t *, Node_t *, Branch_t *, Node_t **);
 #ifdef __cplusplus
 }
 #endif
-
-#endif				/*SPLIT_Q_H */
