@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,12 +5,12 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#include <digcola.h>
+#include <neatogen/digcola.h>
 #ifdef DIGCOLA
-#include "kkutils.h"
+#include <neatogen/kkutils.h>
 
 static int *given_levels = NULL;
 /*
@@ -53,7 +50,6 @@ compute_hierarchy(vtx_data * graph, int n, double abs_tol,
 {
     double *y;
     int i, rv=0;
-    double spread;
     int use_given_levels = FALSE;
     int *ordering;
     int *levels;
@@ -79,9 +75,7 @@ compute_hierarchy(vtx_data * graph, int n, double abs_tol,
     }
     quicksort_place(y, ordering, 0, n - 1);
 
-    spread = y[ordering[n - 1]] - y[ordering[0]];
-
-    /* after spread is computed, we may take the y-coords as the given levels */
+    /* take the y-coords as the given levels */
     if (given_levels) {
 	use_given_levels = TRUE;
 	for (i = 0; i < n; i++) {
