@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 #include "config.h"
@@ -17,10 +14,10 @@
 #include <stdlib.h>
 #include <string.h>
 #include <math.h>
-#include "cgraph.h"     /* for agerr() and friends */
-#include "delaunay.h"
-#include "memory.h"
-#include "logic.h"
+#include <cgraph/cgraph.h>     /* for agerr() and friends */
+#include <neatogen/delaunay.h>
+#include <common/memory.h>
+#include <common/logic.h>
 
 #if HAVE_GTS
 #include <gts.h>
@@ -201,7 +198,6 @@ tri(double *x, double *y, int npt, int *segs, int nsegs, int sepArr)
 	 * coordinates as v1, in which case we replace v1 with v
 	 */
 	if (v) {
-	    /* agerr (AGWARN, "Duplicate point %d %d\n", i, ((GVertex*)v)->idx); */
 	    gts_vertex_replace (v1, v);
 	}
     }
@@ -213,11 +209,6 @@ tri(double *x, double *y, int npt, int *segs, int nsegs, int sepArr)
     /* destroy enclosing triangle */
     gts_allow_floating_vertices = TRUE;
     gts_allow_floating_edges = TRUE;
-/*
-    gts_object_destroy(GTS_OBJECT(v1));
-    gts_object_destroy(GTS_OBJECT(v2));
-    gts_object_destroy(GTS_OBJECT(v3));
-*/
     destroy(v1);
     destroy(v2);
     destroy(v3);
@@ -540,9 +531,9 @@ freeSurface (surface_t* s)
 }
 #elif HAVE_TRIANGLE
 #define TRILIBRARY
-#include "triangle.c"
-#include "assert.h"
-#include "general.h"
+#include <triangle.c>
+#include <assert.h>
+#include <sparse/general.h>
 
 int*
 get_triangles (double *x, int n, int* tris)
@@ -897,10 +888,8 @@ v_data *UG_graph(double *x, double *y, int n, int accurate_computation)
 void freeGraph (v_data * graph)
 {
     if (graph != NULL) {
-	if (graph[0].edges != NULL)
-	    free(graph[0].edges);
-	if (graph[0].ewgts != NULL)
-	    free(graph[0].ewgts);
+	free(graph[0].edges);
+	free(graph[0].ewgts);
 	free(graph);
     }
 }
@@ -908,17 +897,13 @@ void freeGraph (v_data * graph)
 void freeGraphData(vtx_data * graph)
 {
     if (graph != NULL) {
-	if (graph[0].edges != NULL)
-	    free(graph[0].edges);
-	if (graph[0].ewgts != NULL)
-	    free(graph[0].ewgts);
+	free(graph[0].edges);
+	free(graph[0].ewgts);
 #ifdef USE_STYLES
-	if (graph[0].styles != NULL)
-	    free(graph[0].styles);
+	free(graph[0].styles);
 #endif
 #ifdef DIGCOLA
-	if (graph[0].edists != NULL)
-	    free(graph[0].edists);
+	free(graph[0].edists);
 #endif
 	free(graph);
     }
