@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,13 +5,12 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#ifndef DELAUNAY_H
-#define DELAUNAY_H
+#pragma once
 
-#include "sparsegraph.h"
+#include <neatogen/sparsegraph.h>
 
 typedef struct {
     int  nedges; /* no. of edges in triangulation */
@@ -35,5 +31,3 @@ v_data *UG_graph(double *x, double *y, int n, int accurate_computation);
 surface_t* mkSurface (double *x, double *y, int n, int* segs, int nsegs);
 
 void freeSurface (surface_t* s);
-
-#endif
