@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,13 +5,13 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#include "neato.h"
-#include "mem.h"
-#include "info.h"
-#include "edges.h"
+#include <neatogen/neato.h>
+#include <neatogen/mem.h>
+#include <neatogen/info.h>
+#include <neatogen/edges.h>
 #include <math.h>
 
 
@@ -120,7 +117,7 @@ void clip_line(Edge * e)
 	    x2 = e->c - e->b * y2;
 	}
 
-	if (((x1 > pxmax) & (x2 > pxmax)) | ((x1 < pxmin) & (x2 < pxmin)))
+	if ((x1 > pxmax && x2 > pxmax) || (x1 < pxmin && x2 < pxmin))
 	    return;
 	if (x1 > pxmax) {
 	    x1 = pxmax;
@@ -169,7 +166,7 @@ void clip_line(Edge * e)
 	    y2 = e->c - e->a * x2;
 	}
 
-	if (((y1 > pymax) & (y2 > pymax)) | ((y1 < pymin) & (y2 < pymin)))
+	if ((y1 > pymax && y2 > pymax) || (y1 < pymin && y2 < pymin))
 	    return;
 	if (y1 > pymax) {
 	    y1 = pymax;
