@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,20 +5,17 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
+#pragma once
+
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-
-
-#ifndef HEDGES_H
-#define HEDGES_H
-
-#include "site.h"
-#include "edges.h"
+#include <neatogen/site.h>
+#include <neatogen/edges.h>
 
     typedef struct Halfedge {
 	struct Halfedge *ELleft, *ELright;
@@ -47,8 +41,6 @@ extern "C" {
     extern Halfedge *ELleftbnd(Point *);
     extern Site *leftreg(Halfedge *), *rightreg(Halfedge *);
 
-#endif
-
 #ifdef __cplusplus
 }
 #endif
