@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,12 +5,10 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-
-#ifndef         NEATO_H
-#define         NEATO_H
+#pragma once
 
 #include "config.h"
 
@@ -26,6 +21,7 @@
 #define MODE_MAJOR       1
 #define MODE_HIER        2
 #define MODE_IPSEP       3
+#define MODE_SGD         4
 
 #define INIT_ERROR       -1
 #define INIT_SELF        0
@@ -34,7 +30,5 @@
 
 #include	"render.h"
 #include	"pathplan.h"
-#include	"neatoprocs.h"
-#include	"adjust.h"
-
-#endif				/* NEATO_H */
+#include	<neatogen/neatoprocs.h>
+#include	<neatogen/adjust.h>
