@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,26 +5,25 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 
 #include "config.h"
 
-#include "neato.h"
-#include "adjust.h"
-#include "pathplan.h"
-#include "vispath.h"
-#include "multispline.h"
+#include <neatogen/neato.h>
+#include <neatogen/adjust.h>
+#include <pathplan/pathplan.h>
+#include <pathplan/vispath.h>
+#include <neatogen/multispline.h>
 #ifndef HAVE_DRAND48
 extern double drand48(void);
 #endif
 
 #ifdef ORTHO
-#include <ortho.h>
+#include <ortho/ortho.h>
 #endif
 
-extern void printvis(vconfig_t * cp);
 extern int in_poly(Ppoly_t argpoly, Ppoint_t q);
 
 
@@ -56,7 +52,7 @@ make_barriers(Ppoly_t ** poly, int npoly, int pp, int qp,
 	    continue;
 	if (i == qp)
 	    continue;
-	n = n + poly[i]->pn;
+	n += poly[i]->pn;
     }
     bar = N_GNEW(n, Pedge_t);
     b = 0;
@@ -97,8 +93,8 @@ static Ppoint_t recPt(double x, double y, pointf c, expand_t* m)
 {
     Ppoint_t p;
 
-    p.x = (x * m->x) + c.x;
-    p.y = (y * m->y) + c.y;
+    p.x = x * m->x + c.x;
+    p.y = y * m->y + c.y;
     return p;
 }
 
@@ -227,7 +223,7 @@ void makeSelfArcs(path * P, edge_t * e, int stepx)
 {
     int cnt = ED_count(e);
 
-    if ((cnt == 1) || Concentrate) {
+    if (cnt == 1 || Concentrate) {
 	edge_t *edges1[1];
 	edges1[0] = e;
 	makeSelfEdge(P, edges1, 0, 1, stepx, stepx, &sinfo);
@@ -274,7 +270,6 @@ Ppoly_t *makeObstacle(node_t * n, expand_t* pmargin, boolean isOrtho)
     boxf b;
     pointf pt;
     field_t *fld;
-    epsf_t *desc;
     int isPoly;
     pointf* verts = NULL;
     pointf vs[4];
@@ -403,7 +398,6 @@ Ppoly_t *makeObstacle(node_t * n, expand_t* pmargin, boolean isOrtho)
 	}
 	break;
     case SH_EPSF:
-	desc = (epsf_t *) (ND_shape_info(n));
 	obs = NEW(Ppoly_t);
 	obs->pn = 4;
 	obs->ps = N_NEW(4, Ppoint_t);
@@ -454,14 +448,6 @@ getPath(edge_t * e, vconfig_t * vconfig, int chkPts, Ppoly_t ** obs,
     if (chkPts) {
 	pp = ND_lim(agtail(e));
 	qp = ND_lim(aghead(e));
-/*
-	for (i = 0; i < npoly; i++) {
-	    if ((pp == POLYID_NONE) && in_poly(*obs[i], p))
-		pp = i;
-	    if ((qp == POLYID_NONE) && in_poly(*obs[i], q))
-		qp = i;
-	}
-*/
     }
     Pobspath(vconfig, p, pp, q, qp, &line);
     return line;
@@ -510,9 +496,9 @@ void makeSpline(graph_t* g, edge_t * e, Ppoly_t ** obs, int npoly, boolean chkPt
     pp = qp = POLYID_NONE;
     if (chkPts)
 	for (i = 0; i < npoly; i++) {
-	    if ((pp == POLYID_NONE) && in_poly(*obs[i], p))
+	    if (pp == POLYID_NONE && in_poly(*obs[i], p))
 		pp = i;
-	    if ((qp == POLYID_NONE) && in_poly(*obs[i], q))
+	    if (qp == POLYID_NONE && in_poly(*obs[i], q))
 		qp = i;
 	}
 
@@ -555,7 +541,7 @@ static int _spline_edges(graph_t * g, expand_t* pmargin, int edgetype)
     int cnt, i = 0, npoly;
     vconfig_t *vconfig = 0;
     path *P = NULL;
-    int useEdges = (Nop > 1);
+    int useEdges = Nop > 1;
     int legal = 0;
 
 #ifdef HAVE_GTS
@@ -593,7 +579,7 @@ static int _spline_edges(graph_t * g, expand_t* pmargin, int edgetype)
     /* route edges  */
     if (Verbose)
 	fprintf(stderr, "Creating edges using %s\n",
-	    (legal && (edgetype == ET_ORTHO)) ? "orthogonal lines" :
+	    (legal && edgetype == ET_ORTHO) ? "orthogonal lines" :
 	    (vconfig ? (edgetype == ET_SPLINE ? "splines" : "polylines") : 
 		"line segments"));
     if (vconfig) {
@@ -605,7 +591,7 @@ static int _spline_edges(graph_t * g, expand_t* pmargin, int edgetype)
 	}
     }
 #ifdef ORTHO
-    else if (legal && (edgetype == ET_ORTHO)) {
+    else if (legal && edgetype == ET_ORTHO) {
 	orthoEdges (g, 0);
 	useEdges = 1;
     }
@@ -630,9 +616,9 @@ static int _spline_edges(graph_t * g, expand_t* pmargin, int edgetype)
 		makeSelfArcs(P, e, GD_nodesep(g->root));
 	    } else if (vconfig) { /* ET_SPLINE or ET_PLINE */
 #ifdef HAVE_GTS
-		if ((ED_count(e) > 1) || BOUNDARY_PORT(e)) {
+		if (ED_count(e) > 1 || BOUNDARY_PORT(e)) {
 		    int fail = 0;
-		    if ((ED_path(e).pn == 2) && !BOUNDARY_PORT(e))
+		    if (ED_path(e).pn == 2 && !BOUNDARY_PORT(e))
 			     /* if a straight line can connect the ends */
 			makeStraightEdge(g, e, edgetype, &sinfo);
 		    else { 
@@ -717,7 +703,7 @@ splineEdges(graph_t * g, int (*edgefn) (graph_t *, expand_t*, int),
     map = dtopen(&edgeItemDisc, Dtoset);
     for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
 	for (e = agfstout(g, n); e; e = agnxtout(g, e)) {
-	    if ((Nop > 1 && ED_spl(e))) {
+	    if (Nop > 1 && ED_spl(e)) {
 		/* If Nop > 1 (use given edges) and e has a spline, it
  		 * should have its own equivalence class.
 		 */
@@ -838,11 +824,11 @@ static void scaleEdge(edge_t * e, double xf, double yf)
     for (i = 0; i < ED_spl(e)->size; i++) {
 	pt = bez->list;
 	for (j = 0; j < bez->size; j++) {
-	    if ((i == 0) && (j == 0)) {
+	    if (i == 0 && j == 0) {
 		pt->x += delt.x;
 		pt->y += delt.y;
 	    }
-	    else if ((i == ED_spl(e)->size-1) && (j == bez->size-1)) {
+	    else if (i == ED_spl(e)->size-1 && j == bez->size-1) {
 		pt->x += delh.x;
 		pt->y += delh.y;
 	    }
@@ -1008,7 +994,6 @@ static boolean _neato_set_aspect(graph_t * g)
     if (g->root != g)
 	return FALSE;
 
-    /* compute_bb(g); */
     if (GD_drawing(g)->ratio_kind) {
 	if (GD_bb(g).LL.x || GD_bb(g).LL.y) {
 	    translated = TRUE;
@@ -1023,32 +1008,32 @@ static boolean _neato_set_aspect(graph_t * g)
 	if (GD_drawing(g)->ratio_kind == R_FILL) {
 	    /* fill is weird because both X and Y can stretch */
 	    if (GD_drawing(g)->size.x <= 0)
-		return (translated || FALSE);
+		return translated;
 	    xf = (double) GD_drawing(g)->size.x / GD_bb(g).UR.x;
 	    yf = (double) GD_drawing(g)->size.y / GD_bb(g).UR.y;
 	    /* handle case where one or more dimensions is too big */
-	    if ((xf < 1.0) || (yf < 1.0)) {
+	    if (xf < 1.0 || yf < 1.0) {
 		if (xf < yf) {
-		    yf = yf / xf;
+		    yf /= xf;
 		    xf = 1.0;
 		} else {
-		    xf = xf / yf;
+		    xf /= yf;
 		    yf = 1.0;
 		}
 	    }
 	} else if (GD_drawing(g)->ratio_kind == R_EXPAND) {
 	    if (GD_drawing(g)->size.x <= 0)
-		return (translated || FALSE);
+		return translated;
 	    xf = (double) GD_drawing(g)->size.x / GD_bb(g).UR.x;
 	    yf = (double) GD_drawing(g)->size.y / GD_bb(g).UR.y;
-	    if ((xf > 1.0) && (yf > 1.0)) {
+	    if (xf > 1.0 && yf > 1.0) {
 		double scale = MIN(xf, yf);
 		xf = yf = scale;
 	    } else
-		return (translated || FALSE);
+		return translated;
 	} else if (GD_drawing(g)->ratio_kind == R_VALUE) {
 	    desired = GD_drawing(g)->ratio;
-	    actual = (GD_bb(g).UR.y) / (GD_bb(g).UR.x);
+	    actual = GD_bb(g).UR.y / GD_bb(g).UR.x;
 	    if (actual < desired) {
 		yf = desired / actual;
 		xf = 1.0;
@@ -1057,7 +1042,7 @@ static boolean _neato_set_aspect(graph_t * g)
 		yf = 1.0;
 	    }
 	} else
-	    return (translated || FALSE);
+	    return translated;
 	if (GD_flip(g)) {
 	    double t = xf;
 	    xf = yf;
@@ -1076,8 +1061,8 @@ static boolean _neato_set_aspect(graph_t * g)
 	 * allocate it in the root graph and the connected components. 
 	 */
 	for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
-	    ND_pos(n)[0] = ND_pos(n)[0] * xf;
-	    ND_pos(n)[1] = ND_pos(n)[1] * yf;
+	    ND_pos(n)[0] *= xf;
+	    ND_pos(n)[1] *= yf;
 	}
 	scaleBB(g, xf, yf);
         return TRUE;
@@ -1101,8 +1086,8 @@ boolean neato_set_aspect(graph_t * g)
 	/* setting aspect ratio only makes sense on root graph */
     moved = _neato_set_aspect(g);
     for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
-	ND_coord(n).x = POINTS_PER_INCH * (ND_pos(n)[0]);
-	ND_coord(n).y = POINTS_PER_INCH * (ND_pos(n)[1]);
+	ND_coord(n).x = POINTS_PER_INCH * ND_pos(n)[0];
+	ND_coord(n).y = POINTS_PER_INCH * ND_pos(n)[1];
     }
     return moved;
 }
