@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,17 +5,16 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
+#pragma once
+
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-#ifndef POLY_H
-#define POLY_H
-
-#include "geometry.h"
+#include <neatogen/geometry.h>
 
     typedef struct {
 	Point origin;
@@ -34,8 +30,6 @@ extern "C" {
     extern int makeAddPoly(Poly *, Agnode_t *, float, float);
     extern void breakPoly(Poly *);
 
-#endif
-
 #ifdef __cplusplus
 }
 #endif
