@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,19 +5,19 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 
-#include "neato.h"
-#include "dijkstra.h"
-#include "bfs.h"
-#include "pca.h"
-#include "matrix_ops.h"
-#include "conjgrad.h"
-#include "embed_graph.h"
-#include "kkutils.h"
-#include "stress.h"
+#include <neatogen/neato.h>
+#include <neatogen/dijkstra.h>
+#include <neatogen/bfs.h>
+#include <neatogen/pca.h>
+#include <neatogen/matrix_ops.h>
+#include <neatogen/conjgrad.h>
+#include <neatogen/embed_graph.h>
+#include <neatogen/kkutils.h>
+#include <neatogen/stress.h>
 #include <math.h>
 #include <stdlib.h>
 #include <time.h>
@@ -543,7 +540,7 @@ static int sparse_stress_subspace_majorization_kD(vtx_data * graph,	/* Input gra
 	} else {
 	    for (j = 1; j < lap[i].nedges; j++) {
 		edges[j] = distances[i].edges[j - 1];
-		ewgts[j] = -1.0 / (float) dist_list[j];
+		ewgts[j] = -1.0f / (float) dist_list[j];
 		degree -= ewgts[j];
 	    }
 	}
@@ -791,8 +788,6 @@ float *compute_apsp_packed(vtx_data * graph, int n)
     return Dij;
 }
 
-#define max(x,y) ((x)>(y)?(x):(y))
-
 float *compute_apsp_artifical_weights_packed(vtx_data * graph, int n)
 {
     /* compute all-pairs-shortest-path-length while weighting the graph */
@@ -823,12 +818,8 @@ float *compute_apsp_artifical_weights_packed(vtx_data * graph, int n)
 	    for (j = 1; j <= deg_i; j++) {
 		neighbor = graph[i].edges[j];
 		deg_j = graph[neighbor].nedges - 1;
-		weights[j] = (float)
-		    max((float)
-			(deg_i + deg_j -
-			 2 * common_neighbors(graph, i, neighbor,
-					      vtx_vec)),
-			graph[i].ewgts[j]);
+		weights[j] = fmaxf((float)(deg_i + deg_j -
+			 2 * common_neighbors(graph, i, neighbor, vtx_vec)), graph[i].ewgts[j]);
 	    }
 	    empty_neighbors_vec(graph, i, vtx_vec);
 	    graph[i].ewgts = weights;
@@ -1166,12 +1157,11 @@ int stress_majorization_kD_mkernel(vtx_data * graph,	/* Input graph in sparse re
 
 	    /* put into 'dist_accumulator' all squared distances between 'i' and 'i'+1,...,'n'-1 */
 	    for (k = 0; k < dim; k++) {
-		set_vector_valf(len, coords[k][i], tmp_coords);
-		vectors_mult_additionf(len, tmp_coords, -1,
-				       coords[k] + i + 1);
-		square_vec(len, tmp_coords);
-		vectors_additionf(len, tmp_coords, dist_accumulator,
-				  dist_accumulator);
+		size_t x;
+		for (x = 0; x < (size_t)len; ++x) {
+		    float tmp = coords[k][i] + -1.0f * (coords[k] + i + 1)[x];
+		    dist_accumulator[x] += tmp * tmp;
+		}
 	    }
 
 	    /* convert to 1/d_{ij} */
@@ -1249,7 +1239,7 @@ int stress_majorization_kD_mkernel(vtx_data * graph,	/* Input graph in sparse re
 	 */
 	{
 	    double diff = old_stress - new_stress;
-	    double change = ABS(diff);
+	    double change = fabs(diff);
 	    converged = (((change / old_stress) < Epsilon)
 			 || (new_stress < Epsilon));
 	}
