@@ -1,6 +1,3 @@
-/* $Id$Revision: */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 
@@ -25,25 +22,25 @@
 #include "config.h"
 
 #define DEBUG
+#include <assert.h>
+#include <stdbool.h>
 #include <stddef.h>
-#include <setjmp.h>
-#include <maze.h>
-#include "fPQ.h"
-#include "memory.h"
-#include "geomprocs.h"
-#include "globals.h"
-#include "render.h"
-#include "pointset.h"
+#include <ortho/maze.h>
+#include <ortho/fPQ.h>
+#include <ortho/ortho.h>
+#include <common/memory.h>
+#include <common/geomprocs.h>
+#include <common/globals.h>
+#include <common/render.h>
+#include <common/pointset.h>
 typedef struct {
     int d;
     Agedge_t* e;
 } epair_t;
 
-static jmp_buf jbuf;
-
 #ifdef DEBUG
 static void emitSearchGraph (FILE* fp, sgraph* sg);
-static void emitGraph (FILE* fp, maze* mp, int n_edges, route* route_list, epair_t[]);
+static void emitGraph (FILE* fp, maze* mp, size_t n_edges, route* route_list, epair_t[]);
 int odb_flags;
 #endif
 
@@ -58,7 +55,7 @@ static cell*
 cellOf (snode* p, snode* q)
 {
     cell* cp = p->cells[0];
-    if ((cp == q->cells[0]) || (cp == q->cells[1])) return cp; 
+    if (cp == q->cells[0] || cp == q->cells[1]) return cp;
     else return p->cells[1];
 }
 
@@ -108,7 +105,7 @@ sidePt (snode* ptr, cell* cp)
  * Assume b1 != b2
  */
 static void
-setSeg (segment* sp, int dir, double fix, double b1, double b2, int l1, int l2)
+setSeg (segment* sp, bool dir, double fix, double b1, double b2, int l1, int l2)
 {
     sp->isVert = dir;
     sp->comm_coord = fix;
@@ -144,7 +141,7 @@ convertSPtoRoute (sgraph* g, snode* fst, snode* lst)
     snode* ptr;
     snode* next;
     snode* prev;  /* node in shortest path just previous to next */
-    int i, sz = 0;
+    size_t sz = 0;
     cell* cp;
     cell* ncp;
     segment seg;
@@ -155,6 +152,7 @@ convertSPtoRoute (sgraph* g, snode* fst, snode* lst)
 	/* count no. of nodes in shortest path */
     for (ptr = fst; ptr; ptr = N_DAD(ptr)) sz++;
     rte.n = 0;
+    assert(sz >= 2);
     rte.segs = N_NEW(sz-2, segment);  /* at most sz-2 segments */
 
     seg.prev = seg.next = 0;
@@ -170,7 +168,7 @@ convertSPtoRoute (sgraph* g, snode* fst, snode* lst)
 	updateWts (g, ncp, N_EDGE(ptr));
 
         /* add seg if path bends or at end */
-	if ((ptr->isVert != next->isVert) || (N_DAD(next) == lst)) {
+	if (ptr->isVert != next->isVert || N_DAD(next) == lst) {
 	    if (ptr->isVert != next->isVert)
 		bp2 = midPt (ncp);
 	    else
@@ -206,7 +204,7 @@ convertSPtoRoute (sgraph* g, snode* fst, snode* lst)
 	    cp = ncp;
 	    prevbp = bp1;
 	    bp1 = bp2;
-	    if ((ptr->isVert != next->isVert) && (N_DAD(next) == lst)) {
+	    if (ptr->isVert != next->isVert && N_DAD(next) == lst) {
 		bp2 = sidePt(next, ncp);
 		l2 = B_NODE;
 		if (next->isVert) {   /* horizontal segment */
@@ -233,7 +231,7 @@ convertSPtoRoute (sgraph* g, snode* fst, snode* lst)
     }
 
     rte.segs = realloc (rte.segs, rte.n*sizeof(segment));
-    for (i=0; i<rte.n; i++) {
+    for (size_t i=0; i<rte.n; i++) {
 	if (i > 0)
 	    rte.segs[i].prev = rte.segs + (i-1);
 	if (i < rte.n-1)
@@ -252,6 +250,9 @@ typedef struct {
 static void
 freeChannel (Dt_t* d, channel* cp, Dtdisc_t* disc)
 {
+    (void)d;
+    (void)disc;
+
     free_graph (cp->G);
     free (cp->seg_list);
     free (cp);
@@ -260,6 +261,9 @@ freeChannel (Dt_t* d, channel* cp, Dtdisc_t* disc)
 static void
 freeChanItem (Dt_t* d, chanItem* cp, Dtdisc_t* disc)
 {
+    (void)d;
+    (void)disc;
+
     dtclose (cp->chans);
     free (cp);
 }
@@ -276,6 +280,9 @@ freeChanItem (Dt_t* d, chanItem* cp, Dtdisc_t* disc)
 static int
 chancmpid(Dt_t* d, paird* key1, paird* key2, Dtdisc_t* disc)
 {
+  (void)d;
+  (void)disc;
+
   if (key1->p1 > key2->p1) {
     if (key1->p2 <= key2->p2) return 0;
     else return 1;
@@ -290,6 +297,9 @@ chancmpid(Dt_t* d, paird* key1, paird* key2, Dtdisc_t* disc)
 static int
 dcmpid(Dt_t* d, double* key1, double* key2, Dtdisc_t* disc)
 {
+  (void)d;
+  (void)disc;
+
   if (*key1 > *key2) return 1;
   else if (*key1 < *key2) return -1;
   else return 0;
@@ -427,14 +437,13 @@ chanSearch (Dt_t* chans, segment* seg)
 }
 
 static void
-assignSegs (int nrtes, route* route_list, maze* mp)
+assignSegs (size_t nrtes, route* route_list, maze* mp)
 {
     channel* chan;
-    int i, j;
 
-    for (i=0;i<nrtes;i++) {
+    for (size_t i=0;i<nrtes;i++) {
 	route rte = route_list[i];
-	for (j=0;j<rte.n;j++) {
+	for (size_t j=0;j<rte.n;j++) {
 	    segment* seg = rte.segs+j;
 	    if (seg->isVert)
 		chan = chanSearch(mp->vchans, seg);
@@ -454,25 +463,17 @@ addLoop (sgraph* sg, cell* cp, snode* dp, snode* sp)
 {
     int i;
     int onTop;
-    pointf midp = midPt (cp);
 
     for (i = 0; i < cp->nsides; i++) {
-	cell* ocp;
-	pointf p;
-	double wt;
 	snode* onp = cp->sides[i];
 
 	if (onp->isVert) continue;
 	if (onp->cells[0] == cp) {
 	    onTop = 1;
-	    ocp = onp->cells[1];
 	}
 	else {
 	    onTop = 0;
-	    ocp = onp->cells[0];
 	}
-	p = sidePt (onp, ocp);
-	wt = fabs(p.x - midp.x) +  fabs(p.y - midp.y);
 	if (onTop)
 	    createSEdge (sg, sp, onp, 0);  /* FIX weight */
 	else
@@ -489,20 +490,10 @@ static void
 addNodeEdges (sgraph* sg, cell* cp, snode* np)
 {
     int i;
-    pointf midp = midPt (cp);
 
     for (i = 0; i < cp->nsides; i++) {
 	snode* onp = cp->sides[i];
-	cell* ocp;
-	pointf p;
-	double wt;
 
-	if (onp->cells[0] == cp)
-	    ocp = onp->cells[1];
-	else
-	    ocp = onp->cells[0];
-	p = sidePt (onp, ocp);
-	wt = fabs(p.x - midp.x) +  fabs(p.y - midp.y);
 	createSEdge (sg, np, onp, 0);  /* FIX weight */
     }
     sg->nnodes++;
@@ -513,7 +504,7 @@ addNodeEdges (sgraph* sg, cell* cp, snode* np)
 
 #ifdef DEBUG
 
-#include <intset.h>
+#include <common/intset.h>
 static char* bendToStr (bend b)
 {
   char* s = NULL;
@@ -530,7 +521,8 @@ static char* bendToStr (bend b)
   case B_DOWN :
     s = "B_DOWN";
     break;
-  case B_RIGHT :
+  default:
+    assert(b == B_RIGHT);
     s = "B_RIGHT";
     break;
   }
@@ -561,7 +553,7 @@ dumpChanG (channel* cp, int v)
     if (dtsize(adj) == 0) continue;
     putSeg (stderr, cp->seg_list[k]);
     fputs (" ->\n", stderr);
-    for (ip = (intitem*)dtfirst(adj); ip; ip = (intitem*)dtnext(adj, ip)) {
+    for (ip = dtfirst(adj); ip; ip = dtnext(adj, ip)) {
       fputs ("     ", stderr);
       putSeg (stderr, cp->seg_list[ip->id]);
       fputs ("\n", stderr);
@@ -615,11 +607,10 @@ create_graphs(Dt_t* chans)
 static int
 eqEndSeg (bend S1l2, bend S2l2, bend T1, bend T2)
 {
-    if (((S1l2==T2)&&(S2l2=!T2))
-     || ((S1l2==B_NODE)&&(S2l2==T1)))
-	return(0);
+    if ((S1l2==T2 && S2l2!=T2) || (S1l2==B_NODE && S2l2==T1))
+	return 0;
     else
-	return(-1);
+	return -1;
 }
 
 static int
@@ -655,7 +646,7 @@ static int
 segCmp (segment* S1, segment* S2, bend T1, bend T2)
 {
 	/* no overlap */
-    if((S1->p.p2<S2->p.p1)||(S1->p.p1>S2->p.p2)) return(0);
+    if (S1->p.p2 < S2->p.p1 || S1->p.p1 > S2->p.p2) return 0;
 	/* left endpoint of S2 inside S1 */
     if(S1->p.p1<S2->p.p1&&S2->p.p1<S1->p.p2)
 	return overlapSeg (S1, S2, T1, T2);
@@ -664,32 +655,32 @@ segCmp (segment* S1, segment* S2, bend T1, bend T2)
 	return -1*overlapSeg (S2, S1, T1, T2);
     else if(S1->p.p1==S2->p.p1) {
 	if(S1->p.p2==S2->p.p2) {
-	    if((S1->l1==S2->l1)&&(S1->l2==S2->l2))
-		return(0);
+	    if (S1->l1 == S2->l1 && S1->l2 == S2->l2)
+		return 0;
 	    else if (S2->l1==S2->l2) {
-		if(S2->l1==T1) return(1);
-		else if(S2->l1==T2) return(-1);
-		else if ((S1->l1!=T1)&&(S1->l2!=T1)) return (1);
-		else if ((S1->l1!=T2)&&(S1->l2!=T2)) return (-1);
+		if (S2->l1 == T1) return 1;
+		else if (S2->l1 == T2) return -1;
+		else if (S1->l1 != T1 && S1->l2 != T1) return 1;
+		else if (S1->l1 != T2 && S1->l2 != T2) return -1;
 		else return 0;
 	    }
-	    else if ((S2->l1==T1)&&(S2->l2==T2)) {
-		if ((S1->l1!=T1)&&(S1->l2==T2)) return 1;
-		else if ((S1->l1==T1)&&(S1->l2!=T2)) return -1;
+	    else if (S2->l1 == T1 && S2->l2 == T2) {
+		if (S1->l1 != T1 && S1->l2 == T2) return 1;
+		else if (S1->l1 == T1 && S1->l2 != T2) return -1;
 		else return 0;
 	    }
-	    else if ((S2->l2==T1)&&(S2->l1==T2)) {
-		if ((S1->l2!=T1)&&(S1->l1==T2)) return 1;
-		else if ((S1->l2==T1)&&(S1->l1!=T2)) return -1;
+	    else if (S2->l2 == T1 && S2->l1 == T2) {
+		if (S1->l2 != T1 && S1->l1 == T2) return 1;
+		else if (S1->l2 == T1 && S1->l1 != T2) return -1;
 		else return 0;
 	    }
-	    else if ((S2->l1==B_NODE)&&(S2->l2==T1)) {
+	    else if (S2->l1 == B_NODE && S2->l2 == T1) {
 		return ellSeg (S1->l1, S1->l2, T1);
 	    }
-	    else if ((S2->l1==B_NODE)&&(S2->l2==T2)) {
+	    else if (S2->l1 == B_NODE && S2->l2 == T2) {
 		return -1*ellSeg (S1->l1, S1->l2, T2);
 	    }
-	    else if ((S2->l1==T1)&&(S2->l2==B_NODE)) {
+	    else if (S2->l1 == T1 && S2->l2 == B_NODE) {
 		return ellSeg (S1->l2, S1->l1, T1);
 	    }
 	    else { /* ((S2->l1==T2)&&(S2->l2==B_NODE)) */
@@ -710,14 +701,14 @@ segCmp (segment* S1, segment* S2, bend T1, bend T2)
 	}
     }
     else if(S1->p.p2==S2->p.p1) {
-	if(S1->l2==S2->l1) return(0);
-	else if(S1->l2==T2) return(1);
-	else return(-1);
+	if (S1->l2 == S2->l1) return 0;
+	else if (S1->l2 == T2) return 1;
+	else return -1;
     }
     else { /* S1->p.p1==S2->p.p2 */
-	if(S1->l1==S2->l2) return(0);
-	else if(S1->l1==T2) return(1);
-	else return(-1);
+	if (S1->l1 == S2->l2) return 0;
+	else if (S1->l1 == T2) return 1;
+	else return -1;
     }
     assert(0);
     return 0;
@@ -728,6 +719,7 @@ segCmp (segment* S1, segment* S2, bend T1, bend T2)
  *   0 if a crossing is unavoidable or there is no crossing at all or 
  *     the segments are parallel,
  *   1 if S1 HAS TO BE to the left/above S2 to avoid a crossing
+ *  -2 if S1 and S2 are incomparable
  *
  * Note: This definition means horizontal segments have track numbers
  * increasing as y decreases, while vertical segments have track numbers
@@ -742,7 +734,7 @@ seg_cmp(segment* S1, segment* S2)
 {
     if(S1->isVert!=S2->isVert||S1->comm_coord!=S2->comm_coord) {
 	agerr (AGERR, "incomparable segments !! -- Aborting\n");
-	longjmp(jbuf, 1);
+	return -2;
     }
     if(S1->isVert)
 	return segCmp (S1, S2, B_RIGHT, B_LEFT);
@@ -750,7 +742,7 @@ seg_cmp(segment* S1, segment* S2)
 	return segCmp (S1, S2, B_DOWN, B_UP);
 }
 
-static void 
+static int
 add_edges_in_G(channel* cp)
 {
     int x,y;
@@ -760,21 +752,21 @@ add_edges_in_G(channel* cp)
 
     for(x=0;x+1<size;x++) {
 	for(y=x+1;y<size;y++) {
-	    switch (seg_cmp(seg_list[x],seg_list[y])) {
-	    case 1:
+	    int cmp = seg_cmp(seg_list[x],seg_list[y]);
+	    if (cmp == -2) {
+		return -1;
+	    } else if (cmp > 0) {
 		insert_edge(G,x,y);
-		break;
-	    case 0:
-		break;
-	    case -1:
+	    } else if (cmp == -1) {
 		insert_edge(G,y,x);
-		break;
 	    }
 	}
     }
+
+    return 0;
 }
 
-static void
+static int
 add_np_edges (Dt_t* chans)
 {
     Dt_t* lp;
@@ -787,9 +779,13 @@ add_np_edges (Dt_t* chans)
 	for (l2 = dtflatten (lp); l2; l2 = dtlink(lp,l2)) {
 	    cp = (channel*)l2;
 	    if (cp->cnt)
-		add_edges_in_G(cp);
+		if (add_edges_in_G(cp)) {
+		  return -1;
+		}
    	}
     }
+
+    return 0;
 }
 
 static segment*
@@ -797,9 +793,9 @@ next_seg(segment* seg, int dir)
 {
     assert(seg);
     if (!dir)
-        return(seg->prev);
+        return seg->prev;
     else
-        return(seg->next);
+        return seg->next;
 }
 
 /* propagate_prec propagates the precedence relationship along 
@@ -834,28 +830,28 @@ propagate_prec(segment* seg, int prec, int hops, int dir)
 	}
 	current = next;
     }
-    return(ans);
+    return ans;
 }
 
-static int
+static bool
 is_parallel(segment* s1, segment* s2)
 {
     assert (s1->comm_coord==s2->comm_coord);
-    return ((s1->p.p1==s2->p.p1)&&
-            (s1->p.p2==s2->p.p2)&&
-            (s1->l1==s2->l1)&&
-            (s1->l2==s2->l2));
+    return s1->p.p1 == s2->p.p1 &&
+           s1->p.p2 == s2->p.p2 &&
+           s1->l1 == s2->l1 &&
+           s1->l2 == s2->l2;
 }
 
-/* decide_point returns the number of hops needed in the given directions 
- * along the 2 edges to get to a deciding point (or NODES) and also puts 
- * into prec the appropriate dependency (follows same convention as seg_cmp)
+/* decide_point returns (through ret) the number of hops needed in the given
+ * directions along the 2 edges to get to a deciding point (or NODES) and also
+ * puts into prec the appropriate dependency (follows same convention as
+ * seg_cmp)
  */
-static pair 
-decide_point(segment* si, segment* sj, int dir1, int dir2)
+static int
+decide_point(pair *ret, segment* si, segment* sj, int dir1, int dir2)
 {
     int prec, ans = 0, temp;
-    pair ret;
     segment* np1;
     segment* np2;
     
@@ -871,12 +867,15 @@ decide_point(segment* si, segment* sj, int dir1, int dir2)
 	assert(0); /* FIXME */
     else {
 	temp = seg_cmp(np1, np2);
+	if (temp == -2) {
+	    return -1;
+	}
 	prec = propagate_prec(np1, temp, ans+1, 1-dir1);
     }
 		
-    ret.a = ans;
-    ret.b = prec;
-    return(ret);
+    ret->a = ans;
+    ret->b = prec;
+    return 0;
 }
 
 /* sets the edges for a series of parallel segments along two edges starting 
@@ -992,7 +991,7 @@ removeEdge(segment* seg1, segment* seg2, int dir, maze* mp)
     remove_redge (chan->G, ptr1->ind_no, ptr2->ind_no);
 }
 
-static void
+static int
 addPEdges (channel* cp, maze* mp)
 {
     int i,j;
@@ -1031,50 +1030,48 @@ addPEdges (channel* cp, maze* mp)
 			    dir = 1;
 		    }
 
-		    p = decide_point(segs[i], segs[j], 0, dir);
+		    if (decide_point(&p, segs[i], segs[j], 0, dir) != 0) {
+			return -1;
+		    }
 		    hops.a = p.a;
 		    prec1 = p.b;
-		    p = decide_point(segs[i], segs[j], 1, 1-dir);
+		    if (decide_point(&p, segs[i], segs[j], 1, 1-dir) != 0) {
+			return -1;
+		    }
 		    hops.b = p.a;
 		    prec2 = p.b;
 
-		    switch(prec1) {
-		    case -1 :
+		    if (prec1 == -1) {
 			set_parallel_edges (segs[j], segs[i], dir, 0, hops.a, mp);
 			set_parallel_edges (segs[j], segs[i], 1-dir, 1, hops.b, mp);
 			if(prec2==1)
 			    removeEdge (segs[i], segs[j], 1-dir, mp);
-			break;
-		    case 0 :
-			switch(prec2) {
-			case -1:
+		    } else if (prec1 == 0) {
+			if (prec2 == -1) {
 			    set_parallel_edges (segs[j], segs[i], dir, 0, hops.a, mp);
 			    set_parallel_edges (segs[j], segs[i], 1-dir, 1, hops.b, mp);
-			    break;
-			case 0 :
+			} else if (prec2 == 0) {
 			    set_parallel_edges (segs[i], segs[j], 0, dir, hops.a, mp);
 			    set_parallel_edges (segs[i], segs[j], 1, 1-dir, hops.b, mp);
-			    break;
-			case 1:
+			} else if (prec2 == 1) {
 			    set_parallel_edges (segs[i], segs[j], 0, dir, hops.a, mp);
 			    set_parallel_edges (segs[i], segs[j], 1, 1-dir, hops.b, mp);
-			    break;
 			}
-			break;
-		    case 1 :
+		    } else if (prec1 == 1) {
 			set_parallel_edges (segs[i], segs[j], 0, dir, hops.a, mp);
 			set_parallel_edges (segs[i], segs[j], 1, 1-dir, hops.b, mp);
 			if(prec2==-1)
 			    removeEdge (segs[i], segs[j], 1-dir, mp);
-			break;
 		    }
 		}
 	    }
 	}
     }
+
+    return 0;
 }
 
-static void 
+static int
 add_p_edges (Dt_t* chans, maze* mp)
 {
     Dt_t* lp;
@@ -1084,29 +1081,43 @@ add_p_edges (Dt_t* chans, maze* mp)
     for (l1 = dtflatten (chans); l1; l1 = dtlink(chans,l1)) {
 	lp = ((chanItem*)l1)->chans;
 	for (l2 = dtflatten (lp); l2; l2 = dtlink(lp,l2)) {
-	    addPEdges ((channel*)l2, mp);
+	    if (addPEdges((channel*)l2, mp) != 0) {
+	        return -1;
+	    }
    	}
     }
+
+    return 0;
 }
 
-static void
-assignTracks (int nrtes, route* route_list, maze* mp)
+static int
+assignTracks (maze* mp)
 {
     /* Create the graphs for each channel */
     create_graphs(mp->hchans);
     create_graphs(mp->vchans);
 
     /* add edges between non-parallel segments */
-    add_np_edges(mp->hchans);
-    add_np_edges(mp->vchans);
+    if (add_np_edges(mp->hchans) != 0) {
+	return -1;
+    }
+    if (add_np_edges(mp->vchans) != 0) {
+	return -1;
+    }
 
     /* add edges between parallel segments + remove appropriate edges */
-    add_p_edges(mp->hchans, mp);
-    add_p_edges(mp->vchans, mp);
+    if (add_p_edges(mp->hchans, mp) != 0) {
+	return -1;
+    }
+    if (add_p_edges(mp->vchans, mp) != 0) {
+	return -1;
+    }
 
     /* Assign the tracks after a top sort */
     assignTrackNo (mp->hchans);
     assignTrackNo (mp->vchans);
+
+    return 0;
 }
 
 static double
@@ -1138,27 +1149,26 @@ addPoints(pointf p0, pointf p1)
 }
 
 static void
-attachOrthoEdges (Agraph_t* g, maze* mp, int n_edges, route* route_list, splineInfo *sinfo, epair_t es[], int doLbls)
+attachOrthoEdges (Agraph_t* g, maze* mp, size_t n_edges, route* route_list, splineInfo *sinfo, epair_t es[], int doLbls)
 {
-    int irte = 0;
-    int i, ipt, npts;
+    int ipt;
     pointf* ispline = 0;
-    int splsz = 0;
+    size_t splsz = 0;
     pointf p, p1, q1;
     route rte;
     segment* seg;
     Agedge_t* e;
     textlabel_t* lbl;
 
-    for (; irte < n_edges; irte++) {
+    for (size_t irte = 0; irte < n_edges; irte++) {
 	e = es[irte].e;
 	p1 = addPoints(ND_coord(agtail(e)), ED_tail_port(e).p);
 	q1 = addPoints(ND_coord(aghead(e)), ED_head_port(e).p);
 
 	rte = route_list[irte];
-	npts = 1 + 3*rte.n;
+	size_t npts = 1 + 3*rte.n;
 	if (npts > splsz) {
-		if (ispline) free (ispline);
+		free (ispline);
 		ispline = N_GNEW(npts, pointf);
 		splsz = npts;
 	}
@@ -1175,7 +1185,7 @@ attachOrthoEdges (Agraph_t* g, maze* mp, int n_edges, route* route_list, splineI
 	ispline[0] = ispline[1] = p;
 	ipt = 2;
 
-	for (i = 1;i<rte.n;i++) {
+	for (size_t i = 1;i<rte.n;i++) {
 		seg = rte.segs+i;
 		if (seg->isVert)
 		    p.x = vtrack(seg, mp);
@@ -1213,16 +1223,18 @@ edgeLen (Agedge_t* e)
 
 static int edgecmp(epair_t* e0, epair_t* e1)
 {
-    return (e0->d - e1->d);
+    return e0->d - e1->d;
 }
 
 static boolean spline_merge(node_t * n)
 {
+    (void)n;
     return FALSE;
 }
 
 static boolean swap_ends_p(edge_t * e)
 {
+    (void)e;
     return FALSE;
 }
 
@@ -1238,9 +1250,8 @@ orthoEdges (Agraph_t* g, int doLbls)
 {
     sgraph* sg;
     maze* mp;
-    int n_edges;
     route* route_list;
-    int i, gstart;
+    int gstart;
     Agnode_t* n;
     Agedge_t* e;
     snode* sn;
@@ -1248,7 +1259,7 @@ orthoEdges (Agraph_t* g, int doLbls)
     epair_t* es = N_GNEW(agnedges(g), epair_t);
     cell* start;
     cell* dest;
-    PointSet* ps;
+    PointSet* ps = NULL;
     textlabel_t* lbl;
 
     if (Concentrate) 
@@ -1259,7 +1270,7 @@ orthoEdges (Agraph_t* g, int doLbls)
 	char* s = agget(g, "odb");
         char c;
 	odb_flags = 0;
-	if (s && (*s != '\0')) {
+	if (s && *s != '\0') {
 	    while ((c = *s++)) {
 		switch (c) {
 		case 'c' :
@@ -1293,10 +1304,10 @@ orthoEdges (Agraph_t* g, int doLbls)
 #endif
 
     /* store edges to be routed in es, along with their lengths */
-    n_edges = 0;
+    size_t n_edges = 0;
     for (n = agfstnode (g); n; n = agnxtnode(g, n)) {
         for (e = agfstout(g, n); e; e = agnxtout(g,e)) {
-	    if ((Nop == 2) && ED_spl(e)) continue;
+	    if (Nop == 2 && ED_spl(e)) continue;
 	    if (Concentrate) {
 		int ti = AGSEQ(agtail(e));
 		int hi = AGSEQ(aghead(e));
@@ -1317,15 +1328,15 @@ orthoEdges (Agraph_t* g, int doLbls)
 
     route_list = N_NEW (n_edges, route);
 
-    qsort((char *)es, n_edges, sizeof(epair_t), (qsort_cmpf) edgecmp);
+    qsort(es, n_edges, sizeof(epair_t), (qsort_cmpf) edgecmp);
 
     gstart = sg->nnodes;
     PQgen (sg->nnodes+2);
     sn = &sg->nodes[gstart];
     dn = &sg->nodes[gstart+1];
-    for (i = 0; i < n_edges; i++) {
+    for (size_t i = 0; i < n_edges; i++) {
 #ifdef DEBUG
-	if ((i > 0) && (odb_flags & ODB_IGRAPH)) emitSearchGraph (stderr, sg);
+	if (i > 0 && (odb_flags & ODB_IGRAPH)) emitSearchGraph (stderr, sg);
 #endif
 	e = es[i].e;
         start = CELL(agtail(e));
@@ -1351,9 +1362,8 @@ orthoEdges (Agraph_t* g, int doLbls)
     mp->hchans = extractHChans (mp);
     mp->vchans = extractVChans (mp);
     assignSegs (n_edges, route_list, mp);
-    if (setjmp(jbuf))
+    if (assignTracks(mp) != 0)
 	goto orthofinish;
-    assignTracks (n_edges, route_list, mp);
 #ifdef DEBUG
     if (odb_flags & ODB_ROUTE) emitGraph (stderr, mp, n_edges, route_list, es);
 #endif
@@ -1363,7 +1373,7 @@ orthofinish:
     if (Concentrate)
 	freePS (ps);
 
-    for (i=0; i < n_edges; i++)
+    for (size_t i=0; i < n_edges; i++)
 	free (route_list[i].segs);
     free (route_list);
     freeMaze (mp);
@@ -1371,8 +1381,7 @@ orthofinish:
 }
 
 #ifdef DEBUG
-#include <arith.h>
-/* #include <values.h> */
+#include <common/arith.h>
 #define TRANS 10
 
 static char* prolog2 =
@@ -1432,13 +1441,17 @@ coordOf (cell* cp, snode* np)
 	p.y = (cp->bb.LL.y + cp->bb.UR.y)/2;
 	p.x = cp->bb.UR.x;
     }
+    else {
+	agerr (AGERR, "Node not adjacent to cell -- Aborting\n");
+	exit(EXIT_FAILURE);
+    }
     return p;
 }
 
 static boxf
-emitEdge (FILE* fp, Agedge_t* e, route rte, maze* m, int ix, boxf bb)
+emitEdge (FILE* fp, Agedge_t* e, route rte, maze* m, boxf bb)
 {
-    int i, x, y;
+    int x, y;
     boxf n = CELL(agtail(e))->bb;
     segment* seg = rte.segs;
     if (seg->isVert) {
@@ -1455,7 +1468,7 @@ emitEdge (FILE* fp, Agedge_t* e, route rte, maze* m, int ix, boxf bb)
     bb.UR.y = MAX(bb.UR.y, SC*y);
     fprintf (fp, "newpath %d %d moveto\n", SC*x, SC*y);
 
-    for (i = 1;i<rte.n;i++) {
+    for (size_t i = 1;i<rte.n;i++) {
 	seg = rte.segs+i;
 	if (seg->isVert) {
 	    x = vtrack(seg, m);
@@ -1520,9 +1533,8 @@ emitSearchGraph (FILE* fp, sgraph* sg)
 }
 
 static void
-emitGraph (FILE* fp, maze* mp, int n_edges, route* route_list, epair_t es[])
+emitGraph (FILE* fp, maze* mp, size_t n_edges, route* route_list, epair_t es[])
 {
-    int i;
     boxf bb, absbb;
     box bbox;
 
@@ -1533,17 +1545,17 @@ emitGraph (FILE* fp, maze* mp, int n_edges, route* route_list, epair_t es[])
     fprintf (fp, "%d %d translate\n", TRANS, TRANS);
 
     fputs ("0 0 1 setrgbcolor\n", fp);
-    for (i = 0; i < mp->ngcells; i++) {
+    for (int i = 0; i < mp->ngcells; i++) {
       bb = mp->gcells[i].bb;
       fprintf (fp, "%f %f %f %f node\n", bb.LL.x, bb.LL.y, bb.UR.x, bb.UR.y);
     }
 
-    for (i = 0; i < n_edges; i++) {
-	absbb = emitEdge (fp, es[i].e, route_list[i], mp, i, absbb);
+    for (size_t i = 0; i < n_edges; i++) {
+	absbb = emitEdge (fp, es[i].e, route_list[i], mp, absbb);
     }
     
     fputs ("0.8 0.8 0.8 setrgbcolor\n", fp);
-    for (i = 0; i < mp->ncells; i++) {
+    for (int i = 0; i < mp->ncells; i++) {
       bb = mp->cells[i].bb;
       fprintf (fp, "%f %f %f %f cell\n", bb.LL.x, bb.LL.y, bb.UR.x, bb.UR.y);
       absbb.LL.x = MIN(absbb.LL.x, bb.LL.x);
