@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,23 +5,15 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-
-#include <stdlib.h>
+#include <stdbool.h>
 #include <stdio.h>
-#include <setjmp.h>
-#ifdef HAVE_MALLOC_H
-#include <malloc.h>
-#endif
+#include <stdlib.h>
 #include <limits.h>
 #include <math.h>
-#include "pathutil.h"
-
-#ifdef DMALLOC
-#include "dmalloc.h"
-#endif
+#include <pathplan/pathutil.h>
 
 #define ISCCW 1
 #define ISCW  2
@@ -33,11 +22,6 @@
 #define DQ_FRONT 1
 #define DQ_BACK  2
 
-#ifndef TRUE
-#define TRUE 1
-#define FALSE 0
-#endif
-
 #define prerror(msg) \
         fprintf (stderr, "libpath/%s:%d: %s\n", __FILE__, __LINE__, (msg))
 
@@ -70,7 +54,6 @@ typedef struct deque_t {
     int pnlpn, fpnlpi, lpnlpi, apex;
 } deque_t;
 
-static jmp_buf jbuf;
 static pointnlink_t *pnls, **pnlps;
 static int pnln, pnll;
 
@@ -82,25 +65,25 @@ static deque_t dq;
 static Ppoint_t *ops;
 static int opn;
 
-static void triangulate(pointnlink_t **, int);
-static int isdiagonal(int, int, pointnlink_t **, int);
-static void loadtriangle(pointnlink_t *, pointnlink_t *, pointnlink_t *);
+static int triangulate(pointnlink_t **, int);
+static bool isdiagonal(int, int, pointnlink_t **, int);
+static int loadtriangle(pointnlink_t *, pointnlink_t *, pointnlink_t *);
 static void connecttris(int, int);
-static int marktripath(int, int);
+static bool marktripath(int, int);
 
 static void add2dq(int, pointnlink_t *);
 static void splitdq(int, int);
 static int finddqsplit(pointnlink_t *);
 
 static int ccw(Ppoint_t *, Ppoint_t *, Ppoint_t *);
-static int intersects(Ppoint_t *, Ppoint_t *, Ppoint_t *, Ppoint_t *);
-static int between(Ppoint_t *, Ppoint_t *, Ppoint_t *);
+static bool intersects(Ppoint_t *, Ppoint_t *, Ppoint_t *, Ppoint_t *);
+static bool between(Ppoint_t *, Ppoint_t *, Ppoint_t *);
 static int pointintri(int, Ppoint_t *);
 
-static void growpnls(int);
-static void growtris(int);
-static void growdq(int);
-static void growops(int);
+static int growpnls(int);
+static int growtris(int);
+static int growdq(int);
+static int growops(int);
 
 /* Pshortestpath:
  * Find a shortest path contained in the polygon polyp going between the
@@ -121,13 +104,13 @@ int Pshortestpath(Ppoly_t * polyp, Ppoint_t * eps, Ppolyline_t * output)
     int pnli;
 #endif
 
-    if (setjmp(jbuf))
-	return -2;
     /* make space */
-    growpnls(polyp->pn);
+    if (growpnls(polyp->pn) != 0)
+	return -2;
     pnll = 0;
     tril = 0;
-    growdq(polyp->pn * 2);
+    if (growdq(polyp->pn * 2) != 0)
+	return -2;
     dq.fpnlpi = dq.pnlpn / 2, dq.lpnlpi = dq.fpnlpi - 1;
 
     /* make sure polygon is CCW and load pnls array */
@@ -169,7 +152,8 @@ int Pshortestpath(Ppoly_t * polyp, Ppoint_t * eps, Ppolyline_t * output)
 #endif
 
     /* generate list of triangles */
-    triangulate(pnlps, pnll);
+    if (triangulate(pnlps, pnll))
+	return -2;
 
 #if defined(DEBUG) && DEBUG >= 2
     fprintf(stderr, "triangles\n%d\n", tril);
@@ -206,7 +190,8 @@ int Pshortestpath(Ppoly_t * polyp, Ppoint_t * eps, Ppolyline_t * output)
     if (!marktripath(ftrii, ltrii)) {
 	prerror("cannot find triangle path");
 	/* a straight line is better than failing */
-	growops(2);
+	if (growops(2) != 0)
+		return -2;
 	output->pn = 2;
 	ops[0] = eps[0], ops[1] = eps[1];
 	output->ps = ops;
@@ -215,7 +200,8 @@ int Pshortestpath(Ppoly_t * polyp, Ppoint_t * eps, Ppolyline_t * output)
 
     /* if endpoints in same triangle, use a single line */
     if (ftrii == ltrii) {
-	growops(2);
+	if (growops(2) != 0)
+		return -2;
 	output->pn = 2;
 	ops[0] = eps[0], ops[1] = eps[1];
 	output->ps = ops;
@@ -292,7 +278,8 @@ int Pshortestpath(Ppoly_t * polyp, Ppoint_t * eps, Ppolyline_t * output)
 
     for (pi = 0, pnlp = &epnls[1]; pnlp; pnlp = pnlp->link)
 	pi++;
-    growops(pi);
+    if (growops(pi) != 0)
+	return -2;
     output->pn = pi;
     for (pi = pi - 1, pnlp = &epnls[1]; pnlp; pi--, pnlp = pnlp->link)
 	ops[pi] = *pnlp->pp;
@@ -302,7 +289,7 @@ int Pshortestpath(Ppoly_t * polyp, Ppoint_t * eps, Ppolyline_t * output)
 }
 
 /* triangulate polygon */
-static void triangulate(pointnlink_t ** pnlps, int pnln)
+static int triangulate(pointnlink_t ** pnlps, int pnln)
 {
     int pnli, pnlip1, pnlip2;
 
@@ -314,21 +301,25 @@ static void triangulate(pointnlink_t ** pnlps, int pnln)
 			pnlip2 = (pnli + 2) % pnln;
 			if (isdiagonal(pnli, pnlip2, pnlps, pnln)) 
 			{
-				loadtriangle(pnlps[pnli], pnlps[pnlip1], pnlps[pnlip2]);
+				if (loadtriangle(pnlps[pnli], pnlps[pnlip1], pnlps[pnlip2]) != 0)
+					return -1;
 				for (pnli = pnlip1; pnli < pnln - 1; pnli++)
 					pnlps[pnli] = pnlps[pnli + 1];
-				triangulate(pnlps, pnln - 1);
-				return;
+				return triangulate(pnlps, pnln - 1);
 			}
 		}
 		prerror("triangulation failed");
     } 
-	else
-		loadtriangle(pnlps[0], pnlps[1], pnlps[2]);
+	else {
+		if (loadtriangle(pnlps[0], pnlps[1], pnlps[2]) != 0)
+			return -1;
+	}
+
+    return 0;
 }
 
 /* check if (i, i + 2) is a diagonal */
-static int isdiagonal(int pnli, int pnlip2, pointnlink_t ** pnlps,
+static bool isdiagonal(int pnli, int pnlip2, pointnlink_t ** pnlps,
 		      int pnln)
 {
     int pnlip1, pnlim1, pnlj, pnljp1, res;
@@ -349,7 +340,7 @@ static int isdiagonal(int pnli, int pnlip2, pointnlink_t ** pnlps,
 	res = (ccw(pnlps[pnli]->pp, pnlps[pnlip2]->pp,
 		   pnlps[pnlip1]->pp) == ISCW);
     if (!res)
-	return FALSE;
+	return false;
 
     /* check against all other edges */
     for (pnlj = 0; pnlj < pnln; pnlj++) {
@@ -358,20 +349,22 @@ static int isdiagonal(int pnli, int pnlip2, pointnlink_t ** pnlps,
 	      (pnlj == pnlip2) || (pnljp1 == pnlip2)))
 	    if (intersects(pnlps[pnli]->pp, pnlps[pnlip2]->pp,
 			   pnlps[pnlj]->pp, pnlps[pnljp1]->pp))
-		return FALSE;
+		return false;
     }
-    return TRUE;
+    return true;
 }
 
-static void loadtriangle(pointnlink_t * pnlap, pointnlink_t * pnlbp,
+static int loadtriangle(pointnlink_t * pnlap, pointnlink_t * pnlbp,
 			 pointnlink_t * pnlcp)
 {
     triangle_t *trip;
     int ei;
 
     /* make space */
-    if (tril >= trin)
-	growtris(trin + 20);
+    if (tril >= trin) {
+	if (growtris(trin + 20) != 0)
+		return -1;
+    }
     trip = &tris[tril++];
     trip->mark = 0;
     trip->e[0].pnl0p = pnlap, trip->e[0].pnl1p = pnlbp, trip->e[0].rtp =
@@ -382,6 +375,8 @@ static void loadtriangle(pointnlink_t * pnlap, pointnlink_t * pnlbp,
 	NULL;
     for (ei = 0; ei < 3; ei++)
 	trip->e[ei].ltp = trip;
+
+    return 0;
 }
 
 /* connect a pair of triangles at their common edge (if any) */
@@ -403,21 +398,21 @@ static void connecttris(int tri1, int tri2)
 }
 
 /* find and mark path from trii, to trij */
-static int marktripath(int trii, int trij)
+static bool marktripath(int trii, int trij)
 {
     int ei;
 
     if (tris[trii].mark)
-	return FALSE;
+	return false;
     tris[trii].mark = 1;
     if (trii == trij)
-	return TRUE;
+	return true;
     for (ei = 0; ei < 3; ei++)
 	if (tris[trii].e[ei].rtp &&
 	    marktripath(tris[trii].e[ei].rtp - tris, trij))
-	    return TRUE;
+	    return true;
     tris[trii].mark = 0;
-    return FALSE;
+    return false;
 }
 
 /* add a new point to the deque, either front or back */
@@ -470,7 +465,7 @@ static int ccw(Ppoint_t * p1p, Ppoint_t * p2p, Ppoint_t * p3p)
 }
 
 /* line to line intersection */
-static int intersects(Ppoint_t * pap, Ppoint_t * pbp,
+static bool intersects(Ppoint_t * pap, Ppoint_t * pbp,
 		      Ppoint_t * pcp, Ppoint_t * pdp)
 {
     int ccw1, ccw2, ccw3, ccw4;
@@ -479,7 +474,7 @@ static int intersects(Ppoint_t * pap, Ppoint_t * pbp,
 	ccw(pcp, pdp, pap) == ISON || ccw(pcp, pdp, pbp) == ISON) {
 	if (between(pap, pbp, pcp) || between(pap, pbp, pdp) ||
 	    between(pcp, pdp, pap) || between(pcp, pdp, pbp))
-	    return TRUE;
+	    return true;
     } else {
 	ccw1 = (ccw(pap, pbp, pcp) == ISCCW) ? 1 : 0;
 	ccw2 = (ccw(pap, pbp, pdp) == ISCCW) ? 1 : 0;
@@ -487,18 +482,18 @@ static int intersects(Ppoint_t * pap, Ppoint_t * pbp,
 	ccw4 = (ccw(pcp, pdp, pbp) == ISCCW) ? 1 : 0;
 	return (ccw1 ^ ccw2) && (ccw3 ^ ccw4);
     }
-    return FALSE;
+    return false;
 }
 
 /* is pbp between pap and pcp */
-static int between(Ppoint_t * pap, Ppoint_t * pbp, Ppoint_t * pcp)
+static bool between(Ppoint_t * pap, Ppoint_t * pbp, Ppoint_t * pcp)
 {
     Ppoint_t p1, p2;
 
     p1.x = pbp->x - pap->x, p1.y = pbp->y - pap->y;
     p2.x = pcp->x - pap->x, p2.y = pcp->y - pap->y;
     if (ccw(pap, pbp, pcp) != ISON)
-	return FALSE;
+	return false;
     return (p2.x * p1.x + p2.y * p1.y >= 0) &&
 	(p2.x * p2.x + p2.y * p2.y <= p1.x * p1.x + p1.y * p1.y);
 }
@@ -514,91 +509,56 @@ static int pointintri(int trii, Ppoint_t * pp)
     return (sum == 3 || sum == 0);
 }
 
-static void growpnls(int newpnln)
+static int growpnls(int newpnln)
 {
     if (newpnln <= pnln)
-	return;
-    if (!pnls) {
-	if (!(pnls = (pointnlink_t *) malloc(POINTNLINKSIZE * newpnln))) {
-	    prerror("cannot malloc pnls");
-	    longjmp(jbuf,1);
-	}
-	if (!(pnlps = (pointnlink_t **) malloc(POINTNLINKPSIZE * newpnln))) {
-	    prerror("cannot malloc pnlps");
-	    longjmp(jbuf,1);
-	}
-    } else {
-	if (!(pnls = (pointnlink_t *) realloc((void *) pnls,
-					      POINTNLINKSIZE * newpnln))) {
-	    prerror("cannot realloc pnls");
-	    longjmp(jbuf,1);
-	}
-	if (!(pnlps = (pointnlink_t **) realloc((void *) pnlps,
-						POINTNLINKPSIZE *
-						newpnln))) {
-	    prerror("cannot realloc pnlps");
-	    longjmp(jbuf,1);
-	}
+	return 0;
+    if (!(pnls = realloc(pnls, POINTNLINKSIZE * newpnln))) {
+	prerror("cannot realloc pnls");
+	return -1;
+    }
+    if (!(pnlps = realloc(pnlps, POINTNLINKPSIZE * newpnln))) {
+	prerror("cannot realloc pnlps");
+	return -1;
     }
     pnln = newpnln;
+    return 0;
 }
 
-static void growtris(int newtrin)
+static int growtris(int newtrin)
 {
     if (newtrin <= trin)
-	return;
-    if (!tris) {
-	if (!(tris = (triangle_t *) malloc(TRIANGLESIZE * newtrin))) {
-	    prerror("cannot malloc tris");
-	    longjmp(jbuf,1);
-	}
-    } else {
-	if (!(tris = (triangle_t *) realloc((void *) tris,
-					    TRIANGLESIZE * newtrin))) {
-	    prerror("cannot realloc tris");
-	    longjmp(jbuf,1);
-	}
+	return 0;
+    if (!(tris = realloc(tris, TRIANGLESIZE * newtrin))) {
+	prerror("cannot realloc tris");
+	return -1;
     }
     trin = newtrin;
+
+    return 0;
 }
 
-static void growdq(int newdqn)
+static int growdq(int newdqn)
 {
     if (newdqn <= dq.pnlpn)
-	return;
-    if (!dq.pnlps) {
-	if (!
-	    (dq.pnlps =
-	     (pointnlink_t **) malloc(POINTNLINKPSIZE * newdqn))) {
-	    prerror("cannot malloc dq.pnls");
-	    longjmp(jbuf,1);
-	}
-    } else {
-	if (!(dq.pnlps = (pointnlink_t **) realloc((void *) dq.pnlps,
-						   POINTNLINKPSIZE *
-						   newdqn))) {
-	    prerror("cannot realloc dq.pnls");
-	    longjmp(jbuf,1);
-	}
+	return 0;
+    if (!(dq.pnlps = realloc(dq.pnlps, POINTNLINKPSIZE * newdqn))) {
+	prerror("cannot realloc dq.pnls");
+	return -1;
     }
     dq.pnlpn = newdqn;
+    return 0;
 }
 
-static void growops(int newopn)
+static int growops(int newopn)
 {
     if (newopn <= opn)
-	return;
-    if (!ops) {
-	if (!(ops = (Ppoint_t *) malloc(POINTSIZE * newopn))) {
-	    prerror("cannot malloc ops");
-	    longjmp(jbuf,1);
-	}
-    } else {
-	if (!(ops = (Ppoint_t *) realloc((void *) ops,
-					 POINTSIZE * newopn))) {
-	    prerror("cannot realloc ops");
-	    longjmp(jbuf,1);
-	}
+	return 0;
+    if (!(ops = realloc(ops, POINTSIZE * newopn))) {
+	prerror("cannot realloc ops");
+	return -1;
     }
     opn = newopn;
+
+    return 0;
 }
