@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,16 +5,16 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#include "Multilevel.h"
-#include "PriorityQueue.h"
-#include "memory.h"
-#include "logic.h"
-#include "assert.h"
-#include "arith.h"
-
+#include <sfdpgen/Multilevel.h>
+#include <sfdpgen/PriorityQueue.h>
+#include <common/memory.h>
+#include <common/logic.h>
+#include <assert.h>
+#include <common/arith.h>
+#include <stddef.h>
 
 Multilevel_control Multilevel_control_new(int scheme, int mode){
   Multilevel_control ctrl;
@@ -85,6 +82,7 @@ void Multilevel_delete(Multilevel grid){
 
 static void maximal_independent_vertex_set(SparseMatrix A, int randomize, int **vset, int *nvset, int *nzc){
   int i, ii, j, *ia, *ja, m, n, *p = NULL;
+  NOTUSED(n);
   assert(A);
   assert(SparseMatrix_known_strucural_symmetric(A));
   ia = A->ia;
@@ -137,6 +135,8 @@ static void maximal_independent_vertex_set_RS(SparseMatrix A, int randomize, int
    */
   int i, jj, ii, *p = NULL, j, k, *ia, *ja, m, n, gain, removed, nf = 0;
   PriorityQueue q;
+  NOTUSED(removed);
+  NOTUSED(n);
   assert(A);
   assert(SparseMatrix_known_strucural_symmetric(A));
 
@@ -325,6 +325,7 @@ static void maximal_independent_edge_set_heavest_edge_pernode(SparseMatrix A, in
 
 static void maximal_independent_edge_set_heavest_edge_pernode_leaves_first(SparseMatrix A, int randomize, int **cluster, int **clusterp, int *ncluster){
   int i, ii, j, *ia, *ja, m, n, *p = NULL, q;
+  NOTUSED(n);
   real *a, amax = 0;
   int first = TRUE, jamax = 0;
   int *matched, nz, ncmax = 0, nz0, nzz,k ;
@@ -500,6 +501,7 @@ static void maximal_independent_edge_set_heavest_edge_pernode_leaves_first(Spars
 
 static void maximal_independent_edge_set_heavest_edge_pernode_supernodes_first(SparseMatrix A, int randomize, int **cluster, int **clusterp, int *ncluster){
   int i, ii, j, *ia, *ja, m, n, *p = NULL;
+  NOTUSED(n);
   real *a, amax = 0;
   int first = TRUE, jamax = 0;
   int *matched, nz, nz0;
@@ -629,9 +631,9 @@ static void maximal_independent_edge_set_heavest_edge_pernode_supernodes_first(S
 }
 
 static int scomp(const void *s1, const void *s2){
-  real *ss1, *ss2;
-  ss1 = (real*) s1;
-  ss2 = (real*) s2;
+  const real *ss1, *ss2;
+  ss1 = (const real*) s1;
+  ss2 = (const real*) s2;
 
   if ((ss1)[1] > (ss2)[1]){
     return -1;
@@ -644,6 +646,7 @@ static int scomp(const void *s1, const void *s2){
 static void maximal_independent_edge_set_heavest_cluster_pernode_leaves_first(SparseMatrix A, int csize, 
 									      int randomize, int **cluster, int **clusterp, int *ncluster){
   int i, ii, j, *ia, *ja, m, n, *p = NULL, q, iv;
+  NOTUSED(n);
   real *a;
   int *matched, nz,  nz0, nzz,k, nv;
   enum {UNMATCHED = -2, MATCHED = -1};
@@ -812,133 +815,17 @@ static void maximal_independent_edge_set_heavest_edge_pernode_scaled(SparseMatri
   }
 }
 
-SparseMatrix DistanceMatrix_restrict_cluster(int ncluster, int *clusterp, int *cluster, SparseMatrix P, SparseMatrix R, SparseMatrix D){
-#if 0
-  /* this construct a distance matrix of a coarse graph, for a coarsen give by merging all nodes in each cluster */
-  SparseMatrix cD = NULL;
-  int i, j, nzc;
-  int **irn, **jcn;
-  real **val;
-  int n = D->m;
-  int *assignment = NULL;
-  int nz;
-  int *id = D->ia, jd = D->ja;
-  int *mask = NULL;
-  int *nnodes, *mask;
-  real *d = NULL;
-
-
-  assert(D->m == D->n);
-  if (!D) return NULL;
-  if (D->a && D->type == MATRIX_TYPE_REAL) d = (real*) D->val;
-
-  irn = N_GNEW(ncluster,int*);
-  jcn = N_GNEW(ncluster,int*);
-  val = N_GNEW(ncluster,real*);
-  assignment = N_GNEW(n,int);
-  nz = N_GNEW(ncluster,int);
-  mask = N_GNEW(n,int);
-  nnodes = N_GNEW(ncluster,int);
-
-
-  /* find ncluster-subgrahs induced by the ncluster -clusters, find the diameter of each,
-     then use the radius as the distance from the supernode to the rest of the "world"
-  */
-  for (i = 0; i < ncluster; i++) nz[i] = 0;
-  for (i = 0; i < ncluster; i++){
-    for (j = clusterp[i]; j < clusterp[i+1]; j++){
-      assert(clusterp[i+1] > clusterp[i]);
-      assignment[cluster[j]] = i;
-    }
-  }
-
-  for (i = 0; i < n; i++){/* figure out how many entries per submatrix */
-    ic = asignment[i];
-    for (j = id[i]; j < id[i+1]; j++){
-      if (i != jd[j] && ic == assignment[jd[j]]) {
-	nz[ic]++;
-      }
-    }
-  }
-  for (i = 0; i < ncluster; i++) {
-    irn[i] = N_GNEW(nz[i],int);
-    jcn[i] = N_GNEW(nz[i],int);
-    val[i] = N_GNEW(nz[i],int);  
-    val[i] = NULL;
-  }
-
-  
-  for (i = 0; i < ncluster; i++) nz[i] = 0;/* get subgraphs */
-  for (i = 0; i < n; i++) mask[i] = -1;
-  for (i = 0; i < ncluster; i++) nnodes[i] = -1;
-  for (i = 0; i < n; i++){
-    ic = asignment[i];
-    ii = mask[i];
-    if (ii < 0){
-      mask[i] = ii = nnodes[ic];
-      nnodes[ic]++;
-    }
-    for (j = id[i]; j < id[i+1]; j++){
-      jc = assignment[jd[j]];
-      if (i != jd[j] && ic == jc) {
-	jj = mask[jd[j]];
-	if (jj < 0){
-	  mask[jd[j]] = jj = nnodes[jc];
-	  nnodes[jc]++;
-	}
-	irn[ic][nz[ic]] = ii;
-	jcn[ic][nz[ic]] = jj;
-	if (d) val[ic][nz[ic]] = d[j];
-      }
-    }
-  }
-
-  for (i = 0; i < ncluster; i++){/* form subgraphs */
-    SparseMatrix A;
-    A = SparseMatrix_from_coordinate_arrays(nz[nz[i]], nnodes[i], nnodes[i], irn[i], jcn[i], (void*) val[i], MATRIX_TYPE_REAL);
-    
-    SparseMatrix_delete(A);
-  }
-
-
-  for (i = 0; i < ncluster; i++){
-    for (j = clusterp[i]; j < clusterp[i+1]; j++){
-      assert(clusterp[i+1] > clusterp[i]);
-      irn[nzc] = cluster[j];
-      jcn[nzc] = i;
-      val[nzc++] = 1.;
-    }
-  }
-  assert(nzc == n);
-  cD = SparseMatrix_multiply3(R, D, P); 
-  
-  SparseMatrix_set_symmetric(cD);
-  SparseMatrix_set_pattern_symmetric(cD);
-  cD = SparseMatrix_remove_diagonal(cD);
-
-  FREE(nz);
-  FREE(assignment);
-  for (i = 0; i < ncluster; i++){
-    FREE(irn[i]);
-    FREE(jcn[i]);
-    FREE(val[i]);
-  }
-  FREE(irn); FREE(jcn); FREE(val);
-  FREE(mask);
-  FREE(nnodes);
-
-  return cD;
-#endif
+static SparseMatrix DistanceMatrix_restrict_cluster(int ncluster, int *clusterp, int *cluster, SparseMatrix P, SparseMatrix R, SparseMatrix D){
   return NULL;
 }
 
-SparseMatrix DistanceMatrix_restrict_matching(int *matching, SparseMatrix D){
+static SparseMatrix DistanceMatrix_restrict_matching(int *matching, SparseMatrix D){
   if (!D) return NULL;
   assert(0);/* not yet implemented! */
   return NULL;
 }
 
-SparseMatrix DistanceMatrix_restrict_filtering(int *mask, int is_C, int is_F, SparseMatrix D){
+static SparseMatrix DistanceMatrix_restrict_filtering(int *mask, int is_C, int is_F, SparseMatrix D){
   /* max independent vtx set based coarsening. Coarsen nodes has mask >= is_C. Fine nodes == is_F. */
   if (!D) return NULL;
   assert(0);/* not yet implemented! */
@@ -1300,7 +1187,7 @@ Multilevel Multilevel_new(SparseMatrix A0, SparseMatrix D0, real *node_weights,
     A = SparseMatrix_get_real_adjacency_matrix_symmetrized(A);
   }
   if (D && (!SparseMatrix_is_symmetric(D, FALSE) || D->type != MATRIX_TYPE_REAL)){
-    D = SparseMatrix_symmetrize_nodiag(D, FALSE);
+    D = SparseMatrix_symmetrize_nodiag(D);
   }
   grid = Multilevel_init(A, D, node_weights);
   grid = Multilevel_establish(grid, ctrl);
