@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 #include "config.h"
@@ -16,239 +13,22 @@
 #include <time.h>
 #include <string.h>
 #include <math.h>
+#include <stdlib.h>
 
-#include "types.h"
-#include "memory.h"
-#include "globals.h"
+#include <common/types.h>
+#include <common/memory.h>
+#include <common/globals.h>
 
-#include "sparse_solve.h"
-#include "post_process.h"
-#include "overlap.h"
-#include "spring_electrical.h"
-#include "call_tri.h"
-#include "sfdpinternal.h"
+#include <sfdpgen/sparse_solve.h>
+#include <sfdpgen/post_process.h>
+#include <neatogen/overlap.h>
+#include <sfdpgen/spring_electrical.h>
+#include <neatogen/call_tri.h>
+#include <sfdpgen/sfdpinternal.h>
 
 #define node_degree(i) (ia[(i)+1] - ia[(i)])
 
-#ifdef UNUSED
-static void  get_neighborhood_precision_recall(char *outfile, SparseMatrix A0, real *ideal_dist_matrix, real *dist_matrix){
-  SparseMatrix A = A0;
-  int i, j, k, n = A->m;
-  //  int *ia, *ja;
-  int *g_order = NULL, *p_order = NULL;/* ordering using graph/physical distance */
-  real *gdist, *pdist, radius;
-  int np_neighbors;
-  int ng_neighbors; /*number of (graph theoretical) neighbors */
-  real node_dist;/* distance of a node to the center node */
-  real true_positive;
-  real recall;
-  FILE *fp;
-  
-  fp = fopen(outfile,"w");
-
-  if (!SparseMatrix_is_symmetric(A, FALSE)){
-    A = SparseMatrix_symmetrize(A, FALSE);
-  } 
-  //  ia = A->ia;
-  // ja = A->ja;
-
-  for (k = 5; k <= 50; k+= 5){
-    recall = 0;
-    for (i = 0; i < n; i++){
-      gdist = &(ideal_dist_matrix[i*n]);
-      vector_ordering(n, gdist, &g_order, TRUE);
-      pdist = &(dist_matrix[i*n]);
-      vector_ordering(n, pdist, &p_order, TRUE);
-      ng_neighbors = MIN(n-1, k); /* set the number of closest neighbor in the graph space to consider, excluding the node itself */
-      np_neighbors = ng_neighbors;/* set the number of closest neighbor in the embedding to consider, excluding the node itself */
-      radius = pdist[p_order[np_neighbors]];
-      true_positive = 0;
-      for (j = 1; j <= ng_neighbors; j++){
-	node_dist = pdist[g_order[j]];/* the phisical distance for j-th closest node (in graph space) */
-	if (node_dist <= radius) true_positive++;
-      }
-      recall += true_positive/np_neighbors;
-    }
-    recall /= n;
-
-    fprintf(fp,"%d %f\n", k, recall);
-  }
-  fprintf(stderr,"wrote precision/recall in file %s\n", outfile);
-  fclose(fp);
-
-  if (A != A0) SparseMatrix_delete(A);
-  FREE(g_order); FREE(p_order);
-}
-
-
-
-void dump_distance_edge_length(char *outfile, SparseMatrix A, int dim, real *x){
-  int weighted = TRUE;
-  int n, i, j, nzz;
-  real *dist_matrix = NULL;
-  int flag;
-  real *dij, *xij, wij, top = 0, bot = 0, t;
-
-  int *p = NULL;
-  real dmin, dmax, xmax, xmin, bsta, bwidth, *xbin, x25, x75, median;
-  int nbins = 30, nsta,  nz = 0;
-  FILE *fp;
-
-  fp = fopen(outfile,"w");
-
-  flag = SparseMatrix_distance_matrix(A, weighted,  &dist_matrix);
-  assert(!flag);
-
-  n = A->m;
-  dij = MALLOC(sizeof(real)*(n*(n-1)/2));
-  xij = MALLOC(sizeof(real)*(n*(n-1)/2));
-  for (i = 0; i < n; i++){
-    for (j = i+1; j < n; j++){
-      dij[nz] = dist_matrix[i*n+j];
-      xij[nz] = distance(x, dim, i, j);
-      if (dij[nz] > 0){
-	wij = 1/(dij[nz]*dij[nz]);
-      } else {
-	wij = 1;
-      }
-      top += wij * dij[nz] * xij[nz];
-      bot += wij*xij[nz]*xij[nz];   
-      nz++;
-    }
-  }
-  if (bot > 0){
-    t = top/bot;
-  } else {
-    t = 1;
-  }
-  fprintf(stderr,"scaling factor = %f\n", t);
-
-  for (i = 0; i < nz; i++) xij[i] *= t;
-
-  vector_ordering(nz, dij, &p, TRUE);
-  dmin = dij[p[0]];
-  dmax = dij[p[nz-1]];
-  nbins = MIN(nbins, dmax/MAX(1,dmin));/* scale by dmin since edge length of 1 is treated as 72 points in stress/maxent/full_stress */
-  bwidth = (dmax - dmin)/nbins;
-
-  nsta = 0; bsta = dmin;
-  xbin = MALLOC(sizeof(real)*nz);
-  nzz = nz;
-
-  for (i = 0; i < nbins; i++){
-    /* the bin is [dmin + i*(dmax-dmin)/nbins, dmin + (i+1)*(dmax-dmin)/nbins] */
-    nz = 0; xmin = xmax = xij[p[nsta]];
-    while (nsta < nzz && dij[p[nsta]] >= bsta && dij[p[nsta]] <= bsta + bwidth){
-      xbin[nz++] = xij[p[nsta]];
-      xmin = MIN(xmin, xij[p[nsta]]);
-      xmax = MAX(xmax, xij[p[nsta]]);
-      nsta++;
-    }
-    /* find the median, and 25/75% */
-    if (nz > 0){
-      median = vector_median(nz, xbin);
-      x25 = vector_percentile(nz, xbin, 0.25);
-      x75 = vector_percentile(nz, xbin, 0.75);
-      fprintf(fp, "%d %f %f %f %f %f %f %f\n", nz, bsta, bsta + bwidth, xmin, x25, median, x75, xmax);
-    } else {
-      xmin = xmax = median = x25 = x75 = (bsta + 0.5*bwidth);
-    }
-    bsta += bwidth;
-  }
-
-  FREE(dij); FREE(xij); FREE(xbin); FREE(p);
-  FREE(dist_matrix);
-
-}
-
-real get_full_stress(SparseMatrix A, int dim, real *x, int weighting_scheme){
-  /* get the full weighted stress, \sum_ij w_ij (t ||x_i-x_j||^2-d_ij)^2, where t
-     is the optimal scaling factor t = \sum w_ij ||x_i-x_j||^2/(\sum w_ij d_ij ||x_i - x_j||),
-
-     Matrix A is assume to be sparse and a full distance matrix will be generated.
-     We assume undirected graph and only check an undirected edge i--j, not i->j and j->i.
-  */
-  int weighted = TRUE;
-  int n, i, j;
-  real *ideal_dist_matrix = NULL, *dist_matrix;
-  int flag;
-  real t, top = 0, bot = 0, lstress, stress = 0, dij, wij, xij;
-  real sne_disimilarity = 0;
-
-  flag = SparseMatrix_distance_matrix(A, weighted,  &ideal_dist_matrix);
-  assert(!flag);
-
-  n = A->m;
-  dist_matrix = MALLOC(sizeof(real)*n*n);
-
-  for (i = 0; i < n; i++){
-    for (j = i+1; j < n; j++){
-      dij = ideal_dist_matrix[i*n+j];
-      assert(dij >= 0);
-      xij = distance(x, dim, i, j);
-      if (dij > 0){
-	switch (weighting_scheme){
-	case WEIGHTING_SCHEME_SQR_DIST:
-	  wij = 1/(dij*dij);
-	  break;
-	case WEIGHTING_SCHEME_INV_DIST:
-	  wij = 1/(dij);
-	  break;
-	  break;
-	case WEIGHTING_SCHEME_NONE:
-	  wij = 1;
-	default:
-	  assert(0);
-	}
-      } else {
-	wij = 1;
-      }
-      top += wij * dij * xij;
-      bot += wij*xij*xij;
-    }
-  }
-  if (bot > 0){
-    t = top/bot;
-  } else {
-    t = 1;
-  }
-
-  for (i = 0; i < n; i++){
-    dist_matrix[i*n+i] = 0.;
-    for (j = i+1; j < n; j++){
-      dij = ideal_dist_matrix[i*n+j];
-      assert(dij >= 0);
-      xij = distance(x, dim, i, j);
-      dist_matrix[i*n+j] = xij*t;
-      dist_matrix[j*n+i] = xij*t;
-      if (dij > 0){
-	wij = 1/(dij*dij);
-      } else {
-	wij = 1;
-      }
-      lstress = (xij*t - dij);
-      stress += wij*lstress*lstress;
-    }
-  }
-
-  {int K = 20;
-    sne_disimilarity = get_sne_disimilarity(n, ideal_dist_matrix, dist_matrix, K);
-  }
-
-  get_neighborhood_precision_recall("/tmp/recall.txt", A, ideal_dist_matrix, dist_matrix);
-  get_neighborhood_precision_recall("/tmp/precision.txt", A, dist_matrix, ideal_dist_matrix);
-
-  fprintf(stderr,"sne_disimilarity = %f\n",sne_disimilarity);
-  if (n > 0) fprintf(stderr,"sstress per edge = %f\n",stress/n/(n-1)*2);
-
-  FREE(dist_matrix);  
-  FREE(ideal_dist_matrix);
-  return stress;
-}
-#endif
-
-
-SparseMatrix ideal_distance_matrix(SparseMatrix A, int dim, real *x){
+static SparseMatrix ideal_distance_matrix(SparseMatrix A, int dim, real *x){
   /* find the ideal distance between edges, either 1, or |N[i] \Union N[j]| - |N[i] \Intersection N[j]|
    */
   SparseMatrix D;
@@ -798,32 +578,32 @@ static void uniform_stress_augment_rhs(int m, int dim, real *x, real *y, real al
   }
 }
 
-static real uniform_stress_solve(SparseMatrix Lw, real alpha, int dim, real *x0, real *rhs, real tol, int maxit, int *flag){
+static real uniform_stress_solve(SparseMatrix Lw, real alpha, int dim, real *x0, real *rhs, real tol, int maxit){
   Operator Ax;
   Operator Precon;
 
   Ax = Operator_uniform_stress_matmul(Lw, alpha);
   Precon = Operator_uniform_stress_diag_precon_new(Lw, alpha);
 
-  return cg(Ax, Precon, Lw->m, dim, x0, rhs, tol, maxit, flag);
+  return cg(Ax, Precon, Lw->m, dim, x0, rhs, tol, maxit);
 
 }
 
 real StressMajorizationSmoother_smooth(StressMajorizationSmoother sm, int dim, real *x, int maxit_sm, real tol) {
   SparseMatrix Lw = sm->Lw, Lwd = sm->Lwd, Lwdd = NULL;
   int i, j, k, m, *id, *jd, *iw, *jw, idiag, flag = 0, iter = 0;
-  real *w, *dd, *d, *y = NULL, *x0 = NULL, *x00 = NULL, diag, diff = 1, *lambda = sm->lambda, res, alpha = 0., M = 0.;
+  real *w, *dd, *d, *y = NULL, *x0 = NULL, *x00 = NULL, diag, diff = 1, *lambda = sm->lambda, alpha = 0., M = 0.;
   SparseMatrix Lc = NULL;
   real dij, dist;
 
 
   Lwdd = SparseMatrix_copy(Lwd);
   m = Lw->m;
-  x0 = N_GNEW(dim*m,real);
+  x0 = calloc(dim*m, sizeof(real));
   if (!x0) goto RETURN;
 
-  x0 = MEMCPY(x0, x, sizeof(real)*dim*m);
-  y = N_GNEW(dim*m,real);
+  memcpy(x0, x, sizeof(real)*dim*m);
+  y = calloc(dim*m, sizeof(real));
   if (!y) goto RETURN;
 
   id = Lwd->ia; jd = Lwd->ja;
@@ -834,6 +614,9 @@ real StressMajorizationSmoother_smooth(StressMajorizationSmoother sm, int dim, r
 
 #ifdef DEBUG_PRINT
   if (Verbose) fprintf(stderr, "initial stress = %f\n", get_stress(m, dim, iw, jw, w, d, x, sm->scaling, sm->data, 1));
+#else
+  NOTUSED(iw);
+  NOTUSED(jw);
 #endif
   /* for the additional matrix L due to the position constraints */
   if (sm->scheme == SM_SCHEME_NORMAL_ELABEL){
@@ -845,12 +628,6 @@ real StressMajorizationSmoother_smooth(StressMajorizationSmoother sm, int dim, r
   }
 
   while (iter++ < maxit_sm && diff > tol){
-#ifdef GVIEWER
-    if (Gviewer) {
-      drawScene();
-      if (iter%2 == 0) gviewer_dump_current_frame();
-    }
-#endif
 
     if (sm->scheme != SM_SCHEME_STRESS_APPROX){
       for (i = 0; i < m; i++){
@@ -863,9 +640,6 @@ real StressMajorizationSmoother_smooth(StressMajorizationSmoother sm, int dim, r
 	  }
 	  
 	  dist = distance(x, dim, i, jd[j]);
-	  //if (d[j] >= -0.0001*dist){
-	  //   /* sometimes d[j] = 0 and ||x_i-x_j||=0*/
-	  //   dd[j] = d[j]/MAX(0.0001, dist);
 	  if (d[j] == 0){
 	    dd[j] = 0;
 	  } else {
@@ -877,18 +651,6 @@ real StressMajorizationSmoother_smooth(StressMajorizationSmoother sm, int dim, r
 	    }
 	    dd[j] = d[j]/dist;
 	    
-#if 0	  
-	    /* if two points are at the same place, we do not want a huge entry,
-	       as this cause problem with CG./ In any case, 
-	       at thw limit d[j] == ||x[i] - x[jd[j]]||, 
-	       or close. */
-	    if (dist < -d[j]*0.0000001){
-	      dd[j] = -10000.;
-	    } else {
-	      dd[j] = d[j]/dist;
-	    }
-#endif
-	    
 	  }
 	diag += dd[j];
 	}
@@ -897,7 +659,7 @@ real StressMajorizationSmoother_smooth(StressMajorizationSmoother sm, int dim, r
       }
       /* solve (Lw+lambda*I) x = Lwdd y + lambda x0 */
 
-      SparseMatrix_multiply_dense(Lwdd, FALSE, x, FALSE, &y, FALSE, dim);
+      SparseMatrix_multiply_dense(Lwdd, x, &y, dim);
     } else {
       for (i = 0; i < m; i++){
 	for (j = 0; j < dim; j++){
@@ -928,38 +690,6 @@ real StressMajorizationSmoother_smooth(StressMajorizationSmoother sm, int dim, r
       uniform_stress_augment_rhs(m, dim, x, y, alpha, M);
       break;
     } 
-#if UNIMPEMENTED
-    case SM_SCHEME_MAXENT:{
-#ifdef GVIEWER
-      if (Gviewer){
-	char *lab;
-	lab = MALLOC(sizeof(char)*100);
-	sprintf(lab,"maxent. alpha=%10.2g, iter=%d",stress_maxent_data_get_alpha(sm->data), iter);
-	gviewer_set_label(lab);
-	FREE(lab);
-      }
-#endif
-      stress_maxent_augment_rhs_fast(sm, dim, x, y, &flag);
-      if (flag) goto RETURN;
-      break;
-    }
-    case SM_SCHEME_STRESS_APPROX:{
-      stress_approx_augment_rhs(sm, dim, x, y, &flag);
-      if (flag) goto RETURN;
-      break;
-    }
-    case SM_SCHEME_STRESS:{
-#ifdef GVIEWER
-      if (Gviewer){
-	char *lab;
-	lab = MALLOC(sizeof(char)*100);
-	sprintf(lab,"pmds(k), iter=%d", iter);
-	gviewer_set_label(lab);
-	FREE(lab);
-      }
-#endif
-    }
-#endif /* UNIMPEMENTED */
     default:
       break;
   }
@@ -971,10 +701,10 @@ real StressMajorizationSmoother_smooth(StressMajorizationSmoother sm, int dim, r
 #endif
 
     if (sm->scheme == SM_SCHEME_UNIFORM_STRESS){
-      res = uniform_stress_solve(Lw, alpha, dim, x, y, sm->tol_cg, sm->maxit_cg, &flag);
+      uniform_stress_solve(Lw, alpha, dim, x, y, sm->tol_cg, sm->maxit_cg);
     } else {
-      res = SparseMatrix_solve(Lw, dim, x, y,  sm->tol_cg, sm->maxit_cg, SOLVE_METHOD_CG, &flag);
-      //res = SparseMatrix_solve(Lw, dim, x, y,  sm->tol_cg, 1, SOLVE_METHOD_JACOBI, &flag);
+      SparseMatrix_solve(Lw, dim, x, y,  sm->tol_cg, sm->maxit_cg, SOLVE_METHOD_CG, &flag);
+      //SparseMatrix_solve(Lw, dim, x, y,  sm->tol_cg, 1, SOLVE_METHOD_JACOBI, &flag);
     }
 
     if (flag) goto RETURN;
@@ -989,7 +719,7 @@ real StressMajorizationSmoother_smooth(StressMajorizationSmoother sm, int dim, r
 #endif
 
 
-    MEMCPY(x, y, sizeof(real)*m*dim);
+    memcpy(x, y, sizeof(real)*m*dim);
   }
 
 #ifdef DEBUG
