@@ -1,6 +1,3 @@
-/* $Id$Revision: */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property
  * All rights reserved. This program and the accompanying materials
@@ -8,23 +5,25 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 #include "config.h"
 
-#include "SparseMatrix.h"
-#include "spring_electrical.h"
-#include "QuadTree.h"
-#include "Multilevel.h"
-#include "post_process.h"
-#include "overlap.h"
-#include "types.h"
-#include "memory.h"
-#include "arith.h"
-#include "logic.h"
-#include "math.h"
-#include "globals.h"
+#include <sparse/SparseMatrix.h>
+#include <sfdpgen/spring_electrical.h>
+#include <sparse/QuadTree.h>
+#include <sfdpgen/Multilevel.h>
+#include <sfdpgen/post_process.h>
+#include <neatogen/overlap.h>
+#include <common/types.h>
+#include <common/memory.h>
+#include <common/arith.h>
+#include <common/logic.h>
+#include <math.h>
+#include <common/globals.h>
+#include <stdbool.h>
+#include <stddef.h>
 #include <string.h>
 #include <time.h>
 
@@ -316,14 +315,14 @@ static real update_step(int adaptive_cooling, real step, real Fnorm, real Fnorm0
 
 #define node_degree(i) (ia[(i)+1] - ia[(i)])
 
-void check_real_array_size(real **a, int len, int *lenmax){
+static void check_real_array_size(real **a, int len, int *lenmax){
   if (len >= *lenmax){
     *lenmax = len + MAX((int) 0.2*len, 10);
     *a = REALLOC(*a, sizeof(real)*(*lenmax));
   }
 
 }
-void check_int_array_size(int **a, int len, int *lenmax){
+static void check_int_array_size(int **a, int len, int *lenmax){
   if (len >= *lenmax){
     *lenmax = len + MAX((int) 0.2*len, 10);
     *a = REALLOC(*a, sizeof(int)*(*lenmax));
@@ -331,7 +330,7 @@ void check_int_array_size(int **a, int len, int *lenmax){
 
 }
 
-real get_angle(real *x, int dim, int i, int j){
+static real get_angle(real *x, int dim, int i, int j){
   /* between [0, 2Pi)*/
   int k;
   real y[2], res;
@@ -339,7 +338,7 @@ real get_angle(real *x, int dim, int i, int j){
   for (k = 0; k < 2; k++){
     y[k] = x[j*dim+k] - x[i*dim+k];
   }
-  if (ABS(y[0]) <= ABS(y[1])*eps){
+  if (fabs(y[0]) <= fabs(y[1])*eps){
     if (y[1] > 0) return 0.5*PI;
     return 1.5*PI;
   }
@@ -352,9 +351,9 @@ real get_angle(real *x, int dim, int i, int j){
   return res;
 }
 
-int comp_real(const void *x, const void *y){
-  real *xx = (real*) x;
-  real *yy = (real*) y;
+static int comp_real(const void *x, const void *y){
+  const real *xx = (const real*) x;
+  const real *yy = (const real*) y;
 
   if (*xx > *yy){
     return 1;
@@ -375,7 +374,7 @@ static void set_leaves(real *x, int dim, real dist, real ang, int i, int j){
 
 static void beautify_leaves(int dim, SparseMatrix A, real *x){
   int m = A->m, i, j, *ia = A->ia, *ja = A->ja, k;
-  int *checked, p;
+  int p;
   real dist;
   int nleaves, nleaves_max = 10;
   real *angles, maxang, ang1 = 0, ang2 = 0, pad, step;
@@ -383,19 +382,17 @@ static void beautify_leaves(int dim, SparseMatrix A, real *x){
 
   assert(!SparseMatrix_has_diagonal(A));
 
-  checked = MALLOC(sizeof(int)*m);
+  bool *checked = gcalloc(sizeof(bool), m);
   angles = MALLOC(sizeof(real)*nangles_max);
   leaves = MALLOC(sizeof(int)*nleaves_max);
 
 
-  for (i = 0; i < m; i++) checked[i] = FALSE;
-
   for (i = 0; i < m; i++){
     if (ia[i+1] - ia[i] != 1) continue;
     if (checked[i]) continue;
     p = ja[ia[i]];
     if (!checked[p]){
-      checked[p] = TRUE;
+      checked[p] = true;
       dist = 0; nleaves = 0; nangles = 0;
       for (j = ia[p]; j < ia[p+1]; j++){
 	if (node_degree(ja[j]) == 1){
@@ -544,22 +541,8 @@ void spring_electrical_embedding_fast(int dim, SparseMatrix A0, spring_electrica
     //start2 = clock();
 #endif
 
-#ifdef GVIEWER
-    if (Gviewer){
-      char *lab;
-      lab = MALLOC(sizeof(char)*100);
-      sprintf(lab,"sfdp, iter=%d", iter);
-      gviewer_set_label(lab);
-      gviewer_reset_graph_coord(A, dim, x);
-      drawScene();
-      gviewer_dump_current_frame();
-      //if ((adaptive_cooling && iter%100 == 0) || (!adaptive_cooling && iter%10 == 0)) gviewer_dump_current_frame();
-      FREE(lab);
-    }
-#endif
-
     iter++;
-    xold = MEMCPY(xold, x, sizeof(real)*dim*n);
+    memcpy(xold, x, sizeof(real)*dim*n);
     Fnorm0 = Fnorm;
     Fnorm = 0.;
 
@@ -683,7 +666,7 @@ void spring_electrical_embedding_fast(int dim, SparseMatrix A0, spring_electrica
 }
 
 
-void spring_electrical_embedding_slow(int dim, SparseMatrix A0, spring_electrical_control ctrl, real *node_weights, real *x, int *flag){
+static void spring_electrical_embedding_slow(int dim, SparseMatrix A0, spring_electrical_control ctrl, real *node_weights, real *x, int *flag){
   /* a version that does vertex moves in one go, instead of one at a time, use for debugging the fast version. Quadtree is not used. */
   /* x is a point to a 1D array, x[i*dim+j] gives the coordinate of the i-th node at dimension j.  */
   SparseMatrix A = A0;
@@ -764,7 +747,7 @@ void spring_electrical_embedding_slow(int dim, SparseMatrix A0, spring_electrica
     for (i = 0; i < dim*n; i++) force[i] = 0;
 
     iter++;
-    xold = MEMCPY(xold, x, sizeof(real)*dim*n);
+    memcpy(xold, x, sizeof(real)*dim*n);
     Fnorm0 = Fnorm;
     Fnorm = 0.;
     nsuper_avg = 0;
@@ -801,11 +784,7 @@ void spring_electrical_embedding_slow(int dim, SparseMatrix A0, spring_electrica
 	for (j = 0; j < nsuper; j++){
 	  dist = MAX(distances[j], MINDIST);
 	  for (k = 0; k < dim; k++){
-	    if (p == -1){
-	      f[k] += supernode_wgts[j]*KP*(x[i*dim+k] - center[j*dim+k])/(dist*dist);
-	    } else {
-	      f[k] += supernode_wgts[j]*KP*(x[i*dim+k] - center[j*dim+k])/pow(dist, 1.- p);
-	    }
+	    f[k] += supernode_wgts[j]*KP*(x[i*dim+k] - center[j*dim+k])/pow(dist, 1.- p);
 	  }
 	}
       } else {
@@ -814,11 +793,7 @@ void spring_electrical_embedding_slow(int dim, SparseMatrix A0, spring_electrica
 	    if (j == i) continue;
 	    dist = distance_cropped(x, dim, i, j);
 	    for (k = 0; k < dim; k++){
-	      if (p == -1){
-		f[k] += node_weights[j]*KP*(x[i*dim+k] - x[j*dim+k])/(dist*dist);
-	      } else {
-		f[k] += node_weights[j]*KP*(x[i*dim+k] - x[j*dim+k])/pow(dist, 1.- p);
-	      }
+	      f[k] += node_weights[j]*KP*(x[i*dim+k] - x[j*dim+k])/pow(dist, 1.- p);
 	    }
 	  }
 	} else {
@@ -826,11 +801,7 @@ void spring_electrical_embedding_slow(int dim, SparseMatrix A0, spring_electrica
 	    if (j == i) continue;
 	    dist = distance_cropped(x, dim, i, j);
 	    for (k = 0; k < dim; k++){
-	      if (p == -1){
-		f[k] += KP*(x[i*dim+k] - x[j*dim+k])/(dist*dist);
-	      } else {
-		f[k] += KP*(x[i*dim+k] - x[j*dim+k])/pow(dist, 1.- p);
-	      }
+	      f[k] += KP*(x[i*dim+k] - x[j*dim+k])/pow(dist, 1.- p);
 	    }
 	  }
 	}
@@ -1031,22 +1002,9 @@ void spring_electrical_embedding(int dim, SparseMatrix A0, spring_electrical_con
     fclose(f);
   }
 #endif
-#ifdef GVIEWER
-    if (Gviewer){
-      char *lab;
-      lab = MALLOC(sizeof(char)*100);
-      sprintf(lab,"sfdp, adaptive_cooling = %d iter=%d", adaptive_cooling, iter);
-      gviewer_set_label(lab);
-      gviewer_reset_graph_coord(A, dim, x);
-      drawScene();
-      gviewer_dump_current_frame();
-      //if ((adaptive_cooling && iter%100 == 0) || (!adaptive_cooling && iter%10 == 0)) gviewer_dump_current_frame();
-      FREE(lab);
-    }
-#endif
 
     iter++;
-    xold = MEMCPY(xold, x, sizeof(real)*dim*n);
+    memcpy(xold, x, sizeof(real)*dim*n);
     Fnorm0 = Fnorm;
     Fnorm = 0.;
     nsuper_avg = 0;
@@ -1096,11 +1054,7 @@ void spring_electrical_embedding(int dim, SparseMatrix A0, spring_electrical_con
 	for (j = 0; j < nsuper; j++){
 	  dist = MAX(distances[j], MINDIST);
 	  for (k = 0; k < dim; k++){
-	    if (p == -1){
-	      f[k] += supernode_wgts[j]*KP*(x[i*dim+k] - center[j*dim+k])/(dist*dist);
-	    } else {
-	      f[k] += supernode_wgts[j]*KP*(x[i*dim+k] - center[j*dim+k])/pow(dist, 1.- p);
-	    }
+	    f[k] += supernode_wgts[j]*KP*(x[i*dim+k] - center[j*dim+k])/pow(dist, 1.- p);
 	  }
 	}
       } else {
@@ -1109,11 +1063,7 @@ void spring_electrical_embedding(int dim, SparseMatrix A0, spring_electrical_con
 	    if (j == i) continue;
 	    dist = distance_cropped(x, dim, i, j);
 	    for (k = 0; k < dim; k++){
-	      if (p == -1){
-		f[k] += node_weights[j]*KP*(x[i*dim+k] - x[j*dim+k])/(dist*dist);
-	      } else {
-		f[k] += node_weights[j]*KP*(x[i*dim+k] - x[j*dim+k])/pow(dist, 1.- p);
-	      }
+	      f[k] += node_weights[j]*KP*(x[i*dim+k] - x[j*dim+k])/pow(dist, 1.- p);
 	    }
 	  }
 	} else {
@@ -1121,11 +1071,7 @@ void spring_electrical_embedding(int dim, SparseMatrix A0, spring_electrical_con
 	    if (j == i) continue;
 	    dist = distance_cropped(x, dim, i, j);
 	    for (k = 0; k < dim; k++){
-	      if (p == -1){
-		f[k] += KP*(x[i*dim+k] - x[j*dim+k])/(dist*dist);
-	      } else {
-		f[k] += KP*(x[i*dim+k] - x[j*dim+k])/pow(dist, 1.- p);
-	      }
+	      f[k] += KP*(x[i*dim+k] - x[j*dim+k])/pow(dist, 1.- p);
 	    }
 	  }
 	}
@@ -1242,7 +1188,7 @@ static void scale_coord(int n, int dim, real *x, int *id, int *jd, real *d, real
   fprintf(stderr,"scaling factor = %f\n",s);
 }
 
-static real dmean_get(int n, int *id, int *jd, real* d){
+static real dmean_get(int n, int *id, real* d){
   real dmean = 0;
   int i, j;
 
@@ -1255,7 +1201,7 @@ static real dmean_get(int n, int *id, int *jd, real* d){
   return dmean/((real) id[n]);
 }
 
-void spring_maxent_embedding(int dim, SparseMatrix A0, SparseMatrix D, spring_electrical_control ctrl, real *node_weights, real *x, real rho, int *flag){
+static void spring_maxent_embedding(int dim, SparseMatrix A0, SparseMatrix D, spring_electrical_control ctrl, real *node_weights, real *x, real rho, int *flag){
   /* x is a point to a 1D array, x[i*dim+j] gives the coordinate of the i-th node at dimension j.
 
      Minimize \Sum_{(i,j)\in E} w_ij (||x_i-x_j||-d_ij)^2 - \rho \Sum_{(i,j)\NotIn E} Log ||x_i-x_j||
@@ -1325,7 +1271,7 @@ void spring_maxent_embedding(int dim, SparseMatrix A0, SparseMatrix D, spring_el
     id = ia; jd = ja; d = NULL;
   }
   if (rho < 0) {
-    dmean = dmean_get(n, id, jd, d);
+    dmean = dmean_get(n, id, d);
     rho = rho*(id[n]/((((real) n)*((real) n)) - id[n]))/pow(dmean, p+1);
     fprintf(stderr,"dmean = %f, rho = %f\n",dmean, rho);
   }
@@ -1364,7 +1310,7 @@ void spring_maxent_embedding(int dim, SparseMatrix A0, SparseMatrix D, spring_el
   xold = MALLOC(sizeof(real)*dim*n);
   do {
     iter++;
-    xold = MEMCPY(xold, x, sizeof(real)*dim*n);
+    memcpy(xold, x, sizeof(real)*dim*n);
     Fnorm0 = Fnorm;
     Fnorm = 0.;
     nsuper_avg = 0;
@@ -1397,21 +1343,9 @@ void spring_maxent_embedding(int dim, SparseMatrix A0, SparseMatrix D, spring_el
 	}
 	assert(dj > 0);
 	/* spring force */
-	if (ctrl->q == 2){
-	  w_ij = 1./(dj*dj*dj);
-	  for (k = 0; k < dim; k++){
-	    f[k] += -w_ij*(x[i*dim+k] - x[jd[j]*dim+k])*(dist - dj)*(dist - dj)/dist;
-	  }
-	} else if (ctrl->q == 1){/* square stress force */
-	  w_ij = 1./(dj*dj);
-	  for (k = 0; k < dim; k++){
-	    f[k] += -w_ij*(x[i*dim+k] - x[jd[j]*dim+k])*(dist - dj)/dist;
-	  }
-	} else {
-	  w_ij = 1./pow(dj, ctrl->q + 1);
-	  for (k = 0; k < dim; k++){
-	    f[k] += -w_ij*(x[i*dim+k] - x[jd[j]*dim+k])*pow(dist - dj, ctrl->q)/dist;
-	  }
+	w_ij = 1./pow(dj, ctrl->q + 1);
+	for (k = 0; k < dim; k++){
+	  f[k] += -w_ij*(x[i*dim+k] - x[jd[j]*dim+k])*pow(dist - dj, ctrl->q)/dist;
 	}
 
 #ifdef DEBUG
@@ -1426,19 +1360,11 @@ void spring_maxent_embedding(int dim, SparseMatrix A0, SparseMatrix D, spring_el
 	   repulsive forces between neighboring vertices */
 	if (ctrl->use_node_weights && node_weights){
 	  for (k = 0; k < dim; k++){
-	    if (p == -1){
-	      f[k] -= rho*node_weights[j]*(x[i*dim+k] - x[jd[j]*dim+k])/(dist*dist);
-	    } else {
-	      f[k] -= rho*node_weights[j]*(x[i*dim+k] - x[jd[j]*dim+k])/pow(dist, 1.- p);
-	    }
+	    f[k] -= rho*node_weights[j]*(x[i*dim+k] - x[jd[j]*dim+k])/pow(dist, 1.- p);
 	  }
 	} else {
 	  for (k = 0; k < dim; k++){
-	    if (p == -1){
-	      f[k] -= rho*(x[i*dim+k] - x[jd[j]*dim+k])/(dist*dist);
-	    } else {
-	      f[k] -= rho*(x[i*dim+k] - x[jd[j]*dim+k])/pow(dist, 1.- p);
-	    }
+	    f[k] -= rho*(x[i*dim+k] - x[jd[j]*dim+k])/pow(dist, 1.- p);
 	  }
 
 	}
@@ -1454,11 +1380,7 @@ void spring_maxent_embedding(int dim, SparseMatrix A0, SparseMatrix D, spring_el
 	for (j = 0; j < nsuper; j++){
 	  dist = MAX(distances[j], MINDIST);
 	  for (k = 0; k < dim; k++){
-	    if (p == -1){
-	      f[k] += rho*supernode_wgts[j]*(x[i*dim+k] - center[j*dim+k])/(dist*dist);
-	    } else {
-	      f[k] += rho*supernode_wgts[j]*(x[i*dim+k] - center[j*dim+k])/pow(dist, 1.- p);
-	    }
+	    f[k] += rho*supernode_wgts[j]*(x[i*dim+k] - center[j*dim+k])/pow(dist, 1.- p);
 	  }
 	}
       } else {
@@ -1467,11 +1389,7 @@ void spring_maxent_embedding(int dim, SparseMatrix A0, SparseMatrix D, spring_el
 	    if (j == i) continue;
 	    dist = distance_cropped(x, dim, i, j);
 	    for (k = 0; k < dim; k++){
-	      if (p == -1){
-		f[k] += rho*node_weights[j]*(x[i*dim+k] - x[j*dim+k])/(dist*dist);
-	      } else {
-		f[k] += rho*node_weights[j]*(x[i*dim+k] - x[j*dim+k])/pow(dist, 1.- p);
-	      }
+	      f[k] += rho*node_weights[j]*(x[i*dim+k] - x[j*dim+k])/pow(dist, 1.- p);
 	    }
 	  }
 	} else {
@@ -1479,11 +1397,7 @@ void spring_maxent_embedding(int dim, SparseMatrix A0, SparseMatrix D, spring_el
 	    if (j == i) continue;
 	    dist = distance_cropped(x, dim, i, j);
 	    for (k = 0; k < dim; k++){
-	      if (p == -1){
-		f[k] += rho*(x[i*dim+k] - x[j*dim+k])/(dist*dist);
-	      } else {
-		f[k] += rho*(x[i*dim+k] - x[j*dim+k])/pow(dist, 1.- p);
-	      }
+	      f[k] += rho*(x[i*dim+k] - x[j*dim+k])/pow(dist, 1.- p);
 	    }
 	  }
 	}
@@ -1604,7 +1518,7 @@ void spring_electrical_spring_embedding(int dim, SparseMatrix A0, SparseMatrix D
   xold = MALLOC(sizeof(real)*dim*n);
   do {
     iter++;
-    xold = MEMCPY(xold, x, sizeof(real)*dim*n);
+    memcpy(xold, x, sizeof(real)*dim*n);
     Fnorm0 = Fnorm;
     Fnorm = 0.;
     nsuper_avg = 0;
@@ -1651,11 +1565,7 @@ void spring_electrical_spring_embedding(int dim, SparseMatrix A0, SparseMatrix D
 	for (j = 0; j < nsuper; j++){
 	  dist = MAX(distances[j], MINDIST);
 	  for (k = 0; k < dim; k++){
-	    if (p == -1){
-	      f[k] += supernode_wgts[j]*KP*(x[i*dim+k] - center[j*dim+k])/(dist*dist);
-	    } else {
-	      f[k] += supernode_wgts[j]*KP*(x[i*dim+k] - center[j*dim+k])/pow(dist, 1.- p);
-	    }
+	    f[k] += supernode_wgts[j]*KP*(x[i*dim+k] - center[j*dim+k])/pow(dist, 1.- p);
 	  }
 	}
       } else {
@@ -1664,11 +1574,7 @@ void spring_electrical_spring_embedding(int dim, SparseMatrix A0, SparseMatrix D
 	    if (j == i) continue;
 	    dist = distance_cropped(x, dim, i, j);
 	    for (k = 0; k < dim; k++){
-	      if (p == -1){
-		f[k] += node_weights[j]*KP*(x[i*dim+k] - x[j*dim+k])/(dist*dist);
-	      } else {
-		f[k] += node_weights[j]*KP*(x[i*dim+k] - x[j*dim+k])/pow(dist, 1.- p);
-	      }
+	      f[k] += node_weights[j]*KP*(x[i*dim+k] - x[j*dim+k])/pow(dist, 1.- p);
 	    }
 	  }
 	} else {
@@ -1676,11 +1582,7 @@ void spring_electrical_spring_embedding(int dim, SparseMatrix A0, SparseMatrix D
 	    if (j == i) continue;
 	    dist = distance_cropped(x, dim, i, j);
 	    for (k = 0; k < dim; k++){
-	      if (p == -1){
-		f[k] += KP*(x[i*dim+k] - x[j*dim+k])/(dist*dist);
-	      } else {
-		f[k] += KP*(x[i*dim+k] - x[j*dim+k])/pow(dist, 1.- p);
-	      }
+	      f[k] += KP*(x[i*dim+k] - x[j*dim+k])/pow(dist, 1.- p);
 	    }
 	  }
 	}
@@ -1758,34 +1660,6 @@ void print_matrix(real *x, int n, int dim){
   printf("}\n");
 }
 
-/*
-static void interpolate2(int dim, SparseMatrix A, real *x){
-  int i, j, k, *ia = A->ia, *ja = A->ja, nz, m = A->m;
-  real alpha = 0.5, beta, *y;
-
-  y = MALLOC(sizeof(real)*dim*m);
-  for (k = 0; k < dim*m; k++) y[k] = 0;
-  for (i = 0; i < m; i++){
-    nz = 0;
-    for (j = ia[i]; j < ia[i+1]; j++){
-      if (ja[j] == i) continue;
-      nz++;
-      for (k = 0; k < dim; k++){
-	y[i*dim+k] += x[ja[j]*dim + k];
-      }
-    }
-    if (nz > 0){
-      beta = (1-alpha)/nz;
-      for (k = 0; k < dim; k++) y[i*dim+k] = alpha*x[i*dim+k] +  beta*y[i*dim+k];
-    }
-  }
-  for (k = 0; k < dim*m; k++) x[k] = y[k];
-
-  FREE(y);
-}
-
-*/
-
 void interpolate_coord(int dim, SparseMatrix A, real *x){
   int i, j, k, *ia = A->ia, *ja = A->ja, nz;
   real alpha = 0.5, beta, *y;
@@ -1811,7 +1685,7 @@ void interpolate_coord(int dim, SparseMatrix A, real *x){
 }
 static void prolongate(int dim, SparseMatrix A, SparseMatrix P, SparseMatrix R, real *x, real *y, int coarsen_scheme_used, real delta){
   int nc, *ia, *ja, i, j, k;
-  SparseMatrix_multiply_dense(P, FALSE, x, FALSE, &y, FALSE, dim);
+  SparseMatrix_multiply_dense(P, x, &y, dim);
 
   /* xu yao rao dong */
   if (coarsen_scheme_used > EDGE_BASED_STA && coarsen_scheme_used < EDGE_BASED_STO){
@@ -2079,9 +1953,9 @@ static void multilevel_spring_electrical_embedding_core(int dim, SparseMatrix A0
 
   if (!SparseMatrix_is_symmetric(A, FALSE) || A->type != MATRIX_TYPE_REAL){
     if (ctrl->method == METHOD_SPRING_MAXENT){
-      A = SparseMatrix_symmetrize_nodiag(A, FALSE);
+      A = SparseMatrix_symmetrize_nodiag(A);
       assert(D0);
-      D = SparseMatrix_symmetrize_nodiag(D, FALSE);
+      D = SparseMatrix_symmetrize_nodiag(D);
     } else {
       A = SparseMatrix_get_real_adjacency_matrix_symmetrized(A);
     }
@@ -2105,7 +1979,7 @@ static void multilevel_spring_electrical_embedding_core(int dim, SparseMatrix A0
     assert(!(*flag));
     attach_edge_label_coordinates(dim, A, n_edge_label_nodes, edge_label_nodes, x, x2);
     remove_overlap(dim, A, x, label_sizes, ctrl->overlap, ctrl->initial_scaling,
-		   ctrl->edge_labeling_scheme, n_edge_label_nodes, edge_label_nodes, A, ctrl->do_shrinking, flag);
+		   ctrl->edge_labeling_scheme, n_edge_label_nodes, edge_label_nodes, A, ctrl->do_shrinking);
     SparseMatrix_delete(A2);
     FREE(x2);
     if (A != A0) SparseMatrix_delete(A);
@@ -2225,7 +2099,7 @@ static void multilevel_spring_electrical_embedding_core(int dim, SparseMatrix A0
 
 
   remove_overlap(dim, A, x, label_sizes, ctrl->overlap, ctrl->initial_scaling,
-		 ctrl->edge_labeling_scheme, n_edge_label_nodes, edge_label_nodes, A, ctrl->do_shrinking, flag);
+		 ctrl->edge_labeling_scheme, n_edge_label_nodes, edge_label_nodes, A, ctrl->do_shrinking);
 
  RETURN:
   *ctrl = ctrl0;
@@ -2235,53 +2109,7 @@ static void multilevel_spring_electrical_embedding_core(int dim, SparseMatrix A0
   Multilevel_delete(grid0);
 }
 
-#ifdef GVIEWER
-struct multilevel_spring_electrical_embedding_data {
-  int dim;
-  SparseMatrix A;
-  SparseMatrix D;
-  spring_electrical_control ctrl;
-  real *node_weights;
-  real *label_sizes;
-  real *x;
-  int n_edge_label_nodes;
-  int *edge_label_nodes;
-  int *flag;
-};
-
-void multilevel_spring_electrical_embedding_gv(void* data){
-  struct multilevel_spring_electrical_embedding_data* d;
-
-  d = (struct multilevel_spring_electrical_embedding_data*) data;
-  multilevel_spring_electrical_embedding_core(d->dim, d->A, d->D, d->ctrl, d->node_weights, d->label_sizes, d->x, d->n_edge_label_nodes, d->edge_label_nodes, d->flag);
-  gviewer_reset_graph_coord(d->A, d->dim, d->x);/* A inside spring_electrical gets deleted */
-}
-void multilevel_spring_electrical_embedding(int dim, SparseMatrix A, SparseMatrix D, spring_electrical_control ctrl, real *node_weights, real *label_sizes,
-				 real *x, int n_edge_label_nodes, int *edge_label_nodes, int *flag){
-  struct multilevel_spring_electrical_embedding_data data = {dim, A, D, ctrl, node_weights, label_sizes, x, n_edge_label_nodes, edge_label_nodes, flag};
-
-  int argcc = 1;
-  char **argvv;
-
-  if (!Gviewer) return multilevel_spring_electrical_embedding_core(dim, A, D, ctrl, node_weights, label_sizes, x, n_edge_label_nodes, edge_label_nodes, flag);
-
-  argcc = 1;
-  argvv = malloc(sizeof(char*)*argcc);
-  argvv[0] = malloc(sizeof(char));
-  argvv[0][0] = '1';
-
-  gviewer_set_edge_color_scheme(COLOR_SCHEME_NO);
-  //gviewer_set_edge_color_scheme(COLOR_SCHEME_MEDIAN_AS_GREEN);
-  gviewer_toggle_bgcolor();
-  //gviewer_toggle_vertex();
-  //gviewer_init(&argcc, argvv, 0.01, 20, 60, 2*1010, 2*770, A, dim, x, &(data), multilevel_spring_electrical_embedding_gv);
-  gviewer_init(&argcc, argvv, 0.01, 20, 60, 320, 320, A, dim, x, &(data), multilevel_spring_electrical_embedding_gv);
-  free(argvv);
-
-}
-#else
 void multilevel_spring_electrical_embedding(int dim, SparseMatrix A, SparseMatrix D, spring_electrical_control ctrl, real *node_weights, real *label_sizes,
 				 real *x, int n_edge_label_nodes, int *edge_label_nodes, int *flag){
   multilevel_spring_electrical_embedding_core(dim, A, D, ctrl, node_weights, label_sizes, x, n_edge_label_nodes, edge_label_nodes, flag);
 }
-#endif
