@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 #ifdef __cplusplus
@@ -17,7 +14,7 @@ extern "C" {
 
 #ifndef _SFHDR_H
 #define _SFHDR_H	1
-#if !defined(_BLD_sfio) && !defined(_BLD_stdio)
+#if !defined(_BLD_sfio)
 #define _BLD_sfio	1
 #endif
 
@@ -27,12 +24,9 @@ extern "C" {
 **	Written by Kiem-Phong Vo
 */
 
-#include	"FEATURE/sfio"
-#include	"sfio_t.h"
+#include	<sfio/sfio_t.h>
 #include	"config.h"
 
-#include	<vthread.h>
-
 #if defined(__mips) && __mips == 2 && !defined(_NO_LARGEFILE64_SOURCE)
 #define _NO_LARGEFILE64_SOURCE  1
 #endif
@@ -46,21 +40,7 @@ extern "C" {
 #	undef  _LARGEFILE64_SOURCE
 #endif
 
-/* when building the binary compatibility package, a number of header files
-   are not needed and they may get in the way so we remove them here.
-*/
-#ifdef _SFBINARY_H
-#undef  HAVE_SYS_ST
-#undef  HAVE_STAT_H
-#undef  _lib_poll
-#undef  _stream_peek
-#undef  _socket_peek
-#undef  HAVE_VFORK_H
-#undef  _HAVE_SYS_VFORK_H
-#undef  HAVE_VFORK
-#undef  HAVE_SYS_IOCTL_H
-#endif
-
+#include	<limits.h>
 #include	<stdlib.h>
 #include	<string.h>
 #include	<stdint.h>
@@ -89,65 +69,9 @@ extern "C" {
 #undef SF_MTSAFE		/* no need to worry about thread-safety */
 #define SF_MTSAFE		0
 
-#define SFONCE()		(void)(0)
-
-#define SFMTXLOCK(f)		(void)(0)
-#define SFMTXUNLOCK(f)		(void)(0)
 #define SFMTXSTART(f,v)		{ if(!f) return(v); }
 #define SFMTXRETURN(f,v)	{ return(v); }
 
-#define POOLMTXLOCK(p)
-#define POOLMTXUNLOCK(p)
-#define POOLMTXSTART(p)
-#define POOLMTXRETURN(p,v)	{ return(v); }
-
-/* functions for polling readiness of streams */
-#ifdef HAVE_SELECT
-#undef _lib_poll
-#else
-#if _lib_poll_fd_1 || _lib_poll_fd_2
-#define _lib_poll	1
-#endif
-#endif /*HAVE_SELECT*/
-
-#ifdef _lib_poll
-#include	<poll.h>
-
-#if _lib_poll_fd_1
-#define SFPOLL(pfd,n,tm)	poll((pfd),(ulong)(n),(tm))
-#else
-#define SFPOLL(pfd,n,tm)	poll((ulong)(n),(pfd),(tm))
-#endif
-#endif /*_lib_poll*/
-
-#if _stream_peek
-#include	<stropts.h>
-#endif
-
-#if _socket_peek
-#include	<sys/socket.h>
-#endif
-
-/* to test for executable access mode of a file */
-#ifndef X_OK
-#define X_OK	01
-#endif
-
-/* alternative process forking */
-#if defined(HAVE_VFORK) && !defined(fork) && !defined(sparc) && !defined(__sparc)
-#ifdef HAVE_VFORK_H
-#include	<vfork.h>
-#endif
-#ifdef HAVE_SYS_VFORK_H
-#include	<sys/vfork.h>
-#endif
-#define fork	vfork
-#endif
-
-#ifdef HAVE_UNLINK
-#define remove	unlink
-#endif
-
 /* 64-bit vs 32-bit file stuff */
 #ifdef HAVE_SYS_STAT_H
 #ifdef _LARGEFILE64_SOURCE
@@ -172,33 +96,24 @@ extern "C" {
 #define SF_SEQUENTIAL	00000020	/* sequential access                    */
 #define SF_JUSTSEEK	00000040	/* just did a sfseek                    */
 
-/* this bit signals sfmutex() not to create a mutex for a private stream */
-#define SF_PRIVATE	00000200	/* private stream to Sfio               */
-
 /* on closing, don't be a hero about reread/rewrite on interrupts */
 #define SF_ENDING	00000400
 
-/* private flags that must be cleared in sfclrlock */
 #define SF_DCDOWN	00001000	/* recurse down the discipline stack    */
-#define SF_MVSIZE	00002000
-#define SFMVSET(f)	(((f)->size *= SF_NMAP), ((f)->bits |= SF_MVSIZE) )
-#define SFMVUNSET(f)	(!((f)->bits&SF_MVSIZE) ? 0 : \
-				(((f)->bits &= ~SF_MVSIZE), ((f)->size /= SF_NMAP)) )
-#define SFCLRBITS(f)	(SFMVUNSET(f), ((f)->bits &= ~(SF_DCDOWN|SF_MVSIZE)) )
 
 /* bits for the mode field, SF_INIT defined in sfio_t.h */
-#define SF_RC		00000010	/* peeking for a record                 */
-#define SF_RV		00000020	/* reserve without read or most write   */
-#define SF_LOCK		00000040	/* stream is locked for io op           */
-#define SF_PUSH		00000100	/* stream has been pushed               */
-#define SF_POOL		00000200	/* stream is in a pool but not current  */
-#define SF_PEEK		00000400	/* there is a pending peek              */
-#define SF_PKRD		00001000	/* did a peek read                      */
-#define SF_GETR		00002000	/* did a getr on this stream            */
-#define SF_SYNCED	00004000	/* stream was synced                    */
-#define SF_STDIO	00010000	/* given up the buffer to stdio         */
-#define SF_AVAIL	00020000	/* was closed, available for reuse      */
-#define SF_LOCAL	00100000	/* sentinel for a local call            */
+#define SF_RC		00000010u	/* peeking for a record                 */
+#define SF_RV		00000020u	/* reserve without read or most write   */
+#define SF_LOCK		00000040u	/* stream is locked for io op           */
+#define SF_PUSH		00000100u	/* stream has been pushed               */
+#define SF_POOL		00000200u	/* stream is in a pool but not current  */
+#define SF_PEEK		00000400u	/* there is a pending peek              */
+#define SF_PKRD		00001000u	/* did a peek read                      */
+#define SF_GETR		00002000u	/* did a getr on this stream            */
+#define SF_SYNCED	00004000u	/* stream was synced                    */
+#define SF_STDIO	00010000u	/* given up the buffer to stdio         */
+#define SF_AVAIL	00020000u	/* was closed, available for reuse      */
+#define SF_LOCAL	00100000u	/* sentinel for a local call            */
 
 #ifdef DEBUG
 #define ASSERT(p)	((p) ? 0 : (abort(),0) )
@@ -208,7 +123,6 @@ extern "C" {
 
 /* short-hands */
 #define NIL(t)		((t)0)
-#define reg		register
 #ifndef uchar
 #define uchar		unsigned char
 #endif
@@ -265,19 +179,6 @@ extern "C" {
 #define SF_CREATMODE	0666
 #endif
 
-/* set close-on-exec */
-#ifdef F_SETFD
-#	ifndef FD_CLOEXEC
-#		define FD_CLOEXEC	1
-#	endif			/*FD_CLOEXEC */
-#	define SETCLOEXEC(fd)		((void)fcntl((fd),F_SETFD,FD_CLOEXEC))
-#else
-#	ifdef FIOCLEX
-#		define SETCLOEXEC(fd)	((void)ioctl((fd),FIOCLEX,0))
-#	else
-#		define SETCLOEXEC(fd)
-#	endif /*FIOCLEX*/
-#endif				/*F_SETFD */
 /* a couple of error number that we use, default values are like Linux */
 #ifndef EINTR
 #define EINTR	4
@@ -288,28 +189,13 @@ extern "C" {
 #ifndef EAGAIN
 #define EAGAIN	11
 #endif
-#ifndef ENOMEM
-#define ENOMEM	12
-#endif
 #ifndef EINVAL
 #define EINVAL	22
 #endif
-#ifndef ESPIPE
-#define ESPIPE	29
-#endif
 /* function to get the decimal point for local environment */
 #ifdef MAXFLOAT			/* we don't need these, so we zap them to avoid compiler warnings */
 #undef MAXFLOAT
 #endif
-#ifdef MAXSHORT
-#undef MAXSHORT
-#endif
-#ifdef MAXINT
-#undef MAXINT
-#endif
-#ifdef MAXLONG
-#undef MAXLONG
-#endif
 #include	<locale.h>
 #define SFSETLOCALE(decimal,thousand) \
 	{ struct lconv*	lv; \
@@ -332,7 +218,6 @@ extern "C" {
 	int n_sf;		/* number currently in pool     */
 	Sfio_t **sf;		/* array of streams             */
 	Sfio_t *array[3];	/* start with 3                 */
-	Vtmutex_t mutex;	/* mutex lock object            */
     };
 
 /* reserve buffer structure */
@@ -407,10 +292,6 @@ extern "C" {
 #define RIGHTP		')'
 #define QUOTE		'\''
 
-#ifndef CHAR_BIT
-#define CHAR_BIT	8
-#endif
-
 #define FMTSET(ft, frm,ags, fv, sz, flgs, wid,pr,bs, ts,ns) \
 	((ft->form = (char*)frm), va_copy(ft->args,ags), \
 	 (ft->fmt = fv), (ft->size = sz), \
@@ -453,9 +334,6 @@ extern "C" {
 #define _Sfcleanup	(_Sfextern.sf_cleanup)
 #define _Sfexiting	(_Sfextern.sf_exiting)
 #define _Sfdone		(_Sfextern.sf_done)
-#define _Sfonce		(_Sfextern.sf_once)
-#define _Sfoncef	(_Sfextern.sf_oncef)
-#define _Sfmutex	(_Sfextern.sf_mutex)
     typedef struct _sfextern_s {
 	ssize_t sf_page;
 	struct _sfpool_s sf_pool;
@@ -467,19 +345,8 @@ extern "C" {
 	void (*sf_cleanup) (void);
 	int sf_exiting;
 	int sf_done;
-	Vtonce_t *sf_once;
-	void (*sf_oncef) (void);
-	Vtmutex_t *sf_mutex;
     } Sfextern_t;
 
-/* get the real value of a byte in a coded long or ulong */
-#define SFUVALUE(v)	(((ulong)(v))&(SF_MORE-1))
-#define SFSVALUE(v)	((( long)(v))&(SF_SIGN-1))
-#define SFBVALUE(v)	(((ulong)(v))&(SF_BYTE-1))
-
-/* amount of precision to get in each iteration during coding of doubles */
-#define SF_PRECIS	(SF_UBITS-1)
-
 /* grain size for buffer increment */
 #define SF_GRAIN	1024
 #define SF_PAGE		((ssize_t)(SF_GRAIN*sizeof(int)*2))
@@ -490,26 +357,6 @@ extern "C" {
 #define SFDIRECT(f,n)	(((ssize_t)(n) >= (f)->size) || \
 			 ((n) >= SF_GRAIN && (ssize_t)(n) >= (f)->size/16 ) )
 
-/* number of pages to memory map at a time */
-#define SF_NMAP		8
-
-/* set/unset sequential states for mmap */
-#if defined(_lib_madvise) && defined(MADV_SEQUENTIAL) && defined(MADV_NORMAL)
-#define SFMMSEQON(f,a,s)	(void)(madvise((caddr_t)(a),(size_t)(s),MADV_SEQUENTIAL) )
-#define SFMMSEQOFF(f,a,s)	(void)(madvise((caddr_t)(a),(size_t)(s),MADV_NORMAL) )
-#else
-#define SFMMSEQON(f,a,s)
-#define SFMMSEQOFF(f,a,s)
-#endif
-
-#define SFMUNMAP(f,a,s)		(munmap((caddr_t)(a),(size_t)(s)), \
-				 ((f)->endb = (f)->endr = (f)->endw = (f)->next = \
-				  (f)->data = NIL(uchar*)) )
-
-#ifndef MAP_VARIABLE
-#define MAP_VARIABLE	0
-#endif
-
 /* the bottomless bit bucket */
 #define DEVNULL		"/dev/null"
 #define SFSETNULL(f)	((f)->extent = (Sfoff_t)(-1), (f)->bits |= SF_NULL)
@@ -540,7 +387,6 @@ extern "C" {
 #define SFSETBUF(f,s,n)	(SETLOCAL(f),sfsetbuf(f,s,n))
 #define SFWRITE(f,s,n)	(SETLOCAL(f),sfwrite(f,s,n))
 #define SFREAD(f,s,n)	(SETLOCAL(f),sfread(f,s,n))
-#define SFSEEK(f,p,t)	(SETLOCAL(f),sfseek(f,p,t))
 #define SFNPUTC(f,c,n)	(SETLOCAL(f),sfnputc(f,c,n))
 #define SFRAISE(f,e,d)	(SETLOCAL(f),sfraise(f,e,d))
 
@@ -572,17 +418,17 @@ extern "C" {
 #define SFDCRD(f,buf,n,dc,rv) \
 	{	int		dcdown = f->bits&SF_DCDOWN; f->bits |= SF_DCDOWN; \
 		rv = (*dc->readf)(f,buf,n,dc); \
-		if(!dcdown)	f->bits &= ~SF_DCDOWN; \
+		if(!dcdown)	f->bits &= (unsigned short)~SF_DCDOWN; \
 	}
 #define SFDCWR(f,buf,n,dc,rv) \
 	{	int		dcdown = f->bits&SF_DCDOWN; f->bits |= SF_DCDOWN; \
 		rv = (*dc->writef)(f,buf,n,dc); \
-		if(!dcdown)	f->bits &= ~SF_DCDOWN; \
+		if(!dcdown)	f->bits &= (unsigned short)~SF_DCDOWN; \
 	}
 #define SFDCSK(f,addr,type,dc,rv) \
 	{	int		dcdown = f->bits&SF_DCDOWN; f->bits |= SF_DCDOWN; \
 		rv = (*dc->seekf)(f,addr,type,dc); \
-		if(!dcdown)	f->bits &= ~SF_DCDOWN; \
+		if(!dcdown)	f->bits &= (unsigned short)~SF_DCDOWN; \
 	}
 
 /* fast peek of a stream */
@@ -735,27 +581,7 @@ extern "C" {
 
 /* note that MEMCPY advances the associated pointers */
 #define MEMCPY(to,fr,n) \
-	switch(n) \
-	{ default : memcpy((void*)to,(void*)fr,n); to += n; fr += n; break; \
-	  case  7 : *to++ = *fr++; \
-	  case  6 : *to++ = *fr++; \
-	  case  5 : *to++ = *fr++; \
-	  case  4 : *to++ = *fr++; \
-	  case  3 : *to++ = *fr++; \
-	  case  2 : *to++ = *fr++; \
-	  case  1 : *to++ = *fr++; \
-	}
-#define MEMSET(s,c,n) \
-	switch(n) \
-	{ default : memset((void*)s,(int)c,n); s += n; break; \
-	  case  7 : *s++ = c; \
-	  case  6 : *s++ = c; \
-	  case  5 : *s++ = c; \
-	  case  4 : *s++ = c; \
-	  case  3 : *s++ = c; \
-	  case  2 : *s++ = c; \
-	  case  1 : *s++ = c; \
-	}
+	do { memcpy((void*)to,(void*)fr,n); to += n; fr += n; } while (0)
 
     extern Sfextern_t _Sfextern;
     extern Sftab_t _Sftable;
@@ -769,19 +595,6 @@ extern "C" {
     extern int _sfsetpool(Sfio_t *);
     extern char *_sfcvt(void *, int, int *, int *, int);
     extern char **_sfgetpath(char *);
-    extern Sfdouble_t _sfstrtod(const char *, char **);
-
-#ifndef errno
-    extern int errno;
-#endif
-
-/* for portable encoding of double values */
-#if !__STDC__
-#ifndef _WIN32
-    extern double frexp(double, int *);
-    extern double ldexp(double, int);
-#endif
-#endif
 
 #ifdef _WIN32
 #undef SF_ERROR
@@ -801,44 +614,14 @@ extern "C" {
     extern uint sleep(uint);
     extern int execl(const char *, const char *, ...);
     extern int execv(const char *, char **);
-#ifndef fork
-    extern int fork(void);
-#endif
-#ifdef HAVE_UNLINK
-    extern int unlink(const char *);
-#endif
 
 #endif /*HAVE_UNISTD_H*/
 #endif /* _WIN32 */
 
-    extern time_t time(time_t *);
-    extern int waitpid(int, int *, int);
-#ifndef _WIN32
-    extern void _exit(int);
-#endif
-    typedef int (*Onexit_f)(void);
-    extern Onexit_f onexit(Onexit_f);
-
 #ifdef HAVE_SYS_STAT_H
     extern int fstat(int, Stat_t *);
 #endif
 
-#if defined(HAVE_VFORK) && !defined(HAVE_VFORK_H) && !defined(_HAVE_SYS_VFORK_H)
-    extern pid_t vfork(void);
-#endif /*HAVE_VFORK*/
-
-#ifdef _lib_poll
-#if _lib_poll_fd_1
-    extern int poll(struct pollfd *, ulong, int);
-#else
-    extern int poll(ulong, struct pollfd *, int);
-#endif
-#endif /*_lib_poll*/
-
-#if _proto_open && defined(__cplusplus)
-    extern int open(const char *, int, ...);
-#endif
-
 #endif /*_SFHDR_H*/
 #ifdef __cplusplus
 }
