@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,10 +5,12 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#include	"sfhdr.h"
+#include <inttypes.h>
+#include	<sfio/sfhdr.h>
+#include	<stddef.h>
 
 /*	The engine for formatting data
 **
@@ -33,9 +32,9 @@
  */
 int sfvprintf(Sfio_t * f, const char *form, va_list args)
 {
-    reg int v = 0, n_s, base, fmt, flags;
+    int v = 0, n_s, base, fmt, flags;
     Sflong_t lv;
-    reg char *sp, *ssp, *endsp, *ep, *endep;
+    char *sp, *ssp, *endsp, *ep, *endep;
     int dot, width, precis, n, n_output;
     int sign, decpt;
     ssize_t size;
@@ -58,8 +57,8 @@ int sfvprintf(Sfio_t * f, const char *form, va_list args)
     char decimal = 0, thousand = 0;
 
     /* fast io system */
-    reg uchar *d, *endd;
-    reg int w;
+    uchar *d, *endd;
+    int w;
 #define SFBUF(f)	(d = f->next, endd = f->endb)
 #define SFINIT(f)	(SFBUF(f), n_output = 0)
 #define SFEND(f)	((n_output += d - f->next), (f->next = d))
@@ -104,14 +103,14 @@ int sfvprintf(Sfio_t * f, const char *form, va_list args)
     }
     SFINIT(f);
 
-    tls[1] = NIL(char *);
+    tls[1] = NULL;
 
-    fmstk = NIL(Fmt_t *);
-    ft = NIL(Sffmt_t *);
+    fmstk = NULL;
+    ft = NULL;
 
     oform = (char *) form;
     va_copy(oargs, args);
-    fp = NIL(Fmtpos_t *);
+    fp = NULL;
     argn = -1;
 
   loop_fmt:
@@ -129,9 +128,9 @@ int sfvprintf(Sfio_t * f, const char *form, va_list args)
 	flags = 0;
 	size = width = precis = base = n_s = argp = -1;
 	ssp = _Sfdigits;
-	endep = ep = NIL(char *);
+	endep = ep = NULL;
 	endsp = sp = buf + (sizeof(buf) - 1);
-	t_str = NIL(char *);
+	t_str = NULL;
 	n_str = dot = 0;
 
       loop_flags:		/* LOOP FOR \0, %, FLAGS, WIDTH, PRECISION, BASE, TYPE */
@@ -149,7 +148,7 @@ int sfvprintf(Sfio_t * f, const char *form, va_list args)
 		switch (*form++) {
 		case 0:	/* not balancable, retract */
 		    form = t_str;
-		    t_str = NIL(char *);
+		    t_str = NULL;
 		    n_str = 0;
 		    goto loop_flags;
 		case LEFTP:	/* increasing nested level */
@@ -175,7 +174,7 @@ int sfvprintf(Sfio_t * f, const char *form, va_list args)
 			    n_str = fp[n].ft.size;
 			} else if (ft && ft->extf) {
 			    FMTSET(ft, form, args,
-				   LEFTP, 0, 0, 0, 0, 0, NIL(char *), 0);
+				   LEFTP, 0, 0, 0, 0, 0, NULL, 0);
 			    n = (*ft->extf)
 				(f, (void *) & argv, ft);
 			    if (n < 0)
@@ -244,7 +243,7 @@ int sfvprintf(Sfio_t * f, const char *form, va_list args)
 	    } else if (*form != '*')
 		goto loop_flags;
 	  do_star:
-	    form += 1;		/* fall through for '*' */
+	    form += 1;		/* fall through */
 	case '*':
 	    form = (*_Sffmtintf) (form, &n);
 	    if (*form == '$') {
@@ -258,7 +257,7 @@ int sfvprintf(Sfio_t * f, const char *form, va_list args)
 	    if (fp)
 		v = fp[n].argv.i;
 	    else if (ft && ft->extf) {
-		FMTSET(ft, form, args, '.', dot, 0, 0, 0, 0, NIL(char *),
+		FMTSET(ft, form, args, '.', dot, 0, 0, 0, 0, NULL,
 		       0);
 		if ((*ft->extf) (f, (void *) (&argv), ft) < 0)
 		    goto pop_fmt;
@@ -321,7 +320,7 @@ int sfvprintf(Sfio_t * f, const char *form, va_list args)
 		    size = fp[n].argv.i;
 		else if (ft && ft->extf) {
 		    FMTSET(ft, form, args, 'I', sizeof(int), 0, 0, 0, 0,
-			   NIL(char *), 0);
+			   NULL, 0);
 		    if ((*ft->extf) (f, (void *) (&argv), ft) < 0)
 			goto pop_fmt;
 		    if (ft->flags & SFFMT_VALUE)
@@ -460,7 +459,7 @@ int sfvprintf(Sfio_t * f, const char *form, va_list args)
 		    continue;
 		fmstk->ft = ft = argv.ft;
 	    } else {		/* stack a new environment */
-		if (!(fm = (Fmt_t *) malloc(sizeof(Fmt_t))))
+		if (!(fm = malloc(sizeof(Fmt_t))))
 		    goto done;
 
 		if (argv.ft->form) {
@@ -475,9 +474,9 @@ int sfvprintf(Sfio_t * f, const char *form, va_list args)
 		    form = argv.ft->form;
 		    va_copy(args, argv.ft->args);
 		    argn = -1;
-		    fp = NIL(Fmtpos_t *);
+		    fp = NULL;
 		} else
-		    fm->form = NIL(char *);
+		    fm->form = NULL;
 
 		fm->eventf = argv.ft->eventf;
 		fm->ft = ft;
@@ -576,13 +575,13 @@ int sfvprintf(Sfio_t * f, const char *form, va_list args)
 	    flags =
 		(flags & ~(SFFMT_SIGN | SFFMT_BLANK | SFFMT_ZERO)) |
 		SFFMT_ALTER;
-#if _more_void_int
-	    lv = (Sflong_t) ((Sfulong_t) argv.vp);
-	    goto long_cvt;
-#else
-	    v = (int) ((uint) argv.vp);
-	    goto int_cvt;
-#endif
+	    if (sizeof(void*) > sizeof(int)) {
+		lv = (Sflong_t)(intptr_t)argv.vp;
+		goto long_cvt;
+	    } else {
+		v = (int)(intptr_t)argv.vp;
+		goto int_cvt;
+	    }
 	case 'o':
 	    base = 8;
 	    n_s = 7;
@@ -617,11 +616,12 @@ int sfvprintf(Sfio_t * f, const char *form, va_list args)
 		n_s = base == 10 ? -1 : 0;
 
 	  int_arg:
-#if _more_long_int || _more_void_int
-	    if (FMTCMP(size, Sflong_t, Sflong_t)) {
+	    if ((sizeof(long) > sizeof(int) || sizeof(void*) > sizeof(int))
+	        && FMTCMP(size, Sflong_t, Sflong_t)) {
 		lv = argv.ll;
 		goto long_cvt;
-	    } else if (FMTCMP(size, long, Sflong_t)) {
+	    } else if ((sizeof(long) > sizeof(int) || sizeof(void*) > sizeof(int))
+	               && FMTCMP(size, long, Sflong_t)) {
 		if (fmt == 'd')
 		    lv = (Sflong_t) argv.l;
 		else
@@ -639,7 +639,7 @@ int sfvprintf(Sfio_t * f, const char *form, va_list args)
 			lv = -lv;
 		}
 		if (n_s < 0) {	/* base 10 */
-		    reg Sflong_t nv;
+		    Sflong_t nv;
 		    sfucvt(lv, sp, nv, ssp, Sflong_t, Sfulong_t);
 		} else if (n_s > 0) {	/* base power-of-2 */
 		    do {
@@ -651,7 +651,6 @@ int sfvprintf(Sfio_t * f, const char *form, va_list args)
 		    } while ((lv = ((Sfulong_t) lv) / base));
 		}
 	    } else
-#endif
 	    if (sizeof(short) < sizeof(int)
 		    && FMTCMP(size, short, Sflong_t)) {
 		if (ft && ft->extf && (ft->flags & SFFMT_VALUE)) {
@@ -956,14 +955,12 @@ int sfvprintf(Sfio_t * f, const char *form, va_list args)
     }
 
   pop_fmt:
-    if (fp) {
-	free(fp);
-	fp = NIL(Fmtpos_t *);
-    }
+    free(fp);
+    fp = NULL;
     while ((fm = fmstk)) {	/* pop the format stack and continue */
 	if (fm->eventf) {
 	    if (!form || !form[0])
-		(*fm->eventf) (f, SF_FINAL, NIL(void *), ft);
+		(*fm->eventf) (f, SF_FINAL, NULL, ft);
 	    else if ((*fm->eventf) (f, SF_DPOP, (void *) form, ft) < 0)
 		goto loop_fmt;
 	}
@@ -983,11 +980,10 @@ int sfvprintf(Sfio_t * f, const char *form, va_list args)
     }
 
   done:
-    if (fp)
-	free(fp);
+    free(fp);
     while ((fm = fmstk)) {
 	if (fm->eventf)
-	    (*fm->eventf) (f, SF_FINAL, NIL(void *), fm->ft);
+	    (*fm->eventf) (f, SF_FINAL, NULL, fm->ft);
 	fmstk = fm->next;
 	free(fm);
     }
@@ -996,7 +992,7 @@ int sfvprintf(Sfio_t * f, const char *form, va_list args)
 
     n = f->next - f->data;
     if ((d = f->data) == (uchar *) data)
-	f->endw = f->endr = f->endb = f->data = NIL(uchar *);
+	f->endw = f->endr = f->endb = f->data = NULL;
     f->next = f->data;
 
     if ((((flags = f->flags) & SF_SHARE) && !(flags & SF_PUBLIC)) ||
