@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,10 +5,12 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#include	"sfhdr.h"
+#include <inttypes.h>
+#include	<sfio/sfhdr.h>
+#include	<stddef.h>
 
 /*	The main engine for reading formatted data
 **
@@ -24,9 +23,9 @@
  * @param form format string
  * @param accept accepted characters are set to 1
  */
-static char *setclass(reg char *form, reg char *accept)
+static char *setclass(char *form, char *accept)
 {
-    reg int fmt, c, yes;
+    int fmt, c, yes;
 
     if ((fmt = *form++) == '^') {	/* we want the complement of this set */
 	yes = 0;
@@ -77,10 +76,10 @@ static void _sfbuf(Sfio_t * f, int *rs)
  * @param form scanning format
  * @param args
  */
-int sfvscanf(Sfio_t * f, reg const char *form, va_list args)
+int sfvscanf(Sfio_t * f, const char *form, va_list args)
 {
-    reg uchar *d, *endd, *data;
-    reg int inp, shift, base, width;
+    uchar *d, *endd, *data;
+    int inp, shift, base, width;
     ssize_t size;
     int fmt, flags, dot, n_assign, v, n, n_input;
     char *sp;
@@ -126,10 +125,10 @@ int sfvscanf(Sfio_t * f, reg const char *form, va_list args)
 
     inp = -1;
 
-    fmstk = NIL(Fmt_t *);
-    ft = NIL(Sffmt_t *);
+    fmstk = NULL;
+    ft = NULL;
 
-    fp = NIL(Fmtpos_t *);
+    fp = NULL;
     argn = -1;
     oform = (char *) form;
     va_copy(oargs, args);
@@ -177,9 +176,9 @@ int sfvscanf(Sfio_t * f, reg const char *form, va_list args)
 	base = 10;
 	size = -1;
 	width = dot = 0;
-	t_str = NIL(char *);
+	t_str = NULL;
 	n_str = 0;
-	value = NIL(void *);
+	value = NULL;
 	argp = -1;
 
       loop_flags:		/* LOOP FOR FLAGS, WIDTH, BASE, TYPE */
@@ -190,7 +189,7 @@ int sfvscanf(Sfio_t * f, reg const char *form, va_list args)
 		switch (*form++) {
 		case 0:	/* not balanceable, retract */
 		    form = t_str;
-		    t_str = NIL(char *);
+		    t_str = NULL;
 		    n_str = 0;
 		    goto loop_flags;
 		case LEFTP:	/* increasing nested level */
@@ -216,7 +215,7 @@ int sfvscanf(Sfio_t * f, reg const char *form, va_list args)
 			    n_str = fp[n].ft.size;
 			} else if (ft && ft->extf) {
 			    FMTSET(ft, form, args,
-				   LEFTP, 0, 0, 0, 0, 0, NIL(char *), 0);
+				   LEFTP, 0, 0, 0, 0, 0, NULL, 0);
 			    n = (*ft->extf)
 				(f, (void *) & argv, ft);
 			    if (n < 0)
@@ -259,7 +258,7 @@ int sfvscanf(Sfio_t * f, reg const char *form, va_list args)
 		    v = fp[n].argv.i;
 		else if (ft && ft->extf) {
 		    FMTSET(ft, form, args, '.', dot, 0, 0, 0, 0,
-			   NIL(char *), 0);
+			   NULL, 0);
 		    if ((*ft->extf) (f, (void *) (&argv), ft) < 0)
 			goto pop_fmt;
 		    if (ft->flags & SFFMT_VALUE)
@@ -323,7 +322,7 @@ int sfvscanf(Sfio_t * f, reg const char *form, va_list args)
 		    size = fp[n].argv.i;
 		else if (ft && ft->extf) {
 		    FMTSET(ft, form, args, 'I', sizeof(int), 0, 0, 0, 0,
-			   NIL(char *), 0);
+			   NULL, 0);
 		    if ((*ft->extf) (f, (void *) (&argv), ft) < 0)
 			goto pop_fmt;
 		    if (ft->flags & SFFMT_VALUE)
@@ -438,7 +437,7 @@ int sfvscanf(Sfio_t * f, reg const char *form, va_list args)
 		    continue;
 		fmstk->ft = ft = argv.ft;
 	    } else {		/* stack a new environment */
-		if (!(fm = (Fmt_t *) malloc(sizeof(Fmt_t))))
+		if (!(fm = malloc(sizeof(Fmt_t))))
 		    goto done;
 
 		if (argv.ft->form) {
@@ -453,9 +452,9 @@ int sfvscanf(Sfio_t * f, reg const char *form, va_list args)
 		    form = argv.ft->form;
 		    va_copy(args, argv.ft->args);
 		    argn = -1;
-		    fp = NIL(Fmtpos_t *);
+		    fp = NULL;
 		} else
-		    fm->form = NIL(char *);
+		    fm->form = NULL;
 
 		fm->eventf = argv.ft->eventf;
 		fm->ft = ft;
@@ -501,8 +500,8 @@ int sfvscanf(Sfio_t * f, reg const char *form, va_list args)
 	    goto done;
 
 	if (_Sftype[fmt] == SFFMT_FLOAT) {
-	    reg char *val;
-	    reg int dot, exponent;
+	    char *val;
+	    int dot, exponent;
 
 	    val = accept;
 	    if (width >= SF_MAXDIGITS)
@@ -534,7 +533,7 @@ int sfvscanf(Sfio_t * f, reg const char *form, va_list args)
 
 	    if (value) {
 		*val = '\0';
-		    argv.d = (double) strtod(accept, NIL(char **));
+		    argv.d = (double) strtod(accept, NULL);
 	    }
 
 	    if (value) {
@@ -650,13 +649,9 @@ int sfvscanf(Sfio_t * f, reg const char *form, va_list args)
 	    if (value) {
 		n_assign += 1;
 
-		if (fmt == 'p')
-#if _more_void_int
-		    *((void **) value) = (void *) ((ulong) argv.lu);
-#else
-		    *((void **) value) = (void *) ((uint) argv.lu);
-#endif
-		else if (sizeof(long) > sizeof(int) &&
+		if (fmt == 'p') {
+		    *((void **) value) = (void *)(uintptr_t)argv.lu;
+		} else if (sizeof(long) > sizeof(int) &&
 			 FMTCMP(size, long, Sflong_t)) {
 		    if (fmt == 'd' || fmt == 'i')
 			*((long *) value) = (long) argv.ll;
@@ -731,14 +726,12 @@ int sfvscanf(Sfio_t * f, reg const char *form, va_list args)
     }
 
   pop_fmt:
-    if (fp) {
-	free(fp);
-	fp = NIL(Fmtpos_t *);
-    }
+    free(fp);
+    fp = NULL;
     while ((fm = fmstk)) {	/* pop the format stack and continue */
 	if (fm->eventf) {
 	    if (!form || !form[0])
-		(*fm->eventf) (f, SF_FINAL, NIL(void *), ft);
+		(*fm->eventf) (f, SF_FINAL, NULL, ft);
 	    else if ((*fm->eventf) (f, SF_DPOP, (void *) form, ft) < 0)
 		goto loop_fmt;
 	}
@@ -758,11 +751,10 @@ int sfvscanf(Sfio_t * f, reg const char *form, va_list args)
     }
 
   done:
-    if (fp)
-	free(fp);
+    free(fp);
     while ((fm = fmstk)) {
 	if (fm->eventf)
-	    (*fm->eventf) (f, SF_FINAL, NIL(void *), fm->ft);
+	    (*fm->eventf) (f, SF_FINAL, NULL, fm->ft);
 	fmstk = fm->next;
 	free(fm);
     }
