@@ -1,6 +1,3 @@
-/* $Id$Revision: */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 #ifndef COLOR_PALLETE_H
@@ -27,7 +24,6 @@ extern int color_palettes_Q(char *color_palette_name);
 extern float palette_pastel[1001][3];
 extern float palette_blue_to_yellow[1001][3];
 extern float palette_grey_to_red[1001][3];
-extern float palette_grey_to_red[1001][3];
 extern float palette_white_to_red[1001][3];
 extern float palette_grey[1001][3];
 extern float palette_primary[1001][3];
