@@ -1,6 +1,3 @@
-/* $Id$Revision: */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 /* Modularity Quality definitation:
@@ -59,10 +56,11 @@
 */
 
 #define STANDALONE
-#include "general.h"
-#include "SparseMatrix.h"
-#include "mq.h"
-#include "LinkedList.h"
+#include <sparse/general.h>
+#include <sparse/SparseMatrix.h>
+#include <sparse/mq.h>
+#include <sparse/LinkedList.h>
+#include <string.h>
 
 static real get_mq(SparseMatrix A, int *assignment, int *ncluster0, real *mq_in0, real *mq_out0, real **dout0){
   /* given a symmetric matrix representation of a graph and an assignment of nodes into clusters, calculate the modularity quality.
@@ -152,7 +150,7 @@ static real get_mq(SparseMatrix A, int *assignment, int *ncluster0, real *mq_in0
   }
 }
 
-Multilevel_MQ_Clustering Multilevel_MQ_Clustering_init(SparseMatrix A, int level){
+static Multilevel_MQ_Clustering Multilevel_MQ_Clustering_init(SparseMatrix A, int level){
   Multilevel_MQ_Clustering grid;
   int n = A->n, i;
   int *matching;
@@ -206,7 +204,7 @@ Multilevel_MQ_Clustering Multilevel_MQ_Clustering_init(SparseMatrix A, int level
   return grid;
 } 
 
-void Multilevel_MQ_Clustering_delete(Multilevel_MQ_Clustering grid){
+static void Multilevel_MQ_Clustering_delete(Multilevel_MQ_Clustering grid){
   if (!grid) return;
   if (grid->A){
     if (grid->level == 0) {
@@ -225,7 +223,7 @@ void Multilevel_MQ_Clustering_delete(Multilevel_MQ_Clustering grid){
   FREE(grid);
 }
 
-Multilevel_MQ_Clustering Multilevel_MQ_Clustering_establish(Multilevel_MQ_Clustering grid, int maxcluster){
+static Multilevel_MQ_Clustering Multilevel_MQ_Clustering_establish(Multilevel_MQ_Clustering grid, int maxcluster){
   int *matching = grid->matching;
   SparseMatrix A = grid->A;
   int n = grid->n, level = grid->level, nc = 0, nclusters = n;
@@ -340,7 +338,7 @@ Multilevel_MQ_Clustering Multilevel_MQ_Clustering_establish(Multilevel_MQ_Cluste
 	double mq2, mq_in2, mq_out2, *dout2;
 	int *matching2, nc2 = nc;
 	matching2 = MALLOC(sizeof(int)*A->m);
-	matching2 = MEMCPY(matching2, matching, sizeof(real)*A->m);
+	memcpy(matching2, matching, sizeof(real)*A->m);
 	if (jc != UNMATCHED) {
 	  matching2[i] = jc;
 	} else {
@@ -470,9 +468,19 @@ Multilevel_MQ_Clustering Multilevel_MQ_Clustering_establish(Multilevel_MQ_Cluste
     SparseMatrix_delete(R0);
     P = SparseMatrix_transpose(R);
     B = SparseMatrix_multiply(R, A);
-    if (!B) goto RETURN;
+    if (!B) {
+        FREE(deg_intra_new);
+        FREE(wgt_new);
+        FREE(dout_new);
+        goto RETURN;
+    }
     cA = SparseMatrix_multiply(B, P); 
-    if (!cA) goto RETURN;
+    if (!cA) {
+        FREE(deg_intra_new);
+        FREE(wgt_new);
+        FREE(dout_new);
+        goto RETURN;
+    }
     SparseMatrix_delete(B);
     grid->P = P;
     grid->R = R;
@@ -508,7 +516,7 @@ Multilevel_MQ_Clustering Multilevel_MQ_Clustering_establish(Multilevel_MQ_Cluste
   return grid;
 }
 
-Multilevel_MQ_Clustering Multilevel_MQ_Clustering_new(SparseMatrix A0, int maxcluster){
+static Multilevel_MQ_Clustering Multilevel_MQ_Clustering_new(SparseMatrix A0, int maxcluster){
   /* maxcluster is used to specify the maximum number of cluster desired, e.g., maxcluster=10 means that a maximum of 10 clusters
      is desired. this may not always be realized, and mq may be low when this is specified. Default: maxcluster = 0 */
   Multilevel_MQ_Clustering grid;
