@@ -1,13 +1,7 @@
 #ifndef SPINEHDR_T
 #define SPINEHDR_T
 
-/*
-#include <stdlib.h>
-#include <math.h>
-#include <subset.h>
-#include <assert.h>
-*/
-#include <spine.h>
+#include <spine/spine.h>
 
 #define N_NEW(n,t)       (t*)mcalloc((n),sizeof(t))
 #define NEW(t)       (t*)mcalloc((1),sizeof(t))
