@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,22 +5,26 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-
-#include	"vmhdr.h"
+#include <stddef.h>
+#include <string.h>
+#include	<vmalloc/vmhdr.h>
 /*
  * return a copy of s using vmalloc
  */
 
-char *vmstrdup(Vmalloc_t * v, register const char *s)
+char *vmstrdup(Vmalloc_t * v, const char *s)
 {
-    register char *t;
-    register int n;
 
-    return ((t =
-	     vmalloc(v, n =
-		     strlen(s) + 1)) ? (char *) memcpy(t, s,
-						       n) : (char *) 0);
+  size_t len = strlen(s) + 1;
+  char *t = vmalloc(v, len);
+  if (t == NULL) {
+    return NULL;
+  }
+
+  memcpy(t, s, len);
+
+  return t;
 }
