@@ -1,5 +1,3 @@
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -7,16 +5,16 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#include <xdot.h>
+#include <xdot/xdot.h>
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
 
-#define NEW(t)           (t*)calloc(1, sizeof(t))
-#define N_NEW(n,t)       (t*)calloc((n), sizeof(t))
+#define NEW(t)           calloc(1, sizeof(t))
+#define N_NEW(n,t)       calloc((n), sizeof(t))
 
 typedef struct {
     unsigned char *buf;		/* start of buffer */
@@ -25,8 +23,6 @@ typedef struct {
     int dyna;			/* true if buffer is malloc'ed */
 } agxbuf;
 
-#define agxbputc(X,C) ((((X)->ptr >= (X)->eptr) ? agxbmore(X,1) : 0), \
-          (void)(*(X)->ptr++ = ((unsigned char)C)))
 #define agxbuse(X) (agxbputc(X,'\0'),(char*)((X)->ptr = (X)->buf))
 
 static void agxbinit(agxbuf * xb, unsigned int hint, unsigned char *init)
@@ -79,6 +75,16 @@ static int agxbput(char *s, agxbuf * xb)
     return ssz;
 }
 
+static int agxbputc(agxbuf * xb, char c) {
+  if (xb->ptr >= xb->eptr) {
+    if (agxbmore(xb, 1) != 0) {
+      return -1;
+    }
+  }
+  *xb->ptr++ = (unsigned char)c;
+  return 0;
+}
+
 /* agxbfree:
  * Free any malloced resources.
  */
@@ -106,12 +112,6 @@ static char *parseInt(char *s, int *ip)
 {
     char* endp;
 
-#ifdef UNUSED
-    r = sscanf(s, "%d%n", ip, &sz);
-    if (r != 1) return 0;
-    else return (s + sz);
-#endif
-
     *ip = (int)strtol (s, &endp, 10);
     if (s == endp)
 	return 0;
@@ -130,27 +130,9 @@ static char *parseUInt(char *s, unsigned int *ip)
 	return endp;
 }
 
-#ifdef UNUSED
-static char *parsePoint(char *s, xdot_point * pp)
-{
-    int r, sz;
-    r = sscanf(s, "%lf %lf%n", &(pp->x), &(pp->y), &sz);
-    if (r != 2) return 0;
-    pp->z = 0;
-    return (s + sz);
-}
-#endif
-
 static char *parseRect(char *s, xdot_rect * rp)
 {
     char* endp;
-#ifdef UNUSED
-    int r, sz;
-    r = sscanf(s, "%lf %lf %lf %lf%n", &(rp->x), &(rp->y), &(rp->w),
-	       &(rp->h), &sz);
-    if (r != 4) return 0;
-    else return (s + sz);
-#endif
 
     rp->x = strtod (s, &endp);
     if (s == endp)
@@ -218,15 +200,15 @@ static char *parseString(char *s, char **sp)
     char *c;
     char *p;
     s = parseInt(s, &i);
-    if (!s || (i <= 0)) return 0;
-    while (*s && (*s != '-')) s++;
+    if (!s || i <= 0) return 0;
+    while (*s && *s != '-') s++;
     if (*s) s++;
     else {
 	return 0;
     }
     c = N_NEW(i + 1, char);
     p = c;
-    while ((i > 0) && *s) {
+    while (i > 0 && *s) {
 	*p++ = *s++;
 	i--;
     }
@@ -454,29 +436,29 @@ xdot *parseXDotFOn (char *s, drawfunc_t fns[], int sz, xdot* x)
 
     if (initcnt == 0) {
 	bufsz = XDBSIZE;
-	ops = (char *) calloc(XDBSIZE, sz);
+	ops = calloc(XDBSIZE, sz);
     }
     else {
 	ops = (char*)(x->ops);
 	bufsz = initcnt + XDBSIZE;
-	ops = (char *) realloc(ops, bufsz * sz);
-	memset(ops + (initcnt*sz), '\0', (bufsz - initcnt)*sz);
+	ops = realloc(ops, bufsz * sz);
+	memset(ops + initcnt*sz, '\0', (bufsz - initcnt)*sz);
     }
 
     while ((s = parseOp(&op, s, fns, &error))) {
 	if (x->cnt == bufsz) {
 	    oldsz = bufsz;
 	    bufsz *= 2;
-	    ops = (char *) realloc(ops, bufsz * sz);
-	    memset(ops + (oldsz*sz), '\0', (bufsz - oldsz)*sz);
+	    ops = realloc(ops, bufsz * sz);
+	    memset(ops + oldsz*sz, '\0', (bufsz - oldsz)*sz);
 	}
-	*(xdot_op *) (ops + (x->cnt * sz)) = op;
+	*(xdot_op *) (ops + x->cnt * sz) = op;
 	x->cnt++;
     }
     if (error)
 	x->flags |= XDOT_PARSE_ERROR;
     if (x->cnt) {
-	x->ops = (xdot_op *) realloc(ops, x->cnt * sz);
+	x->ops = realloc(ops, x->cnt * sz);
     }
     else {
 	free (ops);
@@ -524,16 +506,16 @@ static void printRect(xdot_rect * r, pf print, void *info)
 {
     char buf[128];
 
-    sprintf(buf, " %.02f", r->x);
+    snprintf(buf, sizeof(buf), " %.02f", r->x);
     trim(buf);
     print(buf, info);
-    sprintf(buf, " %.02f", r->y);
+    snprintf(buf, sizeof(buf), " %.02f", r->y);
     trim(buf);
     print(buf, info);
-    sprintf(buf, " %.02f", r->w);
+    snprintf(buf, sizeof(buf), " %.02f", r->w);
     trim(buf);
     print(buf, info);
-    sprintf(buf, " %.02f", r->h);
+    snprintf(buf, sizeof(buf), " %.02f", r->h);
     trim(buf);
     print(buf, info);
 }
@@ -543,13 +525,13 @@ static void printPolyline(xdot_polyline * p, pf print, void *info)
     int i;
     char buf[512];
 
-    sprintf(buf, " %d", p->cnt);
+    snprintf(buf, sizeof(buf), " %d", p->cnt);
     print(buf, info);
     for (i = 0; i < p->cnt; i++) {
-	sprintf(buf, " %.02f", p->pts[i].x);
+	snprintf(buf, sizeof(buf), " %.02f", p->pts[i].x);
 	trim(buf);
 	print(buf, info);
-	sprintf(buf, " %.02f", p->pts[i].y);
+	snprintf(buf, sizeof(buf), " %.02f", p->pts[i].y);
 	trim(buf);
 	print(buf, info);
     }
@@ -559,7 +541,7 @@ static void printString(char *p, pf print, void *info)
 {
     char buf[30];
 
-    sprintf(buf, " %d -", (int) strlen(p));
+    snprintf(buf, sizeof(buf), " %zu -", strlen(p));
     print(buf, info);
     print(p, info);
 }
@@ -568,7 +550,7 @@ static void printInt(int i, pf print, void *info)
 {
     char buf[30];
 
-    sprintf(buf, " %d", i);
+    snprintf(buf, sizeof(buf), " %d", i);
     print(buf, info);
 }
 
@@ -577,9 +559,9 @@ static void printFloat(float f, pf print, void *info, int space)
     char buf[128];
 
     if (space)
-	sprintf(buf, " %.02f", f);
+	snprintf(buf, sizeof(buf), " %.02f", f);
     else
-	sprintf(buf, "%.02f", f);
+	snprintf(buf, sizeof(buf), "%.02f", f);
     trim (buf);
     print(buf, info);
 }
@@ -734,7 +716,8 @@ static void jsonRect(xdot_rect * r, pf print, void *info)
 {
     char buf[128];
 
-    sprintf(buf, "[%.06f,%.06f,%.06f,%.06f]", r->x, r->y, r->w, r->h);
+    snprintf(buf, sizeof(buf), "[%.06f,%.06f,%.06f,%.06f]", r->x, r->y, r->w,
+             r->h);
     print(buf, info);
 }
 
@@ -745,7 +728,7 @@ static void jsonPolyline(xdot_polyline * p, pf print, void *info)
 
     print("[", info);
     for (i = 0; i < p->cnt; i++) {
-	sprintf(buf, "%.06f,%.06f", p->pts[i].x, p->pts[i].y);
+	snprintf(buf, sizeof(buf), "%.06f,%.06f", p->pts[i].x, p->pts[i].y);
 	print(buf, info);
 	if (i < p->cnt-1) print(",", info);
     }
@@ -754,20 +737,18 @@ static void jsonPolyline(xdot_polyline * p, pf print, void *info)
 
 static void jsonString(char *p, pf print, void *info)
 {
-    unsigned char c, buf[BUFSIZ];
-    agxbuf xb;
+    char c;
 
-    agxbinit(&xb, BUFSIZ, buf);
-    agxbputc(&xb, '"');
+    print("\"", info);
     while ((c = *p++)) {
-	if (c == '"') agxbput("\\\"", &xb);
-	else if (c == '\\') agxbput("\\\\", &xb);
-	/* else if (c > 127) handle UTF-8 */
-	else agxbputc(&xb, c);
+	if (c == '"') print("\\\"", info);
+	else if (c == '\\') print("\\\\", info);
+	else {
+		char buf[2] = { c, '\0' };
+		print(buf, info);
+	}
     }
-    agxbputc(&xb, '"');
-    print(agxbuse(&xb), info);
-    agxbfree(&xb);
+    print("\"", info);
 }
 
 static void jsonXDot_Op(xdot_op * op, pf print, void *info, int more)
@@ -874,7 +855,7 @@ static void _printXDot(xdot * x, pf print, void *info, print_op ofn)
     char *base = (char *) (x->ops);
     for (i = 0; i < x->cnt; i++) {
 	op = (xdot_op *) (base + i * x->sz);
-	ofn(op, print, info, (i < x->cnt - 1));
+	ofn(op, print, info, i < x->cnt - 1);
     }
 }
 
@@ -1022,25 +1003,6 @@ int statXDot (xdot* x, xdot_stats* sp)
     return 0;
 }
 
-xdot_grad_type 
-colorType (char* cp)
-{
-    xdot_grad_type rv;
-
-    switch (*cp) {
-    case '[' :
-	rv = xd_linear;
-	break;
-    case '(' :
-	rv = xd_radial;
-	break;
-    default :
-	rv = xd_none;
-	break;
-    }
-    return rv;
-}
-
 #define CHK1(s) if(!s){free(stops);return NULL;}
 
 /* radGradient:
@@ -1172,10 +1134,3 @@ void freeXDotColor (xdot_color* cp)
 	free (cp->u.ring.stops);
     }
 }
-
-#if 0
-static void execOp(xdot_op * op, int param)
-{
-    op->drawfunc(op, param);
-}
-#endif
