@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,31 +5,31 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 #include "config.h"
 
 #ifdef _WIN32
 #include <io.h>
-#include "compat.h"
 #endif
 
+#include <limits.h>
 #include <stdarg.h>
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
 
-#include "macros.h"
-#include "const.h"
+#include <common/macros.h>
+#include <common/const.h>
 
-#include "gvplugin_render.h"
-#include "gvplugin_device.h"
-#include "agxbuf.h"
-#include "utils.h"
-#include "gvio.h"
+#include <gvc/gvplugin_render.h>
+#include <gvc/gvplugin_device.h>
+#include <cgraph/agxbuf.h>
+#include <common/utils.h>
+#include <gvc/gvio.h>
 
-#define GNEW(t)          (t*)malloc(sizeof(t))
+#define GNEW(t)          malloc(sizeof(t))
 
 /* #define NEW_XDOT */
 
@@ -83,17 +80,12 @@ typedef struct {
 } xdot_state_t;
 static xdot_state_t* xd;
 
-static void xdot_str_xbuf (agxbuf* xb, char* pfx, char* s)
+static void xdot_str_xbuf (agxbuf* xb, char* pfx, const char* s)
 {
-    char buf[BUFSIZ];
-
-    sprintf (buf, "%s%d -", pfx, (int)strlen(s));
-    agxbput(xb, buf);
-    agxbput(xb, s);
-    agxbputc(xb, ' ');
+    agxbprint (xb, "%s%zu -%s ", pfx, strlen(s), s);
 }
 
-static void xdot_str (GVJ_t *job, char* pfx, char* s)
+static void xdot_str (GVJ_t *job, char* pfx, const char* s)
 {   
     emit_state_t emit_state = job->obj->emit_state;
     xdot_str_xbuf (xbufs[emit_state], pfx, s);
@@ -136,37 +128,35 @@ static void xdot_fmt_num (char* buf, double v)
     // Prevents values like -0
     if (v > -0.00000001 && v < 0.00000001)
     {
-        v = 0;
+        strcpy(buf, "0 ");
+        return;
     }
     sprintf(buf, "%.02f", v);
     xdot_trim_zeros (buf, 1);
 }
 
-static void xdot_point(agxbuf *xbuf, pointf p)
+static void xdot_point(agxbuf *xb, pointf p)
 {
     char buf[BUFSIZ];
     xdot_fmt_num (buf, p.x);
-    agxbput(xbuf, buf);
+    agxbput(xb, buf);
     xdot_fmt_num (buf, yDir(p.y));
-    agxbput(xbuf, buf);
+    agxbput(xb, buf);
 }
 
-static void xdot_num(agxbuf *xbuf, double v)
+static void xdot_num(agxbuf *xb, double v)
 {
     char buf[BUFSIZ];
     xdot_fmt_num (buf, v);
-    agxbput(xbuf, buf);
+    agxbput(xb, buf);
 }
 
 static void xdot_points(GVJ_t *job, char c, pointf * A, int n)
 {
     emit_state_t emit_state = job->obj->emit_state;
-    char buf[BUFSIZ];
     int i;
 
-    agxbputc(xbufs[emit_state], c);
-    sprintf(buf, " %d ", n);
-    agxbput(xbufs[emit_state], buf);
+    agxbprint(xbufs[emit_state], "%c %d ", c, n);
     for (i = 0; i < n; i++)
         xdot_point(xbufs[emit_state], A[i]);
 }
@@ -177,9 +167,10 @@ color2str (unsigned char rgba[4])
     static char buf [10];
 
     if (rgba[3] == 0xFF)
-	sprintf (buf, "#%02x%02x%02x", rgba[0], rgba[1],  rgba[2]);
+	snprintf(buf, sizeof(buf), "#%02x%02x%02x", rgba[0], rgba[1],  rgba[2]);
     else
-	sprintf (buf, "#%02x%02x%02x%02x", rgba[0], rgba[1],  rgba[2], rgba[3]);
+	snprintf(buf, sizeof(buf), "#%02x%02x%02x%02x", rgba[0], rgba[1],  rgba[2],
+	         rgba[3]);
     return buf;
 }
 
@@ -197,21 +188,20 @@ static void xdot_style (GVJ_t *job)
 {
     unsigned char buf0[BUFSIZ];
     char buf [128]; /* enough to hold a double */
-    agxbuf xbuf;
+    agxbuf xb;
     char* p, **s;
     int more;
 
-    agxbinit(&xbuf, BUFSIZ, buf0);
+    agxbinit(&xb, BUFSIZ, buf0);
 
     /* First, check if penwidth state is correct */
     if (job->obj->penwidth != penwidth[job->obj->emit_state]) {
 	penwidth[job->obj->emit_state] = job->obj->penwidth;
-	agxbput (&xbuf, "setlinewidth(");
-	sprintf (buf, "%.3f", job->obj->penwidth);
+	agxbput (&xb, "setlinewidth(");
+	snprintf(buf, sizeof(buf), "%.3f", job->obj->penwidth);
 	xdot_trim_zeros (buf, 0);
-	agxbput(&xbuf, buf);
-	agxbputc (&xbuf, ')');
-        xdot_str (job, "S ", agxbuse(&xbuf));
+	agxbprint(&xb, "%s)", buf);
+        xdot_str (job, "S ", agxbuse(&xb));
     }
 
     /* now process raw style, if any */
@@ -221,37 +211,72 @@ static void xdot_style (GVJ_t *job)
 
     while ((p = *s++)) {
 	if (streq(p, "filled") || streq(p, "bold") || streq(p, "setlinewidth")) continue;
-        agxbput(&xbuf, p);
+        agxbput(&xb, p);
         while (*p)
             p++;
         p++;
         if (*p) {  /* arguments */
-            agxbputc(&xbuf, '(');
+            agxbputc(&xb, '(');
             more = 0;
             while (*p) {
                 if (more)
-                    agxbputc(&xbuf, ',');
-                agxbput(&xbuf, p);
+                    agxbputc(&xb, ',');
+                agxbput(&xb, p);
                 while (*p) p++;
                 p++;
                 more++;
             }
-            agxbputc(&xbuf, ')');
+            agxbputc(&xb, ')');
         }
-        xdot_str (job, "S ", agxbuse(&xbuf));
+        xdot_str (job, "S ", agxbuse(&xb));
     }
 
-    agxbfree(&xbuf);
+    agxbfree(&xb);
 
 }
 
+/** set the value of a symbol within a node, escaping backslashes
+ *
+ * The back ends that output certain text-based formats, e.g. xdot, assume that
+ * all characters that have special meaning within a string have already been
+ * escaped, with the exception of double quote ("). Hence, any string being
+ * constructed from user-provided input needs to be escaped for other
+ * problematic characters (namely \) beforehand. This is a little utility
+ * function to do such.
+ *
+ * @param n Node to operate on
+ * @param sym Symbol to set
+ * @param value Unescaped string
+ */
+static void put_escaping_backslashes(Agobj_t* n, Agsym_t *sym, const char *value)
+{
+    agxbuf buf;
+
+    /* create a temporary buffer */
+    agxbinit(&buf, 0, NULL);
+
+    /* print the given string to the buffer, escaping as we go */
+    for (; *value != '\0'; ++value) {
+        if (*value == '\\') {
+            agxbputc(&buf, '\\');
+        }
+        agxbputc(&buf, *value);
+    }
+
+    /* update the node's symbol to the escaped text */
+    agxset(n, sym, agxbuse(&buf));
+
+    /* discard the buffer */
+    agxbfree(&buf);
+}
+
 static void xdot_end_node(GVJ_t* job)
 {
     Agnode_t* n = job->obj->u.n; 
     if (agxblen(xbufs[EMIT_NDRAW]))
 	agxset(n, xd->n_draw, agxbuse(xbufs[EMIT_NDRAW]));
     if (agxblen(xbufs[EMIT_NLABEL]))
-	agxset(n, xd->n_l_draw, agxbuse(xbufs[EMIT_NLABEL]));
+	put_escaping_backslashes(&n->base, xd->n_l_draw, agxbuse(xbufs[EMIT_NLABEL]));
     penwidth[EMIT_NDRAW] = 1;
     penwidth[EMIT_NLABEL] = 1;
     textflags[EMIT_NDRAW] = 0;
@@ -269,7 +294,7 @@ static void xdot_end_edge(GVJ_t* job)
     if (agxblen(xbufs[EMIT_HDRAW]))
 	agxset(e, xd->h_draw, agxbuse(xbufs[EMIT_HDRAW]));
     if (agxblen(xbufs[EMIT_ELABEL]))
-	agxset(e, xd->e_l_draw,agxbuse(xbufs[EMIT_ELABEL]));
+	put_escaping_backslashes(&e->base, xd->e_l_draw, agxbuse(xbufs[EMIT_ELABEL]));
     if (agxblen(xbufs[EMIT_TLABEL]))
 	agxset(e, xd->tl_draw, agxbuse(xbufs[EMIT_TLABEL]));
     if (agxblen(xbufs[EMIT_HLABEL]))
@@ -296,7 +321,6 @@ static void xdot_end_edge(GVJ_t* job)
 static void xdot_begin_anchor(GVJ_t * job, char *href, char *tooltip, char *target, char *id)
 {
     emit_state_t emit_state = job->obj->emit_state;
-    char buf[3];  /* very small integer */
     unsigned int flags = 0;
 
     agxbput(xbufs[emit_state], "H ");
@@ -306,8 +330,7 @@ static void xdot_begin_anchor(GVJ_t * job, char *href, char *tooltip, char *targ
 	flags |= 2;
     if (target)
 	flags |= 4;
-    sprintf (buf, "%d ", flags);
-    agxbput(xbufs[emit_state], buf);
+    agxbprint(xbufs[emit_state], "%d ", flags);
     if (href)
 	xdot_str (job, "", href);
     if (tooltip)
@@ -338,26 +361,14 @@ static void xdot_end_cluster(GVJ_t * job)
 }
 
 static unsigned short
-versionStr2Version (char* str)
+versionStr2Version (const char* str)
 {
-    char c, buf[BUFSIZ];
-    int n = 0;
-    char* s = str;
-    unsigned short us;
+  unsigned long u = strtoul(str, NULL, 10);
+  if (u == 0 || u > USHRT_MAX) {
+    agerr(AGWARN, "xdot version \"%s\" too long", str);
+  }
 
-    while ((c = *s++)) {
-	if (isdigit(c)) {
-	    if (n < BUFSIZ-1) buf[n++] = c;
-	    else {
-		agerr(AGWARN, "xdot version \"%s\" too long", str);
-		break;
-	    }
-	}
-    }
-    buf[n] = '\0';
-    
-    us = atoi(buf);
-    return us;
+  return (unsigned short)u;
 }
 
 /* 
@@ -385,7 +396,8 @@ versionStr2Version (char* str)
 static void
 xdot_begin_graph (graph_t *g, int s_arrows, int e_arrows, format_type id)
 {
-    int i, us;
+    int i;
+    unsigned short us;
     char* s;
 
     xd = GNEW(xdot_state_t);
@@ -481,7 +493,7 @@ static void xdot_end_graph(graph_t* g)
 	agxset(g, xd->g_draw, agxbuse(xbufs[EMIT_GDRAW]));
     }
     if (GD_label(g))
-	agxset(g, xd->g_l_draw, agxbuse(xbufs[EMIT_GLABEL]));
+	put_escaping_backslashes(&g->base, xd->g_l_draw, agxbuse(xbufs[EMIT_GLABEL]));
     agsafeset (g, "xdotversion", xd->version_s, "");
 
     for (i = 0; i < NUMXBUFS; i++)
@@ -519,14 +531,14 @@ static void dot_end_graph(GVJ_t *job)
 	case FORMAT_DOT:
 	case FORMAT_CANON:
 	    if (!(job->flags & OUTPUT_NOT_REQUIRED))
-		agwrite(g, (FILE*)job);
+		agwrite(g, job);
 	    break;
 	case FORMAT_XDOT:
 	case FORMAT_XDOT12:
 	case FORMAT_XDOT14:
 	    xdot_end_graph(g);
 	    if (!(job->flags & OUTPUT_NOT_REQUIRED))
-		agwrite(g, (FILE*)job);
+		agwrite(g, job);
 	    break;
     }
     g->clos->disc.io = io_save;
@@ -537,7 +549,7 @@ static unsigned int flag_masks[] = { 0x1F, 0x3F, 0x7F };
 static void xdot_textspan(GVJ_t * job, pointf p, textspan_t * span)
 {
     emit_state_t emit_state = job->obj->emit_state;
-    int flags;
+    unsigned flags;
     char buf[BUFSIZ];
     int j;
     
@@ -567,8 +579,7 @@ static void xdot_textspan(GVJ_t * job, pointf p, textspan_t * span)
 	unsigned int mask = flag_masks[xd->version-15];
 	unsigned int bits = flags & mask;
 	if (textflags[emit_state] != bits) {
-	    sprintf (buf, "t %u ", bits);
-	    agxbput(xbufs[emit_state], buf);
+	    agxbprint(xbufs[emit_state], "t %u ", bits);
 	    textflags[emit_state] = bits;
 	}
     }
@@ -576,8 +587,7 @@ static void xdot_textspan(GVJ_t * job, pointf p, textspan_t * span)
     p.y += span->yoffset_centerline;
     agxbput(xbufs[emit_state], "T ");
     xdot_point(xbufs[emit_state], p);
-    sprintf(buf, "%d ", j);
-    agxbput(xbufs[emit_state], buf);
+    agxbprint(xbufs[emit_state], "%d ", j);
     xdot_fmt_num (buf, span->size.x);
     agxbput(xbufs[emit_state], buf);
     xdot_str (job, "", span->str);
@@ -587,7 +597,7 @@ static void xdot_color_stop (agxbuf* xb, float v, gvcolor_t* clr)
 {
     char buf[BUFSIZ];
 
-    sprintf (buf, "%.03f", v);
+    snprintf(buf, sizeof(buf), "%.03f", v);
     xdot_trim_zeros (buf, 1);
     xdot_str_xbuf (xb, buf, color2str (clr->u.rgba));
 }
@@ -595,7 +605,7 @@ static void xdot_color_stop (agxbuf* xb, float v, gvcolor_t* clr)
 static void xdot_gradient_fillcolor (GVJ_t* job, int filled, pointf* A, int n)
 {
     unsigned char buf0[BUFSIZ];
-    agxbuf xbuf;
+    agxbuf xb;
     obj_state_t* obj = job->obj;
     float angle = obj->gradient_angle * M_PI / 180;
     float r1,r2;
@@ -606,12 +616,12 @@ static void xdot_gradient_fillcolor (GVJ_t* job, int filled, pointf* A, int n)
 	return;
     }
 
-    agxbinit(&xbuf, BUFSIZ, buf0);
+    agxbinit(&xb, BUFSIZ, buf0);
     if (filled == GRADIENT) {
 	get_gradient_points(A, G, n, angle, 2);
-	agxbputc (&xbuf, '[');
-	xdot_point (&xbuf, G[0]);
-	xdot_point (&xbuf, G[1]);
+	agxbputc (&xb, '[');
+	xdot_point (&xb, G[0]);
+	xdot_point (&xb, G[1]);
     }
     else {
 	get_gradient_points(A, G, n, 0, 3);
@@ -629,29 +639,29 @@ static void xdot_gradient_fillcolor (GVJ_t* job, int filled, pointf* A, int n)
 	c2.x = G[0].x;
 	c2.y = G[0].y;
 	r1 = r2/4;
-	agxbputc(&xbuf, '(');
-	xdot_point (&xbuf, c1);
-	xdot_num (&xbuf, r1);
-	xdot_point (&xbuf, c2);
-	xdot_num (&xbuf, r2);
+	agxbputc(&xb, '(');
+	xdot_point (&xb, c1);
+	xdot_num (&xb, r1);
+	xdot_point (&xb, c2);
+	xdot_num (&xb, r2);
     }
     
-    agxbput(&xbuf, "2 ");
+    agxbput(&xb, "2 ");
     if (obj->gradient_frac > 0) {
-	xdot_color_stop (&xbuf, obj->gradient_frac, &obj->fillcolor);
-	xdot_color_stop (&xbuf, obj->gradient_frac, &obj->stopcolor);
+	xdot_color_stop (&xb, obj->gradient_frac, &obj->fillcolor);
+	xdot_color_stop (&xb, obj->gradient_frac, &obj->stopcolor);
     }
     else {
-	xdot_color_stop (&xbuf, 0, &obj->fillcolor);
-	xdot_color_stop (&xbuf, 1, &obj->stopcolor);
+	xdot_color_stop (&xb, 0, &obj->fillcolor);
+	xdot_color_stop (&xb, 1, &obj->stopcolor);
     }
-    agxbpop(&xbuf);
+    agxbpop(&xb);
     if (filled == GRADIENT)
-	agxbputc(&xbuf, ']');
+	agxbputc(&xb, ']');
     else
-	agxbputc(&xbuf, ')');
-    xdot_str (job, "C ", agxbuse(&xbuf));
-    agxbfree(&xbuf);
+	agxbputc(&xb, ')');
+    xdot_str (job, "C ", agxbuse(&xb));
+    agxbfree(&xb);
 }
 
 static void xdot_ellipse(GVJ_t * job, pointf * A, int filled)
@@ -681,6 +691,9 @@ static void xdot_ellipse(GVJ_t * job, pointf * A, int filled)
 
 static void xdot_bezier(GVJ_t * job, pointf * A, int n, int arrow_at_start, int arrow_at_end, int filled)
 {
+    (void)arrow_at_start;
+    (void)arrow_at_end;
+
     xdot_style (job);
     xdot_pencolor (job);
     if (filled) {
@@ -729,7 +742,7 @@ void core_loadimage_xdot(GVJ_t * job, usershape_t *us, boxf b, boolean filled)
     agxbput(xbufs[emit_state], buf);
     xdot_fmt_num (buf, b.UR.y - b.LL.y);
     agxbput(xbufs[emit_state], buf);
-    xdot_str (job, "", (char*)(us->name));
+    xdot_str (job, "", us->name);
 }
 
 gvrender_engine_t dot_engine = {
