@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 #include "config.h"
@@ -18,21 +15,19 @@
 #include <stdarg.h>
 #include <ctype.h>
 
-#include "gvplugin_render.h"
-#include "gvplugin_device.h"
-#include "gvio.h"
-#include "agxbuf.h"
-#include "utils.h"
-#include "color.h"
-#include "colorprocs.h"
+#include <gvc/gvplugin_render.h>
+#include <gvc/gvplugin_device.h>
+#include <gvc/gvio.h>
+#include <cgraph/agxbuf.h>
+#include <common/utils.h>
+#include <common/color.h>
+#include <common/colorprocs.h>
 
-#include "const.h"
+#include <common/const.h>
 
 /* Number of points to split splines into */
 #define BEZIERSUBDIVISION 6
 
-#define PIC_COORDS_PER_LINE (16)        /* to avoid stdio BUF overflow */
-
 typedef enum { FORMAT_PIC, } format_type;
 
 static int onetime = TRUE;
@@ -59,7 +54,7 @@ static double Fontscale;
   The first approach is used here.
 */
 
-static const char *EscComment = ".\\\" ";       /* troff comment */
+static const char EscComment[] = "# ";       /* PIC comment */
 static const char picgen_msghdr[] = "dot pic plugin: ";
 
 static void unsupported(char *s)
@@ -138,11 +133,15 @@ static void picptarray(GVJ_t *job, pointf * A, int n, int close)
 
     for (i = 0; i < n; i++) {
 	PF2P(A[i],p);
-        gvprintf(job, " %d %d", p.x, p.y);
+        if (i == 0) {
+            gvprintf(job, "move to (%d, %d)", p.x, p.y);
+        } else {
+            gvprintf(job, "; line to (%d, %d)", p.x, p.y);
+        }
     }
     if (close) {
 	PF2P(A[0],p);
-        gvprintf(job, " %d %d", p.x, p.y);
+        gvprintf(job, "; line to (%d, %d)", p.x, p.y);
     }
     gvputs(job, "\n");
 }
@@ -150,10 +149,10 @@ static void picptarray(GVJ_t *job, pointf * A, int n, int close)
 static char *pic_string(char *s)
 {
     static char *buf = NULL;
-    static int bufsize = 0;
-    int pos = 0;
+    static size_t bufsize = 0;
+    size_t pos = 0;
     char *p;
-    unsigned char c;
+    char c;
 
     if (!buf) {
         bufsize = 64;
@@ -176,7 +175,7 @@ static char *pic_string(char *s)
             pos++;
         } else {
             *p++ = '\\';
-            sprintf(p, "%03o", c);
+            sprintf(p, "%03o", (unsigned)c);
             p += 3;
             pos += 4;
         }
@@ -383,7 +382,7 @@ static void pic_ellipse(GVJ_t * job, pointf * A, int filled)
     /* A[] contains 2 points: the center and corner. */
 
     gvprintf(job,
-		"ellipse attrs%d %swid %.5f ht %.5f at (%.5f,%.5f);\n", 1,
+		"ellipse attrs0 %swid %.5f ht %.5f at (%.5f,%.5f);\n",
 		filled ? "fill " : "",
 		PS2INCH(2*(A[1].x - A[0].x)),
 		PS2INCH(2*(A[1].y - A[0].y)),
@@ -392,58 +391,31 @@ static void pic_ellipse(GVJ_t * job, pointf * A, int filled)
 }
 
 static void pic_bezier(GVJ_t * job, pointf * A, int n, int arrow_at_start,
-//            start_y, end_x, end_y);
 	      int arrow_at_end, int filled)
 {
+    (void)arrow_at_start;
+    (void)arrow_at_end;
+    (void)filled;
+
     obj_state_t *obj = job->obj;
 
-//  int object_code = 3;        /* always 3 for spline */
-    int sub_type;
     int line_style;		/* solid, dotted, dashed */
-//  int thickness = obj->penwidth;
-//  int pen_color = obj->pencolor.u.index;
-    int fill_color = obj->fillcolor.u.index;
-//  int pen_style = 0;          /* not used */
-    int area_fill;
     double style_val;
-//  int cap_style = 0;
-//  int forward_arrow = 0;
-//  int backward_arrow = 0;
-    int npoints = n;
     int i;
 
     pointf pf, V[4];
     point p;
     int j, step;
     int count = 0;
-    int size;
-
-    char *buffer;
-    char *buf;
-    buffer =
-        malloc((npoints + 1) * (BEZIERSUBDIVISION +
-                                1) * 20 * sizeof(char));
-    buf = buffer;
 
     pic_line_style(obj, &line_style, &style_val);
 
-    if (filled) {
-        sub_type = 5;     /* closed X-spline */
-        area_fill = 20;   /* fully saturated color */
-        fill_color = job->obj->fillcolor.u.index;
-    }
-    else {
-        sub_type = 4;     /* opened X-spline */
-        area_fill = -1;
-        fill_color = 0;
-    }
     V[3].x = A[0].x;
     V[3].y = A[0].y;
     /* Write first point in line */
     count++;
     PF2P(A[0], p);
-    size = sprintf(buf, " %d %d", p.x, p.y);
-    buf += size;
+    gvprintf(job, "move to (%d, %d)", p.x, p.y);
     /* write subsequent points */
     for (i = 0; i + 3 < n; i += 3) {
         V[0] = V[3];
@@ -455,58 +427,24 @@ static void pic_bezier(GVJ_t * job, pointf * A, int n, int arrow_at_start,
             count++;
             pf = Bezier (V, 3, (double) step / BEZIERSUBDIVISION, NULL, NULL);
 	    PF2P(pf, p);
-            size = sprintf(buf, " %d %d", p.x, p.y);
-            buf += size;
+            gvprintf(job, "; spline to (%d, %d)", p.x, p.y);
         }
     }
 
-//    gvprintf(job, "%d %d %d %d %d %d %d %d %d %.1f %d %d %d %d\n",
-//            object_code,
-//            sub_type,
-//            line_style,
-//            thickness,
-//            pen_color,
-//            fill_color,
-//            depth,
-//            pen_style,
-//            area_fill,
-//            style_val, cap_style, forward_arrow, backward_arrow, count);
-
-    gvprintf(job, " %s\n", buffer);      /* print points */
-    free(buffer);
-    for (i = 0; i < count; i++) {
-        gvprintf(job, " %d", i % (count + 1) ? 1 : 0);   /* -1 on all */
-    }
     gvputs(job, "\n");
 }
 
 static void pic_polygon(GVJ_t * job, pointf * A, int n, int filled)
 {
+    (void)filled;
+
     obj_state_t *obj = job->obj;
 
-//  int object_code = 2;        /* always 2 for polyline */
-//  int sub_type = 3;           /* always 3 for polygon */
     int line_style;		/* solid, dotted, dashed */
-//  int thickness = obj->penwidth;
-//  int pen_color = obj->pencolor.u.index;
-//  int fill_color = obj->fillcolor.u.index;
-//  int pen_style = 0;          /* not used */
-//  int area_fill = filled ? 20 : -1;
     double style_val;
-//  int join_style = 0;
-//  int cap_style = 0;
-//  int radius = 0;
-//  int forward_arrow = 0;
-//  int backward_arrow = 0;
-//  int npoints = n + 1;
 
     pic_line_style(obj, &line_style, &style_val);
 
-//    gvprintf(job,
-//            "%d %d %d %d %d %d %d %d %d %.1f %d %d %d %d %d %d\n",
-//            object_code, sub_type, line_style, thickness, pen_color,
-//            fill_color, depth, pen_style, area_fill, style_val, join_style,
-//            cap_style, radius, forward_arrow, backward_arrow, npoints);
     picptarray(job, A, n, 1);        /* closed shape */
 }
 
@@ -514,29 +452,11 @@ static void pic_polyline(GVJ_t * job, pointf * A, int n)
 {
     obj_state_t *obj = job->obj;
 
-//  int object_code = 2;        /* always 2 for polyline */
-//  int sub_type = 1;           /* always 1 for polyline */
     int line_style;		/* solid, dotted, dashed */
-//  int thickness = obj->penwidth;
-//  int pen_color = obj->pencolor.u.index;
-//  int fill_color = 0;
-//  int pen_style = 0;          /* not used */
-//  int area_fill = 0;
     double style_val;
-//  int join_style = 0;
-//  int cap_style = 0;
-//  int radius = 0;
-//  int forward_arrow = 0;
-//  int backward_arrow = 0;
-//  int npoints = n;
 
     pic_line_style(obj, &line_style, &style_val);
 
-//    gvprintf(job,
-//            "%d %d %d %d %d %d %d %d %d %.1f %d %d %d %d %d %d\n",
-//            object_code, sub_type, line_style, thickness, pen_color,
-//            fill_color, depth, pen_style, area_fill, style_val, join_style,
-//            cap_style, radius, forward_arrow, backward_arrow, npoints);
     picptarray(job, A, n, 0);        /* open shape */
 }
 
