@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 /* Comments on the SVG coordinate system (SN 8 Dec 2006):
@@ -28,18 +25,26 @@
 #include <string.h>
 #include <ctype.h>
 
-#include "macros.h"
-#include "const.h"
+#include <common/macros.h>
+#include <common/const.h>
 
-#include "gvplugin_render.h"
-#include "agxbuf.h"
-#include "utils.h"
-#include "gvplugin_device.h"
-#include "gvio.h"
-#include "gvcint.h"
+#include <gvc/gvplugin_render.h>
+#include <cgraph/agxbuf.h>
+#include <common/utils.h>
+#include <gvc/gvplugin_device.h>
+#include <gvc/gvio.h>
+#include <gvc/gvcint.h>
+#include <cgraph/strcasecmp.h>
 
 #define LOCALNAMEPREFIX		'%'
 
+#ifndef EDGEALIGN
+  #define EDGEALIGN 0
+#endif
+
+// optimized gvputs for string literals
+#define GVPUTS(job, str) gvwrite((job), (str), sizeof(str) - 1)
+
 typedef enum { FORMAT_SVG, FORMAT_SVGZ, } format_type;
 
 /* SVG dash array */
@@ -47,10 +52,6 @@ static char *sdasharray = "5,2";
 /* SVG dot array */
 static char *sdotarray = "1,5";
 
-#ifndef HAVE_STRCASECMP
-extern int strcasecmp(const char *s1, const char *s2);
-#endif
-
 static void svg_bzptarray(GVJ_t * job, pointf * A, int n)
 {
     int i;
@@ -61,9 +62,9 @@ static void svg_bzptarray(GVJ_t * job, pointf * A, int n)
     if (A[0].x <= A[n-1].x) {
 #endif
 	for (i = 0; i < n; i++) {
-	    gvprintf(job, "%c", c);
+	    gvwrite(job, &c, 1);
             gvprintdouble(job, A[i].x);
-            gvputs(job, ",");
+            GVPUTS(job, ",");
             gvprintdouble(job, -A[i].y);
 	    if (i == 0)
 		c = 'C';		/* second point */
@@ -73,9 +74,9 @@ static void svg_bzptarray(GVJ_t * job, pointf * A, int n)
 #if EDGEALIGN
     } else {
 	for (i = n-1; i >= 0; i--) {
-	    gvprintf(job, "%c", c);
+	    gvwrite(job, &c, 1);
             gvprintdouble(job, A[i].x);
-            gvputs(job, ",");
+            GVPUTS(job, ",");
             gvprintdouble(job, -A[i].y);
 	    if (i == 0)
 		c = 'C';		/* second point */
@@ -90,16 +91,16 @@ static void svg_print_id_class(GVJ_t * job, char* id, char* idx, char* kind, voi
 {
     char* str;
 
-    gvputs(job, "<g id=\"");
+    GVPUTS(job, "<g id=\"");
     gvputs(job, xml_string(id));
     if (idx)
 	gvprintf (job, "_%s", xml_string(idx));
     gvprintf(job, "\" class=\"%s", kind);
     if ((str = agget(obj, "class")) && *str) {
-	gvputs(job, " ");
+	GVPUTS(job, " ");
 	gvputs(job, xml_string(str));
     }
-    gvputs(job, "\"");
+    GVPUTS(job, "\"");
 }
 
 static void svg_print_color(GVJ_t * job, gvcolor_t color)
@@ -110,7 +111,7 @@ static void svg_print_color(GVJ_t * job, gvcolor_t color)
 	break;
     case RGBA_BYTE:
 	if (color.u.rgba[3] == 0)	/* transparent */
-	    gvputs(job, "transparent");
+	    GVPUTS(job, "transparent");
 	else
 	    gvprintf(job, "#%02x%02x%02x",
 		     color.u.rgba[0], color.u.rgba[1], color.u.rgba[2]);
@@ -124,7 +125,7 @@ static void svg_grstyle(GVJ_t * job, int filled, int gid)
 {
     obj_state_t *obj = job->obj;
 
-    gvputs(job, " fill=\"");
+    GVPUTS(job, " fill=\"");
     if (filled == GRADIENT) {
 	gvprintf(job, "url(#l_%d)", gid);
     } else if (filled == RGRADIENT) {
@@ -137,12 +138,12 @@ static void svg_grstyle(GVJ_t * job, int filled, int gid)
 	    gvprintf(job, "\" fill-opacity=\"%f",
 		     ((float) obj->fillcolor.u.rgba[3] / 255.0));
     } else {
-	gvputs(job, "none");
+	GVPUTS(job, "none");
     }
-    gvputs(job, "\" stroke=\"");
+    GVPUTS(job, "\" stroke=\"");
     svg_print_color(job, obj->pencolor);
     if (obj->penwidth != PENWIDTH_NORMAL) {
-	gvputs(job, "\" stroke-width=\"");
+	GVPUTS(job, "\" stroke-width=\"");
         gvprintdouble(job, obj->penwidth);
     }
     if (obj->pen == PEN_DASHED) {
@@ -155,56 +156,46 @@ static void svg_grstyle(GVJ_t * job, int filled, int gid)
 	gvprintf(job, "\" stroke-opacity=\"%f",
 		 ((float) obj->pencolor.u.rgba[3] / 255.0));
 
-    gvputs(job, "\"");
+    GVPUTS(job, "\"");
 }
 
 static void svg_comment(GVJ_t * job, char *str)
 {
-    gvputs(job, "<!-- ");
+    GVPUTS(job, "<!-- ");
     gvputs(job, xml_string(str));
-    gvputs(job, " -->\n");
+    GVPUTS(job, " -->\n");
 }
 
 static void svg_begin_job(GVJ_t * job)
 {
     char *s;
-    gvputs(job,
+    GVPUTS(job,
 	   "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\"?>\n");
     if ((s = agget(job->gvc->g, "stylesheet")) && s[0]) {
-	gvputs(job, "<?xml-stylesheet href=\"");
+	GVPUTS(job, "<?xml-stylesheet href=\"");
 	gvputs(job, s);
-	gvputs(job, "\" type=\"text/css\"?>\n");
+	GVPUTS(job, "\" type=\"text/css\"?>\n");
     }
-#if 0
-    gvputs(job, "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.0//EN\"\n");
-    gvputs(job,
-	   " \"http://www.w3.org/TR/2001/REC-SVG-20010904/DTD/svg10.dtd\"");
-    /* This is to work around a bug in the SVG 1.0 DTD */
-    gvputs(job,
-	   " [\n <!ATTLIST svg xmlns:xlink CDATA #FIXED \"http://www.w3.org/1999/xlink\">\n]");
-#else
-    gvputs(job, "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n");
-    gvputs(job,
-	   " \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n");
-#endif
+    GVPUTS(job, "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n"
+                " \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n"
 
-    gvputs(job, "<!-- Generated by ");
+                "<!-- Generated by ");
     gvputs(job, xml_string(job->common->info[0]));
-    gvputs(job, " version ");
+    GVPUTS(job, " version ");
     gvputs(job, xml_string(job->common->info[1]));
-    gvputs(job, " (");
+    GVPUTS(job, " (");
     gvputs(job, xml_string(job->common->info[2]));
-    gvputs(job, ")\n");
-    gvputs(job, " -->\n");
+    GVPUTS(job, ")\n"
+                " -->\n");
 }
 
 static void svg_begin_graph(GVJ_t * job)
 {
     obj_state_t *obj = job->obj;
 
-    gvputs(job, "<!--");
+    GVPUTS(job, "<!--");
     if (agnameof(obj->u.g)[0] && agnameof(obj->u.g)[0] != LOCALNAMEPREFIX) {
-	gvputs(job, " Title: ");
+	GVPUTS(job, " Title: ");
 	gvputs(job, xml_string(agnameof(obj->u.g)));
     }
     gvprintf(job, " Pages: %d -->\n",
@@ -218,29 +209,32 @@ static void svg_begin_graph(GVJ_t * job)
 	job->canvasBox.UR.x,
 	job->canvasBox.UR.y);
     /* namespace of svg */
-    gvputs(job, " xmlns=\"http://www.w3.org/2000/svg\"");
+    GVPUTS(job, " xmlns=\"http://www.w3.org/2000/svg\""
     /* namespace of xlink */
-    gvputs(job, " xmlns:xlink=\"http://www.w3.org/1999/xlink\"");
-    gvputs(job, ">\n");
+                " xmlns:xlink=\"http://www.w3.org/1999/xlink\""
+                ">\n");
 }
 
 static void svg_end_graph(GVJ_t * job)
 {
-    gvputs(job, "</svg>\n");
+    GVPUTS(job, "</svg>\n");
 }
 
 static void svg_begin_layer(GVJ_t * job, char *layername, int layerNum,
 			    int numLayers)
 {
+    (void)layerNum;
+    (void)numLayers;
+
     obj_state_t *obj = job->obj;
 
     svg_print_id_class(job, layername, NULL, "layer", obj->u.g);
-    gvputs(job, ">\n");
+    GVPUTS(job, ">\n");
 }
 
 static void svg_end_layer(GVJ_t * job)
 {
-    gvputs(job, "</g>\n");
+    GVPUTS(job, "</g>\n");
 }
 
 /* svg_begin_page:
@@ -254,26 +248,26 @@ static void svg_begin_page(GVJ_t * job)
     /* its really just a page of the graph, but its still a graph,
      * and it is the entire graph if we're not currently paging */
     svg_print_id_class(job, obj->id, NULL, "graph", obj->u.g);
-    gvputs(job, " transform=\"scale(");
+    GVPUTS(job, " transform=\"scale(");
     gvprintdouble(job, job->scale.x);
-    gvputs(job, " ");
+    GVPUTS(job, " ");
     gvprintdouble(job, job->scale.y);
     gvprintf(job, ") rotate(%d) translate(", -job->rotation);
     gvprintdouble(job, job->translation.x);
-    gvputs(job, " ");
+    GVPUTS(job, " ");
     gvprintdouble(job, -job->translation.y);
-    gvputs(job, ")\">\n");
+    GVPUTS(job, ")\">\n");
     /* default style */
     if (agnameof(obj->u.g)[0] && agnameof(obj->u.g)[0] != LOCALNAMEPREFIX) {
-	gvputs(job, "<title>");
+	GVPUTS(job, "<title>");
 	gvputs(job, xml_string(agnameof(obj->u.g)));
-	gvputs(job, "</title>\n");
+	GVPUTS(job, "</title>\n");
     }
 }
 
 static void svg_end_page(GVJ_t * job)
 {
-    gvputs(job, "</g>\n");
+    GVPUTS(job, "</g>\n");
 }
 
 static void svg_begin_cluster(GVJ_t * job)
@@ -281,15 +275,15 @@ static void svg_begin_cluster(GVJ_t * job)
     obj_state_t *obj = job->obj;
 
     svg_print_id_class(job, obj->id, NULL, "cluster", obj->u.sg);
-    gvputs(job, ">\n");
-    gvputs(job, "<title>");
+    GVPUTS(job, ">\n"
+                "<title>");
     gvputs(job, xml_string(agnameof(obj->u.g)));
-    gvputs(job, "</title>\n");
+    GVPUTS(job, "</title>\n");
 }
 
 static void svg_end_cluster(GVJ_t * job)
 {
-    gvputs(job, "</g>\n");
+    GVPUTS(job, "</g>\n");
 }
 
 static void svg_begin_node(GVJ_t * job)
@@ -302,15 +296,15 @@ static void svg_begin_node(GVJ_t * job)
     else
 	idx = NULL;
     svg_print_id_class(job, obj->id, idx, "node", obj->u.n);
-    gvputs(job, ">\n");
-    gvputs(job, "<title>");
+    GVPUTS(job, ">\n"
+                "<title>");
     gvputs(job, xml_string(agnameof(obj->u.n)));
-    gvputs(job, "</title>\n");
+    GVPUTS(job, "</title>\n");
 }
 
 static void svg_end_node(GVJ_t * job)
 {
-    gvputs(job, "</g>\n");
+    GVPUTS(job, "</g>\n");
 }
 
 static void svg_begin_edge(GVJ_t * job)
@@ -319,70 +313,55 @@ static void svg_begin_edge(GVJ_t * job)
     char *ename;
 
     svg_print_id_class(job, obj->id, NULL, "edge", obj->u.e);
-    gvputs(job, ">\n");
+    GVPUTS(job, ">\n"
 
-    gvputs(job, "<title>");
+                "<title>");
     ename = strdup_and_subst_obj("\\E", (void *) (obj->u.e));
     gvputs(job, xml_string(ename));
     free(ename);
-    gvputs(job, "</title>\n");
+    GVPUTS(job, "</title>\n");
 }
 
 static void svg_end_edge(GVJ_t * job)
 {
-    gvputs(job, "</g>\n");
+    GVPUTS(job, "</g>\n");
 }
 
 static void
 svg_begin_anchor(GVJ_t * job, char *href, char *tooltip, char *target,
 		 char *id)
 {
-    gvputs(job, "<g");
+    GVPUTS(job, "<g");
     if (id) {
-	gvputs(job, " id=\"a_");
+	GVPUTS(job, " id=\"a_");
         gvputs(job, xml_string(id));
-        gvputs(job, "\"");
+        GVPUTS(job, "\"");
     }
-    gvputs(job, ">");
+    GVPUTS(job, ">"
 
-    gvputs(job, "<a");
-#if 0
-    /* the svg spec implies this can be omitted: http://www.w3.org/TR/SVG/linking.html#Links */
-    gvputs(job, " xlink:type=\"simple\"");
-#endif
+                "<a");
     if (href && href[0]) {
-	gvputs(job, " xlink:href=\"");
+	GVPUTS(job, " xlink:href=\"");
 	gvputs(job, xml_url_string(href));
-	gvputs(job, "\"");
+	GVPUTS(job, "\"");
     }
-#if 0
-    /* linking to itself, just so that it can have a xlink:link in the anchor, seems wrong.
-     * it changes the behavior in browsers, the link apears in the bottom information bar
-     */
-    else {
-	assert(id && id[0]);	/* there should always be an id available */
-	gvputs(job, " xlink:href=\"#");
-	gvputs(job, xml_url_string(href));
-	gvputs(job, "\"");
-    }
-#endif
     if (tooltip && tooltip[0]) {
-	gvputs(job, " xlink:title=\"");
+	GVPUTS(job, " xlink:title=\"");
 	gvputs(job, xml_string0(tooltip, 1));
-	gvputs(job, "\"");
+	GVPUTS(job, "\"");
     }
     if (target && target[0]) {
-	gvputs(job, " target=\"");
+	GVPUTS(job, " target=\"");
 	gvputs(job, xml_string(target));
-	gvputs(job, "\"");
+	GVPUTS(job, "\"");
     }
-    gvputs(job, ">\n");
+    GVPUTS(job, ">\n");
 }
 
 static void svg_end_anchor(GVJ_t * job)
 {
-    gvputs(job, "</a>\n");
-    gvputs(job, "</g>\n");
+    GVPUTS(job, "</a>\n"
+                "</g>\n");
 }
 
 static void svg_textspan(GVJ_t * job, pointf p, textspan_t * span)
@@ -392,26 +371,26 @@ static void svg_textspan(GVJ_t * job, pointf p, textspan_t * span)
     char *family = NULL, *weight = NULL, *stretch = NULL, *style = NULL;
     unsigned int flags;
 
-    gvputs(job, "<text");
+    GVPUTS(job, "<text");
     switch (span->just) {
     case 'l':
-	gvputs(job, " text-anchor=\"start\"");
+	GVPUTS(job, " text-anchor=\"start\"");
 	break;
     case 'r':
-	gvputs(job, " text-anchor=\"end\"");
+	GVPUTS(job, " text-anchor=\"end\"");
 	break;
     default:
     case 'n':
-	gvputs(job, " text-anchor=\"middle\"");
+	GVPUTS(job, " text-anchor=\"middle\"");
 	break;
     }
     p.y += span->yoffset_centerline;
     if (!obj->labeledgealigned) {
-	gvputs(job, " x=\"");
+	GVPUTS(job, " x=\"");
         gvprintdouble(job, p.x);
-        gvputs(job, "\" y=\"");
+        GVPUTS(job, "\" y=\"");
         gvprintdouble(job, -p.y);
-        gvputs(job, "\"");
+        GVPUTS(job, "\"");
     }
     pA = span->font->postscript_alias;
     if (pA) {
@@ -438,7 +417,7 @@ static void svg_textspan(GVJ_t * job, pointf p, textspan_t * span)
 	gvprintf(job, " font-family=\"%s", family);
 	if (pA->svg_font_family)
 	    gvprintf(job, ",%s", pA->svg_font_family);
-	gvputs(job, "\"");
+	GVPUTS(job, "\"");
 	if (weight)
 	    gvprintf(job, " font-weight=\"%s\"", weight);
 	if (stretch)
@@ -449,14 +428,14 @@ static void svg_textspan(GVJ_t * job, pointf p, textspan_t * span)
 	gvprintf(job, " font-family=\"%s\"", span->font->name);
     if ((span->font) && (flags = span->font->flags)) {
 	if ((flags & HTML_BF) && !weight)
-	    gvprintf(job, " font-weight=\"bold\"");
+	    GVPUTS(job, " font-weight=\"bold\"");
 	if ((flags & HTML_IF) && !style)
-	    gvprintf(job, " font-style=\"italic\"");
+	    GVPUTS(job, " font-style=\"italic\"");
 	if ((flags & (HTML_UL|HTML_S|HTML_OL))) {
 	    int comma = 0;
-	    gvprintf(job, " text-decoration=\"");
+	    GVPUTS(job, " text-decoration=\"");
 	    if ((flags & HTML_UL)) {
-		gvprintf(job, "underline");
+		GVPUTS(job, "underline");
 		comma = 1;
 	    }
 	    if ((flags & HTML_OL)) {
@@ -465,12 +444,12 @@ static void svg_textspan(GVJ_t * job, pointf p, textspan_t * span)
 	    }
 	    if ((flags & HTML_S))
 		gvprintf(job, "%sline-through", (comma?",":""));
-	    gvprintf(job, "\"");
+	    GVPUTS(job, "\"");
 	}
 	if ((flags & HTML_SUP))
-	    gvprintf(job, " baseline-shift=\"super\"");
+	    GVPUTS(job, " baseline-shift=\"super\"");
 	if ((flags & HTML_SUB))
-	    gvprintf(job, " baseline-shift=\"sub\"");
+	    GVPUTS(job, " baseline-shift=\"sub\"");
     }
 
     gvprintf(job, " font-size=\"%.2f\"", span->font->size);
@@ -489,17 +468,17 @@ static void svg_textspan(GVJ_t * job, pointf p, textspan_t * span)
     default:
 	assert(0);		/* internal error */
     }
-    gvputs(job, ">");
+    GVPUTS(job, ">");
     if (obj->labeledgealigned) {
 	gvprintf(job, "<textPath xlink:href=\"#%s_p\" startOffset=\"50%%\">", xml_string(obj->id));
-	gvputs(job, "<tspan x=\"0\" dy=\"");
+	GVPUTS(job, "<tspan x=\"0\" dy=\"");
         gvprintdouble(job, -p.y);
-        gvputs(job, "\">");
+        GVPUTS(job, "\">");
     }
     gvputs(job, xml_string0(span->str, TRUE));
     if (obj->labeledgealigned)
-	gvprintf (job, "</tspan></textPath>");
-    gvputs(job, "</text>\n");
+	GVPUTS(job, "</tspan></textPath>");
+    GVPUTS(job, "</text>\n");
 }
 
 /* svg_gradstyle
@@ -519,48 +498,47 @@ static int svg_gradstyle(GVJ_t * job, pointf * A, int n)
 
     gvprintf(job,
 	     "<defs>\n<linearGradient id=\"l_%d\" gradientUnits=\"userSpaceOnUse\" ", id);
-    gvputs(job, "x1=\"");
+    GVPUTS(job, "x1=\"");
     gvprintdouble(job, G[0].x);
-    gvputs(job, "\" y1=\"");
+    GVPUTS(job, "\" y1=\"");
     gvprintdouble(job, G[0].y);
-    gvputs(job, "\" x2=\"");
+    GVPUTS(job, "\" x2=\"");
     gvprintdouble(job, G[1].x);
-    gvputs(job, "\" y2=\"");
+    GVPUTS(job, "\" y2=\"");
     gvprintdouble(job, G[1].y);
-    gvputs(job, "\" >\n");
+    GVPUTS(job, "\" >\n");
     if (obj->gradient_frac > 0)
 	gvprintf(job, "<stop offset=\"%.03f\" style=\"stop-color:", obj->gradient_frac - 0.001);
     else
-	gvputs(job, "<stop offset=\"0\" style=\"stop-color:");
+	GVPUTS(job, "<stop offset=\"0\" style=\"stop-color:");
     svg_print_color(job, obj->fillcolor);
-    gvputs(job, ";stop-opacity:");
+    GVPUTS(job, ";stop-opacity:");
     if (obj->fillcolor.type == RGBA_BYTE && obj->fillcolor.u.rgba[3] > 0
 	&& obj->fillcolor.u.rgba[3] < 255)
 	gvprintf(job, "%f", ((float) obj->fillcolor.u.rgba[3] / 255.0));
     else
-	gvputs(job, "1.");
-    gvputs(job, ";\"/>\n");
+	GVPUTS(job, "1.");
+    GVPUTS(job, ";\"/>\n");
     if (obj->gradient_frac > 0)
 	gvprintf(job, "<stop offset=\"%.03f\" style=\"stop-color:", obj->gradient_frac);
     else
-	gvputs(job, "<stop offset=\"1\" style=\"stop-color:");
+	GVPUTS(job, "<stop offset=\"1\" style=\"stop-color:");
     svg_print_color(job, obj->stopcolor);
-    gvputs(job, ";stop-opacity:");
+    GVPUTS(job, ";stop-opacity:");
     if (obj->stopcolor.type == RGBA_BYTE && obj->stopcolor.u.rgba[3] > 0
 	&& obj->stopcolor.u.rgba[3] < 255)
 	gvprintf(job, "%f", ((float) obj->stopcolor.u.rgba[3] / 255.0));
     else
-	gvputs(job, "1.");
-    gvputs(job, ";\"/>\n</linearGradient>\n</defs>\n");
+	GVPUTS(job, "1.");
+    GVPUTS(job, ";\"/>\n</linearGradient>\n</defs>\n");
     return id;
 }
 
 /* svg_rgradstyle
  * Outputs the SVG statements that define the radial gradient pattern
  */
-static int svg_rgradstyle(GVJ_t * job, pointf * A, int n)
+static int svg_rgradstyle(GVJ_t * job)
 {
-    /* pointf G[2]; */
     float angle;
     int ifx, ify;
     static int rgradId;
@@ -568,8 +546,6 @@ static int svg_rgradstyle(GVJ_t * job, pointf * A, int n)
 
     obj_state_t *obj = job->obj;
     angle = obj->gradient_angle * M_PI / 180;	//angle of gradient line
-    /* G[0].x = G[0].y = G[1].x = G[1].y; */
-    /* get_gradient_points(A, G, n, 0, 1); */
     if (angle == 0.) {
 	ifx = ify = 50;
     } else {
@@ -579,24 +555,24 @@ static int svg_rgradstyle(GVJ_t * job, pointf * A, int n)
     gvprintf(job,
 	     "<defs>\n<radialGradient id=\"r_%d\" cx=\"50%%\" cy=\"50%%\" r=\"75%%\" fx=\"%d%%\" fy=\"%d%%\">\n",
 	     id, ifx, ify);
-    gvputs(job, "<stop offset=\"0\" style=\"stop-color:");
+    GVPUTS(job, "<stop offset=\"0\" style=\"stop-color:");
     svg_print_color(job, obj->fillcolor);
-    gvputs(job, ";stop-opacity:");
+    GVPUTS(job, ";stop-opacity:");
     if (obj->fillcolor.type == RGBA_BYTE && obj->fillcolor.u.rgba[3] > 0
 	&& obj->fillcolor.u.rgba[3] < 255)
 	gvprintf(job, "%f", ((float) obj->fillcolor.u.rgba[3] / 255.0));
     else
-	gvputs(job, "1.");
-    gvputs(job, ";\"/>\n");
-    gvputs(job, "<stop offset=\"1\" style=\"stop-color:");
+	GVPUTS(job, "1.");
+    GVPUTS(job, ";\"/>\n"
+                "<stop offset=\"1\" style=\"stop-color:");
     svg_print_color(job, obj->stopcolor);
-    gvputs(job, ";stop-opacity:");
+    GVPUTS(job, ";stop-opacity:");
     if (obj->stopcolor.type == RGBA_BYTE && obj->stopcolor.u.rgba[3] > 0
 	&& obj->stopcolor.u.rgba[3] < 255)
 	gvprintf(job, "%f", ((float) obj->stopcolor.u.rgba[3] / 255.0));
     else
-	gvputs(job, "1.");
-    gvputs(job, ";\"/>\n</radialGradient>\n</defs>\n");
+	GVPUTS(job, "1.");
+    GVPUTS(job, ";\"/>\n</radialGradient>\n</defs>\n");
     return id;
 }
 
@@ -609,43 +585,46 @@ static void svg_ellipse(GVJ_t * job, pointf * A, int filled)
     if (filled == GRADIENT) {
 	gid = svg_gradstyle(job, A, 2);
     } else if (filled == (RGRADIENT)) {
-	gid = svg_rgradstyle(job, A, 2);
+	gid = svg_rgradstyle(job);
     }
-    gvputs(job, "<ellipse");
+    GVPUTS(job, "<ellipse");
     svg_grstyle(job, filled, gid);
-    gvputs(job, " cx=\"");
+    GVPUTS(job, " cx=\"");
     gvprintdouble(job, A[0].x);
-    gvputs(job, "\" cy=\"");
+    GVPUTS(job, "\" cy=\"");
     gvprintdouble(job, -A[0].y);
-    gvputs(job, "\" rx=\"");
+    GVPUTS(job, "\" rx=\"");
     gvprintdouble(job, A[1].x - A[0].x);
-    gvputs(job, "\" ry=\"");
+    GVPUTS(job, "\" ry=\"");
     gvprintdouble(job, A[1].y - A[0].y);
-    gvputs(job, "\"/>\n");
+    GVPUTS(job, "\"/>\n");
 }
 
 static void
 svg_bezier(GVJ_t * job, pointf * A, int n, int arrow_at_start,
 	   int arrow_at_end, int filled)
 {
+    (void)arrow_at_start;
+    (void)arrow_at_end;
+
     int gid = 0;
     obj_state_t *obj = job->obj;
   
     if (filled == GRADIENT) {
 	gid = svg_gradstyle(job, A, n);
     } else if (filled == (RGRADIENT)) {
-	gid = svg_rgradstyle(job, A, n);
+	gid = svg_rgradstyle(job);
     }
-    gvputs(job, "<path");
+    GVPUTS(job, "<path");
     if (obj->labeledgealigned) {
-	gvputs(job, " id=\"");
+	GVPUTS(job, " id=\"");
 	gvputs(job, xml_string(obj->id));
-	gvputs(job, "_p\" ");
+	GVPUTS(job, "_p\" ");
     } 
     svg_grstyle(job, filled, gid);
-    gvputs(job, " d=\"");
+    GVPUTS(job, " d=\"");
     svg_bzptarray(job, A, n);
-    gvputs(job, "\"/>\n");
+    GVPUTS(job, "\"/>\n");
 }
 
 static void svg_polygon(GVJ_t * job, pointf * A, int n, int filled)
@@ -654,38 +633,38 @@ static void svg_polygon(GVJ_t * job, pointf * A, int n, int filled)
     if (filled == GRADIENT) {
 	gid = svg_gradstyle(job, A, n);
     } else if (filled == (RGRADIENT)) {
-	gid = svg_rgradstyle(job, A, n);
+	gid = svg_rgradstyle(job);
     }
-    gvputs(job, "<polygon");
+    GVPUTS(job, "<polygon");
     svg_grstyle(job, filled, gid);
-    gvputs(job, " points=\"");
+    GVPUTS(job, " points=\"");
     for (i = 0; i < n; i++) {
         gvprintdouble(job, A[i].x);
-        gvputs(job, ",");
+        GVPUTS(job, ",");
         gvprintdouble(job, -A[i].y);
-        gvputs(job, " ");
+        GVPUTS(job, " ");
     }
     /* repeat the first point because Adobe SVG is broken */
     gvprintdouble(job, A[0].x);
-    gvputs(job, ",");
+    GVPUTS(job, ",");
     gvprintdouble(job, -A[0].y);
-    gvputs(job, "\"/>\n");
+    GVPUTS(job, "\"/>\n");
 }
 
 static void svg_polyline(GVJ_t * job, pointf * A, int n)
 {
     int i;
 
-    gvputs(job, "<polyline");
+    GVPUTS(job, "<polyline");
     svg_grstyle(job, 0, 0);
-    gvputs(job, " points=\"");
+    GVPUTS(job, " points=\"");
     for (i = 0; i < n; i++) {
         gvprintdouble(job, A[i].x);
-        gvputs(job, ",");
+        GVPUTS(job, ",");
         gvprintdouble(job, -A[i].y);
-        gvputs(job, " ");
+        GVPUTS(job, " ");
     }
-    gvputs(job, "\"/>\n");
+    GVPUTS(job, "\"/>\n");
 }
 
 /* color names from http://www.w3.org/TR/SVG/types.html */
@@ -727,7 +706,7 @@ static char *svg_knowncolors[] = {
     "saddlebrown", "salmon", "sandybrown", "seagreen", "seashell",
     "sienna", "silver", "skyblue", "slateblue", "slategray",
     "slategrey", "snow", "springgreen", "steelblue",
-    "tan", "teal", "thistle", "tomato", "turquoise",
+    "tan", "teal", "thistle", "tomato", "transparent", "turquoise",
     "violet",
     "wheat", "white", "whitesmoke",
     "yellow", "yellowgreen"
