@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 #include "config.h"
@@ -19,10 +16,10 @@
 #include <string.h>
 #include <fcntl.h>
 
-#include "gvplugin_render.h"
-#include "gvplugin_device.h"
-#include "gvcint.h"	/* for gvc->g for agget */
-#include "gd.h"
+#include <gvc/gvplugin_render.h>
+#include <gvc/gvplugin_device.h>
+#include <gvc/gvcint.h>	/* for gvc->g for agget */
+#include <gd.h>
 
 #ifndef INT32_MAX
 #define INT32_MAX              (2147483647)
@@ -31,6 +28,7 @@
 #define UINT32_MAX             (4294967295U)
 #endif
 
+#define NOTUSED(x)	(void) (x)
 
 typedef enum {
 	FORMAT_GIF,
@@ -77,17 +75,15 @@ static void gdgen_begin_page(GVJ_t * job)
 {
     char *bgcolor_str = NULL, *truecolor_str = NULL;
     boolean truecolor_p = FALSE;	/* try to use cheaper paletted mode */
-    boolean bg_transparent_p = FALSE;
     gdImagePtr im = NULL;
 
-    truecolor_str = agget((graph_t*)(job->gvc->g), "truecolor");	/* allow user to force truecolor */
-    bgcolor_str = agget((graph_t*)(job->gvc->g), "bgcolor");
+    truecolor_str = agget(job->gvc->g, "truecolor");	/* allow user to force truecolor */
+    bgcolor_str = agget(job->gvc->g, "bgcolor");
 
     if (truecolor_str && truecolor_str[0])
 	truecolor_p = mapbool(truecolor_str);
 
     if (bgcolor_str && strcmp(bgcolor_str, "transparent") == 0) {
-	bg_transparent_p = TRUE;
 	if (job->render.features->flags & GVDEVICE_DOES_TRUECOLOR)
 	    truecolor_p = TRUE;	/* force truecolor */
     }
@@ -186,6 +182,8 @@ static void gdgen_end_page(GVJ_t * job)
 #ifdef HAVE_GD_GIF
 	    gdImageTrueColorToPalette(im, 0, 256);
 	    gdImageGifCtx(im, &ctx);
+#else
+            NOTUSED(ctx);
 #endif
 	    break;
 	case FORMAT_JPEG:
@@ -249,6 +247,7 @@ static void gdgen_end_page(GVJ_t * job)
     }
 }
 
+#ifdef HAVE_GD_FREETYPE
 static void gdgen_missingfont(char *err, char *fontreq)
 {
     static char *lastmissing = 0;
@@ -271,8 +270,7 @@ static void gdgen_missingfont(char *err, char *fontreq)
 	agerr(AGERR, "%s : %s in %s\n", err, fontreq, p);
 #endif
 #endif
-	if (lastmissing)
-	    free(lastmissing);
+	free(lastmissing);
 	lastmissing = strdup(fontreq);
 	n_errors++;
 #if 0
@@ -282,6 +280,7 @@ static void gdgen_missingfont(char *err, char *fontreq)
 #endif
     }
 }
+#endif
 
 /* fontsize at which text is omitted entirely */
 #define FONTSIZE_MUCH_TOO_SMALL 0.15
@@ -289,7 +288,7 @@ static void gdgen_missingfont(char *err, char *fontreq)
 #define FONTSIZE_TOO_SMALL 1.5
 
 #ifdef _WIN32
-#   define GD_IMPORT __declspec(dllimport)
+#   define GD_IMPORT __declspec(dllimport) extern
 #else
 #   define GD_IMPORT extern
 #endif
@@ -637,6 +636,7 @@ static gvrender_features_t render_features_gd = {
     RGBA_BYTE,			/* color_type */
 };
 
+#ifdef HAVE_GD_GIF
 static gvdevice_features_t device_features_gd = {
     GVDEVICE_BINARY_FORMAT,	/* flags */
     {0.,0.},			/* default margin - points */
@@ -651,6 +651,7 @@ static gvdevice_features_t device_features_gd_tc = {
     {0.,0.},                    /* default page width, height - points */
     {96.,96.},			/* default dpi */
 };
+#endif
 
 static gvdevice_features_t device_features_gd_tc_no_writer = {
     GVDEVICE_BINARY_FORMAT
