@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,12 +5,13 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 #ifndef GVPLUGIN_GDIPLUS_H
 #define GVPLUGIN_GDIPLUS_H
 
+#include <memory>
 #include <vector>
 
 #include <Windows.h>
@@ -38,7 +36,7 @@ struct DeviceContext
 	HWND hwnd;
 	HDC hdc;
 	
-	DeviceContext(HWND wnd = NULL): hwnd(wnd), hdc(GetDC(wnd))
+	DeviceContext(HWND wnd = nullptr): hwnd(wnd), hdc(GetDC(wnd))
 	{
 	}
 	
@@ -53,11 +51,10 @@ struct DeviceContext
 
 struct Layout
 {
-	Gdiplus::Font* font;
+	std::unique_ptr<Gdiplus::Font> font;
 	std::vector<WCHAR> text;
 	
 	Layout(char *fontname, double fontsize, char* string);
-	~Layout();
 };
 
 static const int BYTES_PER_PIXEL = 4;		/* bytes per pixel */
