@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 #include "config.h"
@@ -16,7 +13,7 @@
 #include <stdlib.h>
 #include <sys/stat.h>
 
-#include "gvplugin_loadimage.h"
+#include <gvc/gvplugin_loadimage.h>
 
 #ifdef HAVE_PANGOCAIRO
 #ifdef HAVE_RSVG
@@ -26,12 +23,6 @@
 #endif
 #include <cairo/cairo-svg.h>
 
-#ifdef _WIN32
-#define NUL_FILE "nul"
-#else
-#define NUL_FILE "/dev/null"
-#endif
-
 typedef enum {
     FORMAT_SVG_CAIRO,
 } format_type;
@@ -187,7 +178,7 @@ static void gvloadimage_rsvg_cairo(GVJ_t * job, usershape_t *us, boxf b, boolean
     if (rsvgh) {
         cairo_save(cr);
 
-       	surface = cairo_svg_surface_create(NUL_FILE, us->w, us->h); 
+       	surface = cairo_svg_surface_create(NULL, us->w, us->h); 
 
 	cairo_surface_reference(surface);
 
