@@ -1,9 +1,8 @@
 /* manually generated configuration for Windows */
 
-/* Command to open a browser on a URL */
-#define BROWSER "xdg-open"
-
-#define HAVE_ARGZ_APPEND 0
+/* Include generated files */
+#include "builddate.h"
+#include "version.h"
 
 /* Define to one of `_getb67', `GETB67', `getb67' for Cray-2 and Cray-YMP
    systems. This function is required for `alloca.c' support on those systems.
@@ -34,12 +33,6 @@
 /* Define if you have the ann library */
 #define HAVE_ANN 1
 
-/* Define to 1 if you have the `cbrt' function. */
-//#define HAVE_CBRT 1
-
-/* Define to 1 if you have the <crt_externs.h> header file. */
-/* #undef HAVE_CRT_EXTERNS_H */
-
 /* Define to 1 if you have the `deflateBound' function. */
 /* #undef HAVE_DEFLATEBOUND */
 
@@ -59,7 +52,7 @@
 #define HAVE_EXPAT_H 1
 
 /* Define if FILE structure provides _cnt */
-#define HAVE_FILE_CNT 1
+#define HAVE_FILE_CNT 0
 
 /* Define if FILE structure provides _IO_read_end */
 /* #undef HAVE_FILE_IO_READ_END */
@@ -91,15 +84,9 @@
 /* Define if the GD library has the GD_GIF feature */
 #define HAVE_GD_GIF 1
 
-/* Define if the GD library supports GIFANIM */
-/* #undef HAVE_GD_GIFANIM */
-
 /* Define if the GD library has the GD_JPEG feature */
 #define HAVE_GD_JPEG 1
 
-/* Define if the GD library supports OPENPOLYGON */
-/* #undef HAVE_GD_OPENPOLYGON */
-
 /* Define if the GD library has the GD_PNG feature */
 #define HAVE_GD_PNG 1
 
@@ -131,15 +118,6 @@
 #undef HAVE_GTS
 #define HAVE_GTS 0
 
-/* Define if you have the iconv() function. */
-#define HAVE_ICONV 1
-
-/* Define to 1 if you have the <iconv.h> header file. */
-#define HAVE_ICONV_H 1
-
-/* Define if <iconv.h> defines iconv_t. */
-#define HAVE_ICONV_T_DEF 1
-
 /* Define to 1 if you have the <IL/il.h> header file. */
 /* #undef HAVE_IL_IL_H */
 
@@ -167,9 +145,6 @@
 /* Define to 1 if you have the `lrand48' function. */
 /* #undef HAVE_LRAND48 */
 
-/* Define to 1 if you have the <malloc.h> header file. */
-#define HAVE_MALLOC_H 1
-
 /* Define to 1 if you have the <memory.h> header file. */
 #define HAVE_MEMORY_H 1
 
@@ -209,15 +184,9 @@
 /* Define to 1 if you have the `srand48' function. */
 /* #undef HAVE_SRAND48 */
 
-/* Define to 1 if you have the `strcasecmp' function. */
-//#define HAVE_STRCASECMP 1
-
 /* Define to 1 if you have the <strings.h> header file. */
 //#define HAVE_STRINGS_H 1
 
-/* Define to 1 if you have the `strncasecmp' function. */
-//#define HAVE_STRNCASECMP 1
-
 /* Define to 1 if you have the <sys/dir.h> header file, and it defines `DIR'.
    */
 /* #undef HAVE_SYS_DIR_H */
@@ -265,24 +234,12 @@
 /* Define to 1 if you have the <unistd.h> header file. */
 //#define HAVE_UNISTD_H 1
 
-/* Define to 1 if you have the `vsnprintf' function. */
-#define HAVE_VSNPRINTF 1
-
 /* Define to 1 if you have the <X11/Intrinsic.h> header file. */
 /* #undef HAVE_X11_INTRINSIC_H */
 
 /* Define to 1 if you have the <X11/Xaw/Text.h> header file. */
 /* #undef HAVE_X11_XAW_TEXT_H */
 
-/* Define to 1 if the system has the type `_Bool'. */
-#define HAVE__BOOL 1
-
-/* Define to 1 if you have the `_NSGetEnviron' function. */
-/* #undef HAVE__NSGETENVIRON */
-
-/* Define as const if the declaration of iconv() needs const. */
-#define ICONV_CONST const
-
 /* Define if you want IPSEPCOLA */
 /* #undef IPSEPCOLA */
 #define IPSEPCOLA 1
@@ -294,13 +251,13 @@
 #define ORTHO 1
 
 /* Define to the address where bug reports for this package should be sent. */
-#define PACKAGE_BUGREPORT "http://www.graphviz.org/"
+#define PACKAGE_BUGREPORT "https://gitlab.com/graphviz/graphviz/-/issues"
 
 /* Define to the full name of this package. */
 #define PACKAGE_NAME "graphviz"
 
 /* Define to the full name and version of this package. */
-#define PACKAGE_STRING "graphviz 2.39.20160612.1140"
+#define PACKAGE_STRING VERSION "(" BUILDDATE ")"
 
 /* Define to the one symbol short name of this package. */
 #define PACKAGE_TARNAME "graphviz"
@@ -309,7 +266,7 @@
 #define PACKAGE_URL ""
 
 /* Define to the version of this package. */
-#define PACKAGE_VERSION "2.39.20160612.1140"
+#define PACKAGE_VERSION VERSION
 
 /* Path separator character. */
 #define PATHSEPARATOR ":"
@@ -350,6 +307,3 @@
 
 /* Define to `int' if <sys/types.h> does not define. */
 typedef int ssize_t;
-
-/* Define to `int' if <sys/types.h> doesn't define. */
-#define uid_t int
